package com.qcwireless.qcwatch.ui.base.repository.healthy;

import androidx.constraintlayout.core.motion.utils.TypedValues;
import androidx.core.internal.view.SupportMenu;
import com.blankj.utilcode.constant.CacheConstants;
import com.haibin.calendarview.Calendar;
import com.iwown.awlog.Author;
import com.iwown.awlog.AwLog;
import com.oudmon.ble.base.communication.ILargeDataResponse;
import com.oudmon.ble.base.communication.LargeDataHandler;
import com.oudmon.ble.base.communication.rsp.ReadBlePressureRsp;
import com.oudmon.ble.base.communication.utils.ByteUtil;
import com.qcwireless.qc_utils.date.DateUtil;
import com.qcwireless.qcwatch.QCApplication;
import com.qcwireless.qcwatch.base.event.ManualRefreshEvent;
import com.qcwireless.qcwatch.base.ktx.ThreadExtKt;
import com.qcwireless.qcwatch.base.pref.UserConfig;
import com.qcwireless.qcwatch.base.utils.MoshiUtils;
import com.qcwireless.qcwatch.base.utils.MoshiUtilsKt;
import com.qcwireless.qcwatch.base.utils.TypeToken;
import com.qcwireless.qcwatch.ui.base.bean.response.healthy.Spo2DownResp;
import com.qcwireless.qcwatch.ui.base.repository.base.BaseDeviceResult;
import com.qcwireless.qcwatch.ui.base.repository.dao.ManualBloodOxygenDao;
import com.qcwireless.qcwatch.ui.base.repository.dao.QcBloodOxygenDao;
import com.qcwireless.qcwatch.ui.base.repository.dao.QcDatabase;
import com.qcwireless.qcwatch.ui.base.repository.entity.BloodOxygenEntity;
import com.qcwireless.qcwatch.ui.base.repository.entity.BloodOxygenManualEntity;
import com.qcwireless.qcwatch.ui.base.repository.mine.NetState;
import com.qcwireless.qcwatch.ui.base.view.QBloodOxygenLineChartHomeView;
import com.qcwireless.qcwatch.ui.base.view.QBloodOxygenLineChartView;
import com.qcwireless.qcwatch.ui.home.bloodoxgen.bean.BloodOxyDetailBean;
import com.squareup.moshi.JsonAdapter;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Comparator;
import java.util.Iterator;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;
import kotlin.Lazy;
import kotlin.LazyKt;
import kotlin.LazyThreadSafetyMode;
import kotlin.Metadata;
import kotlin.Unit;
import kotlin.collections.CollectionsKt;
import kotlin.comparisons.ComparisonsKt;
import kotlin.coroutines.Continuation;
import kotlin.coroutines.intrinsics.IntrinsicsKt;
import kotlin.jvm.functions.Function0;
import kotlin.jvm.functions.Function1;
import kotlin.jvm.internal.DefaultConstructorMarker;
import kotlin.jvm.internal.Intrinsics;
import kotlinx.coroutines.Dispatchers;
import kotlinx.coroutines.flow.Flow;
import kotlinx.coroutines.flow.FlowCollector;
import kotlinx.coroutines.flow.FlowKt;
import org.greenrobot.eventbus.EventBus;

/* compiled from: BloodOxygenRepository.kt */
@Metadata(d1 = {"\u0000\u008a\u0001\n\u0002\u0018\u0002\n\u0002\u0010\u0000\n\u0002\b\u0002\n\u0002\u0018\u0002\n\u0000\n\u0002\u0018\u0002\n\u0000\n\u0002\u0010$\n\u0002\u0010\u000e\n\u0002\u0018\u0002\n\u0000\n\u0002\u0010\b\n\u0002\b\u0002\n\u0002\u0010\u0002\n\u0002\b\u0002\n\u0002\u0010\t\n\u0002\b\u0006\n\u0002\u0010 \n\u0002\u0018\u0002\n\u0002\b\u0002\n\u0002\u0018\u0002\n\u0000\n\u0002\u0018\u0002\n\u0000\n\u0002\u0010%\n\u0000\n\u0002\u0010!\n\u0002\u0018\u0002\n\u0000\n\u0002\u0018\u0002\n\u0000\n\u0002\u0018\u0002\n\u0002\b\b\n\u0002\u0018\u0002\n\u0002\u0018\u0002\n\u0000\n\u0002\u0018\u0002\n\u0002\u0018\u0002\n\u0002\b\u0003\u0018\u0000 72\u00020\u0001:\u00017B\u0005¢\u0006\u0002\u0010\u0002J\"\u0010\u0007\u001a\u000e\u0012\u0004\u0012\u00020\t\u0012\u0004\u0012\u00020\n0\b2\u0006\u0010\u000b\u001a\u00020\f2\u0006\u0010\r\u001a\u00020\fJ\u0006\u0010\u000e\u001a\u00020\u000fJ!\u0010\u0010\u001a\u00020\u000f2\u0006\u0010\u0011\u001a\u00020\u00122\u0006\u0010\u0013\u001a\u00020\u0012H\u0086@ø\u0001\u0000¢\u0006\u0002\u0010\u0014J(\u0010\u0015\u001a\u00020\n2\u0006\u0010\u000b\u001a\u00020\f2\u0006\u0010\r\u001a\u00020\f2\u0006\u0010\u0016\u001a\u00020\f2\u0006\u0010\u0017\u001a\u00020\tH\u0002J\u001c\u0010\u0018\u001a\b\u0012\u0004\u0012\u00020\u001a0\u00192\u0006\u0010\u001b\u001a\u00020\t2\u0006\u0010\u001c\u001a\u00020\u001dJ\u001c\u0010\u001e\u001a\b\u0012\u0004\u0012\u00020\u001f0\u00192\u0006\u0010\u001b\u001a\u00020\t2\u0006\u0010\u001c\u001a\u00020\u001dJ\"\u0010 \u001a\u000e\u0012\u0004\u0012\u00020\f\u0012\u0004\u0012\u00020\u001a0!2\u0006\u0010\u001b\u001a\u00020\t2\u0006\u0010\u001c\u001a\u00020\tJ\u0014\u0010\"\u001a\b\u0012\u0004\u0012\u00020$0#2\u0006\u0010\u001b\u001a\u00020\tJ\b\u0010%\u001a\u0004\u0018\u00010&J\b\u0010'\u001a\u0004\u0018\u00010(J\u0014\u0010)\u001a\b\u0012\u0004\u0012\u00020(0#2\u0006\u0010\u001c\u001a\u00020\u001dJ\u0014\u0010*\u001a\b\u0012\u0004\u0012\u00020(0#2\u0006\u0010\u001c\u001a\u00020\u001dJ\u0016\u0010+\u001a\u00020\u000f2\u0006\u0010,\u001a\u00020\f2\u0006\u0010-\u001a\u00020\fJ\u001c\u0010.\u001a\u00020\u000f2\u0006\u0010/\u001a\u00020\f2\f\u00100\u001a\b\u0012\u0004\u0012\u00020201J\u001d\u00103\u001a\u000e\u0012\n\u0012\b\u0012\u0004\u0012\u00020\f0504H\u0086@ø\u0001\u0000¢\u0006\u0002\u00106R\u000e\u0010\u0003\u001a\u00020\u0004X\u0082\u0004¢\u0006\u0002\n\u0000R\u000e\u0010\u0005\u001a\u00020\u0006X\u0082\u0004¢\u0006\u0002\n\u0000\u0082\u0002\u0004\n\u0002\b\u0019¨\u00068"}, d2 = {"Lcom/qcwireless/qcwatch/ui/base/repository/healthy/BloodOxygenRepository;", "", "()V", "bloodOxygenDao", "Lcom/qcwireless/qcwatch/ui/base/repository/dao/QcBloodOxygenDao;", "bloodOxygenManualDao", "Lcom/qcwireless/qcwatch/ui/base/repository/dao/ManualBloodOxygenDao;", "calendarBloodOxygen", "", "", "Lcom/haibin/calendarview/Calendar;", "year", "", "month", "deleteData", "", "downBoFromServer", "uid", "", "lastSyncId", "(JJLkotlin/coroutines/Continuation;)Ljava/lang/Object;", "getSchemeCalendar", "day", "text", "queryBloodOxygenByDate", "", "Lcom/qcwireless/qcwatch/ui/base/view/QBloodOxygenLineChartView$DataBean;", "mac", "date", "Lcom/qcwireless/qc_utils/date/DateUtil;", "queryBloodOxygenByDateDetail", "Lcom/qcwireless/qcwatch/ui/home/bloodoxgen/bean/BloodOxyDetailBean;", "queryBloodOxygenByDateResultMap", "", "queryLastBloodOxygen", "", "Lcom/qcwireless/qcwatch/ui/base/view/QBloodOxygenLineChartHomeView$DataBean;", "queryLastBloodOxygenDate", "Lcom/qcwireless/qcwatch/ui/base/repository/entity/BloodOxygenEntity;", "queryLastManualBloodOxygenDate", "Lcom/qcwireless/qcwatch/ui/base/repository/entity/BloodOxygenManualEntity;", "queryManualBloodOxygen", "queryManualBloodOxygenAll", "saveManualBloodOxygen", "manualTime", "bloodOxygen", "syncAutoBloodOxygen", TypedValues.CycleType.S_WAVE_OFFSET, "result", "Lcom/qcwireless/qcwatch/ui/base/repository/base/BaseDeviceResult;", "Lcom/oudmon/ble/base/communication/rsp/ReadBlePressureRsp;", "updateBloodOxygenDetailToServer", "Lkotlinx/coroutines/flow/Flow;", "Lcom/qcwireless/qcwatch/ui/base/repository/mine/NetState;", "(Lkotlin/coroutines/Continuation;)Ljava/lang/Object;", "Companion", "app_championRelease"}, k = 1, mv = {1, 6, 0}, xi = 48)
/* loaded from: classes2.dex */
public final class BloodOxygenRepository {

    /* renamed from: Companion, reason: from kotlin metadata */
    public static final Companion INSTANCE = new Companion(null);
    private static final Lazy<BloodOxygenRepository> getInstance$delegate = LazyKt.lazy(LazyThreadSafetyMode.SYNCHRONIZED, (Function0) new Function0<BloodOxygenRepository>() { // from class: com.qcwireless.qcwatch.ui.base.repository.healthy.BloodOxygenRepository$Companion$getInstance$2
        /* JADX WARN: Can't rename method to resolve collision */
        @Override // kotlin.jvm.functions.Function0
        public final BloodOxygenRepository invoke() {
            return new BloodOxygenRepository();
        }
    });
    private final QcBloodOxygenDao bloodOxygenDao = QcDatabase.INSTANCE.getDatabase(QCApplication.INSTANCE.getCONTEXT()).qcBloodOxygenDao();
    private final ManualBloodOxygenDao bloodOxygenManualDao = QcDatabase.INSTANCE.getDatabase(QCApplication.INSTANCE.getCONTEXT()).manualBloodOxygenDao();

    public final void saveManualBloodOxygen(final int manualTime, final int bloodOxygen) {
        ThreadExtKt.ktxRunOnBgSingle(this, new Function1<BloodOxygenRepository, Unit>() { // from class: com.qcwireless.qcwatch.ui.base.repository.healthy.BloodOxygenRepository$saveManualBloodOxygen$1
            /* JADX INFO: Access modifiers changed from: package-private */
            /* JADX WARN: 'super' call moved to the top of the method (can break code semantics) */
            {
                super(1);
            }

            @Override // kotlin.jvm.functions.Function1
            public /* bridge */ /* synthetic */ Unit invoke(BloodOxygenRepository bloodOxygenRepository) {
                invoke2(bloodOxygenRepository);
                return Unit.INSTANCE;
            }

            /* renamed from: invoke, reason: avoid collision after fix types in other method */
            public final void invoke2(BloodOxygenRepository ktxRunOnBgSingle) {
                ManualBloodOxygenDao manualBloodOxygenDao;
                Intrinsics.checkNotNullParameter(ktxRunOnBgSingle, "$this$ktxRunOnBgSingle");
                DateUtil dateUtil = new DateUtil(manualTime, true);
                String deviceAddressNoClear = UserConfig.INSTANCE.getInstance().getDeviceAddressNoClear();
                String y_m_d = dateUtil.getY_M_D();
                Intrinsics.checkNotNullExpressionValue(y_m_d, "date.y_M_D");
                BloodOxygenManualEntity bloodOxygenManualEntity = new BloodOxygenManualEntity(deviceAddressNoClear, y_m_d, bloodOxygen, manualTime);
                manualBloodOxygenDao = ktxRunOnBgSingle.bloodOxygenManualDao;
                manualBloodOxygenDao.insert(bloodOxygenManualEntity);
                EventBus.getDefault().post(new ManualRefreshEvent());
            }
        });
    }

    public final List<BloodOxygenManualEntity> queryManualBloodOxygen(DateUtil date) {
        Intrinsics.checkNotNullParameter(date, "date");
        ManualBloodOxygenDao manualBloodOxygenDao = this.bloodOxygenManualDao;
        String deviceAddressNoClear = UserConfig.INSTANCE.getInstance().getDeviceAddressNoClear();
        String y_m_d = date.getY_M_D();
        Intrinsics.checkNotNullExpressionValue(y_m_d, "date.y_M_D");
        return manualBloodOxygenDao.queryDataLimit(deviceAddressNoClear, y_m_d);
    }

    public final List<BloodOxygenManualEntity> queryManualBloodOxygenAll(DateUtil date) {
        Intrinsics.checkNotNullParameter(date, "date");
        ManualBloodOxygenDao manualBloodOxygenDao = this.bloodOxygenManualDao;
        String deviceAddressNoClear = UserConfig.INSTANCE.getInstance().getDeviceAddressNoClear();
        String y_m_d = date.getY_M_D();
        Intrinsics.checkNotNullExpressionValue(y_m_d, "date.y_M_D");
        return manualBloodOxygenDao.queryDataAll(deviceAddressNoClear, y_m_d);
    }

    public final void deleteData() {
        ThreadExtKt.ktxRunOnBgSingleAnother(this, new Function1<BloodOxygenRepository, Unit>() { // from class: com.qcwireless.qcwatch.ui.base.repository.healthy.BloodOxygenRepository$deleteData$1
            @Override // kotlin.jvm.functions.Function1
            public /* bridge */ /* synthetic */ Unit invoke(BloodOxygenRepository bloodOxygenRepository) {
                invoke2(bloodOxygenRepository);
                return Unit.INSTANCE;
            }

            /* renamed from: invoke, reason: avoid collision after fix types in other method */
            public final void invoke2(BloodOxygenRepository ktxRunOnBgSingleAnother) {
                ManualBloodOxygenDao manualBloodOxygenDao;
                ManualBloodOxygenDao manualBloodOxygenDao2;
                Intrinsics.checkNotNullParameter(ktxRunOnBgSingleAnother, "$this$ktxRunOnBgSingleAnother");
                manualBloodOxygenDao = ktxRunOnBgSingleAnother.bloodOxygenManualDao;
                String deviceAddressNoClear = UserConfig.INSTANCE.getInstance().getDeviceAddressNoClear();
                String y_m_d = new DateUtil().getY_M_D();
                Intrinsics.checkNotNullExpressionValue(y_m_d, "DateUtil().y_M_D");
                BloodOxygenManualEntity queryByDate = manualBloodOxygenDao.queryByDate(deviceAddressNoClear, y_m_d);
                if (queryByDate != null) {
                    manualBloodOxygenDao2 = ktxRunOnBgSingleAnother.bloodOxygenManualDao;
                    manualBloodOxygenDao2.delete(queryByDate);
                }
            }
        });
    }

    public final List<QBloodOxygenLineChartHomeView.DataBean> queryLastBloodOxygen(String mac) {
        Intrinsics.checkNotNullParameter(mac, "mac");
        ArrayList arrayList = new ArrayList();
        BloodOxygenEntity queryBloodOxygenByDateDesc = this.bloodOxygenDao.queryBloodOxygenByDateDesc(mac);
        if (queryBloodOxygenByDateDesc != null) {
            String maxArray = queryBloodOxygenByDateDesc.getMaxArray();
            JsonAdapter adapter = MoshiUtils.INSTANCE.getMoshiBuild().adapter(new TypeToken<List<? extends Integer>>() { // from class: com.qcwireless.qcwatch.ui.base.repository.healthy.BloodOxygenRepository$queryLastBloodOxygen$$inlined$fromJson$1
            }.getType());
            Intrinsics.checkNotNullExpressionValue(adapter, "moshiBuild.adapter(objec…: TypeToken<T>() {}.type)");
            List list = (List) adapter.fromJson(maxArray);
            String minArray = queryBloodOxygenByDateDesc.getMinArray();
            JsonAdapter adapter2 = MoshiUtils.INSTANCE.getMoshiBuild().adapter(new TypeToken<List<? extends Integer>>() { // from class: com.qcwireless.qcwatch.ui.base.repository.healthy.BloodOxygenRepository$queryLastBloodOxygen$$inlined$fromJson$2
            }.getType());
            Intrinsics.checkNotNullExpressionValue(adapter2, "moshiBuild.adapter(objec…: TypeToken<T>() {}.type)");
            List list2 = (List) adapter2.fromJson(minArray);
            if (list != null) {
                Iterator it = list.iterator();
                int i = 0;
                while (it.hasNext()) {
                    int intValue = ((Number) it.next()).intValue();
                    int i2 = i * CacheConstants.HOUR;
                    Intrinsics.checkNotNull(list2);
                    arrayList.add(new QBloodOxygenLineChartHomeView.DataBean(i2, ((Number) list2.get(i)).intValue(), intValue, (int) queryBloodOxygenByDateDesc.getUnixTime()));
                    i++;
                }
            }
        }
        return arrayList;
    }

    public final List<QBloodOxygenLineChartView.DataBean> queryBloodOxygenByDate(String mac, DateUtil date) {
        Intrinsics.checkNotNullParameter(mac, "mac");
        Intrinsics.checkNotNullParameter(date, "date");
        ArrayList arrayList = new ArrayList();
        QcBloodOxygenDao qcBloodOxygenDao = this.bloodOxygenDao;
        String y_m_d = date.getY_M_D();
        Intrinsics.checkNotNullExpressionValue(y_m_d, "date.y_M_D");
        BloodOxygenEntity queryBloodOxygenByDate = qcBloodOxygenDao.queryBloodOxygenByDate(mac, y_m_d);
        if (queryBloodOxygenByDate != null) {
            String maxArray = queryBloodOxygenByDate.getMaxArray();
            JsonAdapter adapter = MoshiUtils.INSTANCE.getMoshiBuild().adapter(new TypeToken<List<? extends Integer>>() { // from class: com.qcwireless.qcwatch.ui.base.repository.healthy.BloodOxygenRepository$queryBloodOxygenByDate$$inlined$fromJson$1
            }.getType());
            Intrinsics.checkNotNullExpressionValue(adapter, "moshiBuild.adapter(objec…: TypeToken<T>() {}.type)");
            List list = (List) adapter.fromJson(maxArray);
            String minArray = queryBloodOxygenByDate.getMinArray();
            JsonAdapter adapter2 = MoshiUtils.INSTANCE.getMoshiBuild().adapter(new TypeToken<List<? extends Integer>>() { // from class: com.qcwireless.qcwatch.ui.base.repository.healthy.BloodOxygenRepository$queryBloodOxygenByDate$$inlined$fromJson$2
            }.getType());
            Intrinsics.checkNotNullExpressionValue(adapter2, "moshiBuild.adapter(objec…: TypeToken<T>() {}.type)");
            List list2 = (List) adapter2.fromJson(minArray);
            if (list != null) {
                Iterator it = list.iterator();
                int i = 0;
                while (it.hasNext()) {
                    int intValue = ((Number) it.next()).intValue();
                    int i2 = i * CacheConstants.HOUR;
                    Intrinsics.checkNotNull(list2);
                    arrayList.add(new QBloodOxygenLineChartView.DataBean(i2, ((Number) list2.get(i)).intValue(), intValue));
                    i++;
                }
            }
        }
        return arrayList;
    }

    public final Map<Integer, QBloodOxygenLineChartView.DataBean> queryBloodOxygenByDateResultMap(String mac, String date) {
        Intrinsics.checkNotNullParameter(mac, "mac");
        Intrinsics.checkNotNullParameter(date, "date");
        LinkedHashMap linkedHashMap = new LinkedHashMap();
        BloodOxygenEntity queryBloodOxygenByDate = this.bloodOxygenDao.queryBloodOxygenByDate(mac, date);
        if (queryBloodOxygenByDate != null) {
            String maxArray = queryBloodOxygenByDate.getMaxArray();
            JsonAdapter adapter = MoshiUtils.INSTANCE.getMoshiBuild().adapter(new TypeToken<List<? extends Integer>>() { // from class: com.qcwireless.qcwatch.ui.base.repository.healthy.BloodOxygenRepository$queryBloodOxygenByDateResultMap$$inlined$fromJson$1
            }.getType());
            Intrinsics.checkNotNullExpressionValue(adapter, "moshiBuild.adapter(objec…: TypeToken<T>() {}.type)");
            List list = (List) adapter.fromJson(maxArray);
            String minArray = queryBloodOxygenByDate.getMinArray();
            JsonAdapter adapter2 = MoshiUtils.INSTANCE.getMoshiBuild().adapter(new TypeToken<List<? extends Integer>>() { // from class: com.qcwireless.qcwatch.ui.base.repository.healthy.BloodOxygenRepository$queryBloodOxygenByDateResultMap$$inlined$fromJson$2
            }.getType());
            Intrinsics.checkNotNullExpressionValue(adapter2, "moshiBuild.adapter(objec…: TypeToken<T>() {}.type)");
            List list2 = (List) adapter2.fromJson(minArray);
            if (list != null) {
                Iterator it = list.iterator();
                int i = 0;
                while (it.hasNext()) {
                    int intValue = ((Number) it.next()).intValue();
                    int i2 = i * CacheConstants.HOUR;
                    Integer valueOf = Integer.valueOf(i2);
                    Intrinsics.checkNotNull(list2);
                    linkedHashMap.put(valueOf, new QBloodOxygenLineChartView.DataBean(i2, ((Number) list2.get(i)).intValue(), intValue));
                    i++;
                }
            }
        }
        return linkedHashMap;
    }

    public final List<BloodOxyDetailBean> queryBloodOxygenByDateDetail(String mac, DateUtil date) {
        Intrinsics.checkNotNullParameter(mac, "mac");
        Intrinsics.checkNotNullParameter(date, "date");
        ArrayList arrayList = new ArrayList();
        QcBloodOxygenDao qcBloodOxygenDao = this.bloodOxygenDao;
        String y_m_d = date.getY_M_D();
        Intrinsics.checkNotNullExpressionValue(y_m_d, "date.y_M_D");
        BloodOxygenEntity queryBloodOxygenByDate = qcBloodOxygenDao.queryBloodOxygenByDate(mac, y_m_d);
        if (queryBloodOxygenByDate != null) {
            String maxArray = queryBloodOxygenByDate.getMaxArray();
            JsonAdapter adapter = MoshiUtils.INSTANCE.getMoshiBuild().adapter(new TypeToken<List<? extends Integer>>() { // from class: com.qcwireless.qcwatch.ui.base.repository.healthy.BloodOxygenRepository$queryBloodOxygenByDateDetail$$inlined$fromJson$1
            }.getType());
            Intrinsics.checkNotNullExpressionValue(adapter, "moshiBuild.adapter(objec…: TypeToken<T>() {}.type)");
            List list = (List) adapter.fromJson(maxArray);
            String minArray = queryBloodOxygenByDate.getMinArray();
            JsonAdapter adapter2 = MoshiUtils.INSTANCE.getMoshiBuild().adapter(new TypeToken<List<? extends Integer>>() { // from class: com.qcwireless.qcwatch.ui.base.repository.healthy.BloodOxygenRepository$queryBloodOxygenByDateDetail$$inlined$fromJson$2
            }.getType());
            Intrinsics.checkNotNullExpressionValue(adapter2, "moshiBuild.adapter(objec…: TypeToken<T>() {}.type)");
            List list2 = (List) adapter2.fromJson(minArray);
            if (list != null) {
                Iterator it = list.iterator();
                int i = 0;
                while (it.hasNext()) {
                    int i2 = i + 1;
                    int intValue = ((Number) it.next()).intValue();
                    if (intValue > 0) {
                        int i3 = i * CacheConstants.HOUR;
                        Intrinsics.checkNotNull(list2);
                        arrayList.add(new BloodOxyDetailBean(i3, ((Number) list2.get(i)).intValue(), intValue));
                    }
                    i = i2;
                }
            }
        }
        if (arrayList.size() > 1) {
            CollectionsKt.sortWith(arrayList, new Comparator() { // from class: com.qcwireless.qcwatch.ui.base.repository.healthy.BloodOxygenRepository$queryBloodOxygenByDateDetail$$inlined$sortByDescending$1
                /* JADX WARN: Multi-variable type inference failed */
                @Override // java.util.Comparator
                public final int compare(T t, T t2) {
                    return ComparisonsKt.compareValues(Integer.valueOf(((BloodOxyDetailBean) t2).getSeconds()), Integer.valueOf(((BloodOxyDetailBean) t).getSeconds()));
                }
            });
        }
        return arrayList;
    }

    public final BloodOxygenEntity queryLastBloodOxygenDate() {
        return this.bloodOxygenDao.queryBloodOxygenByDateDesc(UserConfig.INSTANCE.getInstance().getDeviceAddressNoClear());
    }

    public final BloodOxygenManualEntity queryLastManualBloodOxygenDate() {
        return this.bloodOxygenManualDao.queryDataLimitLast(UserConfig.INSTANCE.getInstance().getDeviceAddressNoClear());
    }

    public final void syncAutoBloodOxygen(int offset, final BaseDeviceResult<ReadBlePressureRsp> result) {
        Intrinsics.checkNotNullParameter(result, "result");
        LargeDataHandler.getInstance().syncBloodOxygen(offset, new ILargeDataResponse() { // from class: com.qcwireless.qcwatch.ui.base.repository.healthy.BloodOxygenRepository$$ExternalSyntheticLambda0
            @Override // com.oudmon.ble.base.communication.ILargeDataResponse
            public final void parseData(int i, byte[] bArr) {
                BloodOxygenRepository.m286syncAutoBloodOxygen$lambda1(BloodOxygenRepository.this, result, i, bArr);
            }
        });
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* renamed from: syncAutoBloodOxygen$lambda-1, reason: not valid java name */
    public static final void m286syncAutoBloodOxygen$lambda1(BloodOxygenRepository this$0, BaseDeviceResult result, int i, byte[] bArr) {
        Intrinsics.checkNotNullParameter(this$0, "this$0");
        Intrinsics.checkNotNullParameter(result, "$result");
        if (i == 42) {
            int bytesToInt = ByteUtil.bytesToInt(Arrays.copyOfRange(bArr, 2, 4)) / 49;
            int i2 = 0;
            while (i2 < bytesToInt) {
                int i3 = (i2 * 49) + 6;
                i2++;
                byte[] copyOfRange = Arrays.copyOfRange(bArr, i3, (i2 * 49) + 6);
                AwLog.i(Author.HeZhiYuan, copyOfRange);
                final DateUtil dateUtil = new DateUtil();
                final ArrayList arrayList = new ArrayList();
                final ArrayList arrayList2 = new ArrayList();
                int length = copyOfRange.length;
                for (int i4 = 0; i4 < length; i4++) {
                    if (i4 == 0) {
                        dateUtil.addDay(-copyOfRange[0]);
                    } else if (i4 % 2 == 0) {
                        arrayList2.add(Integer.valueOf(copyOfRange[i4]));
                    } else {
                        arrayList.add(Integer.valueOf(copyOfRange[i4]));
                    }
                }
                ThreadExtKt.ktxRunOnBgSingle(this$0, new Function1<BloodOxygenRepository, Unit>() { // from class: com.qcwireless.qcwatch.ui.base.repository.healthy.BloodOxygenRepository$syncAutoBloodOxygen$1$1
                    /* JADX INFO: Access modifiers changed from: package-private */
                    /* JADX WARN: 'super' call moved to the top of the method (can break code semantics) */
                    {
                        super(1);
                    }

                    @Override // kotlin.jvm.functions.Function1
                    public /* bridge */ /* synthetic */ Unit invoke(BloodOxygenRepository bloodOxygenRepository) {
                        invoke2(bloodOxygenRepository);
                        return Unit.INSTANCE;
                    }

                    /* renamed from: invoke, reason: avoid collision after fix types in other method */
                    public final void invoke2(BloodOxygenRepository ktxRunOnBgSingle) {
                        QcBloodOxygenDao qcBloodOxygenDao;
                        Intrinsics.checkNotNullParameter(ktxRunOnBgSingle, "$this$ktxRunOnBgSingle");
                        String deviceAddressNoClear = UserConfig.INSTANCE.getInstance().getDeviceAddressNoClear();
                        String y_m_d = DateUtil.this.getY_M_D();
                        Intrinsics.checkNotNullExpressionValue(y_m_d, "date.y_M_D");
                        BloodOxygenEntity bloodOxygenEntity = new BloodOxygenEntity(deviceAddressNoClear, y_m_d, MoshiUtilsKt.toJson(arrayList2), MoshiUtilsKt.toJson(arrayList), DateUtil.this.getZeroTime(), false, new DateUtil().getUnixTimestamp());
                        qcBloodOxygenDao = ktxRunOnBgSingle.bloodOxygenDao;
                        qcBloodOxygenDao.insert(bloodOxygenEntity);
                    }
                });
            }
            if (bytesToInt == 0) {
                ThreadExtKt.ktxRunOnBgSingle(this$0, new Function1<BloodOxygenRepository, Unit>() { // from class: com.qcwireless.qcwatch.ui.base.repository.healthy.BloodOxygenRepository$syncAutoBloodOxygen$1$2
                    @Override // kotlin.jvm.functions.Function1
                    public /* bridge */ /* synthetic */ Unit invoke(BloodOxygenRepository bloodOxygenRepository) {
                        invoke2(bloodOxygenRepository);
                        return Unit.INSTANCE;
                    }

                    /* renamed from: invoke, reason: avoid collision after fix types in other method */
                    public final void invoke2(BloodOxygenRepository ktxRunOnBgSingle) {
                        QcBloodOxygenDao qcBloodOxygenDao;
                        QcBloodOxygenDao qcBloodOxygenDao2;
                        Intrinsics.checkNotNullParameter(ktxRunOnBgSingle, "$this$ktxRunOnBgSingle");
                        qcBloodOxygenDao = ktxRunOnBgSingle.bloodOxygenDao;
                        String deviceAddressNoClear = UserConfig.INSTANCE.getInstance().getDeviceAddressNoClear();
                        String y_m_d = new DateUtil().getY_M_D();
                        Intrinsics.checkNotNullExpressionValue(y_m_d, "DateUtil().y_M_D");
                        BloodOxygenEntity queryBloodOxygenByDate = qcBloodOxygenDao.queryBloodOxygenByDate(deviceAddressNoClear, y_m_d);
                        if (queryBloodOxygenByDate != null) {
                            qcBloodOxygenDao2 = ktxRunOnBgSingle.bloodOxygenDao;
                            qcBloodOxygenDao2.delete(queryBloodOxygenByDate);
                        }
                    }
                });
            }
            result.result(0, new ReadBlePressureRsp());
        }
    }

    public final Object updateBloodOxygenDetailToServer(Continuation<? super Flow<NetState<Integer>>> continuation) {
        return FlowKt.m2572catch(FlowKt.flowOn(FlowKt.onStart(FlowKt.flow(new BloodOxygenRepository$updateBloodOxygenDetailToServer$2(this, null)), new BloodOxygenRepository$updateBloodOxygenDetailToServer$3(null)), Dispatchers.getIO()), new BloodOxygenRepository$updateBloodOxygenDetailToServer$4(null));
    }

    public final Object downBoFromServer(long j, long j2, Continuation<? super Unit> continuation) {
        Object collect = FlowKt.m2572catch(FlowKt.flowOn(FlowKt.onStart(FlowKt.flow(new BloodOxygenRepository$downBoFromServer$2(j, j2, null)), new BloodOxygenRepository$downBoFromServer$3(null)), Dispatchers.getIO()), new BloodOxygenRepository$downBoFromServer$4(null)).collect(new FlowCollector() { // from class: com.qcwireless.qcwatch.ui.base.repository.healthy.BloodOxygenRepository$downBoFromServer$5
            @Override // kotlinx.coroutines.flow.FlowCollector
            public /* bridge */ /* synthetic */ Object emit(Object obj, Continuation continuation2) {
                return emit((NetState<List<Spo2DownResp>>) obj, (Continuation<? super Unit>) continuation2);
            }

            public final Object emit(NetState<List<Spo2DownResp>> netState, Continuation<? super Unit> continuation2) {
                List<Spo2DownResp> isSuccess;
                QcBloodOxygenDao qcBloodOxygenDao;
                if (netState.getRetCode() == 0 && (isSuccess = netState.isSuccess()) != null) {
                    try {
                        for (Spo2DownResp spo2DownResp : isSuccess) {
                            BloodOxygenEntity bloodOxygenEntity = new BloodOxygenEntity(spo2DownResp.getDeviceAddress(), spo2DownResp.getDateStr(), MoshiUtilsKt.toJson(spo2DownResp.getMinValue()), MoshiUtilsKt.toJson(spo2DownResp.getMaxValue()), DateUtil.parse(spo2DownResp.getDateStr(), DateUtil.DateFormater.dFyyyyMMdd).getZeroTime(), true, new DateUtil().getUnixTimestamp());
                            if ((bloodOxygenEntity.getDeviceAddress().length() > 0) && (!spo2DownResp.getMinValue().isEmpty())) {
                                qcBloodOxygenDao = BloodOxygenRepository.this.bloodOxygenDao;
                                qcBloodOxygenDao.insert(bloodOxygenEntity);
                            }
                        }
                    } catch (Exception e) {
                        e.printStackTrace();
                    }
                }
                return Unit.INSTANCE;
            }
        }, continuation);
        return collect == IntrinsicsKt.getCOROUTINE_SUSPENDED() ? collect : Unit.INSTANCE;
    }

    public final Map<String, Calendar> calendarBloodOxygen(int year, int month) {
        LinkedHashMap linkedHashMap = new LinkedHashMap();
        DateUtil dateUtil = new DateUtil(year, month, 1);
        for (int i = 1; i < 32; i++) {
            QcBloodOxygenDao qcBloodOxygenDao = this.bloodOxygenDao;
            String deviceAddressNoClear = UserConfig.INSTANCE.getInstance().getDeviceAddressNoClear();
            String y_m_d = dateUtil.getY_M_D();
            Intrinsics.checkNotNullExpressionValue(y_m_d, "monthDate.y_M_D");
            if (qcBloodOxygenDao.queryBloodOxygenByDate(deviceAddressNoClear, y_m_d) != null) {
                String calendar = getSchemeCalendar(dateUtil.getYear(), dateUtil.getMonth(), dateUtil.getDay(), "").toString();
                Intrinsics.checkNotNullExpressionValue(calendar, "getSchemeCalendar(monthD…           \"\").toString()");
                linkedHashMap.put(calendar, getSchemeCalendar(dateUtil.getYear(), dateUtil.getMonth(), dateUtil.getDay(), ""));
            }
            dateUtil.addDay(1);
        }
        return linkedHashMap;
    }

    private final Calendar getSchemeCalendar(int year, int month, int day, String text) {
        Calendar calendar = new Calendar();
        calendar.setYear(year);
        calendar.setMonth(month);
        calendar.setDay(day);
        calendar.setSchemeColor(SupportMenu.CATEGORY_MASK);
        calendar.setScheme(text);
        return calendar;
    }

    /* compiled from: BloodOxygenRepository.kt */
    @Metadata(d1 = {"\u0000\u0014\n\u0002\u0018\u0002\n\u0002\u0010\u0000\n\u0002\b\u0002\n\u0002\u0018\u0002\n\u0002\b\u0005\b\u0086\u0003\u0018\u00002\u00020\u0001B\u0007\b\u0002¢\u0006\u0002\u0010\u0002R\u001b\u0010\u0003\u001a\u00020\u00048FX\u0086\u0084\u0002¢\u0006\f\n\u0004\b\u0007\u0010\b\u001a\u0004\b\u0005\u0010\u0006¨\u0006\t"}, d2 = {"Lcom/qcwireless/qcwatch/ui/base/repository/healthy/BloodOxygenRepository$Companion;", "", "()V", "getInstance", "Lcom/qcwireless/qcwatch/ui/base/repository/healthy/BloodOxygenRepository;", "getGetInstance", "()Lcom/qcwireless/qcwatch/ui/base/repository/healthy/BloodOxygenRepository;", "getInstance$delegate", "Lkotlin/Lazy;", "app_championRelease"}, k = 1, mv = {1, 6, 0}, xi = 48)
    /* loaded from: classes2.dex */
    public static final class Companion {
        public /* synthetic */ Companion(DefaultConstructorMarker defaultConstructorMarker) {
            this();
        }

        private Companion() {
        }

        public final BloodOxygenRepository getGetInstance() {
            return (BloodOxygenRepository) BloodOxygenRepository.getInstance$delegate.getValue();
        }
    }
}
