package com.qcwireless.qcwatch.ui.base.repository.healthy;

import androidx.core.internal.view.SupportMenu;
import com.haibin.calendarview.Calendar;
import com.iwown.awlog.Author;
import com.iwown.awlog.AwLog;
import com.oudmon.ble.base.communication.CommandHandle;
import com.oudmon.ble.base.communication.ICommandResponse;
import com.oudmon.ble.base.communication.req.BpReadConformReq;
import com.oudmon.ble.base.communication.req.ReadPressureReq;
import com.oudmon.ble.base.communication.req.SimpleKeyReq;
import com.oudmon.ble.base.communication.rsp.BaseRspCmd;
import com.oudmon.ble.base.communication.rsp.BpDataRsp;
import com.oudmon.ble.base.communication.rsp.ReadBlePressureRsp;
import com.oudmon.ble.base.util.DateUtil;
import com.qcwireless.qcwatch.QCApplication;
import com.qcwireless.qcwatch.base.event.ManualRefreshEvent;
import com.qcwireless.qcwatch.base.ktx.ThreadExtKt;
import com.qcwireless.qcwatch.base.pref.UserConfig;
import com.qcwireless.qcwatch.ui.base.bean.response.healthy.BpDownResp;
import com.qcwireless.qcwatch.ui.base.repository.base.BaseDeviceResult;
import com.qcwireless.qcwatch.ui.base.repository.dao.ManualBloodPressureDao;
import com.qcwireless.qcwatch.ui.base.repository.dao.QcBloodPressureDao;
import com.qcwireless.qcwatch.ui.base.repository.dao.QcDatabase;
import com.qcwireless.qcwatch.ui.base.repository.entity.BloodPressureEntity;
import com.qcwireless.qcwatch.ui.base.repository.entity.BloodPressureManualEntity;
import com.qcwireless.qcwatch.ui.base.repository.mine.NetState;
import com.qcwireless.qcwatch.ui.base.view.QBloodPressureChartHomeView;
import java.util.ArrayList;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;
import java.util.Objects;
import kotlin.Lazy;
import kotlin.LazyKt;
import kotlin.LazyThreadSafetyMode;
import kotlin.Metadata;
import kotlin.Unit;
import kotlin.coroutines.Continuation;
import kotlin.coroutines.intrinsics.IntrinsicsKt;
import kotlin.jvm.functions.Function0;
import kotlin.jvm.functions.Function1;
import kotlin.jvm.internal.DefaultConstructorMarker;
import kotlin.jvm.internal.Intrinsics;
import kotlin.jvm.internal.TypeIntrinsics;
import kotlinx.coroutines.BuildersKt__Builders_commonKt;
import kotlinx.coroutines.Dispatchers;
import kotlinx.coroutines.GlobalScope;
import kotlinx.coroutines.flow.Flow;
import kotlinx.coroutines.flow.FlowCollector;
import kotlinx.coroutines.flow.FlowKt;
import org.greenrobot.eventbus.EventBus;

/* compiled from: BloodPressureRepository.kt */
@Metadata(d1 = {"\u0000~\n\u0002\u0018\u0002\n\u0002\u0010\u0000\n\u0002\b\u0002\n\u0002\u0018\u0002\n\u0000\n\u0002\u0018\u0002\n\u0000\n\u0002\u0010$\n\u0002\u0010\u000e\n\u0002\u0018\u0002\n\u0000\n\u0002\u0010\b\n\u0002\b\u0002\n\u0002\u0010\u0002\n\u0002\b\u0002\n\u0002\u0010\t\n\u0002\b\u0006\n\u0002\u0010 \n\u0002\u0018\u0002\n\u0002\b\u0004\n\u0002\u0010!\n\u0002\u0018\u0002\n\u0002\b\u0002\n\u0002\u0018\u0002\n\u0002\b\u0006\n\u0002\u0010\u0005\n\u0002\b\u0003\n\u0002\u0018\u0002\n\u0002\u0018\u0002\n\u0002\b\u0003\n\u0002\u0018\u0002\n\u0002\u0018\u0002\n\u0002\b\u0003\u0018\u0000 62\u00020\u0001:\u00016B\u0005¢\u0006\u0002\u0010\u0002J\"\u0010\u0007\u001a\u000e\u0012\u0004\u0012\u00020\t\u0012\u0004\u0012\u00020\n0\b2\u0006\u0010\u000b\u001a\u00020\f2\u0006\u0010\r\u001a\u00020\fJ\u0006\u0010\u000e\u001a\u00020\u000fJ!\u0010\u0010\u001a\u00020\u000f2\u0006\u0010\u0011\u001a\u00020\u00122\u0006\u0010\u0013\u001a\u00020\u0012H\u0086@ø\u0001\u0000¢\u0006\u0002\u0010\u0014J(\u0010\u0015\u001a\u00020\n2\u0006\u0010\u000b\u001a\u00020\f2\u0006\u0010\r\u001a\u00020\f2\u0006\u0010\u0016\u001a\u00020\f2\u0006\u0010\u0017\u001a\u00020\tH\u0002J\u001e\u0010\u0018\u001a\n\u0012\u0004\u0012\u00020\u001a\u0018\u00010\u00192\u0006\u0010\u001b\u001a\u00020\u00122\u0006\u0010\u001c\u001a\u00020\u0012J\b\u0010\u001d\u001a\u0004\u0018\u00010\u001aJ\u0014\u0010\u001e\u001a\b\u0012\u0004\u0012\u00020 0\u001f2\u0006\u0010!\u001a\u00020\tJ\b\u0010\"\u001a\u0004\u0018\u00010#J\u0014\u0010$\u001a\b\u0012\u0004\u0012\u00020#0\u001f2\u0006\u0010%\u001a\u00020\tJ\u0014\u0010&\u001a\b\u0012\u0004\u0012\u00020#0\u001f2\u0006\u0010%\u001a\u00020\tJ\u001e\u0010'\u001a\u00020\u000f2\u0006\u0010(\u001a\u00020\f2\u0006\u0010)\u001a\u00020*2\u0006\u0010+\u001a\u00020*J\u0014\u0010,\u001a\u00020\u000f2\f\u0010-\u001a\b\u0012\u0004\u0012\u00020/0.J\b\u00100\u001a\u00020\u000fH\u0002J\u0016\u00101\u001a\u00020\u000f2\f\u0010-\u001a\b\u0012\u0004\u0012\u00020/0.H\u0002J\u001d\u00102\u001a\u000e\u0012\n\u0012\b\u0012\u0004\u0012\u00020\f0403H\u0086@ø\u0001\u0000¢\u0006\u0002\u00105R\u000e\u0010\u0003\u001a\u00020\u0004X\u0082\u0004¢\u0006\u0002\n\u0000R\u000e\u0010\u0005\u001a\u00020\u0006X\u0082\u0004¢\u0006\u0002\n\u0000\u0082\u0002\u0004\n\u0002\b\u0019¨\u00067"}, d2 = {"Lcom/qcwireless/qcwatch/ui/base/repository/healthy/BloodPressureRepository;", "", "()V", "bloodPressureDao", "Lcom/qcwireless/qcwatch/ui/base/repository/dao/QcBloodPressureDao;", "bloodPressureManualDao", "Lcom/qcwireless/qcwatch/ui/base/repository/dao/ManualBloodPressureDao;", "calendarBloodPressure", "", "", "Lcom/haibin/calendarview/Calendar;", "year", "", "month", "deleteData", "", "downBpFromServer", "uid", "", "lastSyncId", "(JJLkotlin/coroutines/Continuation;)Ljava/lang/Object;", "getSchemeCalendar", "day", "text", "queryBpByDate", "", "Lcom/qcwireless/qcwatch/ui/base/repository/entity/BloodPressureEntity;", "start", "end", "queryLastBp", "queryLastBpValue", "", "Lcom/qcwireless/qcwatch/ui/base/view/QBloodPressureChartHomeView$BpDataBean;", "mac", "queryLastManualBloodPressureDate", "Lcom/qcwireless/qcwatch/ui/base/repository/entity/BloodPressureManualEntity;", "queryManualBloodPressure", "date", "queryManualBloodPressureAll", "saveManualBloodPressure", "manualTime", "sbp", "", "dbp", "syncAutoBp", "result", "Lcom/qcwireless/qcwatch/ui/base/repository/base/BaseDeviceResult;", "Lcom/oudmon/ble/base/communication/rsp/ReadBlePressureRsp;", "syncAutoBpConfirm", "syncManualBp", "updateBpDetailToServer", "Lkotlinx/coroutines/flow/Flow;", "Lcom/qcwireless/qcwatch/ui/base/repository/mine/NetState;", "(Lkotlin/coroutines/Continuation;)Ljava/lang/Object;", "Companion", "app_championRelease"}, k = 1, mv = {1, 6, 0}, xi = 48)
/* loaded from: classes2.dex */
public final class BloodPressureRepository {

    /* renamed from: Companion, reason: from kotlin metadata */
    public static final Companion INSTANCE = new Companion(null);
    private static final Lazy<BloodPressureRepository> getInstance$delegate = LazyKt.lazy(LazyThreadSafetyMode.SYNCHRONIZED, (Function0) new Function0<BloodPressureRepository>() { // from class: com.qcwireless.qcwatch.ui.base.repository.healthy.BloodPressureRepository$Companion$getInstance$2
        /* JADX WARN: Can't rename method to resolve collision */
        @Override // kotlin.jvm.functions.Function0
        public final BloodPressureRepository invoke() {
            return new BloodPressureRepository();
        }
    });
    private final QcBloodPressureDao bloodPressureDao = QcDatabase.INSTANCE.getDatabase(QCApplication.INSTANCE.getCONTEXT()).qcBloodPressureDao();
    private final ManualBloodPressureDao bloodPressureManualDao = QcDatabase.INSTANCE.getDatabase(QCApplication.INSTANCE.getCONTEXT()).manualBloodPressureDao();

    public final void syncAutoBp(final BaseDeviceResult<ReadBlePressureRsp> result) {
        Intrinsics.checkNotNullParameter(result, "result");
        CommandHandle.getInstance().executeReqCmd(new SimpleKeyReq((byte) 13), new ICommandResponse() { // from class: com.qcwireless.qcwatch.ui.base.repository.healthy.BloodPressureRepository$$ExternalSyntheticLambda0
            @Override // com.oudmon.ble.base.communication.ICommandResponse
            public final void onDataResponse(BaseRspCmd baseRspCmd) {
                BloodPressureRepository.m287syncAutoBp$lambda0(BloodPressureRepository.this, result, (BpDataRsp) baseRspCmd);
            }
        });
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* renamed from: syncAutoBp$lambda-0, reason: not valid java name */
    public static final void m287syncAutoBp$lambda0(BloodPressureRepository this$0, BaseDeviceResult result, BpDataRsp bpDataRsp) {
        Intrinsics.checkNotNullParameter(this$0, "this$0");
        Intrinsics.checkNotNullParameter(result, "$result");
        if (bpDataRsp.getBpDataEntity() != null) {
            BuildersKt__Builders_commonKt.launch$default(GlobalScope.INSTANCE, null, null, new BloodPressureRepository$syncAutoBp$1$1(bpDataRsp, this$0, null), 3, null);
        } else {
            this$0.syncManualBp(result);
            AwLog.i(Author.HeZhiYuan, "同步手动血压");
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    public final void syncAutoBpConfirm() {
        CommandHandle.getInstance().executeReqCmdNoCallback(new BpReadConformReq(true));
    }

    private final void syncManualBp(final BaseDeviceResult<ReadBlePressureRsp> result) {
        CommandHandle.getInstance().executeReqCmd(new ReadPressureReq(0L), new ICommandResponse() { // from class: com.qcwireless.qcwatch.ui.base.repository.healthy.BloodPressureRepository$$ExternalSyntheticLambda1
            @Override // com.oudmon.ble.base.communication.ICommandResponse
            public final void onDataResponse(BaseRspCmd baseRspCmd) {
                BloodPressureRepository.m288syncManualBp$lambda1(BloodPressureRepository.this, result, (ReadBlePressureRsp) baseRspCmd);
            }
        });
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* renamed from: syncManualBp$lambda-1, reason: not valid java name */
    public static final void m288syncManualBp$lambda1(BloodPressureRepository this$0, final BaseDeviceResult result, final ReadBlePressureRsp readBlePressureRsp) {
        Intrinsics.checkNotNullParameter(this$0, "this$0");
        Intrinsics.checkNotNullParameter(result, "$result");
        AwLog.i(Author.HeZhiYuan, "血压数据长度:" + readBlePressureRsp.getValueList().size());
        ThreadExtKt.ktxRunOnBgSingle(this$0, new Function1<BloodPressureRepository, Unit>() { // from class: com.qcwireless.qcwatch.ui.base.repository.healthy.BloodPressureRepository$syncManualBp$1$1
            /* JADX INFO: Access modifiers changed from: package-private */
            /* JADX WARN: 'super' call moved to the top of the method (can break code semantics) */
            {
                super(1);
            }

            @Override // kotlin.jvm.functions.Function1
            public /* bridge */ /* synthetic */ Unit invoke(BloodPressureRepository bloodPressureRepository) {
                invoke2(bloodPressureRepository);
                return Unit.INSTANCE;
            }

            /* JADX WARN: Removed duplicated region for block: B:11:0x006f  */
            /* JADX WARN: Removed duplicated region for block: B:14:0x0098 A[SYNTHETIC] */
            /* renamed from: invoke, reason: avoid collision after fix types in other method */
            /*
                Code decompiled incorrectly, please refer to instructions dump.
                To view partially-correct code enable 'Show inconsistent code' option in preferences
            */
            public final void invoke2(com.qcwireless.qcwatch.ui.base.repository.healthy.BloodPressureRepository r18) {
                /*
                    r17 = this;
                    r0 = r17
                    java.lang.String r1 = "$this$ktxRunOnBgSingle"
                    r2 = r18
                    kotlin.jvm.internal.Intrinsics.checkNotNullParameter(r2, r1)
                    com.oudmon.ble.base.communication.rsp.ReadBlePressureRsp r1 = com.oudmon.ble.base.communication.rsp.ReadBlePressureRsp.this
                    java.util.List r1 = r1.getValueList()
                    java.util.Iterator r1 = r1.iterator()
                    r4 = 0
                L14:
                    boolean r5 = r1.hasNext()
                    if (r5 == 0) goto L9b
                    int r5 = r4 + 1
                    java.lang.Object r6 = r1.next()
                    com.oudmon.ble.base.communication.entity.BlePressure r6 = (com.oudmon.ble.base.communication.entity.BlePressure) r6
                    com.oudmon.ble.base.util.DateUtil r7 = new com.oudmon.ble.base.util.DateUtil
                    long r8 = r6.time
                    r10 = 1
                    r7.<init>(r8, r10)
                    int r14 = r6.sbp
                    com.oudmon.ble.base.communication.rsp.ReadBlePressureRsp r8 = com.oudmon.ble.base.communication.rsp.ReadBlePressureRsp.this
                    java.util.List r8 = r8.getValueList()
                    int r8 = r8.size()
                    int r8 = r8 - r10
                    if (r4 >= r8) goto L62
                    com.oudmon.ble.base.communication.rsp.ReadBlePressureRsp r8 = com.oudmon.ble.base.communication.rsp.ReadBlePressureRsp.this
                    java.util.List r8 = r8.getValueList()
                    java.lang.Object r4 = r8.get(r4)
                    com.oudmon.ble.base.communication.entity.BlePressure r4 = (com.oudmon.ble.base.communication.entity.BlePressure) r4
                    long r8 = r4.time
                    r4 = 60
                    long r11 = (long) r4
                    long r8 = r8 / r11
                    com.oudmon.ble.base.communication.rsp.ReadBlePressureRsp r4 = com.oudmon.ble.base.communication.rsp.ReadBlePressureRsp.this
                    java.util.List r4 = r4.getValueList()
                    java.lang.Object r4 = r4.get(r5)
                    com.oudmon.ble.base.communication.entity.BlePressure r4 = (com.oudmon.ble.base.communication.entity.BlePressure) r4
                    long r3 = r4.time
                    long r3 = r3 / r11
                    int r11 = (r8 > r3 ? 1 : (r8 == r3 ? 0 : -1))
                    if (r11 != 0) goto L62
                    r7.setSecond(r10)
                    goto L66
                L62:
                    r3 = 0
                    r7.setSecond(r3)
                L66:
                    int r3 = r7.getYear()
                    r4 = 2024(0x7e8, float:2.836E-42)
                    if (r3 > r4) goto L6f
                    goto L98
                L6f:
                    com.qcwireless.qcwatch.ui.base.repository.entity.BloodPressureManualEntity r3 = new com.qcwireless.qcwatch.ui.base.repository.entity.BloodPressureManualEntity
                    com.qcwireless.qcwatch.base.pref.UserConfig$Companion r4 = com.qcwireless.qcwatch.base.pref.UserConfig.INSTANCE
                    com.qcwireless.qcwatch.base.pref.UserConfig r4 = r4.getInstance()
                    java.lang.String r12 = r4.getDeviceAddressNoClear()
                    java.lang.String r13 = r7.getY_M_D()
                    java.lang.String r4 = "date.y_M_D"
                    kotlin.jvm.internal.Intrinsics.checkNotNullExpressionValue(r13, r4)
                    int r15 = r6.dbp
                    long r6 = r7.getUnixTimestamp()
                    int r4 = (int) r6
                    r11 = r3
                    r16 = r4
                    r11.<init>(r12, r13, r14, r15, r16)
                    com.qcwireless.qcwatch.ui.base.repository.dao.ManualBloodPressureDao r4 = com.qcwireless.qcwatch.ui.base.repository.healthy.BloodPressureRepository.access$getBloodPressureManualDao$p(r18)
                    r4.insert(r3)
                L98:
                    r4 = r5
                    goto L14
                L9b:
                    com.oudmon.ble.base.communication.rsp.ReadBlePressureRsp r1 = com.oudmon.ble.base.communication.rsp.ReadBlePressureRsp.this
                    int r1 = r1.getStatus()
                    if (r1 != 0) goto Lb0
                    com.qcwireless.qcwatch.ui.base.repository.base.BaseDeviceResult<com.oudmon.ble.base.communication.rsp.ReadBlePressureRsp> r1 = r2
                    com.oudmon.ble.base.communication.rsp.ReadBlePressureRsp r2 = com.oudmon.ble.base.communication.rsp.ReadBlePressureRsp.this
                    java.lang.String r3 = "it"
                    kotlin.jvm.internal.Intrinsics.checkNotNullExpressionValue(r2, r3)
                    r3 = 0
                    r1.result(r3, r2)
                Lb0:
                    return
                */
                throw new UnsupportedOperationException("Method not decompiled: com.qcwireless.qcwatch.ui.base.repository.healthy.BloodPressureRepository$syncManualBp$1$1.invoke2(com.qcwireless.qcwatch.ui.base.repository.healthy.BloodPressureRepository):void");
            }
        });
    }

    public final List<BloodPressureEntity> queryBpByDate(long start, long end) {
        return this.bloodPressureDao.queryByUnixTime(UserConfig.INSTANCE.getInstance().getDeviceAddressNoClear(), start, end);
    }

    public final BloodPressureEntity queryLastBp() {
        return this.bloodPressureDao.queryLastBpValue(UserConfig.INSTANCE.getInstance().getDeviceAddressNoClear());
    }

    public final List<QBloodPressureChartHomeView.BpDataBean> queryLastBpValue(String mac) {
        Intrinsics.checkNotNullParameter(mac, "mac");
        ArrayList arrayList = new ArrayList();
        BloodPressureEntity queryLastBpValue = this.bloodPressureDao.queryLastBpValue(mac);
        if (queryLastBpValue != null) {
            DateUtil dateUtil = new DateUtil(queryLastBpValue.getUnixTime(), true);
            List<BloodPressureEntity> queryByUnixTime = this.bloodPressureDao.queryByUnixTime(mac, dateUtil.getZeroTime(), dateUtil.getZeroTime() + 86399);
            if (queryByUnixTime != null) {
                int i = 0;
                for (BloodPressureEntity bloodPressureEntity : queryByUnixTime) {
                    int i2 = i + 1;
                    if (queryByUnixTime.get(i).getUnixTime() > 1704038400) {
                        if (i > 0) {
                            long j = 60;
                            if (queryByUnixTime.get(i - 1).getUnixTime() / j == queryByUnixTime.get(i).getUnixTime() / j) {
                                AwLog.i(Author.HeZhiYuan, bloodPressureEntity);
                            }
                        }
                        com.qcwireless.qc_utils.date.DateUtil dateUtil2 = new com.qcwireless.qc_utils.date.DateUtil(bloodPressureEntity.getUnixTime(), true);
                        arrayList.add(new QBloodPressureChartHomeView.BpDataBean((dateUtil2.getHour() * 60) + dateUtil2.getMinute(), bloodPressureEntity.getSbp(), bloodPressureEntity.getDbp(), queryLastBpValue.getUnixTime()));
                    }
                    i = i2;
                }
            }
        }
        return arrayList;
    }

    public final Object updateBpDetailToServer(Continuation<? super Flow<NetState<Integer>>> continuation) {
        return FlowKt.m2572catch(FlowKt.flowOn(FlowKt.onStart(FlowKt.flow(new BloodPressureRepository$updateBpDetailToServer$2(this, null)), new BloodPressureRepository$updateBpDetailToServer$3(null)), Dispatchers.getIO()), new BloodPressureRepository$updateBpDetailToServer$4(null));
    }

    public final Object downBpFromServer(long j, long j2, Continuation<? super Unit> continuation) {
        Object collect = FlowKt.m2572catch(FlowKt.flowOn(FlowKt.onStart(FlowKt.flow(new BloodPressureRepository$downBpFromServer$2(j, j2, null)), new BloodPressureRepository$downBpFromServer$3(null)), Dispatchers.getIO()), new BloodPressureRepository$downBpFromServer$4(null)).collect(new FlowCollector() { // from class: com.qcwireless.qcwatch.ui.base.repository.healthy.BloodPressureRepository$downBpFromServer$5
            @Override // kotlinx.coroutines.flow.FlowCollector
            public /* bridge */ /* synthetic */ Object emit(Object obj, Continuation continuation2) {
                return emit((NetState<List<BpDownResp>>) obj, (Continuation<? super Unit>) continuation2);
            }

            public final Object emit(NetState<List<BpDownResp>> netState, Continuation<? super Unit> continuation2) {
                List<BpDownResp> isSuccess;
                QcBloodPressureDao qcBloodPressureDao;
                if (netState.getRetCode() == 0 && (isSuccess = netState.isSuccess()) != null) {
                    try {
                        for (BpDownResp bpDownResp : isSuccess) {
                            String deviceId = bpDownResp.getDeviceId();
                            BloodPressureEntity bloodPressureEntity = deviceId != null ? new BloodPressureEntity(deviceId, bpDownResp.getTime() / 1000, bpDownResp.getSbp(), bpDownResp.getDbp(), false, new DateUtil().getUnixTimestamp()) : null;
                            if (bloodPressureEntity != null) {
                                qcBloodPressureDao = BloodPressureRepository.this.bloodPressureDao;
                                qcBloodPressureDao.insert(bloodPressureEntity);
                            }
                        }
                    } catch (Exception e) {
                        e.printStackTrace();
                    }
                }
                return Unit.INSTANCE;
            }
        }, continuation);
        return collect == IntrinsicsKt.getCOROUTINE_SUSPENDED() ? collect : Unit.INSTANCE;
    }

    public final List<BloodPressureManualEntity> queryManualBloodPressure(String date) {
        Intrinsics.checkNotNullParameter(date, "date");
        return this.bloodPressureManualDao.queryDataLimit(UserConfig.INSTANCE.getInstance().getDeviceAddressNoClear(), date);
    }

    public final List<BloodPressureManualEntity> queryManualBloodPressureAll(String date) {
        Intrinsics.checkNotNullParameter(date, "date");
        return this.bloodPressureManualDao.queryDataAll(UserConfig.INSTANCE.getInstance().getDeviceAddressNoClear(), date);
    }

    public final void saveManualBloodPressure(final int manualTime, final byte sbp, final byte dbp) {
        ThreadExtKt.ktxRunOnBgSingle(this, new Function1<BloodPressureRepository, Unit>() { // from class: com.qcwireless.qcwatch.ui.base.repository.healthy.BloodPressureRepository$saveManualBloodPressure$1
            /* JADX INFO: Access modifiers changed from: package-private */
            /* JADX WARN: 'super' call moved to the top of the method (can break code semantics) */
            {
                super(1);
            }

            @Override // kotlin.jvm.functions.Function1
            public /* bridge */ /* synthetic */ Unit invoke(BloodPressureRepository bloodPressureRepository) {
                invoke2(bloodPressureRepository);
                return Unit.INSTANCE;
            }

            /* renamed from: invoke, reason: avoid collision after fix types in other method */
            public final void invoke2(BloodPressureRepository ktxRunOnBgSingle) {
                ManualBloodPressureDao manualBloodPressureDao;
                Intrinsics.checkNotNullParameter(ktxRunOnBgSingle, "$this$ktxRunOnBgSingle");
                DateUtil dateUtil = new DateUtil(manualTime, true);
                String deviceAddressNoClear = UserConfig.INSTANCE.getInstance().getDeviceAddressNoClear();
                String y_m_d = dateUtil.getY_M_D();
                Intrinsics.checkNotNullExpressionValue(y_m_d, "date.y_M_D");
                BloodPressureManualEntity bloodPressureManualEntity = new BloodPressureManualEntity(deviceAddressNoClear, y_m_d, sbp, dbp, manualTime);
                manualBloodPressureDao = ktxRunOnBgSingle.bloodPressureManualDao;
                manualBloodPressureDao.insert(bloodPressureManualEntity);
                EventBus.getDefault().post(new ManualRefreshEvent());
            }
        });
    }

    public final BloodPressureManualEntity queryLastManualBloodPressureDate() {
        return this.bloodPressureManualDao.queryDataLimitLast(UserConfig.INSTANCE.getInstance().getDeviceAddressNoClear());
    }

    public final void deleteData() {
        ThreadExtKt.ktxRunOnBgSingleAnother(this, new Function1<BloodPressureRepository, Unit>() { // from class: com.qcwireless.qcwatch.ui.base.repository.healthy.BloodPressureRepository$deleteData$1
            @Override // kotlin.jvm.functions.Function1
            public /* bridge */ /* synthetic */ Unit invoke(BloodPressureRepository bloodPressureRepository) {
                invoke2(bloodPressureRepository);
                return Unit.INSTANCE;
            }

            /* renamed from: invoke, reason: avoid collision after fix types in other method */
            public final void invoke2(BloodPressureRepository ktxRunOnBgSingleAnother) {
                ManualBloodPressureDao manualBloodPressureDao;
                ManualBloodPressureDao manualBloodPressureDao2;
                QcBloodPressureDao qcBloodPressureDao;
                Intrinsics.checkNotNullParameter(ktxRunOnBgSingleAnother, "$this$ktxRunOnBgSingleAnother");
                DateUtil dateUtil = new DateUtil();
                List<BloodPressureEntity> queryBpByDate = ktxRunOnBgSingleAnother.queryBpByDate(dateUtil.getZeroTime(), dateUtil.getZeroTime() + 86399);
                List<BloodPressureEntity> list = queryBpByDate;
                if (!(list == null || list.isEmpty())) {
                    qcBloodPressureDao = ktxRunOnBgSingleAnother.bloodPressureDao;
                    Objects.requireNonNull(queryBpByDate, "null cannot be cast to non-null type kotlin.collections.MutableList<com.qcwireless.qcwatch.ui.base.repository.entity.BloodPressureEntity>");
                    qcBloodPressureDao.deleteList(TypeIntrinsics.asMutableList(queryBpByDate));
                }
                manualBloodPressureDao = ktxRunOnBgSingleAnother.bloodPressureManualDao;
                String deviceAddressNoClear = UserConfig.INSTANCE.getInstance().getDeviceAddressNoClear();
                String y_m_d = new DateUtil().getY_M_D();
                Intrinsics.checkNotNullExpressionValue(y_m_d, "DateUtil().y_M_D");
                List<BloodPressureManualEntity> queryDataLimit = manualBloodPressureDao.queryDataLimit(deviceAddressNoClear, y_m_d);
                manualBloodPressureDao2 = ktxRunOnBgSingleAnother.bloodPressureManualDao;
                manualBloodPressureDao2.deleteList(TypeIntrinsics.asMutableList(queryDataLimit));
            }
        });
    }

    public final Map<String, Calendar> calendarBloodPressure(int year, int month) {
        LinkedHashMap linkedHashMap = new LinkedHashMap();
        DateUtil dateUtil = new DateUtil(year, month, 1);
        for (int i = 1; i < 32; i++) {
            if (this.bloodPressureDao.queryBloodPressureByDate(UserConfig.INSTANCE.getInstance().getDeviceAddressNoClear(), dateUtil.getZeroTime(), dateUtil.getZeroTime() + 86399) != null) {
                String calendar = getSchemeCalendar(dateUtil.getYear(), dateUtil.getMonth(), dateUtil.getDay(), "").toString();
                Intrinsics.checkNotNullExpressionValue(calendar, "getSchemeCalendar(monthD…           \"\").toString()");
                linkedHashMap.put(calendar, getSchemeCalendar(dateUtil.getYear(), dateUtil.getMonth(), dateUtil.getDay(), ""));
            }
            dateUtil.addDay(1);
        }
        return linkedHashMap;
    }

    private final Calendar getSchemeCalendar(int year, int month, int day, String text) {
        Calendar calendar = new Calendar();
        calendar.setYear(year);
        calendar.setMonth(month);
        calendar.setDay(day);
        calendar.setSchemeColor(SupportMenu.CATEGORY_MASK);
        calendar.setScheme(text);
        return calendar;
    }

    /* compiled from: BloodPressureRepository.kt */
    @Metadata(d1 = {"\u0000\u0014\n\u0002\u0018\u0002\n\u0002\u0010\u0000\n\u0002\b\u0002\n\u0002\u0018\u0002\n\u0002\b\u0005\b\u0086\u0003\u0018\u00002\u00020\u0001B\u0007\b\u0002¢\u0006\u0002\u0010\u0002R\u001b\u0010\u0003\u001a\u00020\u00048FX\u0086\u0084\u0002¢\u0006\f\n\u0004\b\u0007\u0010\b\u001a\u0004\b\u0005\u0010\u0006¨\u0006\t"}, d2 = {"Lcom/qcwireless/qcwatch/ui/base/repository/healthy/BloodPressureRepository$Companion;", "", "()V", "getInstance", "Lcom/qcwireless/qcwatch/ui/base/repository/healthy/BloodPressureRepository;", "getGetInstance", "()Lcom/qcwireless/qcwatch/ui/base/repository/healthy/BloodPressureRepository;", "getInstance$delegate", "Lkotlin/Lazy;", "app_championRelease"}, k = 1, mv = {1, 6, 0}, xi = 48)
    /* loaded from: classes2.dex */
    public static final class Companion {
        public /* synthetic */ Companion(DefaultConstructorMarker defaultConstructorMarker) {
            this();
        }

        private Companion() {
        }

        public final BloodPressureRepository getGetInstance() {
            return (BloodPressureRepository) BloodPressureRepository.getInstance$delegate.getValue();
        }
    }
}
