package com.qcwireless.qcwatch.ui.base.repository.healthy;

import androidx.constraintlayout.core.motion.utils.TypedValues;
import androidx.core.internal.view.SupportMenu;
import com.blankj.utilcode.constant.CacheConstants;
import com.google.android.gms.common.internal.ServiceSpecificExtraArgs;
import com.haibin.calendarview.Calendar;
import com.oudmon.ble.base.bluetooth.BleOperateManager;
import com.oudmon.ble.base.communication.CommandHandle;
import com.oudmon.ble.base.communication.ICommandResponse;
import com.oudmon.ble.base.communication.LargeDataHandler;
import com.oudmon.ble.base.communication.bigData.bean.ManualHeartRate;
import com.oudmon.ble.base.communication.bigData.resp.ILargeDataManualHeartRateResponse;
import com.oudmon.ble.base.communication.req.ReadHeartRateReq;
import com.oudmon.ble.base.communication.rsp.BaseRspCmd;
import com.oudmon.ble.base.communication.rsp.ReadHeartRateRsp;
import com.oudmon.ble.base.communication.utils.ByteUtil;
import com.qcwireless.qc_utils.date.DateUtil;
import com.qcwireless.qcwatch.QCApplication;
import com.qcwireless.qcwatch.base.event.ManualRefreshEvent;
import com.qcwireless.qcwatch.base.ktx.ThreadExtKt;
import com.qcwireless.qcwatch.base.pref.UserConfig;
import com.qcwireless.qcwatch.base.utils.MoshiUtils;
import com.qcwireless.qcwatch.base.utils.MoshiUtilsKt;
import com.qcwireless.qcwatch.base.utils.TypeToken;
import com.qcwireless.qcwatch.ui.base.bean.response.healthy.HeartRateResp;
import com.qcwireless.qcwatch.ui.base.repository.base.BaseDeviceResult;
import com.qcwireless.qcwatch.ui.base.repository.dao.QcAppManualHeartDao;
import com.qcwireless.qcwatch.ui.base.repository.dao.QcDatabase;
import com.qcwireless.qcwatch.ui.base.repository.dao.QcHeartRateDetailDao;
import com.qcwireless.qcwatch.ui.base.repository.dao.QcManualHeartDao;
import com.qcwireless.qcwatch.ui.base.repository.entity.AppHeartEntity;
import com.qcwireless.qcwatch.ui.base.repository.entity.HeartRateDetail;
import com.qcwireless.qcwatch.ui.base.repository.entity.ManualHeartEntity;
import com.qcwireless.qcwatch.ui.base.repository.mine.NetState;
import com.qcwireless.qcwatch.ui.base.util.StringUtilsKt;
import com.qcwireless.qcwatch.ui.base.view.QHeartLineChartView;
import com.qcwireless.qcwatch.ui.home.heart.bean.HeartRateDetailBean;
import com.squareup.moshi.JsonAdapter;
import java.util.ArrayList;
import java.util.Comparator;
import java.util.Iterator;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;
import java.util.TimeZone;
import java.util.concurrent.ConcurrentHashMap;
import kotlin.Lazy;
import kotlin.LazyKt;
import kotlin.LazyThreadSafetyMode;
import kotlin.Metadata;
import kotlin.Unit;
import kotlin.collections.CollectionsKt;
import kotlin.comparisons.ComparisonsKt;
import kotlin.coroutines.Continuation;
import kotlin.coroutines.intrinsics.IntrinsicsKt;
import kotlin.jvm.functions.Function0;
import kotlin.jvm.functions.Function1;
import kotlin.jvm.internal.DefaultConstructorMarker;
import kotlin.jvm.internal.Intrinsics;
import kotlin.jvm.internal.TypeIntrinsics;
import kotlinx.coroutines.Dispatchers;
import kotlinx.coroutines.flow.Flow;
import kotlinx.coroutines.flow.FlowCollector;
import kotlinx.coroutines.flow.FlowKt;
import org.greenrobot.eventbus.EventBus;

/* compiled from: HeartRateDetailRepository.kt */
@Metadata(d1 = {"\u0000 \u0001\n\u0002\u0018\u0002\n\u0002\u0010\u0000\n\u0002\b\u0002\n\u0002\u0018\u0002\n\u0000\n\u0002\u0018\u0002\n\u0000\n\u0002\u0018\u0002\n\u0002\u0010\u000e\n\u0002\u0010\b\n\u0000\n\u0002\u0018\u0002\n\u0000\n\u0002\u0010$\n\u0002\u0018\u0002\n\u0002\b\u0003\n\u0002\u0010\u0002\n\u0002\b\u0002\n\u0002\u0010\t\n\u0002\b\u0006\n\u0002\u0010\u0007\n\u0000\n\u0002\u0018\u0002\n\u0000\n\u0002\u0018\u0002\n\u0000\n\u0002\u0010 \n\u0002\u0018\u0002\n\u0000\n\u0002\u0018\u0002\n\u0002\b\u0002\n\u0002\u0010!\n\u0002\b\u0002\n\u0002\u0018\u0002\n\u0002\b\u0004\n\u0002\u0018\u0002\n\u0002\b\b\n\u0002\u0018\u0002\n\u0002\b\u0005\n\u0002\u0018\u0002\n\u0002\b\u0003\n\u0002\u0018\u0002\n\u0002\u0018\u0002\n\u0002\b\u0003\u0018\u0000 G2\u00020\u0001:\u0001GB\u0005¢\u0006\u0002\u0010\u0002J\"\u0010\r\u001a\u000e\u0012\u0004\u0012\u00020\t\u0012\u0004\u0012\u00020\u000f0\u000e2\u0006\u0010\u0010\u001a\u00020\n2\u0006\u0010\u0011\u001a\u00020\nJ\u0006\u0010\u0012\u001a\u00020\u0013J!\u0010\u0014\u001a\u00020\u00132\u0006\u0010\u0015\u001a\u00020\u00162\u0006\u0010\u0017\u001a\u00020\u0016H\u0086@ø\u0001\u0000¢\u0006\u0002\u0010\u0018J(\u0010\u0019\u001a\u00020\u000f2\u0006\u0010\u0010\u001a\u00020\n2\u0006\u0010\u0011\u001a\u00020\n2\u0006\u0010\u001a\u001a\u00020\n2\u0006\u0010\u001b\u001a\u00020\tH\u0002J\b\u0010\u001c\u001a\u00020\u001dH\u0002J\b\u0010\u001e\u001a\u0004\u0018\u00010\u001fJ\u0010\u0010\u001e\u001a\u0004\u0018\u00010\u001f2\u0006\u0010 \u001a\u00020!J\u0014\u0010\"\u001a\b\u0012\u0004\u0012\u00020$0#2\u0006\u0010 \u001a\u00020!J\u0014\u0010%\u001a\b\u0012\u0004\u0012\u00020&0#2\u0006\u0010 \u001a\u00020!J\u0014\u0010'\u001a\b\u0012\u0004\u0012\u00020$0#2\u0006\u0010 \u001a\u00020!J\u0014\u0010(\u001a\b\u0012\u0004\u0012\u00020&0)2\u0006\u0010 \u001a\u00020\tJ\b\u0010*\u001a\u0004\u0018\u00010\u001fJ\b\u0010+\u001a\u0004\u0018\u00010,J\f\u0010-\u001a\b\u0012\u0004\u0012\u00020&0#J\u0014\u0010.\u001a\b\u0012\u0004\u0012\u00020\u001f0)2\u0006\u0010 \u001a\u00020!J\u0010\u0010/\u001a\u00020\u00132\u0006\u00100\u001a\u000201H\u0002J\u0010\u00102\u001a\u00020\u00132\u0006\u00100\u001a\u000201H\u0002J\u0016\u00103\u001a\u00020\u00132\u0006\u00104\u001a\u00020\u00162\u0006\u00105\u001a\u00020\nJ&\u00106\u001a\u00020\u00132\u0006\u00107\u001a\u00020\t2\u0006\u00108\u001a\u00020\u00162\f\u00109\u001a\b\u0012\u0004\u0012\u0002010:H\u0002J'\u0010;\u001a\u00020\u00132\u0006\u0010<\u001a\u00020\t2\f\u00109\u001a\b\u0012\u0004\u0012\u0002010:H\u0086@ø\u0001\u0000¢\u0006\u0002\u0010=J\u000e\u0010>\u001a\u00020\u00132\u0006\u0010?\u001a\u00020@J\u0016\u0010>\u001a\u00020\u00132\u0006\u0010A\u001a\u00020\n2\u0006\u0010?\u001a\u00020@J\u001c\u0010B\u001a\u00020\u00132\u0006\u0010 \u001a\u00020!2\f\u00109\u001a\b\u0012\u0004\u0012\u0002010:J\u001d\u0010C\u001a\u000e\u0012\n\u0012\b\u0012\u0004\u0012\u00020\n0E0DH\u0086@ø\u0001\u0000¢\u0006\u0002\u0010FR\u000e\u0010\u0003\u001a\u00020\u0004X\u0082\u0004¢\u0006\u0002\n\u0000R\u000e\u0010\u0005\u001a\u00020\u0006X\u0082\u0004¢\u0006\u0002\n\u0000R\u001a\u0010\u0007\u001a\u000e\u0012\u0004\u0012\u00020\t\u0012\u0004\u0012\u00020\n0\bX\u0082\u000e¢\u0006\u0002\n\u0000R\u000e\u0010\u000b\u001a\u00020\fX\u0082\u0004¢\u0006\u0002\n\u0000\u0082\u0002\u0004\n\u0002\b\u0019¨\u0006H"}, d2 = {"Lcom/qcwireless/qcwatch/ui/base/repository/healthy/HeartRateDetailRepository;", "", "()V", "appManualHeartRateDao", "Lcom/qcwireless/qcwatch/ui/base/repository/dao/QcAppManualHeartDao;", "heartRateDao", "Lcom/qcwireless/qcwatch/ui/base/repository/dao/QcHeartRateDetailDao;", "historyDate", "Ljava/util/concurrent/ConcurrentHashMap;", "", "", "manualHeartRateDao", "Lcom/qcwireless/qcwatch/ui/base/repository/dao/QcManualHeartDao;", "calendarHeartDetail", "", "Lcom/haibin/calendarview/Calendar;", "year", "month", "deleteData", "", "downHeartRateDetailFromServer", "uid", "", "lastSyncId", "(JJLkotlin/coroutines/Continuation;)Ljava/lang/Object;", "getSchemeCalendar", "day", "text", "getTimeZone", "", "queryAppHeartLast", "Lcom/qcwireless/qcwatch/ui/base/repository/entity/AppHeartEntity;", "date", "Lcom/qcwireless/qc_utils/date/DateUtil;", "queryAppHeartRateByDateDetailResp", "", "Lcom/qcwireless/qcwatch/ui/home/heart/bean/HeartRateDetailBean;", "queryHeartDetail", "Lcom/qcwireless/qcwatch/ui/base/view/QHeartLineChartView$HeartDataBean;", "queryHeartRateByDateDetailResp", "queryHeartRateDetailByDate", "", "queryLastAppHeartManual", "queryLastData", "Lcom/qcwireless/qcwatch/ui/base/repository/entity/HeartRateDetail;", "queryLastHeartDetail", "queryManualAppHeart", "saveHeartRate", "heartResp", "Lcom/oudmon/ble/base/communication/rsp/ReadHeartRateRsp;", "saveHeartRateToday", "saveManualHeartRate", "dataTime", "value", "syncHeartRateDetail", "key", "time", "result", "Lcom/qcwireless/qcwatch/ui/base/repository/base/BaseDeviceResult;", "syncHistoryHeartDetail", "deviceAddress", "(Ljava/lang/String;Lcom/qcwireless/qcwatch/ui/base/repository/base/BaseDeviceResult;Lkotlin/coroutines/Continuation;)Ljava/lang/Object;", "syncManualHeartRate", ServiceSpecificExtraArgs.CastExtraArgs.LISTENER, "Lcom/oudmon/ble/base/communication/bigData/resp/ILargeDataManualHeartRateResponse;", TypedValues.CycleType.S_WAVE_OFFSET, "syncTodayHeartRate", "updateHeartRateDetailToServer", "Lkotlinx/coroutines/flow/Flow;", "Lcom/qcwireless/qcwatch/ui/base/repository/mine/NetState;", "(Lkotlin/coroutines/Continuation;)Ljava/lang/Object;", "Companion", "app_championRelease"}, k = 1, mv = {1, 6, 0}, xi = 48)
/* loaded from: classes2.dex */
public final class HeartRateDetailRepository {

    /* renamed from: Companion, reason: from kotlin metadata */
    public static final Companion INSTANCE = new Companion(null);
    private static final Lazy<HeartRateDetailRepository> getInstance$delegate = LazyKt.lazy(LazyThreadSafetyMode.SYNCHRONIZED, (Function0) new Function0<HeartRateDetailRepository>() { // from class: com.qcwireless.qcwatch.ui.base.repository.healthy.HeartRateDetailRepository$Companion$getInstance$2
        /* JADX WARN: Can't rename method to resolve collision */
        @Override // kotlin.jvm.functions.Function0
        public final HeartRateDetailRepository invoke() {
            return new HeartRateDetailRepository();
        }
    });
    private final QcHeartRateDetailDao heartRateDao = QcDatabase.INSTANCE.getDatabase(QCApplication.INSTANCE.getCONTEXT()).qcHeartRateDao();
    private final QcManualHeartDao manualHeartRateDao = QcDatabase.INSTANCE.getDatabase(QCApplication.INSTANCE.getCONTEXT()).qcManualHeartDao();
    private final QcAppManualHeartDao appManualHeartRateDao = QcDatabase.INSTANCE.getDatabase(QCApplication.INSTANCE.getCONTEXT()).qcAppManualHeartDao();
    private ConcurrentHashMap<String, Integer> historyDate = new ConcurrentHashMap<>();

    public final List<QHeartLineChartView.HeartDataBean> queryHeartDetail(DateUtil date) {
        Intrinsics.checkNotNullParameter(date, "date");
        LinkedHashMap linkedHashMap = new LinkedHashMap();
        QcManualHeartDao qcManualHeartDao = this.manualHeartRateDao;
        String deviceAddressNoClear = UserConfig.INSTANCE.getInstance().getDeviceAddressNoClear();
        String y_m_d = date.getY_M_D();
        Intrinsics.checkNotNullExpressionValue(y_m_d, "date.y_M_D");
        ManualHeartEntity queryByDate = qcManualHeartDao.queryByDate(deviceAddressNoClear, y_m_d);
        QcHeartRateDetailDao qcHeartRateDetailDao = this.heartRateDao;
        String deviceAddressNoClear2 = UserConfig.INSTANCE.getInstance().getDeviceAddressNoClear();
        String y_m_d2 = date.getY_M_D();
        Intrinsics.checkNotNullExpressionValue(y_m_d2, "date.y_M_D");
        HeartRateDetail queryHeartByDate = qcHeartRateDetailDao.queryHeartByDate(deviceAddressNoClear2, y_m_d2);
        if (queryHeartByDate != null) {
            int[] stringToIntArray = StringUtilsKt.stringToIntArray(queryHeartByDate.getIndex_str());
            int[] stringToIntArray2 = StringUtilsKt.stringToIntArray(queryHeartByDate.getValue());
            int length = stringToIntArray.length;
            for (int i = 0; i < length; i++) {
                int i2 = stringToIntArray[i];
                if (stringToIntArray2[i] != 0) {
                    QHeartLineChartView.HeartDataBean heartDataBean = new QHeartLineChartView.HeartDataBean(i2 * queryHeartByDate.getIntervar(), stringToIntArray2[i], false, queryHeartByDate.getIntervar());
                    linkedHashMap.put(Integer.valueOf(heartDataBean.getMin()), heartDataBean);
                }
            }
        }
        if (queryByDate != null) {
            String content = queryByDate.getContent();
            JsonAdapter adapter = MoshiUtils.INSTANCE.getMoshiBuild().adapter(new TypeToken<List<? extends ManualHeartRate.DetailBean>>() { // from class: com.qcwireless.qcwatch.ui.base.repository.healthy.HeartRateDetailRepository$queryHeartDetail$$inlined$fromJson$1
            }.getType());
            Intrinsics.checkNotNullExpressionValue(adapter, "moshiBuild.adapter(objec…: TypeToken<T>() {}.type)");
            List<ManualHeartRate.DetailBean> list = (List) adapter.fromJson(content);
            if (list != null) {
                for (ManualHeartRate.DetailBean detailBean : list) {
                    if (detailBean.getV() != 0) {
                        QHeartLineChartView.HeartDataBean heartDataBean2 = new QHeartLineChartView.HeartDataBean(detailBean.getM(), detailBean.getV(), false, 0);
                        linkedHashMap.put(Integer.valueOf(heartDataBean2.getMin()), heartDataBean2);
                    }
                }
            }
        }
        ArrayList arrayList = new ArrayList(linkedHashMap.values());
        if (arrayList.size() > 1) {
            CollectionsKt.sortWith(arrayList, new Comparator() { // from class: com.qcwireless.qcwatch.ui.base.repository.healthy.HeartRateDetailRepository$queryHeartDetail$$inlined$sortBy$1
                /* JADX WARN: Multi-variable type inference failed */
                @Override // java.util.Comparator
                public final int compare(T t, T t2) {
                    return ComparisonsKt.compareValues(Integer.valueOf(((QHeartLineChartView.HeartDataBean) t).getMin()), Integer.valueOf(((QHeartLineChartView.HeartDataBean) t2).getMin()));
                }
            });
        }
        return arrayList;
    }

    public final List<HeartRateDetailBean> queryAppHeartRateByDateDetailResp(DateUtil date) {
        Intrinsics.checkNotNullParameter(date, "date");
        ArrayList arrayList = new ArrayList();
        QcAppManualHeartDao qcAppManualHeartDao = this.appManualHeartRateDao;
        String deviceAddressNoClear = UserConfig.INSTANCE.getInstance().getDeviceAddressNoClear();
        String y_m_d = date.getY_M_D();
        Intrinsics.checkNotNullExpressionValue(y_m_d, "date.y_M_D");
        Iterator<T> it = qcAppManualHeartDao.queryByDate(deviceAddressNoClear, y_m_d).iterator();
        while (it.hasNext()) {
            arrayList.add(new HeartRateDetailBean(r1.getTimestamp(), ((AppHeartEntity) it.next()).getHeart()));
        }
        return arrayList;
    }

    public final List<HeartRateDetailBean> queryHeartRateByDateDetailResp(DateUtil date) {
        Intrinsics.checkNotNullParameter(date, "date");
        ArrayList arrayList = new ArrayList();
        QcManualHeartDao qcManualHeartDao = this.manualHeartRateDao;
        String deviceAddressNoClear = UserConfig.INSTANCE.getInstance().getDeviceAddressNoClear();
        String y_m_d = date.getY_M_D();
        Intrinsics.checkNotNullExpressionValue(y_m_d, "date.y_M_D");
        ManualHeartEntity queryByDate = qcManualHeartDao.queryByDate(deviceAddressNoClear, y_m_d);
        if (queryByDate != null) {
            String content = queryByDate.getContent();
            JsonAdapter adapter = MoshiUtils.INSTANCE.getMoshiBuild().adapter(new TypeToken<List<? extends ManualHeartRate.DetailBean>>() { // from class: com.qcwireless.qcwatch.ui.base.repository.healthy.HeartRateDetailRepository$queryHeartRateByDateDetailResp$$inlined$fromJson$1
            }.getType());
            Intrinsics.checkNotNullExpressionValue(adapter, "moshiBuild.adapter(objec…: TypeToken<T>() {}.type)");
            List<ManualHeartRate.DetailBean> list = (List) adapter.fromJson(content);
            if (list != null) {
                int i = 0;
                for (ManualHeartRate.DetailBean detailBean : list) {
                    int i2 = i + 1;
                    if (detailBean.getV() != 0) {
                        if (i >= 1 && ((ManualHeartRate.DetailBean) list.get(i - 1)).getM() == ((ManualHeartRate.DetailBean) list.get(i)).getM()) {
                            arrayList.add(new HeartRateDetailBean(date.getZeroTime() + (detailBean.getM() * 60) + i, detailBean.getV()));
                        } else {
                            arrayList.add(new HeartRateDetailBean(date.getZeroTime() + (detailBean.getM() * 60), detailBean.getV()));
                        }
                    }
                    i = i2;
                }
            }
        }
        QcHeartRateDetailDao qcHeartRateDetailDao = this.heartRateDao;
        String deviceAddressNoClear2 = UserConfig.INSTANCE.getInstance().getDeviceAddressNoClear();
        String y_m_d2 = date.getY_M_D();
        Intrinsics.checkNotNullExpressionValue(y_m_d2, "date.y_M_D");
        HeartRateDetail queryHeartByDate = qcHeartRateDetailDao.queryHeartByDate(deviceAddressNoClear2, y_m_d2);
        if (queryHeartByDate != null) {
            int[] stringToIntArray = StringUtilsKt.stringToIntArray(queryHeartByDate.getIndex_str());
            int[] stringToIntArray2 = StringUtilsKt.stringToIntArray(queryHeartByDate.getValue());
            int length = stringToIntArray.length;
            for (int i3 = 0; i3 < length; i3++) {
                int i4 = stringToIntArray[i3];
                if (stringToIntArray2[i3] != 0) {
                    arrayList.add(new HeartRateDetailBean(date.getZeroTime() + (i4 * queryHeartByDate.getIntervar() * 60), stringToIntArray2[i3]));
                }
            }
        }
        if (arrayList.size() > 1) {
            CollectionsKt.sortWith(arrayList, new Comparator() { // from class: com.qcwireless.qcwatch.ui.base.repository.healthy.HeartRateDetailRepository$queryHeartRateByDateDetailResp$$inlined$sortByDescending$1
                /* JADX WARN: Multi-variable type inference failed */
                @Override // java.util.Comparator
                public final int compare(T t, T t2) {
                    return ComparisonsKt.compareValues(Long.valueOf(((HeartRateDetailBean) t2).getTimestamp()), Long.valueOf(((HeartRateDetailBean) t).getTimestamp()));
                }
            });
        }
        return arrayList;
    }

    public final void syncTodayHeartRate(DateUtil date, final BaseDeviceResult<ReadHeartRateRsp> result) {
        Intrinsics.checkNotNullParameter(date, "date");
        Intrinsics.checkNotNullParameter(result, "result");
        CommandHandle.getInstance().executeReqCmd(new ReadHeartRateReq(date.getUnixTimestamp() + ((int) (getTimeZone() * CacheConstants.HOUR))), new ICommandResponse() { // from class: com.qcwireless.qcwatch.ui.base.repository.healthy.HeartRateDetailRepository$$ExternalSyntheticLambda0
            @Override // com.oudmon.ble.base.communication.ICommandResponse
            public final void onDataResponse(BaseRspCmd baseRspCmd) {
                HeartRateDetailRepository.m295syncTodayHeartRate$lambda3(HeartRateDetailRepository.this, result, (ReadHeartRateRsp) baseRspCmd);
            }
        });
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* renamed from: syncTodayHeartRate$lambda-3, reason: not valid java name */
    public static final void m295syncTodayHeartRate$lambda3(HeartRateDetailRepository this$0, BaseDeviceResult result, ReadHeartRateRsp it) {
        Intrinsics.checkNotNullParameter(this$0, "this$0");
        Intrinsics.checkNotNullParameter(result, "$result");
        if (it.getStatus() == 0) {
            Intrinsics.checkNotNullExpressionValue(it, "it");
            this$0.saveHeartRateToday(it);
            if (it.isEndFlag()) {
                result.result(0, it);
                return;
            }
            return;
        }
        Intrinsics.checkNotNullExpressionValue(it, "it");
        result.result(-1, it);
    }

    public final void syncManualHeartRate(int offset, final ILargeDataManualHeartRateResponse listener) {
        Intrinsics.checkNotNullParameter(listener, "listener");
        LargeDataHandler.getInstance().syncManualHeartRateList(offset, new ILargeDataManualHeartRateResponse() { // from class: com.qcwireless.qcwatch.ui.base.repository.healthy.HeartRateDetailRepository$$ExternalSyntheticLambda2
            @Override // com.oudmon.ble.base.communication.bigData.resp.ILargeDataManualHeartRateResponse
            public final void manualHeart(ManualHeartRate manualHeartRate) {
                HeartRateDetailRepository.m294syncManualHeartRate$lambda4(ILargeDataManualHeartRateResponse.this, this, manualHeartRate);
            }
        });
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* renamed from: syncManualHeartRate$lambda-4, reason: not valid java name */
    public static final void m294syncManualHeartRate$lambda4(ILargeDataManualHeartRateResponse listener, HeartRateDetailRepository this$0, final ManualHeartRate manualHeartRate) {
        Intrinsics.checkNotNullParameter(listener, "$listener");
        Intrinsics.checkNotNullParameter(this$0, "this$0");
        listener.manualHeart(manualHeartRate);
        final DateUtil dateUtil = new DateUtil();
        dateUtil.addDay(-manualHeartRate.getIndex());
        ThreadExtKt.ktxRunOnBgSingle(this$0, new Function1<HeartRateDetailRepository, Unit>() { // from class: com.qcwireless.qcwatch.ui.base.repository.healthy.HeartRateDetailRepository$syncManualHeartRate$1$1
            /* JADX INFO: Access modifiers changed from: package-private */
            /* JADX WARN: 'super' call moved to the top of the method (can break code semantics) */
            {
                super(1);
            }

            @Override // kotlin.jvm.functions.Function1
            public /* bridge */ /* synthetic */ Unit invoke(HeartRateDetailRepository heartRateDetailRepository) {
                invoke2(heartRateDetailRepository);
                return Unit.INSTANCE;
            }

            /* renamed from: invoke, reason: avoid collision after fix types in other method */
            public final void invoke2(HeartRateDetailRepository ktxRunOnBgSingle) {
                QcManualHeartDao qcManualHeartDao;
                Intrinsics.checkNotNullParameter(ktxRunOnBgSingle, "$this$ktxRunOnBgSingle");
                String deviceAddressNoClear = UserConfig.INSTANCE.getInstance().getDeviceAddressNoClear();
                String y_m_d = DateUtil.this.getY_M_D();
                Intrinsics.checkNotNullExpressionValue(y_m_d, "date.y_M_D");
                List<ManualHeartRate.DetailBean> data = manualHeartRate.getData();
                Intrinsics.checkNotNullExpressionValue(data, "it.data");
                ManualHeartEntity manualHeartEntity = new ManualHeartEntity(deviceAddressNoClear, y_m_d, MoshiUtilsKt.toJson(data));
                qcManualHeartDao = ktxRunOnBgSingle.manualHeartRateDao;
                qcManualHeartDao.insert(manualHeartEntity);
            }
        });
    }

    public final void syncManualHeartRate(ILargeDataManualHeartRateResponse listener) {
        Intrinsics.checkNotNullParameter(listener, "listener");
        DateUtil dateUtil = new DateUtil();
        dateUtil.addDay(-1);
        QcManualHeartDao qcManualHeartDao = this.manualHeartRateDao;
        String deviceAddressNoClear = UserConfig.INSTANCE.getInstance().getDeviceAddressNoClear();
        String y_m_d = dateUtil.getY_M_D();
        Intrinsics.checkNotNullExpressionValue(y_m_d, "date.y_M_D");
        if (qcManualHeartDao.queryByDate(deviceAddressNoClear, y_m_d) == null) {
            syncManualHeartRate(255, listener);
        } else {
            syncManualHeartRate(0, listener);
        }
    }

    public final void saveManualHeartRate(final long dataTime, final int value) {
        ThreadExtKt.ktxRunOnBgSingleAnother(this, new Function1<HeartRateDetailRepository, Unit>() { // from class: com.qcwireless.qcwatch.ui.base.repository.healthy.HeartRateDetailRepository$saveManualHeartRate$1
            /* JADX INFO: Access modifiers changed from: package-private */
            /* JADX WARN: 'super' call moved to the top of the method (can break code semantics) */
            {
                super(1);
            }

            @Override // kotlin.jvm.functions.Function1
            public /* bridge */ /* synthetic */ Unit invoke(HeartRateDetailRepository heartRateDetailRepository) {
                invoke2(heartRateDetailRepository);
                return Unit.INSTANCE;
            }

            /* renamed from: invoke, reason: avoid collision after fix types in other method */
            public final void invoke2(HeartRateDetailRepository ktxRunOnBgSingleAnother) {
                QcAppManualHeartDao qcAppManualHeartDao;
                Intrinsics.checkNotNullParameter(ktxRunOnBgSingleAnother, "$this$ktxRunOnBgSingleAnother");
                DateUtil dateUtil = new DateUtil(dataTime, true);
                String deviceAddressNoClear = UserConfig.INSTANCE.getInstance().getDeviceAddressNoClear();
                String y_m_d = dateUtil.getY_M_D();
                Intrinsics.checkNotNullExpressionValue(y_m_d, "bean.y_M_D");
                AppHeartEntity appHeartEntity = new AppHeartEntity(deviceAddressNoClear, y_m_d, (int) dataTime, value);
                qcAppManualHeartDao = ktxRunOnBgSingleAnother.appManualHeartRateDao;
                qcAppManualHeartDao.insert(appHeartEntity);
                EventBus.getDefault().post(new ManualRefreshEvent());
            }
        });
    }

    public final AppHeartEntity queryLastAppHeartManual() {
        return this.appManualHeartRateDao.queryDataDate(UserConfig.INSTANCE.getInstance().getDeviceAddressNoClear());
    }

    /* JADX INFO: Access modifiers changed from: private */
    public final void syncHeartRateDetail(final String key, long time, final BaseDeviceResult<ReadHeartRateRsp> result) {
        this.historyDate.remove(key);
        CommandHandle.getInstance().executeReqCmd(new ReadHeartRateReq(time), new ICommandResponse() { // from class: com.qcwireless.qcwatch.ui.base.repository.healthy.HeartRateDetailRepository$$ExternalSyntheticLambda1
            @Override // com.oudmon.ble.base.communication.ICommandResponse
            public final void onDataResponse(BaseRspCmd baseRspCmd) {
                HeartRateDetailRepository.m293syncHeartRateDetail$lambda5(HeartRateDetailRepository.this, key, result, (ReadHeartRateRsp) baseRspCmd);
            }
        });
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* renamed from: syncHeartRateDetail$lambda-5, reason: not valid java name */
    public static final void m293syncHeartRateDetail$lambda5(HeartRateDetailRepository this$0, String key, BaseDeviceResult result, ReadHeartRateRsp it) {
        Intrinsics.checkNotNullParameter(this$0, "this$0");
        Intrinsics.checkNotNullParameter(key, "$key");
        Intrinsics.checkNotNullParameter(result, "$result");
        if (it.getStatus() == 0) {
            int i = it.getmUtcTime();
            this$0.historyDate.remove(new DateUtil(i, true).getY_M_D());
            if (i == 0) {
                this$0.historyDate.remove(key);
            }
            Intrinsics.checkNotNullExpressionValue(it, "it");
            this$0.saveHeartRate(it);
            if (!this$0.historyDate.isEmpty()) {
                Iterator<Map.Entry<String, Integer>> it2 = this$0.historyDate.entrySet().iterator();
                if (it2.hasNext()) {
                    Map.Entry<String, Integer> next = it2.next();
                    Intrinsics.checkNotNullExpressionValue(next, "iterator.next()");
                    String key2 = next.getKey();
                    Intrinsics.checkNotNullExpressionValue(key2, "bean.key");
                    this$0.syncHeartRateDetail(key2, r7.getValue().intValue(), result);
                    return;
                }
                return;
            }
            result.result(0, it);
            return;
        }
        Intrinsics.checkNotNullExpressionValue(it, "it");
        result.result(-1, it);
    }

    public final Object syncHistoryHeartDetail(String str, final BaseDeviceResult<ReadHeartRateRsp> baseDeviceResult, Continuation<? super Unit> continuation) {
        if (!BleOperateManager.getInstance().isConnected()) {
            return Unit.INSTANCE;
        }
        Object collect = FlowKt.m2572catch(FlowKt.flowOn(FlowKt.flow(new HeartRateDetailRepository$syncHistoryHeartDetail$2(this, str, null)), Dispatchers.getIO()), new HeartRateDetailRepository$syncHistoryHeartDetail$3(this, null)).collect(new FlowCollector() { // from class: com.qcwireless.qcwatch.ui.base.repository.healthy.HeartRateDetailRepository$syncHistoryHeartDetail$4
            @Override // kotlinx.coroutines.flow.FlowCollector
            public /* bridge */ /* synthetic */ Object emit(Object obj, Continuation continuation2) {
                return emit((Map<String, Integer>) obj, (Continuation<? super Unit>) continuation2);
            }

            public final Object emit(Map<String, Integer> map, Continuation<? super Unit> continuation2) {
                ConcurrentHashMap concurrentHashMap;
                concurrentHashMap = HeartRateDetailRepository.this.historyDate;
                Iterator it = concurrentHashMap.entrySet().iterator();
                if (it.hasNext()) {
                    Object next = it.next();
                    Intrinsics.checkNotNullExpressionValue(next, "iterator.next()");
                    HeartRateDetailRepository heartRateDetailRepository = HeartRateDetailRepository.this;
                    Object key = ((Map.Entry) next).getKey();
                    Intrinsics.checkNotNullExpressionValue(key, "bean.key");
                    heartRateDetailRepository.syncHeartRateDetail((String) key, ((Number) r4.getValue()).intValue(), baseDeviceResult);
                } else {
                    baseDeviceResult.result(0, new ReadHeartRateRsp());
                }
                return Unit.INSTANCE;
            }
        }, continuation);
        return collect == IntrinsicsKt.getCOROUTINE_SUSPENDED() ? collect : Unit.INSTANCE;
    }

    private final void saveHeartRate(final ReadHeartRateRsp heartResp) {
        ThreadExtKt.ktxRunOnBgSingle(this, new Function1<HeartRateDetailRepository, Unit>() { // from class: com.qcwireless.qcwatch.ui.base.repository.healthy.HeartRateDetailRepository$saveHeartRate$1
            /* JADX INFO: Access modifiers changed from: package-private */
            {
                super(1);
            }

            @Override // kotlin.jvm.functions.Function1
            public /* bridge */ /* synthetic */ Unit invoke(HeartRateDetailRepository heartRateDetailRepository) {
                invoke2(heartRateDetailRepository);
                return Unit.INSTANCE;
            }

            /* renamed from: invoke, reason: avoid collision after fix types in other method */
            public final void invoke2(HeartRateDetailRepository ktxRunOnBgSingle) {
                QcHeartRateDetailDao qcHeartRateDetailDao;
                Intrinsics.checkNotNullParameter(ktxRunOnBgSingle, "$this$ktxRunOnBgSingle");
                DateUtil dateUtil = new DateUtil(ReadHeartRateRsp.this.getmUtcTime(), true);
                StringBuilder sb = new StringBuilder();
                StringBuilder sb2 = new StringBuilder();
                byte[] bArr = ReadHeartRateRsp.this.getmHeartRateArray();
                int length = bArr.length;
                for (int i = 0; i < length; i++) {
                    sb.append(i);
                    sb.append(",");
                    int i2 = bArr[i];
                    if (i2 < 0) {
                        i2 = ByteUtil.byteToInt(bArr[i]);
                    }
                    sb2.append(i2);
                    sb2.append(",");
                }
                if (sb.length() > 0) {
                    sb.deleteCharAt(sb.length() - 1);
                    sb2.deleteCharAt(sb2.length() - 1);
                }
                String deviceAddressNoClear = UserConfig.INSTANCE.getInstance().getDeviceAddressNoClear();
                String y_m_d = dateUtil.getY_M_D();
                Intrinsics.checkNotNullExpressionValue(y_m_d, "dateStr.y_M_D");
                int range = ReadHeartRateRsp.this.getRange();
                String sb3 = sb.toString();
                Intrinsics.checkNotNullExpressionValue(sb3, "indexStr.toString()");
                String sb4 = sb2.toString();
                Intrinsics.checkNotNullExpressionValue(sb4, "values.toString()");
                HeartRateDetail heartRateDetail = new HeartRateDetail(deviceAddressNoClear, y_m_d, range, sb3, sb4, dateUtil.getZeroTime(), false, new DateUtil().getUnixTimestamp());
                if (dateUtil.getZeroTime() > 0) {
                    qcHeartRateDetailDao = ktxRunOnBgSingle.heartRateDao;
                    qcHeartRateDetailDao.insert(heartRateDetail);
                }
            }
        });
    }

    private final void saveHeartRateToday(final ReadHeartRateRsp heartResp) {
        ThreadExtKt.ktxRunOnBgSingle(this, new Function1<HeartRateDetailRepository, Unit>() { // from class: com.qcwireless.qcwatch.ui.base.repository.healthy.HeartRateDetailRepository$saveHeartRateToday$1
            /* JADX INFO: Access modifiers changed from: package-private */
            {
                super(1);
            }

            @Override // kotlin.jvm.functions.Function1
            public /* bridge */ /* synthetic */ Unit invoke(HeartRateDetailRepository heartRateDetailRepository) {
                invoke2(heartRateDetailRepository);
                return Unit.INSTANCE;
            }

            /* renamed from: invoke, reason: avoid collision after fix types in other method */
            public final void invoke2(HeartRateDetailRepository ktxRunOnBgSingle) {
                QcHeartRateDetailDao qcHeartRateDetailDao;
                QcHeartRateDetailDao qcHeartRateDetailDao2;
                Intrinsics.checkNotNullParameter(ktxRunOnBgSingle, "$this$ktxRunOnBgSingle");
                DateUtil dateUtil = new DateUtil(ReadHeartRateRsp.this.getmUtcTime(), true);
                StringBuilder sb = new StringBuilder();
                StringBuilder sb2 = new StringBuilder();
                byte[] bArr = ReadHeartRateRsp.this.getmHeartRateArray();
                int length = bArr.length;
                for (int i = 0; i < length; i++) {
                    sb.append(i);
                    sb.append(",");
                    int i2 = bArr[i];
                    if (i2 < 0) {
                        i2 = ByteUtil.byteToInt(bArr[i]);
                    }
                    sb2.append(i2);
                    sb2.append(",");
                }
                if (sb.length() > 0) {
                    sb.deleteCharAt(sb.length() - 1);
                    sb2.deleteCharAt(sb2.length() - 1);
                }
                String deviceAddressNoClear = UserConfig.INSTANCE.getInstance().getDeviceAddressNoClear();
                String y_m_d = dateUtil.getY_M_D();
                Intrinsics.checkNotNullExpressionValue(y_m_d, "dateStr.y_M_D");
                int range = ReadHeartRateRsp.this.getRange();
                String sb3 = sb.toString();
                Intrinsics.checkNotNullExpressionValue(sb3, "indexStr.toString()");
                String sb4 = sb2.toString();
                Intrinsics.checkNotNullExpressionValue(sb4, "values.toString()");
                HeartRateDetail heartRateDetail = new HeartRateDetail(deviceAddressNoClear, y_m_d, range, sb3, sb4, dateUtil.getZeroTime(), false, new DateUtil().getUnixTimestamp());
                if (dateUtil.getZeroTime() > 0) {
                    qcHeartRateDetailDao2 = ktxRunOnBgSingle.heartRateDao;
                    qcHeartRateDetailDao2.insert(heartRateDetail);
                    return;
                }
                qcHeartRateDetailDao = ktxRunOnBgSingle.heartRateDao;
                String deviceAddressNoClear2 = UserConfig.INSTANCE.getInstance().getDeviceAddressNoClear();
                String y_m_d2 = new DateUtil().getY_M_D();
                Intrinsics.checkNotNullExpressionValue(y_m_d2, "DateUtil().y_M_D");
                qcHeartRateDetailDao.delete(new HeartRateDetail(deviceAddressNoClear2, y_m_d2, ReadHeartRateRsp.this.getRange(), "", "", new DateUtil().getZeroTime(), false, new DateUtil().getUnixTimestamp()));
            }
        });
    }

    public final HeartRateDetail queryLastData() {
        return this.heartRateDao.queryLastSyncDate(UserConfig.INSTANCE.getInstance().getDeviceAddressNoClear());
    }

    public final List<QHeartLineChartView.HeartDataBean> queryLastHeartDetail() {
        LinkedHashMap linkedHashMap = new LinkedHashMap();
        HeartRateDetail queryLastSyncDate = this.heartRateDao.queryLastSyncDate(UserConfig.INSTANCE.getInstance().getDeviceAddressNoClear());
        ManualHeartEntity queryDataDate = this.manualHeartRateDao.queryDataDate(UserConfig.INSTANCE.getInstance().getDeviceAddressNoClear());
        long zeroTime = (queryDataDate == null || queryDataDate.getContent().length() <= 2) ? 0L : DateUtil.parse(queryDataDate.getDateStr(), DateUtil.DateFormater.dFyyyyMMdd).getZeroTime();
        long zeroTime2 = queryLastSyncDate != null ? new DateUtil(queryLastSyncDate.getUnixTime(), true).getZeroTime() : 0L;
        if (zeroTime2 == zeroTime) {
            if (queryLastSyncDate != null) {
                int[] stringToIntArray = StringUtilsKt.stringToIntArray(queryLastSyncDate.getIndex_str());
                int[] stringToIntArray2 = StringUtilsKt.stringToIntArray(queryLastSyncDate.getValue());
                int length = stringToIntArray.length;
                for (int i = 0; i < length; i++) {
                    int i2 = stringToIntArray[i];
                    if (stringToIntArray2[i] != 0) {
                        QHeartLineChartView.HeartDataBean heartDataBean = new QHeartLineChartView.HeartDataBean(i2 * queryLastSyncDate.getIntervar(), stringToIntArray2[i], false, queryLastSyncDate.getIntervar());
                        heartDataBean.setUnixTime(queryLastSyncDate.getUnixTime());
                        linkedHashMap.put(Integer.valueOf(heartDataBean.getMin()), heartDataBean);
                    }
                }
            }
            if (queryDataDate != null) {
                String content = queryDataDate.getContent();
                JsonAdapter adapter = MoshiUtils.INSTANCE.getMoshiBuild().adapter(new TypeToken<List<? extends ManualHeartRate.DetailBean>>() { // from class: com.qcwireless.qcwatch.ui.base.repository.healthy.HeartRateDetailRepository$queryLastHeartDetail$$inlined$fromJson$1
                }.getType());
                Intrinsics.checkNotNullExpressionValue(adapter, "moshiBuild.adapter(objec…: TypeToken<T>() {}.type)");
                List<ManualHeartRate.DetailBean> list = (List) adapter.fromJson(content);
                if (list != null) {
                    for (ManualHeartRate.DetailBean detailBean : list) {
                        if (detailBean.getV() != 0) {
                            QHeartLineChartView.HeartDataBean heartDataBean2 = new QHeartLineChartView.HeartDataBean(detailBean.getM(), detailBean.getV(), false, 0);
                            heartDataBean2.setUnixTime(DateUtil.parse(queryDataDate.getDateStr(), DateUtil.DateFormater.dFyyyyMMdd).getUnixTimestamp());
                            linkedHashMap.put(Integer.valueOf(heartDataBean2.getMin()), heartDataBean2);
                        }
                    }
                }
            }
        } else if (zeroTime2 > zeroTime) {
            if (queryLastSyncDate != null) {
                int[] stringToIntArray3 = StringUtilsKt.stringToIntArray(queryLastSyncDate.getIndex_str());
                int[] stringToIntArray4 = StringUtilsKt.stringToIntArray(queryLastSyncDate.getValue());
                int length2 = stringToIntArray3.length;
                for (int i3 = 0; i3 < length2; i3++) {
                    int i4 = stringToIntArray3[i3];
                    if (stringToIntArray4[i3] != 0) {
                        QHeartLineChartView.HeartDataBean heartDataBean3 = new QHeartLineChartView.HeartDataBean(i4 * queryLastSyncDate.getIntervar(), stringToIntArray4[i3], false, queryLastSyncDate.getIntervar());
                        heartDataBean3.setUnixTime(queryLastSyncDate.getUnixTime());
                        linkedHashMap.put(Integer.valueOf(heartDataBean3.getMin()), heartDataBean3);
                    }
                }
            }
        } else if (queryDataDate != null) {
            String content2 = queryDataDate.getContent();
            JsonAdapter adapter2 = MoshiUtils.INSTANCE.getMoshiBuild().adapter(new TypeToken<List<? extends ManualHeartRate.DetailBean>>() { // from class: com.qcwireless.qcwatch.ui.base.repository.healthy.HeartRateDetailRepository$queryLastHeartDetail$$inlined$fromJson$2
            }.getType());
            Intrinsics.checkNotNullExpressionValue(adapter2, "moshiBuild.adapter(objec…: TypeToken<T>() {}.type)");
            List<ManualHeartRate.DetailBean> list2 = (List) adapter2.fromJson(content2);
            if (list2 != null) {
                int i5 = 0;
                for (ManualHeartRate.DetailBean detailBean2 : list2) {
                    int i6 = i5 + 1;
                    if (detailBean2.getV() != 0 && (i5 < 1 || ((ManualHeartRate.DetailBean) list2.get(i5 - 1)).getM() != ((ManualHeartRate.DetailBean) list2.get(i5)).getM())) {
                        QHeartLineChartView.HeartDataBean heartDataBean4 = new QHeartLineChartView.HeartDataBean(detailBean2.getM(), detailBean2.getV(), false, 0);
                        heartDataBean4.setUnixTime(DateUtil.parse(queryDataDate.getDateStr(), DateUtil.DateFormater.dFyyyyMMdd).getUnixTimestamp());
                        linkedHashMap.put(Integer.valueOf(heartDataBean4.getMin()), heartDataBean4);
                    }
                    i5 = i6;
                }
            }
        }
        ArrayList arrayList = new ArrayList(linkedHashMap.values());
        if (arrayList.size() > 1) {
            CollectionsKt.sortWith(arrayList, new Comparator() { // from class: com.qcwireless.qcwatch.ui.base.repository.healthy.HeartRateDetailRepository$queryLastHeartDetail$$inlined$sortBy$1
                /* JADX WARN: Multi-variable type inference failed */
                @Override // java.util.Comparator
                public final int compare(T t, T t2) {
                    return ComparisonsKt.compareValues(Integer.valueOf(((QHeartLineChartView.HeartDataBean) t).getMin()), Integer.valueOf(((QHeartLineChartView.HeartDataBean) t2).getMin()));
                }
            });
        }
        return arrayList;
    }

    /* JADX INFO: Access modifiers changed from: private */
    public final float getTimeZone() {
        return TimeZone.getDefault().getOffset(System.currentTimeMillis()) / 3600000.0f;
    }

    public final Object updateHeartRateDetailToServer(Continuation<? super Flow<NetState<Integer>>> continuation) {
        return FlowKt.m2572catch(FlowKt.flowOn(FlowKt.onStart(FlowKt.flow(new HeartRateDetailRepository$updateHeartRateDetailToServer$2(this, null)), new HeartRateDetailRepository$updateHeartRateDetailToServer$3(null)), Dispatchers.getIO()), new HeartRateDetailRepository$updateHeartRateDetailToServer$4(null));
    }

    public final Object downHeartRateDetailFromServer(long j, long j2, Continuation<? super Unit> continuation) {
        Object collect = FlowKt.m2572catch(FlowKt.flowOn(FlowKt.onStart(FlowKt.flow(new HeartRateDetailRepository$downHeartRateDetailFromServer$2(j, j2, null)), new HeartRateDetailRepository$downHeartRateDetailFromServer$3(null)), Dispatchers.getIO()), new HeartRateDetailRepository$downHeartRateDetailFromServer$4(null)).collect(new FlowCollector() { // from class: com.qcwireless.qcwatch.ui.base.repository.healthy.HeartRateDetailRepository$downHeartRateDetailFromServer$5
            @Override // kotlinx.coroutines.flow.FlowCollector
            public /* bridge */ /* synthetic */ Object emit(Object obj, Continuation continuation2) {
                return emit((NetState<List<HeartRateResp>>) obj, (Continuation<? super Unit>) continuation2);
            }

            public final Object emit(NetState<List<HeartRateResp>> netState, Continuation<? super Unit> continuation2) {
                List<HeartRateResp> isSuccess;
                QcHeartRateDetailDao qcHeartRateDetailDao;
                if (netState.getRetCode() == 0 && (isSuccess = netState.isSuccess()) != null) {
                    try {
                        for (HeartRateResp heartRateResp : isSuccess) {
                            String deviceId = heartRateResp.getDeviceId();
                            Intrinsics.checkNotNull(deviceId);
                            String date = heartRateResp.getDate();
                            Intrinsics.checkNotNull(date);
                            int interval = heartRateResp.getInterval() / 60;
                            HeartRateResp.HeartDetail data = heartRateResp.getData();
                            Intrinsics.checkNotNull(data);
                            String intListToString = StringUtilsKt.intListToString(data.getIndexs());
                            HeartRateResp.HeartDetail data2 = heartRateResp.getData();
                            Intrinsics.checkNotNull(data2);
                            String intListToString2 = StringUtilsKt.intListToString(data2.getValues());
                            String date2 = heartRateResp.getDate();
                            Intrinsics.checkNotNull(date2);
                            HeartRateDetail heartRateDetail = new HeartRateDetail(deviceId, date, interval, intListToString, intListToString2, new DateUtil(DateUtil.dateY_M_D2Stamp(date2), false).getZeroTime(), true, 0L);
                            qcHeartRateDetailDao = HeartRateDetailRepository.this.heartRateDao;
                            qcHeartRateDetailDao.insert(heartRateDetail);
                        }
                    } catch (Exception e) {
                        e.printStackTrace();
                    }
                }
                return Unit.INSTANCE;
            }
        }, continuation);
        return collect == IntrinsicsKt.getCOROUTINE_SUSPENDED() ? collect : Unit.INSTANCE;
    }

    public final List<AppHeartEntity> queryManualAppHeart(DateUtil date) {
        Intrinsics.checkNotNullParameter(date, "date");
        QcAppManualHeartDao qcAppManualHeartDao = this.appManualHeartRateDao;
        String deviceAddressNoClear = UserConfig.INSTANCE.getInstance().getDeviceAddressNoClear();
        String y_m_d = date.getY_M_D();
        Intrinsics.checkNotNullExpressionValue(y_m_d, "date.y_M_D");
        return qcAppManualHeartDao.queryDataLimit(deviceAddressNoClear, y_m_d);
    }

    public final void deleteData() {
        ThreadExtKt.ktxRunOnBgSingleAnother(this, new Function1<HeartRateDetailRepository, Unit>() { // from class: com.qcwireless.qcwatch.ui.base.repository.healthy.HeartRateDetailRepository$deleteData$1
            @Override // kotlin.jvm.functions.Function1
            public /* bridge */ /* synthetic */ Unit invoke(HeartRateDetailRepository heartRateDetailRepository) {
                invoke2(heartRateDetailRepository);
                return Unit.INSTANCE;
            }

            /* renamed from: invoke, reason: avoid collision after fix types in other method */
            public final void invoke2(HeartRateDetailRepository ktxRunOnBgSingleAnother) {
                QcAppManualHeartDao qcAppManualHeartDao;
                QcAppManualHeartDao qcAppManualHeartDao2;
                Intrinsics.checkNotNullParameter(ktxRunOnBgSingleAnother, "$this$ktxRunOnBgSingleAnother");
                qcAppManualHeartDao = ktxRunOnBgSingleAnother.appManualHeartRateDao;
                String deviceAddressNoClear = UserConfig.INSTANCE.getInstance().getDeviceAddressNoClear();
                String y_m_d = new DateUtil().getY_M_D();
                Intrinsics.checkNotNullExpressionValue(y_m_d, "DateUtil().y_M_D");
                List<AppHeartEntity> queryByDate = qcAppManualHeartDao.queryByDate(deviceAddressNoClear, y_m_d);
                if (!queryByDate.isEmpty()) {
                    qcAppManualHeartDao2 = ktxRunOnBgSingleAnother.appManualHeartRateDao;
                    qcAppManualHeartDao2.deleteList(TypeIntrinsics.asMutableList(queryByDate));
                }
            }
        });
    }

    public final AppHeartEntity queryAppHeartLast(DateUtil date) {
        Intrinsics.checkNotNullParameter(date, "date");
        QcAppManualHeartDao qcAppManualHeartDao = this.appManualHeartRateDao;
        String deviceAddressNoClear = UserConfig.INSTANCE.getInstance().getDeviceAddressNoClear();
        String y_m_d = date.getY_M_D();
        Intrinsics.checkNotNullExpressionValue(y_m_d, "date.y_M_D");
        return qcAppManualHeartDao.queryLastData(deviceAddressNoClear, y_m_d);
    }

    public final AppHeartEntity queryAppHeartLast() {
        return this.appManualHeartRateDao.queryDataDate(UserConfig.INSTANCE.getInstance().getDeviceAddressNoClear());
    }

    public final List<QHeartLineChartView.HeartDataBean> queryHeartRateDetailByDate(String date) {
        Intrinsics.checkNotNullParameter(date, "date");
        HeartRateDetail queryHeartByDate = this.heartRateDao.queryHeartByDate(UserConfig.INSTANCE.getInstance().getDeviceAddressNoClear(), date);
        ArrayList arrayList = new ArrayList();
        if (queryHeartByDate != null) {
            int[] stringToIntArray = StringUtilsKt.stringToIntArray(queryHeartByDate.getIndex_str());
            int[] stringToIntArray2 = StringUtilsKt.stringToIntArray(queryHeartByDate.getValue());
            int length = stringToIntArray.length;
            for (int i = 0; i < length; i++) {
                int i2 = stringToIntArray[i];
                if (stringToIntArray2[i] != 0) {
                    arrayList.add(new QHeartLineChartView.HeartDataBean(i2 * queryHeartByDate.getIntervar(), stringToIntArray2[i], false, queryHeartByDate.getIntervar()));
                }
            }
        }
        return arrayList;
    }

    public final Map<String, Calendar> calendarHeartDetail(int year, int month) {
        LinkedHashMap linkedHashMap = new LinkedHashMap();
        DateUtil dateUtil = new DateUtil(year, month, 1);
        for (int i = 1; i < 32; i++) {
            QcHeartRateDetailDao qcHeartRateDetailDao = this.heartRateDao;
            String deviceAddressNoClear = UserConfig.INSTANCE.getInstance().getDeviceAddressNoClear();
            String y_m_d = dateUtil.getY_M_D();
            Intrinsics.checkNotNullExpressionValue(y_m_d, "monthDate.y_M_D");
            if (qcHeartRateDetailDao.queryHeartByDate(deviceAddressNoClear, y_m_d) != null) {
                String calendar = getSchemeCalendar(dateUtil.getYear(), dateUtil.getMonth(), dateUtil.getDay(), "").toString();
                Intrinsics.checkNotNullExpressionValue(calendar, "getSchemeCalendar(monthD…           \"\").toString()");
                linkedHashMap.put(calendar, getSchemeCalendar(dateUtil.getYear(), dateUtil.getMonth(), dateUtil.getDay(), ""));
            }
            dateUtil.addDay(1);
        }
        return linkedHashMap;
    }

    private final Calendar getSchemeCalendar(int year, int month, int day, String text) {
        Calendar calendar = new Calendar();
        calendar.setYear(year);
        calendar.setMonth(month);
        calendar.setDay(day);
        calendar.setSchemeColor(SupportMenu.CATEGORY_MASK);
        calendar.setScheme(text);
        return calendar;
    }

    /* compiled from: HeartRateDetailRepository.kt */
    @Metadata(d1 = {"\u0000\u0014\n\u0002\u0018\u0002\n\u0002\u0010\u0000\n\u0002\b\u0002\n\u0002\u0018\u0002\n\u0002\b\u0005\b\u0086\u0003\u0018\u00002\u00020\u0001B\u0007\b\u0002¢\u0006\u0002\u0010\u0002R\u001b\u0010\u0003\u001a\u00020\u00048FX\u0086\u0084\u0002¢\u0006\f\n\u0004\b\u0007\u0010\b\u001a\u0004\b\u0005\u0010\u0006¨\u0006\t"}, d2 = {"Lcom/qcwireless/qcwatch/ui/base/repository/healthy/HeartRateDetailRepository$Companion;", "", "()V", "getInstance", "Lcom/qcwireless/qcwatch/ui/base/repository/healthy/HeartRateDetailRepository;", "getGetInstance", "()Lcom/qcwireless/qcwatch/ui/base/repository/healthy/HeartRateDetailRepository;", "getInstance$delegate", "Lkotlin/Lazy;", "app_championRelease"}, k = 1, mv = {1, 6, 0}, xi = 48)
    /* loaded from: classes2.dex */
    public static final class Companion {
        public /* synthetic */ Companion(DefaultConstructorMarker defaultConstructorMarker) {
            this();
        }

        private Companion() {
        }

        public final HeartRateDetailRepository getGetInstance() {
            return (HeartRateDetailRepository) HeartRateDetailRepository.getInstance$delegate.getValue();
        }
    }
}
