package com.qcwireless.qcwatch.ui.base.repository.healthy;

import android.util.SparseIntArray;
import androidx.constraintlayout.core.motion.utils.TypedValues;
import androidx.core.internal.view.SupportMenu;
import com.haibin.calendarview.Calendar;
import com.oudmon.ble.base.bluetooth.BleOperateManager;
import com.oudmon.ble.base.communication.CommandHandle;
import com.oudmon.ble.base.communication.ICommandResponse;
import com.oudmon.ble.base.communication.ILargeDataSleepResponse;
import com.oudmon.ble.base.communication.LargeDataHandler;
import com.oudmon.ble.base.communication.entity.BleSleepDetails;
import com.oudmon.ble.base.communication.req.ReadSleepDetailsReq;
import com.oudmon.ble.base.communication.rsp.BaseRspCmd;
import com.oudmon.ble.base.communication.rsp.ReadSleepDetailsRsp;
import com.oudmon.ble.base.communication.rsp.SleepNewProtoResp;
import com.qcwireless.qc_utils.date.DateUtil;
import com.qcwireless.qcwatch.QCApplication;
import com.qcwireless.qcwatch.base.ktx.ThreadExtKt;
import com.qcwireless.qcwatch.base.pref.UserConfig;
import com.qcwireless.qcwatch.base.utils.MoshiUtils;
import com.qcwireless.qcwatch.base.utils.MoshiUtilsKt;
import com.qcwireless.qcwatch.base.utils.TypeToken;
import com.qcwireless.qcwatch.ui.base.bean.response.healthy.SleepDetailNewProtocolResp;
import com.qcwireless.qcwatch.ui.base.bean.response.healthy.SleepDetailResp;
import com.qcwireless.qcwatch.ui.base.repository.base.BaseDeviceResult;
import com.qcwireless.qcwatch.ui.base.repository.dao.QcDatabase;
import com.qcwireless.qcwatch.ui.base.repository.dao.QcSleepDetailDao;
import com.qcwireless.qcwatch.ui.base.repository.dao.QcSleepNewProtocolDao;
import com.qcwireless.qcwatch.ui.base.repository.dao.QcSleepTotalDao;
import com.qcwireless.qcwatch.ui.base.repository.entity.SleepDetail;
import com.qcwireless.qcwatch.ui.base.repository.entity.SleepNewProtocol;
import com.qcwireless.qcwatch.ui.base.repository.entity.SleepTotalHistory;
import com.qcwireless.qcwatch.ui.base.repository.mine.NetState;
import com.qcwireless.qcwatch.ui.base.util.MapUtils;
import com.qcwireless.qcwatch.ui.base.util.StringUtilsKt;
import com.qcwireless.qcwatch.ui.base.view.QHeartLineChartView;
import com.qcwireless.qcwatch.ui.base.view.QHrvLineChartView;
import com.qcwireless.qcwatch.ui.base.view.QSleepBarChart;
import com.qcwireless.qcwatch.ui.base.view.QSleepMonthBarView;
import com.qcwireless.qcwatch.ui.base.view.QSleepWeekBarView;
import com.qcwireless.qcwatch.ui.home.bloodoxgen.bean.BloodOxyDetailBean;
import com.qcwireless.qcwatch.ui.home.sleep.bean.SleepViewBean;
import com.qcwireless.qcwatch.ui.home.sleep.day.DaySleepFragmentViewModel;
import com.squareup.moshi.JsonAdapter;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Date;
import java.util.Iterator;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;
import kotlin.Lazy;
import kotlin.LazyKt;
import kotlin.LazyThreadSafetyMode;
import kotlin.Metadata;
import kotlin.Unit;
import kotlin.coroutines.Continuation;
import kotlin.coroutines.intrinsics.IntrinsicsKt;
import kotlin.coroutines.jvm.internal.Boxing;
import kotlin.jvm.functions.Function0;
import kotlin.jvm.functions.Function1;
import kotlin.jvm.internal.DefaultConstructorMarker;
import kotlin.jvm.internal.Intrinsics;
import kotlin.math.MathKt;
import kotlinx.coroutines.Dispatchers;
import kotlinx.coroutines.flow.Flow;
import kotlinx.coroutines.flow.FlowCollector;
import kotlinx.coroutines.flow.FlowKt;

/* compiled from: SleepDetailRepository.kt */
@Metadata(d1 = {"\u0000°\u0001\n\u0002\u0018\u0002\n\u0002\u0010\u0000\n\u0002\b\u0002\n\u0002\u0010%\n\u0002\u0010\u000e\n\u0002\u0010\b\n\u0000\n\u0002\u0018\u0002\n\u0000\n\u0002\u0018\u0002\n\u0000\n\u0002\u0018\u0002\n\u0000\n\u0002\u0018\u0002\n\u0000\n\u0002\u0018\u0002\n\u0002\b\u0002\n\u0002\u0010$\n\u0002\u0018\u0002\n\u0002\b\u0003\n\u0002\u0010\u0002\n\u0002\b\u0002\n\u0002\u0010\t\n\u0002\b\u000b\n\u0002\u0018\u0002\n\u0002\b\u0004\n\u0002\u0018\u0002\n\u0002\b\u0002\n\u0002\u0018\u0002\n\u0002\b\u0003\n\u0002\u0010 \n\u0002\u0018\u0002\n\u0002\b\u0004\n\u0002\u0018\u0002\n\u0000\n\u0002\u0018\u0002\n\u0002\b\u0005\n\u0002\u0018\u0002\n\u0000\n\u0002\u0018\u0002\n\u0002\b\u0004\n\u0002\u0018\u0002\n\u0002\b\u000b\n\u0002\u0018\u0002\n\u0000\n\u0002\u0018\u0002\n\u0002\u0018\u0002\n\u0002\b\t\u0018\u0000 _2\u00020\u0001:\u0001_B\u0005¢\u0006\u0002\u0010\u0002J\u0016\u0010\r\u001a\u00020\u000e2\u0006\u0010\u000f\u001a\u00020\u00102\u0006\u0010\u0011\u001a\u00020\u0010J\"\u0010\u0012\u001a\u000e\u0012\u0004\u0012\u00020\u0005\u0012\u0004\u0012\u00020\u00140\u00132\u0006\u0010\u0015\u001a\u00020\u00062\u0006\u0010\u0016\u001a\u00020\u0006J\b\u0010\u0017\u001a\u00020\u0018H\u0002J!\u0010\u0019\u001a\u00020\u00182\u0006\u0010\u001a\u001a\u00020\u001b2\u0006\u0010\u001c\u001a\u00020\u001bH\u0086@ø\u0001\u0000¢\u0006\u0002\u0010\u001dJ!\u0010\u001e\u001a\u00020\u00182\u0006\u0010\u001a\u001a\u00020\u001b2\u0006\u0010\u001c\u001a\u00020\u001bH\u0086@ø\u0001\u0000¢\u0006\u0002\u0010\u001dJ(\u0010\u001f\u001a\u00020\u00142\u0006\u0010\u0015\u001a\u00020\u00062\u0006\u0010\u0016\u001a\u00020\u00062\u0006\u0010 \u001a\u00020\u00062\u0006\u0010!\u001a\u00020\u0005H\u0002J\u0018\u0010\"\u001a\u00020\u00102\u0006\u0010#\u001a\u00020\u00102\u0006\u0010$\u001a\u00020\u0010H\u0002J\u0010\u0010%\u001a\u00020\u00182\u0006\u0010&\u001a\u00020'H\u0002J\u0018\u0010(\u001a\u00020\u00182\u0006\u0010&\u001a\u00020'2\u0006\u0010)\u001a\u00020\u0006H\u0002J\b\u0010*\u001a\u0004\u0018\u00010\u0010J\b\u0010+\u001a\u0004\u0018\u00010,J\u0016\u0010-\u001a\u00020\u00182\u0006\u0010.\u001a\u00020/2\u0006\u00100\u001a\u00020\u001bJ\u0010\u00101\u001a\u0004\u0018\u00010\u00102\u0006\u0010.\u001a\u00020\u0005J\u0014\u00102\u001a\b\u0012\u0004\u0012\u000204032\u0006\u00105\u001a\u00020/J\u000e\u00106\u001a\u00020\u000e2\u0006\u00107\u001a\u00020/J\u0010\u00108\u001a\u0004\u0018\u0001092\u0006\u0010.\u001a\u00020\u0005J\u0014\u0010:\u001a\b\u0012\u0004\u0012\u00020;032\u0006\u00105\u001a\u00020/J\u001e\u0010<\u001a\b\u0012\u0004\u0012\u000209032\u0006\u0010=\u001a\u00020/2\u0006\u0010>\u001a\u00020/H\u0002J\u0010\u0010?\u001a\u00020\u00182\u0006\u0010@\u001a\u00020AH\u0002J\u0010\u0010B\u001a\u00020\u00182\u0006\u0010@\u001a\u00020CH\u0002J\u0010\u0010D\u001a\u00020\u00182\u0006\u0010@\u001a\u00020CH\u0002J&\u0010E\u001a\u00020\u00182\u0006\u0010F\u001a\u00020\u00052\u0006\u0010)\u001a\u00020\u00062\f\u0010G\u001a\b\u0012\u0004\u0012\u00020'0HH\u0002J\u001e\u0010I\u001a\u00020\u00182\u0006\u0010J\u001a\u00020\u00062\f\u0010G\u001a\b\u0012\u0004\u0012\u00020'0HH\u0002J/\u0010I\u001a\u00020\u00182\u0006\u0010K\u001a\u00020\u00052\u0006\u0010L\u001a\u00020\u00052\f\u0010G\u001a\b\u0012\u0004\u0012\u00020'0HH\u0086@ø\u0001\u0000¢\u0006\u0002\u0010MJ\u001c\u0010N\u001a\u00020\u00182\u0006\u0010)\u001a\u00020\u00062\f\u0010G\u001a\b\u0012\u0004\u0012\u00020'0HJ\u0006\u0010O\u001a\u00020\u0018J8\u0010P\u001a\u00020\u00102\u0006\u0010K\u001a\u00020\u00052\u0006\u0010L\u001a\u00020\u00052\u0006\u0010Q\u001a\u00020\u00052\u0006\u0010R\u001a\u00020\u00062\u000e\u0010S\u001a\n\u0012\u0004\u0012\u00020T\u0018\u000103H\u0002J\u001d\u0010U\u001a\u000e\u0012\n\u0012\b\u0012\u0004\u0012\u00020\u00060W0VH\u0086@ø\u0001\u0000¢\u0006\u0002\u0010XJ\u001d\u0010Y\u001a\u000e\u0012\n\u0012\b\u0012\u0004\u0012\u00020\u00060W0VH\u0086@ø\u0001\u0000¢\u0006\u0002\u0010XJ.\u0010Z\u001a\u00020\u00182\u0006\u0010.\u001a\u00020\u00052\u0006\u0010[\u001a\u00020\u00062\u0006\u0010\\\u001a\u00020\u00062\u0006\u0010]\u001a\u00020\u00062\u0006\u0010^\u001a\u00020\u0006R\u001a\u0010\u0003\u001a\u000e\u0012\u0004\u0012\u00020\u0005\u0012\u0004\u0012\u00020\u00060\u0004X\u0082\u000e¢\u0006\u0002\n\u0000R\u000e\u0010\u0007\u001a\u00020\bX\u0082\u0004¢\u0006\u0002\n\u0000R\u000e\u0010\t\u001a\u00020\nX\u0082\u0004¢\u0006\u0002\n\u0000R\u000e\u0010\u000b\u001a\u00020\fX\u0082\u0004¢\u0006\u0002\n\u0000\u0082\u0002\u0004\n\u0002\b\u0019¨\u0006`"}, d2 = {"Lcom/qcwireless/qcwatch/ui/base/repository/healthy/SleepDetailRepository;", "", "()V", "historyDate", "", "", "", "sleepDetailDao", "Lcom/qcwireless/qcwatch/ui/base/repository/dao/QcSleepDetailDao;", "sleepNewDao", "Lcom/qcwireless/qcwatch/ui/base/repository/dao/QcSleepNewProtocolDao;", "sleepTotalDao", "Lcom/qcwireless/qcwatch/ui/base/repository/dao/QcSleepTotalDao;", "calcSleepViewData", "Lcom/qcwireless/qcwatch/ui/home/sleep/bean/SleepViewBean;", "currentDay", "Lcom/qcwireless/qcwatch/ui/base/repository/entity/SleepDetail;", "theDayBefore", "calendarSleep", "", "Lcom/haibin/calendarview/Calendar;", "year", "month", "deleteNewSleepData", "", "downSleepDetailFromServer", "uid", "", "lastSyncId", "(JJLkotlin/coroutines/Continuation;)Ljava/lang/Object;", "downSleepDetailNewProtocolFromServer", "getSchemeCalendar", "day", "text", "merge", "oldEntity", "newEntity", "parseSleepDetail", "resultEntity", "Lcom/oudmon/ble/base/communication/rsp/ReadSleepDetailsRsp;", "parseSleepDetailToday", "dayIndex", "queryLastSleep", "queryLastSleepNewProtocol", "Lcom/qcwireless/qcwatch/ui/base/repository/entity/SleepNewProtocol;", "queryOtherSleepData", "dateStr", "Lcom/qcwireless/qc_utils/date/DateUtil;", "endTime", "querySleepByDate", "querySleepMonth", "", "Lcom/qcwireless/qcwatch/ui/base/view/QSleepMonthBarView$SleepDataBean;", "start", "querySleepNewProtocol", "dateUtil", "querySleepTotalByDate", "Lcom/qcwireless/qcwatch/ui/base/repository/entity/SleepTotalHistory;", "querySleepWeek", "Lcom/qcwireless/qcwatch/ui/base/view/QSleepWeekBarView$SleepDataBean;", "queryWeekSleepByDate", "dateStart", "dateEnd", "saveDownloadSleepToTotal", "sleepBean", "Lcom/qcwireless/qcwatch/ui/base/bean/response/healthy/SleepDetailNewProtocolResp;", "saveSleepNewProtocol", "Lcom/oudmon/ble/base/communication/rsp/SleepNewProtoResp;", "saveSleepToTotal", "syncDeviceSleepDetail", "key", "result", "Lcom/qcwireless/qcwatch/ui/base/repository/base/BaseDeviceResult;", "syncSleepDetail", TypedValues.CycleType.S_WAVE_OFFSET, "deviceName", "deviceAddress", "(Ljava/lang/String;Ljava/lang/String;Lcom/qcwireless/qcwatch/ui/base/repository/base/BaseDeviceResult;Lkotlin/coroutines/Continuation;)Ljava/lang/Object;", "syncTodaySleepDetail", "testSleep", "toSleepDetail", "date", "interval", "sleepDetailList", "Lcom/oudmon/ble/base/communication/entity/BleSleepDetails;", "updateSleepDetailToServer", "Lkotlinx/coroutines/flow/Flow;", "Lcom/qcwireless/qcwatch/ui/base/repository/mine/NetState;", "(Lkotlin/coroutines/Continuation;)Ljava/lang/Object;", "updateSleepDetailToServerNewProtocol", "updateSleepTotal", "bedtime", "avgHeart", "spo2", "hrv", "Companion", "app_championRelease"}, k = 1, mv = {1, 6, 0}, xi = 48)
/* loaded from: classes2.dex */
public final class SleepDetailRepository {

    /* renamed from: Companion, reason: from kotlin metadata */
    public static final Companion INSTANCE = new Companion(null);
    private static final Lazy<SleepDetailRepository> getInstance$delegate = LazyKt.lazy(LazyThreadSafetyMode.SYNCHRONIZED, (Function0) new Function0<SleepDetailRepository>() { // from class: com.qcwireless.qcwatch.ui.base.repository.healthy.SleepDetailRepository$Companion$getInstance$2
        /* JADX WARN: Can't rename method to resolve collision */
        @Override // kotlin.jvm.functions.Function0
        public final SleepDetailRepository invoke() {
            return new SleepDetailRepository();
        }
    });
    private final QcSleepDetailDao sleepDetailDao = QcDatabase.INSTANCE.getDatabase(QCApplication.INSTANCE.getCONTEXT()).qcSleepDetailDao();
    private final QcSleepTotalDao sleepTotalDao = QcDatabase.INSTANCE.getDatabase(QCApplication.INSTANCE.getCONTEXT()).qcSleepTotalDao();
    private final QcSleepNewProtocolDao sleepNewDao = QcDatabase.INSTANCE.getDatabase(QCApplication.INSTANCE.getCONTEXT()).qcSleepNewProtocolDao();
    private Map<String, Integer> historyDate = new LinkedHashMap();

    public final void testSleep() {
    }

    public final SleepViewBean querySleepNewProtocol(DateUtil dateUtil) {
        int i;
        int i2;
        Intrinsics.checkNotNullParameter(dateUtil, "dateUtil");
        SleepViewBean sleepViewBean = new SleepViewBean(null, 0, 0, 0, 0, 0L, 0L, 127, null);
        QcSleepNewProtocolDao qcSleepNewProtocolDao = this.sleepNewDao;
        String y_m_d = dateUtil.getY_M_D();
        Intrinsics.checkNotNullExpressionValue(y_m_d, "dateUtil.y_M_D");
        SleepNewProtocol queryByDate = qcSleepNewProtocolDao.queryByDate(y_m_d, UserConfig.INSTANCE.getInstance().getDeviceAddressNoClear());
        if (queryByDate != null) {
            String detail = queryByDate.getDetail();
            JsonAdapter adapter = MoshiUtils.INSTANCE.getMoshiBuild().adapter(new TypeToken<List<SleepNewProtoResp.DetailBean>>() { // from class: com.qcwireless.qcwatch.ui.base.repository.healthy.SleepDetailRepository$querySleepNewProtocol$$inlined$fromJson$1
            }.getType());
            Intrinsics.checkNotNullExpressionValue(adapter, "moshiBuild.adapter(objec…: TypeToken<T>() {}.type)");
            List<SleepNewProtoResp.DetailBean> list = (List) adapter.fromJson(detail);
            ArrayList arrayList = new ArrayList();
            int i3 = 0;
            if (list != null) {
                ArrayList<SleepNewProtoResp.DetailBean> arrayList2 = new ArrayList();
                SleepNewProtoResp.DetailBean detailBean = new SleepNewProtoResp.DetailBean();
                int i4 = 0;
                for (SleepNewProtoResp.DetailBean detailBean2 : list) {
                    int i5 = i4 + 1;
                    if (i4 == 0) {
                        detailBean = detailBean2;
                    }
                    if (i5 < list.size()) {
                        if (detailBean2.getT() == ((SleepNewProtoResp.DetailBean) list.get(i5)).getT()) {
                            detailBean.setD(((SleepNewProtoResp.DetailBean) list.get(i5)).getD() + ((SleepNewProtoResp.DetailBean) list.get(i4)).getD());
                        } else {
                            arrayList2.add(detailBean);
                            detailBean = (SleepNewProtoResp.DetailBean) list.get(i5);
                        }
                    } else {
                        arrayList2.add(detailBean);
                    }
                    i4 = i5;
                }
                i = 0;
                i2 = 0;
                int i6 = 0;
                for (SleepNewProtoResp.DetailBean detailBean3 : arrayList2) {
                    int i7 = i6 + 1;
                    int t = detailBean3.getT();
                    if (t == 2) {
                        i += detailBean3.getD();
                    } else if (t == 3) {
                        i3 += detailBean3.getD();
                    } else if (t == 5) {
                        i2 += detailBean3.getD();
                    }
                    QSleepBarChart.SleepDataBean sleepDataBean = new QSleepBarChart.SleepDataBean();
                    int t2 = detailBean3.getT();
                    if (t2 == 0 || t2 == 1) {
                        sleepDataBean.setType(4);
                    } else if (t2 == 2) {
                        sleepDataBean.setType(2);
                    } else if (t2 == 3) {
                        sleepDataBean.setType(1);
                    } else if (t2 == 5) {
                        sleepDataBean.setType(3);
                    }
                    if (i6 == 0) {
                        sleepDataBean.setSleepStart(queryByDate.getSt());
                        sleepDataBean.setSleepEnd(queryByDate.getSt() + (detailBean3.getD() * 60));
                        arrayList.add(sleepDataBean);
                    } else {
                        QSleepBarChart.SleepDataBean sleepDataBean2 = (QSleepBarChart.SleepDataBean) arrayList.get(i6 - 1);
                        sleepDataBean.setSleepStart(sleepDataBean2.getSleepEnd());
                        sleepDataBean.setSleepEnd(sleepDataBean2.getSleepEnd() + (detailBean3.getD() * 60));
                        arrayList.add(sleepDataBean);
                    }
                    i6 = i7;
                }
            } else {
                i = 0;
                i2 = 0;
            }
            int i8 = i3 * 60;
            int i9 = i * 60;
            int i10 = i2 * 60;
            sleepViewBean.setStartTime(queryByDate.getSt());
            sleepViewBean.setEndTime(queryByDate.getEt());
            sleepViewBean.setTotalSleep(i8 + i9 + i10);
            sleepViewBean.setDeepSleep(i8);
            sleepViewBean.setLightSleep(i9);
            sleepViewBean.setAwakeSleep(i10);
            sleepViewBean.setData(arrayList);
            return sleepViewBean;
        }
        return new SleepViewBean(null, 0, 0, 0, 0, 0L, 0L, 127, null);
    }

    public final Object syncSleepDetail(String str, String str2, final BaseDeviceResult<ReadSleepDetailsRsp> baseDeviceResult, Continuation<? super Unit> continuation) {
        if (!BleOperateManager.getInstance().isConnected()) {
            return Unit.INSTANCE;
        }
        if (UserConfig.INSTANCE.getInstance().getNewSleepProtocol()) {
            syncSleepDetail(255, baseDeviceResult);
            return Unit.INSTANCE;
        }
        Object collect = FlowKt.m2572catch(FlowKt.flowOn(FlowKt.flow(new SleepDetailRepository$syncSleepDetail$2(this, str2, null)), Dispatchers.getIO()), new SleepDetailRepository$syncSleepDetail$3(this, null)).collect(new FlowCollector() { // from class: com.qcwireless.qcwatch.ui.base.repository.healthy.SleepDetailRepository$syncSleepDetail$4
            @Override // kotlinx.coroutines.flow.FlowCollector
            public /* bridge */ /* synthetic */ Object emit(Object obj, Continuation continuation2) {
                return emit((Map<String, Integer>) obj, (Continuation<? super Unit>) continuation2);
            }

            public final Object emit(Map<String, Integer> map, Continuation<? super Unit> continuation2) {
                Map map2;
                Map map3;
                Map map4;
                DateUtil dateUtil = new DateUtil();
                dateUtil.addDay(-1);
                map2 = SleepDetailRepository.this.historyDate;
                String y_m_d = dateUtil.getY_M_D();
                Intrinsics.checkNotNullExpressionValue(y_m_d, "date.y_M_D");
                map2.put(y_m_d, Boxing.boxInt(1));
                SleepDetailRepository sleepDetailRepository = SleepDetailRepository.this;
                map3 = sleepDetailRepository.historyDate;
                Map<String, Integer> sortMapByValue = MapUtils.sortMapByValue(map3);
                Intrinsics.checkNotNullExpressionValue(sortMapByValue, "sortMapByValue(historyDate)");
                sleepDetailRepository.historyDate = sortMapByValue;
                map4 = SleepDetailRepository.this.historyDate;
                Iterator it = map4.entrySet().iterator();
                if (it.hasNext()) {
                    Map.Entry entry = (Map.Entry) it.next();
                    SleepDetailRepository.this.syncDeviceSleepDetail((String) entry.getKey(), ((Number) entry.getValue()).intValue(), baseDeviceResult);
                } else {
                    baseDeviceResult.result(0, new ReadSleepDetailsRsp());
                }
                return Unit.INSTANCE;
            }
        }, continuation);
        return collect == IntrinsicsKt.getCOROUTINE_SUSPENDED() ? collect : Unit.INSTANCE;
    }

    public final void syncTodaySleepDetail(final int dayIndex, final BaseDeviceResult<ReadSleepDetailsRsp> result) {
        Intrinsics.checkNotNullParameter(result, "result");
        if (UserConfig.INSTANCE.getInstance().getNewSleepProtocol()) {
            syncSleepDetail(0, result);
        } else {
            CommandHandle.getInstance().executeReqCmd(new ReadSleepDetailsReq(dayIndex, 0, 95), new ICommandResponse() { // from class: com.qcwireless.qcwatch.ui.base.repository.healthy.SleepDetailRepository$$ExternalSyntheticLambda0
                @Override // com.oudmon.ble.base.communication.ICommandResponse
                public final void onDataResponse(BaseRspCmd baseRspCmd) {
                    SleepDetailRepository.m300syncTodaySleepDetail$lambda0(SleepDetailRepository.this, dayIndex, result, (ReadSleepDetailsRsp) baseRspCmd);
                }
            });
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* renamed from: syncTodaySleepDetail$lambda-0, reason: not valid java name */
    public static final void m300syncTodaySleepDetail$lambda0(SleepDetailRepository this$0, int i, BaseDeviceResult result, ReadSleepDetailsRsp it) {
        Intrinsics.checkNotNullParameter(this$0, "this$0");
        Intrinsics.checkNotNullParameter(result, "$result");
        if (it.getStatus() == 0) {
            Intrinsics.checkNotNullExpressionValue(it, "it");
            this$0.parseSleepDetailToday(it, i);
            if (i == 1) {
                result.result(0, it);
            }
            if (i == 0) {
                this$0.syncTodaySleepDetail(1, result);
                return;
            }
            return;
        }
        Intrinsics.checkNotNullExpressionValue(it, "it");
        result.result(-1, it);
    }

    private final void syncSleepDetail(int offset, BaseDeviceResult<ReadSleepDetailsRsp> result) {
        LargeDataHandler.getInstance().syncSleepList(offset, new ILargeDataSleepResponse() { // from class: com.qcwireless.qcwatch.ui.base.repository.healthy.SleepDetailRepository$$ExternalSyntheticLambda2
            @Override // com.oudmon.ble.base.communication.ILargeDataSleepResponse
            public final void sleepData(SleepNewProtoResp sleepNewProtoResp) {
                SleepDetailRepository.m299syncSleepDetail$lambda1(SleepDetailRepository.this, sleepNewProtoResp);
            }
        });
        result.result(0, new ReadSleepDetailsRsp());
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* renamed from: syncSleepDetail$lambda-1, reason: not valid java name */
    public static final void m299syncSleepDetail$lambda1(SleepDetailRepository this$0, final SleepNewProtoResp sleepNewProtoResp) {
        Intrinsics.checkNotNullParameter(this$0, "this$0");
        ThreadExtKt.ktxRunOnBgSingle(this$0, new Function1<SleepDetailRepository, Unit>() { // from class: com.qcwireless.qcwatch.ui.base.repository.healthy.SleepDetailRepository$syncSleepDetail$5$1
            /* JADX INFO: Access modifiers changed from: package-private */
            {
                super(1);
            }

            @Override // kotlin.jvm.functions.Function1
            public /* bridge */ /* synthetic */ Unit invoke(SleepDetailRepository sleepDetailRepository) {
                invoke2(sleepDetailRepository);
                return Unit.INSTANCE;
            }

            /* renamed from: invoke, reason: avoid collision after fix types in other method */
            public final void invoke2(SleepDetailRepository ktxRunOnBgSingle) {
                Intrinsics.checkNotNullParameter(ktxRunOnBgSingle, "$this$ktxRunOnBgSingle");
                SleepNewProtoResp it = SleepNewProtoResp.this;
                if (it == null) {
                    ktxRunOnBgSingle.deleteNewSleepData();
                    return;
                }
                Intrinsics.checkNotNullExpressionValue(it, "it");
                ktxRunOnBgSingle.saveSleepNewProtocol(it);
                SleepNewProtoResp it2 = SleepNewProtoResp.this;
                Intrinsics.checkNotNullExpressionValue(it2, "it");
                ktxRunOnBgSingle.saveSleepToTotal(it2);
            }
        });
    }

    /* JADX INFO: Access modifiers changed from: private */
    public final void saveSleepNewProtocol(SleepNewProtoResp sleepBean) {
        String deviceAddressNoClear = UserConfig.INSTANCE.getInstance().getDeviceAddressNoClear();
        String y_m_d = new DateUtil(sleepBean.getEt(), true).getY_M_D();
        Intrinsics.checkNotNullExpressionValue(y_m_d, "DateUtil(sleepBean.et.toLong(), true).y_M_D");
        List<SleepNewProtoResp.DetailBean> list = sleepBean.getList();
        Intrinsics.checkNotNullExpressionValue(list, "sleepBean.list");
        this.sleepNewDao.insert(new SleepNewProtocol(deviceAddressNoClear, y_m_d, MoshiUtilsKt.toJson(list), sleepBean.getSt(), sleepBean.getEt(), false, new DateUtil().getUnixTimestamp()));
    }

    /* JADX INFO: Access modifiers changed from: private */
    public final void deleteNewSleepData() {
        ThreadExtKt.ktxRunOnBgSingle(this, new Function1<SleepDetailRepository, Unit>() { // from class: com.qcwireless.qcwatch.ui.base.repository.healthy.SleepDetailRepository$deleteNewSleepData$1
            @Override // kotlin.jvm.functions.Function1
            public /* bridge */ /* synthetic */ Unit invoke(SleepDetailRepository sleepDetailRepository) {
                invoke2(sleepDetailRepository);
                return Unit.INSTANCE;
            }

            /* renamed from: invoke, reason: avoid collision after fix types in other method */
            public final void invoke2(SleepDetailRepository ktxRunOnBgSingle) {
                QcSleepNewProtocolDao qcSleepNewProtocolDao;
                QcSleepTotalDao qcSleepTotalDao;
                QcSleepTotalDao qcSleepTotalDao2;
                QcSleepNewProtocolDao qcSleepNewProtocolDao2;
                Intrinsics.checkNotNullParameter(ktxRunOnBgSingle, "$this$ktxRunOnBgSingle");
                qcSleepNewProtocolDao = ktxRunOnBgSingle.sleepNewDao;
                String y_m_d = new DateUtil().getY_M_D();
                Intrinsics.checkNotNullExpressionValue(y_m_d, "DateUtil().y_M_D");
                SleepNewProtocol queryByDate = qcSleepNewProtocolDao.queryByDate(y_m_d, UserConfig.INSTANCE.getInstance().getDeviceAddressNoClear());
                if (queryByDate != null) {
                    qcSleepNewProtocolDao2 = ktxRunOnBgSingle.sleepNewDao;
                    qcSleepNewProtocolDao2.delete(queryByDate);
                }
                qcSleepTotalDao = ktxRunOnBgSingle.sleepTotalDao;
                String deviceAddressNoClear = UserConfig.INSTANCE.getInstance().getDeviceAddressNoClear();
                String y_m_d2 = new DateUtil().getY_M_D();
                Intrinsics.checkNotNullExpressionValue(y_m_d2, "DateUtil().y_M_D");
                SleepTotalHistory queryTotalSleepByAddressAndDate = qcSleepTotalDao.queryTotalSleepByAddressAndDate(deviceAddressNoClear, y_m_d2);
                if (queryTotalSleepByAddressAndDate != null) {
                    qcSleepTotalDao2 = ktxRunOnBgSingle.sleepTotalDao;
                    qcSleepTotalDao2.delete(queryTotalSleepByAddressAndDate);
                }
            }
        });
    }

    /* JADX INFO: Access modifiers changed from: private */
    public final void saveSleepToTotal(SleepNewProtoResp sleepBean) {
        int i;
        List<SleepNewProtoResp.DetailBean> list = sleepBean.getList();
        Intrinsics.checkNotNullExpressionValue(list, "sleepBean.list");
        int i2 = 0;
        int i3 = 0;
        int i4 = 0;
        for (SleepNewProtoResp.DetailBean detailBean : list) {
            int t = detailBean.getT();
            if (t == 2) {
                i3 += detailBean.getD();
            } else if (t == 3) {
                i2 += detailBean.getD();
            } else if (t == 5) {
                i4 += detailBean.getD();
            }
        }
        int i5 = i2 * 60;
        int i6 = i3 * 60;
        int i7 = i4 * 60;
        Intrinsics.checkNotNullExpressionValue(sleepBean.getList(), "sleepBean.list");
        if (!r0.isEmpty()) {
            int d = sleepBean.getList().get(0).getD() % 20;
            i = (i6 <= 0 || d != 0) ? d : 20;
        } else {
            i = 0;
        }
        String deviceAddressNoClear = UserConfig.INSTANCE.getInstance().getDeviceAddressNoClear();
        String y_m_d = new DateUtil(sleepBean.getEt(), true).getY_M_D();
        Intrinsics.checkNotNullExpressionValue(y_m_d, "DateUtil(sleepBean.et.toLong(), true).y_M_D");
        this.sleepTotalDao.insert(new SleepTotalHistory(deviceAddressNoClear, y_m_d, i5 + i6 + i7, i5, i6, i7, sleepBean.getSt(), sleepBean.getEt(), (int) new DateUtil(sleepBean.getEt(), true).getZeroTime(), 0, 0, 0, i));
    }

    public final SleepDetail querySleepByDate(String dateStr) {
        Intrinsics.checkNotNullParameter(dateStr, "dateStr");
        return this.sleepDetailDao.queryByDate(dateStr, UserConfig.INSTANCE.getInstance().getDeviceAddressNoClear());
    }

    public final SleepDetail queryLastSleep() {
        return this.sleepDetailDao.queryLastSyncDate(UserConfig.INSTANCE.getInstance().getDeviceAddressNoClear());
    }

    public final SleepNewProtocol queryLastSleepNewProtocol() {
        return this.sleepNewDao.queryLastSyncDate(UserConfig.INSTANCE.getInstance().getDeviceAddressNoClear());
    }

    private final List<SleepTotalHistory> queryWeekSleepByDate(DateUtil dateStart, DateUtil dateEnd) {
        return this.sleepTotalDao.queryByAddressAndDate(UserConfig.INSTANCE.getInstance().getDeviceAddressNoClear(), String.valueOf(dateStart.getZeroTime()), String.valueOf(dateEnd.getUnixTimestamp()));
    }

    public final SleepTotalHistory querySleepTotalByDate(String dateStr) {
        Intrinsics.checkNotNullParameter(dateStr, "dateStr");
        return this.sleepTotalDao.queryTotalSleepByAddressAndDate(UserConfig.INSTANCE.getInstance().getDeviceAddressNoClear(), dateStr);
    }

    public final List<QSleepWeekBarView.SleepDataBean> querySleepWeek(DateUtil start) {
        Intrinsics.checkNotNullParameter(start, "start");
        LinkedHashMap linkedHashMap = new LinkedHashMap();
        DateUtil dateUtil = new DateUtil(start.getUnixTimestamp(), true);
        DateUtil dateUtil2 = new DateUtil(start.getZeroTime() + 86399, true);
        dateUtil2.addDay(6);
        List<SleepTotalHistory> queryWeekSleepByDate = queryWeekSleepByDate(start, dateUtil2);
        for (int i = 0; i < 7; i++) {
            String y_m_d = dateUtil.getY_M_D();
            Intrinsics.checkNotNullExpressionValue(y_m_d, "temp.y_M_D");
            linkedHashMap.put(y_m_d, new QSleepWeekBarView.SleepDataBean(dateUtil.getUnixTimestamp(), 0, 0, 0, 0, 0.0f, 0.0f, 0.0f));
            dateUtil.addDay(1);
        }
        for (SleepTotalHistory sleepTotalHistory : queryWeekSleepByDate) {
            DateUtil dateUtil3 = new DateUtil(sleepTotalHistory.getUnixTime(), true);
            String y_m_d2 = dateUtil3.getY_M_D();
            Intrinsics.checkNotNullExpressionValue(y_m_d2, "dateStr.y_M_D");
            DaySleepFragmentViewModel.DayStepUI dayStepUI = new DaySleepFragmentViewModel.DayStepUI(y_m_d2, 0, 0, 0, 0, sleepTotalHistory.getEndTime());
            int todayMin = new DateUtil(sleepTotalHistory.getEndTime(), true).getTodayMin();
            HeartRateDetailRepository getInstance = HeartRateDetailRepository.INSTANCE.getGetInstance();
            String y_m_d3 = dateUtil3.getY_M_D();
            Intrinsics.checkNotNullExpressionValue(y_m_d3, "dateStr.y_M_D");
            int i2 = 0;
            int i3 = 0;
            for (QHeartLineChartView.HeartDataBean heartDataBean : getInstance.queryHeartRateDetailByDate(y_m_d3)) {
                if (heartDataBean.getMin() <= todayMin) {
                    i2 += heartDataBean.getValue();
                    i3++;
                }
            }
            if (i2 > 0) {
                dayStepUI.setHeart(MathKt.roundToInt((i2 * 1.0f) / i3));
            }
            int i4 = 0;
            int i5 = 0;
            for (BloodOxyDetailBean bloodOxyDetailBean : BloodOxygenRepository.INSTANCE.getGetInstance().queryBloodOxygenByDateDetail(UserConfig.INSTANCE.getInstance().getDeviceAddressNoClear(), dateUtil3)) {
                if (bloodOxyDetailBean.getSeconds() <= todayMin * 60) {
                    i4 += bloodOxyDetailBean.getMaxValue();
                    i5++;
                }
            }
            if (i4 > 0) {
                dayStepUI.setSpo2(MathKt.roundToInt((i4 * 1.0f) / i5));
            }
            SleepViewBean querySleepNewProtocol = INSTANCE.getGetInstance().querySleepNewProtocol(dateUtil3);
            if (!querySleepNewProtocol.getData().isEmpty()) {
                QSleepBarChart.SleepDataBean sleepDataBean = querySleepNewProtocol.getData().get(0);
                dayStepUI.setBedTime((((int) (sleepDataBean.getSleepEnd() - sleepDataBean.getSleepStart())) / 60) % 20);
            }
            int i6 = 0;
            int i7 = 0;
            for (QHrvLineChartView.HeartDataBean heartDataBean2 : HRVRepository.INSTANCE.getGetInstance().queryHrvByDateDetailResp(dateUtil3)) {
                if (heartDataBean2.getMin() <= todayMin) {
                    i6 += heartDataBean2.getValue();
                    i7++;
                }
            }
            if (i6 > 0) {
                dayStepUI.setHrv(MathKt.roundToInt((i6 * 1.0f) / i7));
            }
            SleepDetailRepository getInstance2 = INSTANCE.getGetInstance();
            String y_m_d4 = dateUtil3.getY_M_D();
            Intrinsics.checkNotNullExpressionValue(y_m_d4, "dateStr.y_M_D");
            getInstance2.updateSleepTotal(y_m_d4, dayStepUI.getBedTime(), dayStepUI.getHeart(), dayStepUI.getSpo2(), dayStepUI.getHrv());
            int totalSleep = sleepTotalHistory.getTotalSleep() / 60;
            int deepSleep = sleepTotalHistory.getDeepSleep() / 60;
            int lightSleep = sleepTotalHistory.getLightSleep() / 60;
            int awake = sleepTotalHistory.getAwake() / 60;
            float f = totalSleep;
            QSleepWeekBarView.SleepDataBean sleepDataBean2 = new QSleepWeekBarView.SleepDataBean(sleepTotalHistory.getUnixTime(), totalSleep, deepSleep, lightSleep, awake, (deepSleep * 1.0f) / f, (lightSleep * 1.0f) / f, (awake * 1.0f) / f, dayStepUI.getBedTime(), dayStepUI.getHeart(), dayStepUI.getSpo2(), dayStepUI.getHrv());
            String y_m_d5 = new DateUtil(sleepTotalHistory.getUnixTime(), true).getY_M_D();
            Intrinsics.checkNotNullExpressionValue(y_m_d5, "DateUtil(item.unixTime.toLong(), true).y_M_D");
            linkedHashMap.put(y_m_d5, sleepDataBean2);
        }
        return new ArrayList(linkedHashMap.values());
    }

    public final List<QSleepMonthBarView.SleepDataBean> querySleepMonth(DateUtil start) {
        Intrinsics.checkNotNullParameter(start, "start");
        LinkedHashMap linkedHashMap = new LinkedHashMap();
        int daysOfMonth = DateUtil.getDaysOfMonth(start.toDate());
        DateUtil dateUtil = new DateUtil(start.getUnixTimestamp(), true);
        DateUtil dateUtil2 = new DateUtil(start.getZeroTime() + 86399, true);
        dateUtil2.addDay(daysOfMonth - 1);
        List<SleepTotalHistory> queryWeekSleepByDate = queryWeekSleepByDate(start, dateUtil2);
        for (int i = 0; i < daysOfMonth; i++) {
            String y_m_d = dateUtil.getY_M_D();
            Intrinsics.checkNotNullExpressionValue(y_m_d, "temp.y_M_D");
            linkedHashMap.put(y_m_d, new QSleepMonthBarView.SleepDataBean(dateUtil.getUnixTimestamp(), 0, 0, 0, 0, 0.0f, 0.0f, 0.0f));
            dateUtil.addDay(1);
        }
        for (SleepTotalHistory sleepTotalHistory : queryWeekSleepByDate) {
            DateUtil dateUtil3 = new DateUtil(sleepTotalHistory.getUnixTime(), true);
            String y_m_d2 = dateUtil3.getY_M_D();
            Intrinsics.checkNotNullExpressionValue(y_m_d2, "dateStr.y_M_D");
            DaySleepFragmentViewModel.DayStepUI dayStepUI = new DaySleepFragmentViewModel.DayStepUI(y_m_d2, 0, 0, 0, 0, sleepTotalHistory.getEndTime());
            int todayMin = new DateUtil(sleepTotalHistory.getEndTime(), true).getTodayMin();
            HeartRateDetailRepository getInstance = HeartRateDetailRepository.INSTANCE.getGetInstance();
            String y_m_d3 = dateUtil3.getY_M_D();
            Intrinsics.checkNotNullExpressionValue(y_m_d3, "dateStr.y_M_D");
            int i2 = 0;
            int i3 = 0;
            for (QHeartLineChartView.HeartDataBean heartDataBean : getInstance.queryHeartRateDetailByDate(y_m_d3)) {
                if (heartDataBean.getMin() <= todayMin) {
                    i2 += heartDataBean.getValue();
                    i3++;
                }
            }
            if (i2 > 0) {
                dayStepUI.setHeart(MathKt.roundToInt((i2 * 1.0f) / i3));
            }
            int i4 = 0;
            int i5 = 0;
            for (BloodOxyDetailBean bloodOxyDetailBean : BloodOxygenRepository.INSTANCE.getGetInstance().queryBloodOxygenByDateDetail(UserConfig.INSTANCE.getInstance().getDeviceAddressNoClear(), dateUtil3)) {
                if (bloodOxyDetailBean.getSeconds() <= todayMin * 60) {
                    i4 += bloodOxyDetailBean.getMaxValue();
                    i5++;
                }
            }
            if (i4 > 0) {
                dayStepUI.setSpo2(MathKt.roundToInt((i4 * 1.0f) / i5));
            }
            SleepViewBean querySleepNewProtocol = INSTANCE.getGetInstance().querySleepNewProtocol(dateUtil3);
            if (!querySleepNewProtocol.getData().isEmpty()) {
                QSleepBarChart.SleepDataBean sleepDataBean = querySleepNewProtocol.getData().get(0);
                dayStepUI.setBedTime((((int) (sleepDataBean.getSleepEnd() - sleepDataBean.getSleepStart())) / 60) % 20);
            }
            int i6 = 0;
            int i7 = 0;
            for (QHrvLineChartView.HeartDataBean heartDataBean2 : HRVRepository.INSTANCE.getGetInstance().queryHrvByDateDetailResp(dateUtil3)) {
                if (heartDataBean2.getMin() <= todayMin) {
                    i6 += heartDataBean2.getValue();
                    i7++;
                }
            }
            if (i6 > 0) {
                dayStepUI.setHrv(MathKt.roundToInt((i6 * 1.0f) / i7));
            }
            SleepDetailRepository getInstance2 = INSTANCE.getGetInstance();
            String y_m_d4 = dateUtil3.getY_M_D();
            Intrinsics.checkNotNullExpressionValue(y_m_d4, "dateStr.y_M_D");
            getInstance2.updateSleepTotal(y_m_d4, dayStepUI.getBedTime(), dayStepUI.getHeart(), dayStepUI.getSpo2(), dayStepUI.getHrv());
            int totalSleep = sleepTotalHistory.getTotalSleep() / 60;
            int deepSleep = sleepTotalHistory.getDeepSleep() / 60;
            int lightSleep = sleepTotalHistory.getLightSleep() / 60;
            int awake = sleepTotalHistory.getAwake() / 60;
            float f = totalSleep;
            QSleepMonthBarView.SleepDataBean sleepDataBean2 = new QSleepMonthBarView.SleepDataBean(sleepTotalHistory.getUnixTime(), totalSleep, deepSleep, lightSleep, awake, (deepSleep * 1.0f) / f, (lightSleep * 1.0f) / f, (awake * 1.0f) / f, dayStepUI.getBedTime(), dayStepUI.getHeart(), dayStepUI.getSpo2(), dayStepUI.getHrv());
            String y_m_d5 = new DateUtil(sleepTotalHistory.getUnixTime(), true).getY_M_D();
            Intrinsics.checkNotNullExpressionValue(y_m_d5, "DateUtil(item.unixTime.toLong(), true).y_M_D");
            linkedHashMap.put(y_m_d5, sleepDataBean2);
        }
        return new ArrayList(linkedHashMap.values());
    }

    /* JADX INFO: Access modifiers changed from: private */
    public final void syncDeviceSleepDetail(final String key, int dayIndex, final BaseDeviceResult<ReadSleepDetailsRsp> result) {
        CommandHandle.getInstance().executeReqCmd(new ReadSleepDetailsReq(dayIndex, 0, 95), new ICommandResponse() { // from class: com.qcwireless.qcwatch.ui.base.repository.healthy.SleepDetailRepository$$ExternalSyntheticLambda1
            @Override // com.oudmon.ble.base.communication.ICommandResponse
            public final void onDataResponse(BaseRspCmd baseRspCmd) {
                SleepDetailRepository.m298syncDeviceSleepDetail$lambda9(SleepDetailRepository.this, key, result, (ReadSleepDetailsRsp) baseRspCmd);
            }
        });
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* renamed from: syncDeviceSleepDetail$lambda-9, reason: not valid java name */
    public static final void m298syncDeviceSleepDetail$lambda9(SleepDetailRepository this$0, String key, BaseDeviceResult result, ReadSleepDetailsRsp it) {
        Intrinsics.checkNotNullParameter(this$0, "this$0");
        Intrinsics.checkNotNullParameter(key, "$key");
        Intrinsics.checkNotNullParameter(result, "$result");
        if (it.getStatus() == 0) {
            ArrayList<BleSleepDetails> list = it.getBleSleepDetailses();
            Intrinsics.checkNotNullExpressionValue(list, "list");
            if (!list.isEmpty()) {
                this$0.historyDate.remove(new DateUtil(list.get(0).getYear(), list.get(0).getMonth(), list.get(0).getDay()).getY_M_D());
            } else {
                this$0.historyDate.remove(key);
            }
            Intrinsics.checkNotNullExpressionValue(it, "it");
            this$0.parseSleepDetail(it);
            if (!this$0.historyDate.isEmpty()) {
                Iterator<Map.Entry<String, Integer>> it2 = this$0.historyDate.entrySet().iterator();
                if (it2.hasNext()) {
                    Map.Entry<String, Integer> next = it2.next();
                    this$0.syncDeviceSleepDetail(next.getKey(), next.getValue().intValue(), result);
                    return;
                }
                return;
            }
            result.result(0, it);
            return;
        }
        Intrinsics.checkNotNullExpressionValue(it, "it");
        result.result(-1, it);
    }

    /* JADX WARN: Removed duplicated region for block: B:127:0x035c  */
    /* JADX WARN: Removed duplicated region for block: B:14:0x007c  */
    /* JADX WARN: Removed duplicated region for block: B:150:0x03cb  */
    /* JADX WARN: Removed duplicated region for block: B:152:0x03e8  */
    /* JADX WARN: Removed duplicated region for block: B:24:0x00b2 A[LOOP:2: B:23:0x00b0->B:24:0x00b2, LOOP_END] */
    /* JADX WARN: Removed duplicated region for block: B:28:0x00c4 A[LOOP:3: B:27:0x00c2->B:28:0x00c4, LOOP_END] */
    /* JADX WARN: Removed duplicated region for block: B:36:0x0110  */
    /* JADX WARN: Removed duplicated region for block: B:38:0x012c A[LOOP:4: B:34:0x00ff->B:38:0x012c, LOOP_END] */
    /* JADX WARN: Removed duplicated region for block: B:39:0x012f A[EDGE_INSN: B:39:0x012f->B:41:0x012f BREAK  A[LOOP:4: B:34:0x00ff->B:38:0x012c], SYNTHETIC] */
    /* JADX WARN: Removed duplicated region for block: B:40:0x0120  */
    /* JADX WARN: Removed duplicated region for block: B:44:0x013c  */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
        To view partially-correct code enable 'Show inconsistent code' option in preferences
    */
    public final com.qcwireless.qcwatch.ui.home.sleep.bean.SleepViewBean calcSleepViewData(com.qcwireless.qcwatch.ui.base.repository.entity.SleepDetail r29, com.qcwireless.qcwatch.ui.base.repository.entity.SleepDetail r30) {
        /*
            Method dump skipped, instructions count: 1110
            To view this dump change 'Code comments level' option to 'DEBUG'
        */
        throw new UnsupportedOperationException("Method not decompiled: com.qcwireless.qcwatch.ui.base.repository.healthy.SleepDetailRepository.calcSleepViewData(com.qcwireless.qcwatch.ui.base.repository.entity.SleepDetail, com.qcwireless.qcwatch.ui.base.repository.entity.SleepDetail):com.qcwireless.qcwatch.ui.home.sleep.bean.SleepViewBean");
    }

    private final void parseSleepDetailToday(final ReadSleepDetailsRsp resultEntity, final int dayIndex) {
        ThreadExtKt.ktxRunOnBgSingle(this, new Function1<SleepDetailRepository, Unit>() { // from class: com.qcwireless.qcwatch.ui.base.repository.healthy.SleepDetailRepository$parseSleepDetailToday$1
            /* JADX INFO: Access modifiers changed from: package-private */
            /* JADX WARN: 'super' call moved to the top of the method (can break code semantics) */
            {
                super(1);
            }

            @Override // kotlin.jvm.functions.Function1
            public /* bridge */ /* synthetic */ Unit invoke(SleepDetailRepository sleepDetailRepository) {
                invoke2(sleepDetailRepository);
                return Unit.INSTANCE;
            }

            /* renamed from: invoke, reason: avoid collision after fix types in other method */
            public final void invoke2(SleepDetailRepository ktxRunOnBgSingle) {
                QcSleepDetailDao qcSleepDetailDao;
                SleepDetail sleepDetail;
                QcSleepDetailDao qcSleepDetailDao2;
                QcSleepDetailDao qcSleepDetailDao3;
                Intrinsics.checkNotNullParameter(ktxRunOnBgSingle, "$this$ktxRunOnBgSingle");
                ArrayList<BleSleepDetails> bleSleepDetailses = ReadSleepDetailsRsp.this.getBleSleepDetailses();
                Intrinsics.checkNotNullExpressionValue(bleSleepDetailses, "resultEntity.bleSleepDetailses");
                if (bleSleepDetailses.size() > 0) {
                    DateUtil dateUtil = new DateUtil(bleSleepDetailses.get(0).getYear(), bleSleepDetailses.get(0).getMonth(), bleSleepDetailses.get(0).getDay());
                    if (dateUtil.getZeroTime() > new DateUtil().getZeroTime()) {
                        return;
                    }
                    qcSleepDetailDao = ktxRunOnBgSingle.sleepDetailDao;
                    String y_m_d = dateUtil.getY_M_D();
                    Intrinsics.checkNotNullExpressionValue(y_m_d, "dataDate.y_M_D");
                    SleepDetail queryByDate = qcSleepDetailDao.queryByDate(y_m_d, UserConfig.INSTANCE.getInstance().getDeviceAddressNoClear());
                    String deviceNameNoClear = UserConfig.INSTANCE.getInstance().getDeviceNameNoClear();
                    String deviceAddressNoClear = UserConfig.INSTANCE.getInstance().getDeviceAddressNoClear();
                    String y_m_d2 = dateUtil.getY_M_D();
                    Intrinsics.checkNotNullExpressionValue(y_m_d2, "dataDate.y_M_D");
                    sleepDetail = ktxRunOnBgSingle.toSleepDetail(deviceNameNoClear, deviceAddressNoClear, y_m_d2, TypedValues.Custom.TYPE_INT, bleSleepDetailses);
                    if (DateUtil.isSameDay(dateUtil.toDate(), new Date())) {
                        if (queryByDate != null) {
                            sleepDetail = ktxRunOnBgSingle.merge(queryByDate, sleepDetail);
                        }
                        qcSleepDetailDao3 = ktxRunOnBgSingle.sleepDetailDao;
                        qcSleepDetailDao3.insert(sleepDetail);
                    } else {
                        qcSleepDetailDao2 = ktxRunOnBgSingle.sleepDetailDao;
                        qcSleepDetailDao2.insert(sleepDetail);
                    }
                    DateUtil dateUtil2 = new DateUtil(dateUtil.getUnixTimestamp(), true);
                    dateUtil2.addDay(-1);
                    String y_m_d3 = dateUtil2.getY_M_D();
                    Intrinsics.checkNotNullExpressionValue(y_m_d3, "yesDate.y_M_D");
                    SleepDetail querySleepByDate = ktxRunOnBgSingle.querySleepByDate(y_m_d3);
                    if (querySleepByDate == null) {
                        querySleepByDate = new SleepDetail(UserConfig.INSTANCE.getInstance().getDeviceAddressNoClear(), "", TypedValues.Custom.TYPE_INT, "", "", false, new DateUtil().getUnixTimestamp());
                    }
                    ktxRunOnBgSingle.calcSleepViewData(sleepDetail, querySleepByDate);
                    return;
                }
                if (dayIndex == 0) {
                    ThreadExtKt.ktxRunOnBgSingle(ktxRunOnBgSingle, new Function1<SleepDetailRepository, Unit>() { // from class: com.qcwireless.qcwatch.ui.base.repository.healthy.SleepDetailRepository$parseSleepDetailToday$1.1
                        @Override // kotlin.jvm.functions.Function1
                        public /* bridge */ /* synthetic */ Unit invoke(SleepDetailRepository sleepDetailRepository) {
                            invoke2(sleepDetailRepository);
                            return Unit.INSTANCE;
                        }

                        /* renamed from: invoke, reason: avoid collision after fix types in other method */
                        public final void invoke2(SleepDetailRepository ktxRunOnBgSingle2) {
                            QcSleepDetailDao qcSleepDetailDao4;
                            QcSleepTotalDao qcSleepTotalDao;
                            QcSleepTotalDao qcSleepTotalDao2;
                            QcSleepDetailDao qcSleepDetailDao5;
                            Intrinsics.checkNotNullParameter(ktxRunOnBgSingle2, "$this$ktxRunOnBgSingle");
                            qcSleepDetailDao4 = ktxRunOnBgSingle2.sleepDetailDao;
                            String y_m_d4 = new DateUtil().getY_M_D();
                            Intrinsics.checkNotNullExpressionValue(y_m_d4, "DateUtil().y_M_D");
                            SleepDetail queryByDate2 = qcSleepDetailDao4.queryByDate(y_m_d4, UserConfig.INSTANCE.getInstance().getDeviceAddressNoClear());
                            if (queryByDate2 != null) {
                                qcSleepDetailDao5 = ktxRunOnBgSingle2.sleepDetailDao;
                                qcSleepDetailDao5.delete(queryByDate2);
                            }
                            qcSleepTotalDao = ktxRunOnBgSingle2.sleepTotalDao;
                            String deviceAddressNoClear2 = UserConfig.INSTANCE.getInstance().getDeviceAddressNoClear();
                            String y_m_d5 = new DateUtil().getY_M_D();
                            Intrinsics.checkNotNullExpressionValue(y_m_d5, "DateUtil().y_M_D");
                            SleepTotalHistory queryTotalSleepByAddressAndDate = qcSleepTotalDao.queryTotalSleepByAddressAndDate(deviceAddressNoClear2, y_m_d5);
                            if (queryTotalSleepByAddressAndDate != null) {
                                qcSleepTotalDao2 = ktxRunOnBgSingle2.sleepTotalDao;
                                qcSleepTotalDao2.delete(queryTotalSleepByAddressAndDate);
                            }
                        }
                    });
                }
            }
        });
    }

    private final void parseSleepDetail(final ReadSleepDetailsRsp resultEntity) {
        ThreadExtKt.ktxRunOnBgSingle(this, new Function1<SleepDetailRepository, Unit>() { // from class: com.qcwireless.qcwatch.ui.base.repository.healthy.SleepDetailRepository$parseSleepDetail$1
            /* JADX INFO: Access modifiers changed from: package-private */
            {
                super(1);
            }

            @Override // kotlin.jvm.functions.Function1
            public /* bridge */ /* synthetic */ Unit invoke(SleepDetailRepository sleepDetailRepository) {
                invoke2(sleepDetailRepository);
                return Unit.INSTANCE;
            }

            /* renamed from: invoke, reason: avoid collision after fix types in other method */
            public final void invoke2(SleepDetailRepository ktxRunOnBgSingle) {
                QcSleepDetailDao qcSleepDetailDao;
                SleepDetail sleepDetail;
                QcSleepDetailDao qcSleepDetailDao2;
                QcSleepDetailDao qcSleepDetailDao3;
                Intrinsics.checkNotNullParameter(ktxRunOnBgSingle, "$this$ktxRunOnBgSingle");
                ArrayList<BleSleepDetails> bleSleepDetailses = ReadSleepDetailsRsp.this.getBleSleepDetailses();
                Intrinsics.checkNotNullExpressionValue(bleSleepDetailses, "resultEntity.bleSleepDetailses");
                if (bleSleepDetailses.size() > 0) {
                    DateUtil dateUtil = new DateUtil(bleSleepDetailses.get(0).getYear(), bleSleepDetailses.get(0).getMonth(), bleSleepDetailses.get(0).getDay());
                    if (dateUtil.getZeroTime() > new DateUtil().getZeroTime()) {
                        return;
                    }
                    qcSleepDetailDao = ktxRunOnBgSingle.sleepDetailDao;
                    String y_m_d = dateUtil.getY_M_D();
                    Intrinsics.checkNotNullExpressionValue(y_m_d, "dataDate.y_M_D");
                    SleepDetail queryByDate = qcSleepDetailDao.queryByDate(y_m_d, UserConfig.INSTANCE.getInstance().getDeviceAddressNoClear());
                    String deviceNameNoClear = UserConfig.INSTANCE.getInstance().getDeviceNameNoClear();
                    String deviceAddressNoClear = UserConfig.INSTANCE.getInstance().getDeviceAddressNoClear();
                    String y_m_d2 = dateUtil.getY_M_D();
                    Intrinsics.checkNotNullExpressionValue(y_m_d2, "dataDate.y_M_D");
                    sleepDetail = ktxRunOnBgSingle.toSleepDetail(deviceNameNoClear, deviceAddressNoClear, y_m_d2, TypedValues.Custom.TYPE_INT, bleSleepDetailses);
                    if (DateUtil.isSameDay(dateUtil.toDate(), new Date())) {
                        if (queryByDate != null) {
                            sleepDetail = ktxRunOnBgSingle.merge(queryByDate, sleepDetail);
                        }
                        qcSleepDetailDao3 = ktxRunOnBgSingle.sleepDetailDao;
                        qcSleepDetailDao3.insert(sleepDetail);
                    } else {
                        qcSleepDetailDao2 = ktxRunOnBgSingle.sleepDetailDao;
                        qcSleepDetailDao2.insert(sleepDetail);
                    }
                    DateUtil dateUtil2 = new DateUtil(dateUtil.getUnixTimestamp(), true);
                    dateUtil2.addDay(-1);
                    String y_m_d3 = dateUtil2.getY_M_D();
                    Intrinsics.checkNotNullExpressionValue(y_m_d3, "yesDate.y_M_D");
                    SleepDetail querySleepByDate = ktxRunOnBgSingle.querySleepByDate(y_m_d3);
                    if (querySleepByDate == null) {
                        querySleepByDate = new SleepDetail(UserConfig.INSTANCE.getInstance().getDeviceAddressNoClear(), "", TypedValues.Custom.TYPE_INT, "", "", false, new DateUtil().getUnixTimestamp());
                    }
                    ktxRunOnBgSingle.calcSleepViewData(sleepDetail, querySleepByDate);
                }
            }
        });
    }

    /* JADX INFO: Access modifiers changed from: private */
    public final SleepDetail toSleepDetail(String deviceName, String deviceAddress, String date, int interval, List<? extends BleSleepDetails> sleepDetailList) {
        SparseIntArray sparseIntArray = new SparseIntArray();
        if (sleepDetailList != null) {
            for (BleSleepDetails bleSleepDetails : sleepDetailList) {
                int[] sleepQualities = bleSleepDetails.getSleepQualities();
                sparseIntArray.put(bleSleepDetails.getTimeIndex(), (sleepQualities[1] * 100000) + (sleepQualities[2] * 1000) + sleepQualities[3]);
            }
        }
        int size = sparseIntArray.size();
        int[] iArr = new int[size];
        int size2 = sparseIntArray.size();
        for (int i = 0; i < size2; i++) {
            iArr[i] = sparseIntArray.keyAt(i);
        }
        Arrays.sort(iArr);
        String intArrayToString = StringUtilsKt.intArrayToString(iArr);
        int[] iArr2 = new int[sparseIntArray.size()];
        for (int i2 = 0; i2 < size; i2++) {
            iArr2[i2] = sparseIntArray.get(iArr[i2]);
        }
        return new SleepDetail(deviceAddress, date, interval, intArrayToString, StringUtilsKt.intArrayToString(iArr2), false, new DateUtil().getUnixTimestamp());
    }

    /* JADX INFO: Access modifiers changed from: private */
    public final SleepDetail merge(SleepDetail oldEntity, SleepDetail newEntity) {
        int[] stringToIntArray = StringUtilsKt.stringToIntArray(oldEntity.getIndex_str());
        int[] stringToIntArray2 = StringUtilsKt.stringToIntArray(oldEntity.getQuality());
        int[] stringToIntArray3 = StringUtilsKt.stringToIntArray(newEntity.getIndex_str());
        int[] stringToIntArray4 = StringUtilsKt.stringToIntArray(newEntity.getQuality());
        SparseIntArray sparseIntArray = new SparseIntArray();
        int length = stringToIntArray.length;
        for (int i = 0; i < length; i++) {
            sparseIntArray.put(stringToIntArray[i], stringToIntArray2[i]);
        }
        int length2 = stringToIntArray3.length;
        for (int i2 = 0; i2 < length2; i2++) {
            sparseIntArray.put(stringToIntArray3[i2], stringToIntArray4[i2]);
        }
        int size = sparseIntArray.size();
        int[] iArr = new int[size];
        int size2 = sparseIntArray.size();
        for (int i3 = 0; i3 < size2; i3++) {
            iArr[i3] = sparseIntArray.keyAt(i3);
        }
        Arrays.sort(iArr);
        int[] iArr2 = new int[sparseIntArray.size()];
        for (int i4 = 0; i4 < size; i4++) {
            iArr2[i4] = sparseIntArray.get(iArr[i4]);
        }
        oldEntity.setIndex_str(StringUtilsKt.intArrayToString(iArr));
        oldEntity.setQuality(StringUtilsKt.intArrayToString(iArr2));
        return oldEntity;
    }

    public final Object updateSleepDetailToServer(Continuation<? super Flow<NetState<Integer>>> continuation) {
        return FlowKt.m2572catch(FlowKt.flowOn(FlowKt.onStart(FlowKt.flow(new SleepDetailRepository$updateSleepDetailToServer$2(this, null)), new SleepDetailRepository$updateSleepDetailToServer$3(null)), Dispatchers.getIO()), new SleepDetailRepository$updateSleepDetailToServer$4(null));
    }

    public final Object updateSleepDetailToServerNewProtocol(Continuation<? super Flow<NetState<Integer>>> continuation) {
        return FlowKt.m2572catch(FlowKt.flowOn(FlowKt.onStart(FlowKt.flow(new SleepDetailRepository$updateSleepDetailToServerNewProtocol$2(this, null)), new SleepDetailRepository$updateSleepDetailToServerNewProtocol$3(null)), Dispatchers.getIO()), new SleepDetailRepository$updateSleepDetailToServerNewProtocol$4(null));
    }

    public final Object downSleepDetailFromServer(long j, long j2, Continuation<? super Unit> continuation) {
        Object collect = FlowKt.m2572catch(FlowKt.flowOn(FlowKt.onStart(FlowKt.flow(new SleepDetailRepository$downSleepDetailFromServer$2(j, j2, null)), new SleepDetailRepository$downSleepDetailFromServer$3(null)), Dispatchers.getIO()), new SleepDetailRepository$downSleepDetailFromServer$4(null)).collect(new FlowCollector() { // from class: com.qcwireless.qcwatch.ui.base.repository.healthy.SleepDetailRepository$downSleepDetailFromServer$5
            @Override // kotlinx.coroutines.flow.FlowCollector
            public /* bridge */ /* synthetic */ Object emit(Object obj, Continuation continuation2) {
                return emit((NetState<List<SleepDetailResp>>) obj, (Continuation<? super Unit>) continuation2);
            }

            public final Object emit(NetState<List<SleepDetailResp>> netState, Continuation<? super Unit> continuation2) {
                List<SleepDetailResp> isSuccess;
                QcSleepDetailDao qcSleepDetailDao;
                if (netState.getRetCode() == 0 && (isSuccess = netState.isSuccess()) != null) {
                    try {
                        for (SleepDetailResp sleepDetailResp : isSuccess) {
                            String deviceId = sleepDetailResp.getDeviceId();
                            Intrinsics.checkNotNull(deviceId);
                            String date = sleepDetailResp.getDate();
                            Intrinsics.checkNotNull(date);
                            SleepDetail sleepDetail = new SleepDetail(deviceId, date, sleepDetailResp.getIntervar(), StringUtilsKt.intListToString(sleepDetailResp.getIndexs()), StringUtilsKt.intListToString(sleepDetailResp.getQualitys()), true, new DateUtil().getUnixTimestamp());
                            qcSleepDetailDao = SleepDetailRepository.this.sleepDetailDao;
                            qcSleepDetailDao.insert(sleepDetail);
                        }
                    } catch (Exception e) {
                        e.printStackTrace();
                    }
                }
                return Unit.INSTANCE;
            }
        }, continuation);
        return collect == IntrinsicsKt.getCOROUTINE_SUSPENDED() ? collect : Unit.INSTANCE;
    }

    public final Object downSleepDetailNewProtocolFromServer(long j, long j2, Continuation<? super Unit> continuation) {
        Object collect = FlowKt.m2572catch(FlowKt.flowOn(FlowKt.onStart(FlowKt.flow(new SleepDetailRepository$downSleepDetailNewProtocolFromServer$2(j, j2, null)), new SleepDetailRepository$downSleepDetailNewProtocolFromServer$3(null)), Dispatchers.getIO()), new SleepDetailRepository$downSleepDetailNewProtocolFromServer$4(null)).collect(new FlowCollector() { // from class: com.qcwireless.qcwatch.ui.base.repository.healthy.SleepDetailRepository$downSleepDetailNewProtocolFromServer$5
            @Override // kotlinx.coroutines.flow.FlowCollector
            public /* bridge */ /* synthetic */ Object emit(Object obj, Continuation continuation2) {
                return emit((NetState<List<SleepDetailNewProtocolResp>>) obj, (Continuation<? super Unit>) continuation2);
            }

            public final Object emit(NetState<List<SleepDetailNewProtocolResp>> netState, Continuation<? super Unit> continuation2) {
                List<SleepDetailNewProtocolResp> isSuccess;
                QcSleepNewProtocolDao qcSleepNewProtocolDao;
                if (netState.getRetCode() == 0 && (isSuccess = netState.isSuccess()) != null) {
                    try {
                        for (SleepDetailNewProtocolResp sleepDetailNewProtocolResp : isSuccess) {
                            String str = sleepDetailNewProtocolResp.deviceAddress;
                            Intrinsics.checkNotNull(str);
                            String str2 = sleepDetailNewProtocolResp.date;
                            Intrinsics.checkNotNull(str2);
                            List<SleepDetailNewProtocolResp.SleepDetail> list = sleepDetailNewProtocolResp.datas;
                            Intrinsics.checkNotNull(list);
                            SleepNewProtocol sleepNewProtocol = new SleepNewProtocol(str, str2, MoshiUtilsKt.toJson(list), sleepDetailNewProtocolResp.st, sleepDetailNewProtocolResp.et, true, new DateUtil().getUnixTimestamp());
                            qcSleepNewProtocolDao = SleepDetailRepository.this.sleepNewDao;
                            qcSleepNewProtocolDao.insert(sleepNewProtocol);
                            SleepDetailRepository.this.saveDownloadSleepToTotal(sleepDetailNewProtocolResp);
                        }
                    } catch (Exception e) {
                        e.printStackTrace();
                    }
                }
                return Unit.INSTANCE;
            }
        }, continuation);
        return collect == IntrinsicsKt.getCOROUTINE_SUSPENDED() ? collect : Unit.INSTANCE;
    }

    /* JADX INFO: Access modifiers changed from: private */
    public final void saveDownloadSleepToTotal(SleepDetailNewProtocolResp sleepBean) {
        List<SleepDetailNewProtocolResp.SleepDetail> list = sleepBean.datas;
        Intrinsics.checkNotNullExpressionValue(list, "sleepBean.datas");
        int i = 0;
        int i2 = 0;
        int i3 = 0;
        for (SleepDetailNewProtocolResp.SleepDetail sleepDetail : list) {
            int i4 = sleepDetail.t;
            if (i4 == 2) {
                i2 += sleepDetail.d;
            } else if (i4 == 3) {
                i += sleepDetail.d;
            } else if (i4 == 5) {
                i3 += sleepDetail.d;
            }
        }
        int i5 = i * 60;
        int i6 = i2 * 60;
        int i7 = i3 * 60;
        int i8 = ((sleepBean.et - sleepBean.st) / 60) % 20;
        int i9 = (i6 <= 0 || i8 != 0) ? i8 : 20;
        String str = sleepBean.deviceAddress;
        Intrinsics.checkNotNullExpressionValue(str, "sleepBean.deviceAddress");
        String y_m_d = new DateUtil(sleepBean.et, true).getY_M_D();
        Intrinsics.checkNotNullExpressionValue(y_m_d, "DateUtil(sleepBean.et.toLong(), true).y_M_D");
        this.sleepTotalDao.insert(new SleepTotalHistory(str, y_m_d, i5 + i6 + i7, i5, i6, i7, sleepBean.st, sleepBean.et, (int) new DateUtil(sleepBean.et, true).getZeroTime(), 0, 0, 0, i9));
    }

    public final void updateSleepTotal(String dateStr, int bedtime, int avgHeart, int spo2, int hrv) {
        Intrinsics.checkNotNullParameter(dateStr, "dateStr");
        SleepTotalHistory queryTotalSleepByAddressAndDate = this.sleepTotalDao.queryTotalSleepByAddressAndDate(UserConfig.INSTANCE.getInstance().getDeviceAddressNoClear(), dateStr);
        if (queryTotalSleepByAddressAndDate != null) {
            if (bedtime > 0) {
                queryTotalSleepByAddressAndDate.setBedtime(bedtime);
            }
            if (avgHeart > 0) {
                queryTotalSleepByAddressAndDate.setAvgHeart(avgHeart);
            }
            if (spo2 > 0) {
                queryTotalSleepByAddressAndDate.setAvgBloodOxygen(spo2);
            }
            if (hrv > 0) {
                queryTotalSleepByAddressAndDate.setAvgHrv(hrv);
            }
            this.sleepTotalDao.insert(queryTotalSleepByAddressAndDate);
        }
    }

    public final void queryOtherSleepData(final DateUtil dateStr, final long endTime) {
        Intrinsics.checkNotNullParameter(dateStr, "dateStr");
        ThreadExtKt.ktxRunOnBgSingle(this, new Function1<SleepDetailRepository, Unit>() { // from class: com.qcwireless.qcwatch.ui.base.repository.healthy.SleepDetailRepository$queryOtherSleepData$1
            /* JADX INFO: Access modifiers changed from: package-private */
            /* JADX WARN: 'super' call moved to the top of the method (can break code semantics) */
            {
                super(1);
            }

            @Override // kotlin.jvm.functions.Function1
            public /* bridge */ /* synthetic */ Unit invoke(SleepDetailRepository sleepDetailRepository) {
                invoke2(sleepDetailRepository);
                return Unit.INSTANCE;
            }

            /* renamed from: invoke, reason: avoid collision after fix types in other method */
            public final void invoke2(SleepDetailRepository ktxRunOnBgSingle) {
                Intrinsics.checkNotNullParameter(ktxRunOnBgSingle, "$this$ktxRunOnBgSingle");
                String y_m_d = DateUtil.this.getY_M_D();
                Intrinsics.checkNotNullExpressionValue(y_m_d, "dateStr.y_M_D");
                DaySleepFragmentViewModel.DayStepUI dayStepUI = new DaySleepFragmentViewModel.DayStepUI(y_m_d, 0, 0, 0, 0, (int) endTime);
                int todayMin = new DateUtil(endTime, true).getTodayMin();
                HeartRateDetailRepository getInstance = HeartRateDetailRepository.INSTANCE.getGetInstance();
                String y_m_d2 = DateUtil.this.getY_M_D();
                Intrinsics.checkNotNullExpressionValue(y_m_d2, "dateStr.y_M_D");
                int i = 0;
                int i2 = 0;
                int i3 = 0;
                for (QHeartLineChartView.HeartDataBean heartDataBean : getInstance.queryHeartRateDetailByDate(y_m_d2)) {
                    if (heartDataBean.getMin() <= todayMin) {
                        i2 += heartDataBean.getValue();
                        i3++;
                    }
                }
                if (i2 > 0) {
                    dayStepUI.setHeart(MathKt.roundToInt((i2 * 1.0f) / i3));
                }
                int i4 = 0;
                int i5 = 0;
                for (BloodOxyDetailBean bloodOxyDetailBean : BloodOxygenRepository.INSTANCE.getGetInstance().queryBloodOxygenByDateDetail(UserConfig.INSTANCE.getInstance().getDeviceAddressNoClear(), DateUtil.this)) {
                    if (bloodOxyDetailBean.getSeconds() <= todayMin * 60) {
                        i4 += bloodOxyDetailBean.getMaxValue();
                        i5++;
                    }
                }
                if (i4 > 0) {
                    dayStepUI.setSpo2(MathKt.roundToInt((i4 * 1.0f) / i5));
                }
                SleepViewBean querySleepNewProtocol = SleepDetailRepository.INSTANCE.getGetInstance().querySleepNewProtocol(DateUtil.this);
                if (true ^ querySleepNewProtocol.getData().isEmpty()) {
                    QSleepBarChart.SleepDataBean sleepDataBean = querySleepNewProtocol.getData().get(0);
                    dayStepUI.setBedTime((((int) (sleepDataBean.getSleepEnd() - sleepDataBean.getSleepStart())) / 60) % 20);
                }
                int i6 = 0;
                for (QHrvLineChartView.HeartDataBean heartDataBean2 : HRVRepository.INSTANCE.getGetInstance().queryHrvByDateDetailResp(DateUtil.this)) {
                    if (heartDataBean2.getMin() <= todayMin) {
                        i += heartDataBean2.getValue();
                        i6++;
                    }
                }
                if (i > 0) {
                    dayStepUI.setHrv(MathKt.roundToInt((i * 1.0f) / i6));
                }
                SleepDetailRepository getInstance2 = SleepDetailRepository.INSTANCE.getGetInstance();
                String y_m_d3 = DateUtil.this.getY_M_D();
                Intrinsics.checkNotNullExpressionValue(y_m_d3, "dateStr.y_M_D");
                getInstance2.updateSleepTotal(y_m_d3, dayStepUI.getBedTime(), dayStepUI.getHeart(), dayStepUI.getSpo2(), dayStepUI.getHrv());
            }
        });
    }

    public final Map<String, Calendar> calendarSleep(int year, int month) {
        LinkedHashMap linkedHashMap = new LinkedHashMap();
        DateUtil dateUtil = new DateUtil(year, month, 1);
        for (int i = 1; i < 32; i++) {
            if (UserConfig.INSTANCE.getInstance().getNewSleepProtocol()) {
                QcSleepNewProtocolDao qcSleepNewProtocolDao = this.sleepNewDao;
                String y_m_d = dateUtil.getY_M_D();
                Intrinsics.checkNotNullExpressionValue(y_m_d, "monthDate.y_M_D");
                if (qcSleepNewProtocolDao.queryByDate(y_m_d, UserConfig.INSTANCE.getInstance().getDeviceAddressNoClear()) != null) {
                    String calendar = getSchemeCalendar(dateUtil.getYear(), dateUtil.getMonth(), dateUtil.getDay(), "").toString();
                    Intrinsics.checkNotNullExpressionValue(calendar, "getSchemeCalendar(monthD…thDate.day,\"\").toString()");
                    linkedHashMap.put(calendar, getSchemeCalendar(dateUtil.getYear(), dateUtil.getMonth(), dateUtil.getDay(), ""));
                }
            } else {
                String y_m_d2 = dateUtil.getY_M_D();
                Intrinsics.checkNotNullExpressionValue(y_m_d2, "monthDate.y_M_D");
                if (querySleepByDate(y_m_d2) != null) {
                    String calendar2 = getSchemeCalendar(dateUtil.getYear(), dateUtil.getMonth(), dateUtil.getDay(), "").toString();
                    Intrinsics.checkNotNullExpressionValue(calendar2, "getSchemeCalendar(monthD…thDate.day,\"\").toString()");
                    linkedHashMap.put(calendar2, getSchemeCalendar(dateUtil.getYear(), dateUtil.getMonth(), dateUtil.getDay(), ""));
                }
            }
            dateUtil.addDay(1);
        }
        return linkedHashMap;
    }

    private final Calendar getSchemeCalendar(int year, int month, int day, String text) {
        Calendar calendar = new Calendar();
        calendar.setYear(year);
        calendar.setMonth(month);
        calendar.setDay(day);
        calendar.setSchemeColor(SupportMenu.CATEGORY_MASK);
        calendar.setScheme(text);
        return calendar;
    }

    /* compiled from: SleepDetailRepository.kt */
    @Metadata(d1 = {"\u0000\u0014\n\u0002\u0018\u0002\n\u0002\u0010\u0000\n\u0002\b\u0002\n\u0002\u0018\u0002\n\u0002\b\u0005\b\u0086\u0003\u0018\u00002\u00020\u0001B\u0007\b\u0002¢\u0006\u0002\u0010\u0002R\u001b\u0010\u0003\u001a\u00020\u00048FX\u0086\u0084\u0002¢\u0006\f\n\u0004\b\u0007\u0010\b\u001a\u0004\b\u0005\u0010\u0006¨\u0006\t"}, d2 = {"Lcom/qcwireless/qcwatch/ui/base/repository/healthy/SleepDetailRepository$Companion;", "", "()V", "getInstance", "Lcom/qcwireless/qcwatch/ui/base/repository/healthy/SleepDetailRepository;", "getGetInstance", "()Lcom/qcwireless/qcwatch/ui/base/repository/healthy/SleepDetailRepository;", "getInstance$delegate", "Lkotlin/Lazy;", "app_championRelease"}, k = 1, mv = {1, 6, 0}, xi = 48)
    /* loaded from: classes2.dex */
    public static final class Companion {
        public /* synthetic */ Companion(DefaultConstructorMarker defaultConstructorMarker) {
            this();
        }

        private Companion() {
        }

        public final SleepDetailRepository getGetInstance() {
            return (SleepDetailRepository) SleepDetailRepository.getInstance$delegate.getValue();
        }
    }
}
