package com.qcwireless.qcwatch.ui.base.watch;

import android.os.Build;
import androidx.exifinterface.media.ExifInterface;
import com.iwown.awlog.Author;
import com.iwown.awlog.AwLog;
import com.iwown.awlog.bean.AppLog;
import com.oudmon.ble.base.bluetooth.BleOperateManager;
import com.oudmon.ble.base.communication.CommandHandle;
import com.oudmon.ble.base.communication.ICommandResponse;
import com.oudmon.ble.base.communication.LargeDataHandler;
import com.oudmon.ble.base.communication.file.FileHandle;
import com.oudmon.ble.base.communication.req.BindAncsReq;
import com.oudmon.ble.base.communication.req.BloodOxygenSettingReq;
import com.oudmon.ble.base.communication.req.BpSettingReq;
import com.oudmon.ble.base.communication.req.HeartRateSettingReq;
import com.oudmon.ble.base.communication.req.HrvSettingReq;
import com.oudmon.ble.base.communication.req.PressureSettingReq;
import com.oudmon.ble.base.communication.req.SetMessagePushReq;
import com.oudmon.ble.base.communication.req.SetTimeReq;
import com.oudmon.ble.base.communication.req.SimpleKeyReq;
import com.oudmon.ble.base.communication.req.TargetSettingReq;
import com.oudmon.ble.base.communication.req.TimeFormatReq;
import com.oudmon.ble.base.communication.rsp.BaseRspCmd;
import com.oudmon.ble.base.communication.rsp.BatteryRsp;
import com.oudmon.ble.base.communication.rsp.BloodOxygenSettingRsp;
import com.oudmon.ble.base.communication.rsp.BpSettingRsp;
import com.oudmon.ble.base.communication.rsp.HRVSettingRsp;
import com.oudmon.ble.base.communication.rsp.HeartRateSettingRsp;
import com.oudmon.ble.base.communication.rsp.PressureSettingRsp;
import com.oudmon.ble.base.communication.rsp.ReadMessagePushRsp;
import com.oudmon.ble.base.communication.rsp.SetTimeRsp;
import com.oudmon.ble.base.communication.rsp.TargetSettingRsp;
import com.oudmon.ble.base.communication.rsp.TimeFormatRsp;
import com.qcwireless.qc_utils.date.DateUtil;
import com.qcwireless.qcwatch.QCApplication;
import com.qcwireless.qcwatch.QJavaApplication;
import com.qcwireless.qcwatch.base.event.BatteryLowEvent;
import com.qcwireless.qcwatch.base.event.BluetoothSyncEvent;
import com.qcwireless.qcwatch.base.event.DataSyncEvent;
import com.qcwireless.qcwatch.base.event.DeviceNotifyTypeEvent;
import com.qcwireless.qcwatch.base.ktx.ThreadExtKt;
import com.qcwireless.qcwatch.base.pref.UserConfig;
import com.qcwireless.qcwatch.base.utils.MoshiUtilsKt;
import com.qcwireless.qcwatch.base.view.GlobalKt;
import com.qcwireless.qcwatch.ui.base.bean.device.DeviceSetting;
import com.qcwireless.qcwatch.ui.base.repository.base.DeviceSettingAction;
import com.qcwireless.qcwatch.ui.base.repository.device.DeviceSettingRepository;
import com.qcwireless.qcwatch.ui.base.repository.entity.DeviceSettingEntity;
import com.qcwireless.qcwatch.ui.base.repository.entity.TargetEntity;
import com.qcwireless.qcwatch.ui.base.repository.entity.UserEntity;
import com.qcwireless.qcwatch.ui.base.repository.mine.UserProfileRepository;
import com.qcwireless.qcwatch.ui.device.push.call.PhoneNotifyListener;
import kotlin.Lazy;
import kotlin.LazyKt;
import kotlin.LazyThreadSafetyMode;
import kotlin.Metadata;
import kotlin.Unit;
import kotlin.jvm.functions.Function0;
import kotlin.jvm.functions.Function1;
import kotlin.jvm.internal.DefaultConstructorMarker;
import kotlin.jvm.internal.Intrinsics;
import kotlin.jvm.internal.Lambda;
import kotlinx.coroutines.BuildersKt__Builders_commonKt;
import kotlinx.coroutines.GlobalScope;
import org.greenrobot.eventbus.EventBus;

/* compiled from: DeviceCmdInit.kt */
@Metadata(d1 = {"\u0000\u001a\n\u0002\u0018\u0002\n\u0002\u0010\u0000\n\u0002\b\u0002\n\u0002\u0018\u0002\n\u0000\n\u0002\u0010\u0002\n\u0002\b\u0005\u0018\u0000 \n2\u00020\u0001:\u0001\nB\u0005¢\u0006\u0002\u0010\u0002J\u0006\u0010\u0005\u001a\u00020\u0006J\u0006\u0010\u0007\u001a\u00020\u0006J\u000e\u0010\b\u001a\u00020\u00062\u0006\u0010\u0003\u001a\u00020\u0004J\b\u0010\t\u001a\u00020\u0006H\u0002R\u000e\u0010\u0003\u001a\u00020\u0004X\u0082.¢\u0006\u0002\n\u0000¨\u0006\u000b"}, d2 = {"Lcom/qcwireless/qcwatch/ui/base/watch/DeviceCmdInit;", "", "()V", "deviceSetting", "Lcom/qcwireless/qcwatch/ui/base/bean/device/DeviceSetting;", "init", "", "initDeviceSetting", "saveDeviceSetting", "syncDeviceSetting", "Companion", "app_championRelease"}, k = 1, mv = {1, 6, 0}, xi = 48)
/* loaded from: classes2.dex */
public final class DeviceCmdInit {

    /* renamed from: Companion, reason: from kotlin metadata */
    public static final Companion INSTANCE = new Companion(null);
    private static final Lazy<DeviceCmdInit> getInstance$delegate = LazyKt.lazy(LazyThreadSafetyMode.SYNCHRONIZED, (Function0) new Function0<DeviceCmdInit>() { // from class: com.qcwireless.qcwatch.ui.base.watch.DeviceCmdInit$Companion$getInstance$2
        /* JADX WARN: Can't rename method to resolve collision */
        @Override // kotlin.jvm.functions.Function0
        public final DeviceCmdInit invoke() {
            return new DeviceCmdInit();
        }
    });
    private DeviceSetting deviceSetting;

    /* JADX INFO: Access modifiers changed from: private */
    /* renamed from: syncDeviceSetting$lambda-9$lambda-8, reason: not valid java name */
    public static final void m356syncDeviceSetting$lambda9$lambda8(TimeFormatRsp timeFormatRsp) {
    }

    public final void initDeviceSetting() {
        BuildersKt__Builders_commonKt.launch$default(GlobalScope.INSTANCE, null, null, new DeviceCmdInit$initDeviceSetting$1(this, null), 3, null);
    }

    public final void init() {
        AwLog.wtfJson(MoshiUtilsKt.toJson(new AppLog(QJavaApplication.getInstance().getYMD(), "phone brand: " + Build.BRAND + "phone model: " + Build.MODEL + "android sdk: " + Build.VERSION.SDK_INT + "os version: " + Build.VERSION.RELEASE + '-' + GlobalKt.getAppName(QCApplication.INSTANCE.getCONTEXT()) + '-' + GlobalKt.getVersionName(QCApplication.INSTANCE.getCONTEXT()), ExifInterface.GPS_MEASUREMENT_2D)), QJavaApplication.getAppLogPath());
        FileHandle.getInstance().clearCallback();
        BleOperateManager.getInstance().addNotifyListener(17, new PhoneNotifyListener(QCApplication.INSTANCE.getCONTEXT()));
        EventBus.getDefault().post(new DataSyncEvent(true));
        CommandHandle.getInstance().executeReqCmd(new SetTimeReq(1), new ICommandResponse() { // from class: com.qcwireless.qcwatch.ui.base.watch.DeviceCmdInit$$ExternalSyntheticLambda10
            @Override // com.oudmon.ble.base.communication.ICommandResponse
            public final void onDataResponse(BaseRspCmd baseRspCmd) {
                DeviceCmdInit.m346init$lambda0((SetTimeRsp) baseRspCmd);
            }
        });
        CommandHandle.getInstance().executeReqCmd(new SetMessagePushReq(), new ICommandResponse() { // from class: com.qcwireless.qcwatch.ui.base.watch.DeviceCmdInit$$ExternalSyntheticLambda9
            @Override // com.oudmon.ble.base.communication.ICommandResponse
            public final void onDataResponse(BaseRspCmd baseRspCmd) {
                DeviceCmdInit.m347init$lambda1((ReadMessagePushRsp) baseRspCmd);
            }
        });
        CommandHandle.getInstance().executeReqCmd(new SimpleKeyReq((byte) 3), new ICommandResponse() { // from class: com.qcwireless.qcwatch.ui.base.watch.DeviceCmdInit$$ExternalSyntheticLambda8
            @Override // com.oudmon.ble.base.communication.ICommandResponse
            public final void onDataResponse(BaseRspCmd baseRspCmd) {
                DeviceCmdInit.m348init$lambda2((BatteryRsp) baseRspCmd);
            }
        });
        CommandHandle.getInstance().executeReqCmdNoCallback(new BindAncsReq());
        syncDeviceSetting();
        QCApplication.INSTANCE.getGetInstance().getLocationOnce(QCApplication.INSTANCE.getApplication());
        EventBus.getDefault().post(new BluetoothSyncEvent());
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* renamed from: init$lambda-0, reason: not valid java name */
    public static final void m346init$lambda0(SetTimeRsp setTimeRsp) {
        BuildersKt__Builders_commonKt.launch$default(GlobalScope.INSTANCE, null, null, new DeviceCmdInit$init$1$1(setTimeRsp, null), 3, null);
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* renamed from: init$lambda-1, reason: not valid java name */
    public static final void m347init$lambda1(ReadMessagePushRsp readMessagePushRsp) {
        UserConfig.INSTANCE.getInstance().setMessagePushSupport(readMessagePushRsp.getDeviceSupport1());
        UserConfig.INSTANCE.getInstance().save();
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* renamed from: init$lambda-2, reason: not valid java name */
    public static final void m348init$lambda2(BatteryRsp batteryRsp) {
        UserConfig.INSTANCE.getInstance().setBattery(String.valueOf(batteryRsp.getBatteryValue()));
        UserConfig.INSTANCE.getInstance().save();
        EventBus.getDefault().post(new BatteryLowEvent());
    }

    private final void syncDeviceSetting() {
        CommandHandle.getInstance().executeReqCmd(HeartRateSettingReq.getReadInstance(), new ICommandResponse() { // from class: com.qcwireless.qcwatch.ui.base.watch.DeviceCmdInit$$ExternalSyntheticLambda4
            @Override // com.oudmon.ble.base.communication.ICommandResponse
            public final void onDataResponse(BaseRspCmd baseRspCmd) {
                DeviceCmdInit.m350syncDeviceSetting$lambda3(DeviceCmdInit.this, (HeartRateSettingRsp) baseRspCmd);
            }
        });
        CommandHandle.getInstance().executeReqCmd(HrvSettingReq.getReadInstance(), new ICommandResponse() { // from class: com.qcwireless.qcwatch.ui.base.watch.DeviceCmdInit$$ExternalSyntheticLambda3
            @Override // com.oudmon.ble.base.communication.ICommandResponse
            public final void onDataResponse(BaseRspCmd baseRspCmd) {
                DeviceCmdInit.m351syncDeviceSetting$lambda4(DeviceCmdInit.this, (HRVSettingRsp) baseRspCmd);
            }
        });
        CommandHandle.getInstance().executeReqCmd(PressureSettingReq.getReadInstance(), new ICommandResponse() { // from class: com.qcwireless.qcwatch.ui.base.watch.DeviceCmdInit$$ExternalSyntheticLambda5
            @Override // com.oudmon.ble.base.communication.ICommandResponse
            public final void onDataResponse(BaseRspCmd baseRspCmd) {
                DeviceCmdInit.m352syncDeviceSetting$lambda5(DeviceCmdInit.this, (PressureSettingRsp) baseRspCmd);
            }
        });
        CommandHandle.getInstance().executeReqCmd(BloodOxygenSettingReq.getReadInstance(), new ICommandResponse() { // from class: com.qcwireless.qcwatch.ui.base.watch.DeviceCmdInit$$ExternalSyntheticLambda0
            @Override // com.oudmon.ble.base.communication.ICommandResponse
            public final void onDataResponse(BaseRspCmd baseRspCmd) {
                DeviceCmdInit.m353syncDeviceSetting$lambda6(DeviceCmdInit.this, (BloodOxygenSettingRsp) baseRspCmd);
            }
        });
        CommandHandle.getInstance().executeReqCmd(BpSettingReq.getReadInstance(), new ICommandResponse() { // from class: com.qcwireless.qcwatch.ui.base.watch.DeviceCmdInit$$ExternalSyntheticLambda2
            @Override // com.oudmon.ble.base.communication.ICommandResponse
            public final void onDataResponse(BaseRspCmd baseRspCmd) {
                DeviceCmdInit.m354syncDeviceSetting$lambda7(DeviceCmdInit.this, (BpSettingRsp) baseRspCmd);
            }
        });
        CommandHandle.getInstance().executeReqCmd(TimeFormatReq.getReadInstance(), new ICommandResponse() { // from class: com.qcwireless.qcwatch.ui.base.watch.DeviceCmdInit$$ExternalSyntheticLambda7
            @Override // com.oudmon.ble.base.communication.ICommandResponse
            public final void onDataResponse(BaseRspCmd baseRspCmd) {
                DeviceCmdInit.m355syncDeviceSetting$lambda9(DeviceCmdInit.this, (TimeFormatRsp) baseRspCmd);
            }
        });
        CommandHandle.getInstance().executeReqCmd(TargetSettingReq.getReadInstance(), new ICommandResponse() { // from class: com.qcwireless.qcwatch.ui.base.watch.DeviceCmdInit$$ExternalSyntheticLambda6
            @Override // com.oudmon.ble.base.communication.ICommandResponse
            public final void onDataResponse(BaseRspCmd baseRspCmd) {
                DeviceCmdInit.m349syncDeviceSetting$lambda10(DeviceCmdInit.this, (TargetSettingRsp) baseRspCmd);
            }
        });
        ThreadExtKt.ktxRunOnBgSingle(this, new Function1<DeviceCmdInit, Unit>() { // from class: com.qcwireless.qcwatch.ui.base.watch.DeviceCmdInit$syncDeviceSetting$8
            @Override // kotlin.jvm.functions.Function1
            public /* bridge */ /* synthetic */ Unit invoke(DeviceCmdInit deviceCmdInit) {
                invoke2(deviceCmdInit);
                return Unit.INSTANCE;
            }

            /* renamed from: invoke, reason: avoid collision after fix types in other method */
            public final void invoke2(DeviceCmdInit ktxRunOnBgSingle) {
                Intrinsics.checkNotNullParameter(ktxRunOnBgSingle, "$this$ktxRunOnBgSingle");
                UserEntity queryUserByUid = UserProfileRepository.INSTANCE.getGetInstance().queryUserByUid(UserConfig.INSTANCE.getInstance().getUid());
                if (queryUserByUid != null) {
                    ThreadExtKt.ktxRunOnUi(ktxRunOnBgSingle, new AnonymousClass1(queryUserByUid, DateUtil.getAgeByBirthday(DateUtil.String2Date("yyyy-MM-dd", queryUserByUid.getBirthday() + "-01"))));
                }
            }

            /* JADX INFO: Access modifiers changed from: package-private */
            /* compiled from: DeviceCmdInit.kt */
            @Metadata(d1 = {"\u0000\f\n\u0000\n\u0002\u0010\u0002\n\u0002\u0018\u0002\n\u0000\u0010\u0000\u001a\u00020\u0001*\u00020\u0002H\n¢\u0006\u0002\b\u0003"}, d2 = {"<anonymous>", "", "Lcom/qcwireless/qcwatch/ui/base/watch/DeviceCmdInit;", "invoke"}, k = 3, mv = {1, 6, 0}, xi = 48)
            /* renamed from: com.qcwireless.qcwatch.ui.base.watch.DeviceCmdInit$syncDeviceSetting$8$1, reason: invalid class name */
            /* loaded from: classes2.dex */
            public static final class AnonymousClass1 extends Lambda implements Function1<DeviceCmdInit, Unit> {
                final /* synthetic */ int $age;
                final /* synthetic */ UserEntity $userEntity;

                /* JADX WARN: 'super' call moved to the top of the method (can break code semantics) */
                AnonymousClass1(UserEntity userEntity, int i) {
                    super(1);
                    this.$userEntity = userEntity;
                    this.$age = i;
                }

                /* JADX INFO: Access modifiers changed from: private */
                /* renamed from: invoke$lambda-0, reason: not valid java name */
                public static final void m357invoke$lambda0(TimeFormatRsp timeFormatRsp) {
                }

                @Override // kotlin.jvm.functions.Function1
                public /* bridge */ /* synthetic */ Unit invoke(DeviceCmdInit deviceCmdInit) {
                    invoke2(deviceCmdInit);
                    return Unit.INSTANCE;
                }

                /* renamed from: invoke, reason: avoid collision after fix types in other method */
                public final void invoke2(DeviceCmdInit ktxRunOnUi) {
                    DeviceSetting deviceSetting;
                    DeviceSetting deviceSetting2;
                    Intrinsics.checkNotNullParameter(ktxRunOnUi, "$this$ktxRunOnUi");
                    CommandHandle commandHandle = CommandHandle.getInstance();
                    deviceSetting = ktxRunOnUi.deviceSetting;
                    DeviceSetting deviceSetting3 = null;
                    if (deviceSetting == null) {
                        Intrinsics.throwUninitializedPropertyAccessException("deviceSetting");
                        deviceSetting = null;
                    }
                    boolean z = deviceSetting.getTimeFormat() == 0;
                    deviceSetting2 = ktxRunOnUi.deviceSetting;
                    if (deviceSetting2 == null) {
                        Intrinsics.throwUninitializedPropertyAccessException("deviceSetting");
                    } else {
                        deviceSetting3 = deviceSetting2;
                    }
                    commandHandle.executeReqCmd(TimeFormatReq.getWriteInstance(z, deviceSetting3.getMetricUnit(), this.$userEntity.getGender() - 1, this.$age, (int) this.$userEntity.getHeight(), (int) this.$userEntity.getWeight(), 120, 90, 0), DeviceCmdInit$syncDeviceSetting$8$1$$ExternalSyntheticLambda0.INSTANCE);
                    AwLog.i(Author.HeZhiYuan, this.$userEntity.getNickName());
                    LargeDataHandler.getInstance().setDeviceNickName(this.$userEntity.getNickName());
                }
            }
        });
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* renamed from: syncDeviceSetting$lambda-3, reason: not valid java name */
    public static final void m350syncDeviceSetting$lambda3(DeviceCmdInit this$0, HeartRateSettingRsp heartRateSettingRsp) {
        Intrinsics.checkNotNullParameter(this$0, "this$0");
        DeviceSetting deviceSetting = this$0.deviceSetting;
        DeviceSetting deviceSetting2 = null;
        if (deviceSetting == null) {
            Intrinsics.throwUninitializedPropertyAccessException("deviceSetting");
            deviceSetting = null;
        }
        deviceSetting.setHrDetection(heartRateSettingRsp.isEnable());
        DeviceSetting deviceSetting3 = this$0.deviceSetting;
        if (deviceSetting3 == null) {
            Intrinsics.throwUninitializedPropertyAccessException("deviceSetting");
            deviceSetting3 = null;
        }
        deviceSetting3.setHrInterval(heartRateSettingRsp.getHeartInterval());
        AwLog.i(Author.HeZhiYuan, Integer.valueOf(heartRateSettingRsp.getHeartInterval()));
        if (heartRateSettingRsp.getHeartInterval() > 0) {
            UserConfig.INSTANCE.getInstance().setHeartRateInterval(true);
            UserConfig.INSTANCE.getInstance().save();
        } else {
            UserConfig.INSTANCE.getInstance().setHeartRateInterval(false);
            UserConfig.INSTANCE.getInstance().save();
        }
        DeviceSetting deviceSetting4 = this$0.deviceSetting;
        if (deviceSetting4 == null) {
            Intrinsics.throwUninitializedPropertyAccessException("deviceSetting");
        } else {
            deviceSetting2 = deviceSetting4;
        }
        this$0.saveDeviceSetting(deviceSetting2);
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* renamed from: syncDeviceSetting$lambda-4, reason: not valid java name */
    public static final void m351syncDeviceSetting$lambda4(DeviceCmdInit this$0, HRVSettingRsp hRVSettingRsp) {
        Intrinsics.checkNotNullParameter(this$0, "this$0");
        DeviceSetting deviceSetting = this$0.deviceSetting;
        DeviceSetting deviceSetting2 = null;
        if (deviceSetting == null) {
            Intrinsics.throwUninitializedPropertyAccessException("deviceSetting");
            deviceSetting = null;
        }
        deviceSetting.setHrvEnable(hRVSettingRsp.isEnable());
        AwLog.i(Author.HeZhiYuan, "hrv->开关" + hRVSettingRsp.isEnable());
        DeviceSetting deviceSetting3 = this$0.deviceSetting;
        if (deviceSetting3 == null) {
            Intrinsics.throwUninitializedPropertyAccessException("deviceSetting");
        } else {
            deviceSetting2 = deviceSetting3;
        }
        this$0.saveDeviceSetting(deviceSetting2);
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* renamed from: syncDeviceSetting$lambda-5, reason: not valid java name */
    public static final void m352syncDeviceSetting$lambda5(DeviceCmdInit this$0, PressureSettingRsp pressureSettingRsp) {
        Intrinsics.checkNotNullParameter(this$0, "this$0");
        DeviceSetting deviceSetting = this$0.deviceSetting;
        DeviceSetting deviceSetting2 = null;
        if (deviceSetting == null) {
            Intrinsics.throwUninitializedPropertyAccessException("deviceSetting");
            deviceSetting = null;
        }
        deviceSetting.setPressureDetection(pressureSettingRsp.isEnable());
        DeviceSetting deviceSetting3 = this$0.deviceSetting;
        if (deviceSetting3 == null) {
            Intrinsics.throwUninitializedPropertyAccessException("deviceSetting");
        } else {
            deviceSetting2 = deviceSetting3;
        }
        this$0.saveDeviceSetting(deviceSetting2);
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* renamed from: syncDeviceSetting$lambda-6, reason: not valid java name */
    public static final void m353syncDeviceSetting$lambda6(DeviceCmdInit this$0, BloodOxygenSettingRsp bloodOxygenSettingRsp) {
        Intrinsics.checkNotNullParameter(this$0, "this$0");
        DeviceSetting deviceSetting = this$0.deviceSetting;
        DeviceSetting deviceSetting2 = null;
        if (deviceSetting == null) {
            Intrinsics.throwUninitializedPropertyAccessException("deviceSetting");
            deviceSetting = null;
        }
        deviceSetting.setBo2Detection(bloodOxygenSettingRsp.isEnable());
        DeviceSetting deviceSetting3 = this$0.deviceSetting;
        if (deviceSetting3 == null) {
            Intrinsics.throwUninitializedPropertyAccessException("deviceSetting");
        } else {
            deviceSetting2 = deviceSetting3;
        }
        this$0.saveDeviceSetting(deviceSetting2);
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* renamed from: syncDeviceSetting$lambda-7, reason: not valid java name */
    public static final void m354syncDeviceSetting$lambda7(DeviceCmdInit this$0, BpSettingRsp bpSettingRsp) {
        Intrinsics.checkNotNullParameter(this$0, "this$0");
        DeviceSetting deviceSetting = this$0.deviceSetting;
        DeviceSetting deviceSetting2 = null;
        if (deviceSetting == null) {
            Intrinsics.throwUninitializedPropertyAccessException("deviceSetting");
            deviceSetting = null;
        }
        deviceSetting.setBpSwitch(bpSettingRsp.isEnable());
        DeviceSetting deviceSetting3 = this$0.deviceSetting;
        if (deviceSetting3 == null) {
            Intrinsics.throwUninitializedPropertyAccessException("deviceSetting");
        } else {
            deviceSetting2 = deviceSetting3;
        }
        this$0.saveDeviceSetting(deviceSetting2);
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* renamed from: syncDeviceSetting$lambda-9, reason: not valid java name */
    public static final void m355syncDeviceSetting$lambda9(DeviceCmdInit this$0, TimeFormatRsp timeFormatRsp) {
        Intrinsics.checkNotNullParameter(this$0, "this$0");
        DeviceSetting deviceSetting = null;
        if (timeFormatRsp.is24()) {
            DeviceSetting deviceSetting2 = this$0.deviceSetting;
            if (deviceSetting2 == null) {
                Intrinsics.throwUninitializedPropertyAccessException("deviceSetting");
                deviceSetting2 = null;
            }
            deviceSetting2.setTimeFormat(0);
        } else {
            DeviceSetting deviceSetting3 = this$0.deviceSetting;
            if (deviceSetting3 == null) {
                Intrinsics.throwUninitializedPropertyAccessException("deviceSetting");
                deviceSetting3 = null;
            }
            deviceSetting3.setTimeFormat(1);
        }
        if (UserConfig.INSTANCE.getInstance().getMetric()) {
            DeviceSetting deviceSetting4 = this$0.deviceSetting;
            if (deviceSetting4 == null) {
                Intrinsics.throwUninitializedPropertyAccessException("deviceSetting");
                deviceSetting4 = null;
            }
            deviceSetting4.setMetricUnit(0);
        } else {
            DeviceSetting deviceSetting5 = this$0.deviceSetting;
            if (deviceSetting5 == null) {
                Intrinsics.throwUninitializedPropertyAccessException("deviceSetting");
                deviceSetting5 = null;
            }
            deviceSetting5.setMetricUnit(1);
        }
        DeviceSetting deviceSetting6 = this$0.deviceSetting;
        if (deviceSetting6 == null) {
            Intrinsics.throwUninitializedPropertyAccessException("deviceSetting");
            deviceSetting6 = null;
        }
        this$0.saveDeviceSetting(deviceSetting6);
        CommandHandle commandHandle = CommandHandle.getInstance();
        DeviceSetting deviceSetting7 = this$0.deviceSetting;
        if (deviceSetting7 == null) {
            Intrinsics.throwUninitializedPropertyAccessException("deviceSetting");
            deviceSetting7 = null;
        }
        boolean z = deviceSetting7.getTimeFormat() == 0;
        DeviceSetting deviceSetting8 = this$0.deviceSetting;
        if (deviceSetting8 == null) {
            Intrinsics.throwUninitializedPropertyAccessException("deviceSetting");
        } else {
            deviceSetting = deviceSetting8;
        }
        commandHandle.executeReqCmd(TimeFormatReq.getWriteInstance(z, (byte) deviceSetting.getMetricUnit()), new ICommandResponse() { // from class: com.qcwireless.qcwatch.ui.base.watch.DeviceCmdInit$$ExternalSyntheticLambda1
            @Override // com.oudmon.ble.base.communication.ICommandResponse
            public final void onDataResponse(BaseRspCmd baseRspCmd) {
                DeviceCmdInit.m356syncDeviceSetting$lambda9$lambda8((TimeFormatRsp) baseRspCmd);
            }
        });
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* renamed from: syncDeviceSetting$lambda-10, reason: not valid java name */
    public static final void m349syncDeviceSetting$lambda10(DeviceCmdInit this$0, final TargetSettingRsp targetSettingRsp) {
        Intrinsics.checkNotNullParameter(this$0, "this$0");
        AwLog.i(Author.HeZhiYuan, targetSettingRsp);
        if (targetSettingRsp.getAction() == 1) {
            ThreadExtKt.ktxRunOnBgSingle(this$0, new Function1<DeviceCmdInit, Unit>() { // from class: com.qcwireless.qcwatch.ui.base.watch.DeviceCmdInit$syncDeviceSetting$7$1
                /* JADX INFO: Access modifiers changed from: package-private */
                {
                    super(1);
                }

                @Override // kotlin.jvm.functions.Function1
                public /* bridge */ /* synthetic */ Unit invoke(DeviceCmdInit deviceCmdInit) {
                    invoke2(deviceCmdInit);
                    return Unit.INSTANCE;
                }

                /* renamed from: invoke, reason: avoid collision after fix types in other method */
                public final void invoke2(DeviceCmdInit ktxRunOnBgSingle) {
                    Intrinsics.checkNotNullParameter(ktxRunOnBgSingle, "$this$ktxRunOnBgSingle");
                    if (TargetSettingRsp.this.getStep() > 0) {
                        UserProfileRepository.INSTANCE.getGetInstance().insertTarget(new TargetEntity(UserConfig.INSTANCE.getInstance().getDeviceAddressNoClear(), TargetSettingRsp.this.getStep(), TargetSettingRsp.this.getCalorie() / 1000.0f, TargetSettingRsp.this.getDistance() / 1000.0f, 3.0f, 8.0f));
                        EventBus.getDefault().post(new DeviceNotifyTypeEvent(16));
                    }
                }
            });
        }
    }

    public final void saveDeviceSetting(DeviceSetting deviceSetting) {
        Intrinsics.checkNotNullParameter(deviceSetting, "deviceSetting");
        DeviceSettingRepository.INSTANCE.getGetInstance().saveDeviceSetting(new DeviceSettingEntity(UserConfig.INSTANCE.getInstance().getDeviceAddressNoClear(), DeviceSettingAction.WatchSetting, MoshiUtilsKt.toJson(deviceSetting)));
    }

    /* compiled from: DeviceCmdInit.kt */
    @Metadata(d1 = {"\u0000\u0014\n\u0002\u0018\u0002\n\u0002\u0010\u0000\n\u0002\b\u0002\n\u0002\u0018\u0002\n\u0002\b\u0005\b\u0086\u0003\u0018\u00002\u00020\u0001B\u0007\b\u0002¢\u0006\u0002\u0010\u0002R\u001b\u0010\u0003\u001a\u00020\u00048FX\u0086\u0084\u0002¢\u0006\f\n\u0004\b\u0007\u0010\b\u001a\u0004\b\u0005\u0010\u0006¨\u0006\t"}, d2 = {"Lcom/qcwireless/qcwatch/ui/base/watch/DeviceCmdInit$Companion;", "", "()V", "getInstance", "Lcom/qcwireless/qcwatch/ui/base/watch/DeviceCmdInit;", "getGetInstance", "()Lcom/qcwireless/qcwatch/ui/base/watch/DeviceCmdInit;", "getInstance$delegate", "Lkotlin/Lazy;", "app_championRelease"}, k = 1, mv = {1, 6, 0}, xi = 48)
    /* loaded from: classes2.dex */
    public static final class Companion {
        public /* synthetic */ Companion(DefaultConstructorMarker defaultConstructorMarker) {
            this();
        }

        private Companion() {
        }

        public final DeviceCmdInit getGetInstance() {
            return (DeviceCmdInit) DeviceCmdInit.getInstance$delegate.getValue();
        }
    }
}
