package com.qcwireless.qcwatch.ui.home.step.day;

import android.content.Intent;
import android.os.Bundle;
import android.os.Parcelable;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import androidx.constraintlayout.core.motion.utils.TypedValues;
import androidx.fragment.app.FragmentActivity;
import androidx.lifecycle.LifecycleOwner;
import androidx.lifecycle.Observer;
import com.iwown.awlog.Author;
import com.iwown.awlog.AwLog;
import com.oudmon.ble.base.bluetooth.BleOperateManager;
import com.oudmon.ble.base.communication.responseImpl.DeviceNotifyListener;
import com.oudmon.ble.base.communication.rsp.DeviceNotifyRsp;
import com.oudmon.ble.base.communication.rsp.ReadDetailSportDataRsp;
import com.oudmon.ble.base.communication.rsp.TodaySportDataRsp;
import com.oudmon.ble.base.communication.utils.BLEDataFormatUtils;
import com.oudmon.ble.base.communication.utils.ByteUtil;
import com.oudmon.ble.base.util.LogToFile;
import com.qcwireless.qc_utils.date.DateUtil;
import com.qcwireless.qcwatch.QCApplication;
import com.qcwireless.qcwatch.base.event.CalendarNotifyEvent;
import com.qcwireless.qcwatch.base.event.HomeStepRefreshEvent;
import com.qcwireless.qcwatch.base.event.ManualRefreshEvent;
import com.qcwireless.qcwatch.base.event.MessageEvent;
import com.qcwireless.qcwatch.base.ktx.ThreadExtKt;
import com.qcwireless.qcwatch.base.pref.UserConfig;
import com.qcwireless.qcwatch.base.utils.MetricUtilsKt;
import com.qcwireless.qcwatch.base.view.ViewKt;
import com.qcwireless.qcwatch.databinding.FragmentDayStepBinding;
import com.qcwireless.qcwatch.ui.activity.MainActivity;
import com.qcwireless.qcwatch.ui.base.BaseFragment;
import com.qcwireless.qcwatch.ui.base.repository.base.BaseDeviceResult;
import com.qcwireless.qcwatch.ui.base.repository.entity.SportPlusDetail;
import com.qcwireless.qcwatch.ui.base.repository.entity.TargetEntity;
import com.qcwireless.qcwatch.ui.base.repository.healthy.SportPlusRepository;
import com.qcwireless.qcwatch.ui.base.repository.healthy.StepDetailRepository;
import com.qcwireless.qcwatch.ui.base.repository.mine.UserProfileRepository;
import com.qcwireless.qcwatch.ui.base.view.QDateSwitchView;
import com.qcwireless.qcwatch.ui.base.view.QStepBarChart;
import com.qcwireless.qcwatch.ui.home.healthy.sync.SyncStatus;
import com.qcwireless.qcwatch.ui.home.sport.SportActivity;
import com.qcwireless.qcwatch.ui.home.step.StepActivity;
import com.qcwireless.qcwatch.ui.home.step.day.DayStepFragmentViewModel;
import com.qcwireless.ring.R;
import java.io.Serializable;
import java.math.RoundingMode;
import java.text.DecimalFormat;
import java.util.ArrayList;
import kotlin.Lazy;
import kotlin.LazyKt;
import kotlin.Metadata;
import kotlin.Pair;
import kotlin.Unit;
import kotlin.jvm.functions.Function0;
import kotlin.jvm.functions.Function1;
import kotlin.jvm.internal.DefaultConstructorMarker;
import kotlin.jvm.internal.Intrinsics;
import kotlin.jvm.internal.Ref;
import kotlin.jvm.internal.Reflection;
import org.greenrobot.eventbus.EventBus;
import org.greenrobot.eventbus.Subscribe;
import org.greenrobot.eventbus.ThreadMode;
import org.koin.androidx.viewmodel.ext.android.LifecycleOwnerExtKt;
import org.koin.core.qualifier.Qualifier;

/* compiled from: DayStepFragment.kt */
@Metadata(d1 = {"\u0000r\n\u0002\u0018\u0002\n\u0002\u0018\u0002\n\u0002\b\u0002\n\u0002\u0018\u0002\n\u0000\n\u0002\u0018\u0002\n\u0000\n\u0002\u0018\u0002\n\u0000\n\u0002\u0018\u0002\n\u0000\n\u0002\u0018\u0002\n\u0000\n\u0002\u0018\u0002\n\u0002\b\u0005\n\u0002\u0010\u0002\n\u0002\b\u0004\n\u0002\u0018\u0002\n\u0000\n\u0002\u0018\u0002\n\u0000\n\u0002\u0018\u0002\n\u0000\n\u0002\u0018\u0002\n\u0002\b\u0003\n\u0002\u0018\u0002\n\u0002\b\u0003\n\u0002\u0010\u000e\n\u0000\n\u0002\u0010\u0007\n\u0002\b\u0002\n\u0002\u0010\b\n\u0002\b\u0004\u0018\u0000 .2\u00020\u0001:\u0002./B\u0005¢\u0006\u0002\u0010\u0002J\u0010\u0010\u0013\u001a\u00020\u00142\u0006\u0010\u0015\u001a\u00020\u0006H\u0002J\b\u0010\u0016\u001a\u00020\u0014H\u0016J\u0012\u0010\u0017\u001a\u00020\u00142\b\u0010\u0018\u001a\u0004\u0018\u00010\u0019H\u0016J&\u0010\u001a\u001a\u0004\u0018\u00010\u001b2\u0006\u0010\u001c\u001a\u00020\u001d2\b\u0010\u001e\u001a\u0004\u0018\u00010\u001f2\b\u0010\u0018\u001a\u0004\u0018\u00010\u0019H\u0016J\b\u0010 \u001a\u00020\u0014H\u0016J\u0010\u0010!\u001a\u00020\u00142\u0006\u0010\"\u001a\u00020#H\u0007J\b\u0010$\u001a\u00020\u0014H\u0016J(\u0010%\u001a\u00020\u00142\u0006\u0010&\u001a\u00020'2\u0006\u0010(\u001a\u00020)2\u0006\u0010*\u001a\u00020'2\u0006\u0010+\u001a\u00020,H\u0002J\b\u0010-\u001a\u00020\u0014H\u0002R\u000e\u0010\u0003\u001a\u00020\u0004X\u0082.¢\u0006\u0002\n\u0000R\u000e\u0010\u0005\u001a\u00020\u0006X\u0082\u000e¢\u0006\u0002\n\u0000R\u0012\u0010\u0007\u001a\u00060\bR\u00020\u0000X\u0082.¢\u0006\u0002\n\u0000R\u000e\u0010\t\u001a\u00020\nX\u0082.¢\u0006\u0002\n\u0000R\u000e\u0010\u000b\u001a\u00020\fX\u0082\u000e¢\u0006\u0002\n\u0000R\u001b\u0010\r\u001a\u00020\u000e8BX\u0082\u0084\u0002¢\u0006\f\n\u0004\b\u0011\u0010\u0012\u001a\u0004\b\u000f\u0010\u0010¨\u00060"}, d2 = {"Lcom/qcwireless/qcwatch/ui/home/step/day/DayStepFragment;", "Lcom/qcwireless/qcwatch/ui/base/BaseFragment;", "()V", "binding", "Lcom/qcwireless/qcwatch/databinding/FragmentDayStepBinding;", "date", "Lcom/qcwireless/qc_utils/date/DateUtil;", "deviceNotifyListener", "Lcom/qcwireless/qcwatch/ui/home/step/day/DayStepFragment$MyDeviceNotifyListener;", "df", "Ljava/text/DecimalFormat;", TypedValues.AttributesType.S_TARGET, "Lcom/qcwireless/qcwatch/ui/base/repository/entity/TargetEntity;", "viewModel", "Lcom/qcwireless/qcwatch/ui/home/step/day/DayStepFragmentViewModel;", "getViewModel", "()Lcom/qcwireless/qcwatch/ui/home/step/day/DayStepFragmentViewModel;", "viewModel$delegate", "Lkotlin/Lazy;", "daySportPlusDetail", "", "start", "loadDataOnce", "onCreate", "savedInstanceState", "Landroid/os/Bundle;", "onCreateView", "Landroid/view/View;", "inflater", "Landroid/view/LayoutInflater;", "container", "Landroid/view/ViewGroup;", "onDestroy", "onMessageEvent", "messageEvent", "Lcom/qcwireless/qcwatch/base/event/MessageEvent;", "onResume", "queryTarget", "step", "", "distanceSource", "", "distance", "calorie", "", "syncTodayStep", "Companion", "MyDeviceNotifyListener", "app_championRelease"}, k = 1, mv = {1, 6, 0}, xi = 48)
/* loaded from: classes2.dex */
public final class DayStepFragment extends BaseFragment {

    /* renamed from: Companion, reason: from kotlin metadata */
    public static final Companion INSTANCE = new Companion(null);
    private FragmentDayStepBinding binding;
    private DateUtil date;
    private MyDeviceNotifyListener deviceNotifyListener;
    private DecimalFormat df;
    private TargetEntity target;

    /* renamed from: viewModel$delegate, reason: from kotlin metadata */
    private final Lazy viewModel;

    public DayStepFragment() {
        final DayStepFragment dayStepFragment = this;
        final Qualifier qualifier = null;
        final byte b = 0 == true ? 1 : 0;
        this.viewModel = LazyKt.lazy(new Function0<DayStepFragmentViewModel>() { // from class: com.qcwireless.qcwatch.ui.home.step.day.DayStepFragment$special$$inlined$viewModel$default$1
            /* JADX WARN: 'super' call moved to the top of the method (can break code semantics) */
            {
                super(0);
            }

            /* JADX WARN: Can't rename method to resolve collision */
            /* JADX WARN: Type inference failed for: r0v1, types: [androidx.lifecycle.ViewModel, com.qcwireless.qcwatch.ui.home.step.day.DayStepFragmentViewModel] */
            @Override // kotlin.jvm.functions.Function0
            public final DayStepFragmentViewModel invoke() {
                return LifecycleOwnerExtKt.getViewModel(LifecycleOwner.this, Reflection.getOrCreateKotlinClass(DayStepFragmentViewModel.class), qualifier, b);
            }
        });
        this.date = new DateUtil();
        this.target = new TargetEntity(UserConfig.INSTANCE.getInstance().getDeviceAddressNoClear(), 10000, 200.0f, 5.0f, 1.5f, 8.0f);
    }

    /* JADX INFO: Access modifiers changed from: private */
    public final DayStepFragmentViewModel getViewModel() {
        return (DayStepFragmentViewModel) this.viewModel.getValue();
    }

    @Override // com.qcwireless.qcwatch.ui.base.BaseFragment, androidx.fragment.app.Fragment
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
    }

    @Override // com.qcwireless.qcwatch.ui.base.BaseFragment, androidx.fragment.app.Fragment
    public View onCreateView(LayoutInflater inflater, ViewGroup container, Bundle savedInstanceState) {
        Intrinsics.checkNotNullParameter(inflater, "inflater");
        FragmentDayStepBinding inflate = FragmentDayStepBinding.inflate(getLayoutInflater());
        Intrinsics.checkNotNullExpressionValue(inflate, "inflate(layoutInflater)");
        this.binding = inflate;
        if (inflate == null) {
            Intrinsics.throwUninitializedPropertyAccessException("binding");
            inflate = null;
        }
        return inflate.getRoot();
    }

    @Override // com.qcwireless.qcwatch.ui.base.BaseFragment
    public void loadDataOnce() {
        super.loadDataOnce();
        EventBus.getDefault().register(this);
        DecimalFormat decimalFormat = new DecimalFormat("0.00");
        this.df = decimalFormat;
        decimalFormat.setRoundingMode(RoundingMode.HALF_UP);
        DayStepFragmentViewModel viewModel = getViewModel();
        String y_m_d = new DateUtil().getY_M_D();
        Intrinsics.checkNotNullExpressionValue(y_m_d, "DateUtil().y_M_D");
        viewModel.queryStepDetailByDate(y_m_d);
        final FragmentDayStepBinding fragmentDayStepBinding = this.binding;
        FragmentDayStepBinding fragmentDayStepBinding2 = null;
        if (fragmentDayStepBinding == null) {
            Intrinsics.throwUninitializedPropertyAccessException("binding");
            fragmentDayStepBinding = null;
        }
        fragmentDayStepBinding.qcDateChange.setDateUtil(new DateUtil());
        fragmentDayStepBinding.qcDateChange.setDateListener(new QDateSwitchView.QDateBefore() { // from class: com.qcwireless.qcwatch.ui.home.step.day.DayStepFragment$loadDataOnce$1$1
            @Override // com.qcwireless.qcwatch.ui.base.view.QDateSwitchView.QDateBefore
            public void clickBefore(boolean r3, DateUtil dateUtil) {
                DayStepFragmentViewModel viewModel2;
                Intrinsics.checkNotNullParameter(dateUtil, "dateUtil");
                FragmentDayStepBinding.this.qcDateChange.setDateUtil(dateUtil);
                viewModel2 = this.getViewModel();
                String y_m_d2 = dateUtil.getY_M_D();
                Intrinsics.checkNotNullExpressionValue(y_m_d2, "dateUtil.y_M_D");
                viewModel2.queryStepDetailByDate(y_m_d2);
                this.date = dateUtil;
            }
        });
        fragmentDayStepBinding.qcDateChange.setCalendarClick(new View.OnClickListener() { // from class: com.qcwireless.qcwatch.ui.home.step.day.DayStepFragment$$ExternalSyntheticLambda2
            @Override // android.view.View.OnClickListener
            public final void onClick(View view) {
                DayStepFragment.m906loadDataOnce$lambda2$lambda0(DayStepFragment.this, view);
            }
        });
        fragmentDayStepBinding.qcStepChart.setListener(new QStepBarChart.OnSelectedListener() { // from class: com.qcwireless.qcwatch.ui.home.step.day.DayStepFragment$$ExternalSyntheticLambda4
            @Override // com.qcwireless.qcwatch.ui.base.view.QStepBarChart.OnSelectedListener
            public final void onSelected(QStepBarChart.StepDataBean stepDataBean) {
                DayStepFragment.m907loadDataOnce$lambda2$lambda1(DayStepFragment.this, fragmentDayStepBinding, stepDataBean);
            }
        });
        getViewModel().getUiState().observe(this, new Observer() { // from class: com.qcwireless.qcwatch.ui.home.step.day.DayStepFragment$$ExternalSyntheticLambda3
            @Override // androidx.lifecycle.Observer
            public final void onChanged(Object obj) {
                DayStepFragment.m908loadDataOnce$lambda4(DayStepFragment.this, (DayStepFragmentViewModel.DayStepUI) obj);
            }
        });
        FragmentDayStepBinding fragmentDayStepBinding3 = this.binding;
        if (fragmentDayStepBinding3 == null) {
            Intrinsics.throwUninitializedPropertyAccessException("binding");
            fragmentDayStepBinding3 = null;
        }
        fragmentDayStepBinding3.todayStepActivity.setOnClickListener(new View.OnClickListener() { // from class: com.qcwireless.qcwatch.ui.home.step.day.DayStepFragment$$ExternalSyntheticLambda0
            @Override // android.view.View.OnClickListener
            public final void onClick(View view) {
                DayStepFragment.m909loadDataOnce$lambda5(DayStepFragment.this, view);
            }
        });
        FragmentDayStepBinding fragmentDayStepBinding4 = this.binding;
        if (fragmentDayStepBinding4 == null) {
            Intrinsics.throwUninitializedPropertyAccessException("binding");
        } else {
            fragmentDayStepBinding2 = fragmentDayStepBinding4;
        }
        fragmentDayStepBinding2.tvMoreText.setOnClickListener(new View.OnClickListener() { // from class: com.qcwireless.qcwatch.ui.home.step.day.DayStepFragment$$ExternalSyntheticLambda1
            @Override // android.view.View.OnClickListener
            public final void onClick(View view) {
                DayStepFragment.m910loadDataOnce$lambda6(DayStepFragment.this, view);
            }
        });
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* renamed from: loadDataOnce$lambda-2$lambda-0, reason: not valid java name */
    public static final void m906loadDataOnce$lambda2$lambda0(DayStepFragment this$0, View view) {
        Intrinsics.checkNotNullParameter(this$0, "this$0");
        if (this$0.getActivity() instanceof MainActivity) {
            ((MainActivity) this$0.getActivity()).doCalendar(1, this$0.date);
        } else if (this$0.getActivity() instanceof StepActivity) {
            ((StepActivity) this$0.getActivity()).doCalendar(this$0.date);
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* renamed from: loadDataOnce$lambda-2$lambda-1, reason: not valid java name */
    public static final void m907loadDataOnce$lambda2$lambda1(DayStepFragment this$0, FragmentDayStepBinding this_run, QStepBarChart.StepDataBean stepDataBean) {
        Intrinsics.checkNotNullParameter(this$0, "this$0");
        Intrinsics.checkNotNullParameter(this_run, "$this_run");
        if (stepDataBean != null) {
            FragmentDayStepBinding fragmentDayStepBinding = this$0.binding;
            if (fragmentDayStepBinding == null) {
                Intrinsics.throwUninitializedPropertyAccessException("binding");
                fragmentDayStepBinding = null;
            }
            fragmentDayStepBinding.tvStepRange.setText(DateUtil.dayMinToStr((int) (stepDataBean.getTimeStamp() / 60)));
            this_run.tvDayStep.setText(String.valueOf(stepDataBean.getSteps()));
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Removed duplicated region for block: B:27:0x0125  */
    /* JADX WARN: Removed duplicated region for block: B:30:0x013f  */
    /* JADX WARN: Removed duplicated region for block: B:33:0x0156  */
    /* JADX WARN: Removed duplicated region for block: B:37:0x015a  */
    /* JADX WARN: Type inference failed for: r11v0, types: [java.lang.Object, com.qcwireless.qcwatch.ui.home.step.day.DayStepFragment] */
    /* JADX WARN: Type inference failed for: r3v20, types: [com.qcwireless.qcwatch.ui.base.view.QStepComponentView] */
    /* JADX WARN: Type inference failed for: r3v23, types: [com.qcwireless.qcwatch.ui.base.view.QStepComponentView] */
    /* JADX WARN: Type inference failed for: r4v10, types: [java.lang.String] */
    /* JADX WARN: Type inference failed for: r4v14 */
    /* JADX WARN: Type inference failed for: r4v19 */
    /* JADX WARN: Type inference failed for: r4v20 */
    /* JADX WARN: Type inference failed for: r4v7, types: [boolean] */
    /* JADX WARN: Type inference failed for: r4v8 */
    /* JADX WARN: Type inference failed for: r4v9 */
    /* renamed from: loadDataOnce$lambda-4, reason: not valid java name */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
        To view partially-correct code enable 'Show inconsistent code' option in preferences
    */
    public static final void m908loadDataOnce$lambda4(com.qcwireless.qcwatch.ui.home.step.day.DayStepFragment r11, com.qcwireless.qcwatch.ui.home.step.day.DayStepFragmentViewModel.DayStepUI r12) {
        /*
            Method dump skipped, instructions count: 363
            To view this dump change 'Code comments level' option to 'DEBUG'
        */
        throw new UnsupportedOperationException("Method not decompiled: com.qcwireless.qcwatch.ui.home.step.day.DayStepFragment.m908loadDataOnce$lambda4(com.qcwireless.qcwatch.ui.home.step.day.DayStepFragment, com.qcwireless.qcwatch.ui.home.step.day.DayStepFragmentViewModel$DayStepUI):void");
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* renamed from: loadDataOnce$lambda-5, reason: not valid java name */
    public static final void m909loadDataOnce$lambda5(DayStepFragment this$0, View view) {
        Intrinsics.checkNotNullParameter(this$0, "this$0");
        DayStepFragment dayStepFragment = this$0;
        FragmentActivity it = dayStepFragment.getActivity();
        if (it != null) {
            ArrayList<Pair> arrayList = new ArrayList();
            Intrinsics.checkNotNullExpressionValue(it, "it");
            Intent intent = new Intent(it, (Class<?>) SportActivity.class);
            for (Pair pair : arrayList) {
                if (pair != null) {
                    String str = (String) pair.getFirst();
                    Object second = pair.getSecond();
                    if (second instanceof Integer) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).intValue()), "putExtra(name, value)");
                    } else if (second instanceof Byte) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).byteValue()), "putExtra(name, value)");
                    } else if (second instanceof Character) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Character) second).charValue()), "putExtra(name, value)");
                    } else if (second instanceof Short) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).shortValue()), "putExtra(name, value)");
                    } else if (second instanceof Boolean) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Boolean) second).booleanValue()), "putExtra(name, value)");
                    } else if (second instanceof Long) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).longValue()), "putExtra(name, value)");
                    } else if (second instanceof Float) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).floatValue()), "putExtra(name, value)");
                    } else if (second instanceof Double) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).doubleValue()), "putExtra(name, value)");
                    } else if (second instanceof String) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (String) second), "putExtra(name, value)");
                    } else if (second instanceof CharSequence) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (CharSequence) second), "putExtra(name, value)");
                    } else if (second instanceof Parcelable) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Parcelable) second), "putExtra(name, value)");
                    } else if (second instanceof Object[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Serializable) second), "putExtra(name, value)");
                    } else if (second instanceof ArrayList) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Serializable) second), "putExtra(name, value)");
                    } else if (second instanceof Serializable) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Serializable) second), "putExtra(name, value)");
                    } else if (second instanceof boolean[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (boolean[]) second), "putExtra(name, value)");
                    } else if (second instanceof byte[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (byte[]) second), "putExtra(name, value)");
                    } else if (second instanceof short[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (short[]) second), "putExtra(name, value)");
                    } else if (second instanceof char[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (char[]) second), "putExtra(name, value)");
                    } else if (second instanceof int[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (int[]) second), "putExtra(name, value)");
                    } else if (second instanceof long[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (long[]) second), "putExtra(name, value)");
                    } else if (second instanceof float[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (float[]) second), "putExtra(name, value)");
                    } else if (second instanceof double[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (double[]) second), "putExtra(name, value)");
                    } else if (second instanceof Bundle) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Bundle) second), "putExtra(name, value)");
                    } else if (second instanceof Intent) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Parcelable) second), "putExtra(name, value)");
                    } else {
                        Unit unit = Unit.INSTANCE;
                    }
                }
            }
            dayStepFragment.startActivity(intent);
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* renamed from: loadDataOnce$lambda-6, reason: not valid java name */
    public static final void m910loadDataOnce$lambda6(DayStepFragment this$0, View view) {
        Intrinsics.checkNotNullParameter(this$0, "this$0");
        DayStepFragment dayStepFragment = this$0;
        FragmentActivity it = dayStepFragment.getActivity();
        if (it != null) {
            ArrayList<Pair> arrayList = new ArrayList();
            Intrinsics.checkNotNullExpressionValue(it, "it");
            Intent intent = new Intent(it, (Class<?>) SportActivity.class);
            for (Pair pair : arrayList) {
                if (pair != null) {
                    String str = (String) pair.getFirst();
                    Object second = pair.getSecond();
                    if (second instanceof Integer) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).intValue()), "putExtra(name, value)");
                    } else if (second instanceof Byte) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).byteValue()), "putExtra(name, value)");
                    } else if (second instanceof Character) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Character) second).charValue()), "putExtra(name, value)");
                    } else if (second instanceof Short) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).shortValue()), "putExtra(name, value)");
                    } else if (second instanceof Boolean) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Boolean) second).booleanValue()), "putExtra(name, value)");
                    } else if (second instanceof Long) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).longValue()), "putExtra(name, value)");
                    } else if (second instanceof Float) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).floatValue()), "putExtra(name, value)");
                    } else if (second instanceof Double) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).doubleValue()), "putExtra(name, value)");
                    } else if (second instanceof String) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (String) second), "putExtra(name, value)");
                    } else if (second instanceof CharSequence) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (CharSequence) second), "putExtra(name, value)");
                    } else if (second instanceof Parcelable) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Parcelable) second), "putExtra(name, value)");
                    } else if (second instanceof Object[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Serializable) second), "putExtra(name, value)");
                    } else if (second instanceof ArrayList) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Serializable) second), "putExtra(name, value)");
                    } else if (second instanceof Serializable) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Serializable) second), "putExtra(name, value)");
                    } else if (second instanceof boolean[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (boolean[]) second), "putExtra(name, value)");
                    } else if (second instanceof byte[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (byte[]) second), "putExtra(name, value)");
                    } else if (second instanceof short[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (short[]) second), "putExtra(name, value)");
                    } else if (second instanceof char[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (char[]) second), "putExtra(name, value)");
                    } else if (second instanceof int[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (int[]) second), "putExtra(name, value)");
                    } else if (second instanceof long[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (long[]) second), "putExtra(name, value)");
                    } else if (second instanceof float[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (float[]) second), "putExtra(name, value)");
                    } else if (second instanceof double[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (double[]) second), "putExtra(name, value)");
                    } else if (second instanceof Bundle) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Bundle) second), "putExtra(name, value)");
                    } else if (second instanceof Intent) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Parcelable) second), "putExtra(name, value)");
                    } else {
                        Unit unit = Unit.INSTANCE;
                    }
                }
            }
            dayStepFragment.startActivity(intent);
        }
    }

    @Subscribe(threadMode = ThreadMode.MAIN)
    public final void onMessageEvent(MessageEvent messageEvent) {
        Intrinsics.checkNotNullParameter(messageEvent, "messageEvent");
        if (messageEvent instanceof ManualRefreshEvent ? true : messageEvent instanceof HomeStepRefreshEvent) {
            ThreadExtKt.ktxRunOnUi(this, new Function1<DayStepFragment, Unit>() { // from class: com.qcwireless.qcwatch.ui.home.step.day.DayStepFragment$onMessageEvent$1
                @Override // kotlin.jvm.functions.Function1
                public /* bridge */ /* synthetic */ Unit invoke(DayStepFragment dayStepFragment) {
                    invoke2(dayStepFragment);
                    return Unit.INSTANCE;
                }

                /* renamed from: invoke, reason: avoid collision after fix types in other method */
                public final void invoke2(DayStepFragment ktxRunOnUi) {
                    Intrinsics.checkNotNullParameter(ktxRunOnUi, "$this$ktxRunOnUi");
                    FragmentDayStepBinding fragmentDayStepBinding = ktxRunOnUi.binding;
                    if (fragmentDayStepBinding == null) {
                        Intrinsics.throwUninitializedPropertyAccessException("binding");
                        fragmentDayStepBinding = null;
                    }
                    fragmentDayStepBinding.qcDateChange.setDateUtil(ktxRunOnUi.date);
                }
            });
            if (this.date.isToday()) {
                syncTodayStep();
            } else {
                DayStepFragmentViewModel viewModel = getViewModel();
                String y_m_d = this.date.getY_M_D();
                Intrinsics.checkNotNullExpressionValue(y_m_d, "date.y_M_D");
                viewModel.queryStepDetailByDate(y_m_d);
            }
            daySportPlusDetail(this.date);
            return;
        }
        if (messageEvent instanceof CalendarNotifyEvent) {
            DateUtil date = ((CalendarNotifyEvent) messageEvent).getDate();
            this.date = date;
            FragmentDayStepBinding fragmentDayStepBinding = this.binding;
            if (fragmentDayStepBinding == null) {
                Intrinsics.throwUninitializedPropertyAccessException("binding");
                fragmentDayStepBinding = null;
            }
            fragmentDayStepBinding.qcDateChange.setDateUtil(date);
            AwLog.i(Author.HeZhiYuan, date.getY_M_D());
            DayStepFragmentViewModel viewModel2 = getViewModel();
            String y_m_d2 = date.getY_M_D();
            Intrinsics.checkNotNullExpressionValue(y_m_d2, "calendarDate.y_M_D");
            viewModel2.queryStepDetailByDate(y_m_d2);
        }
    }

    private final void syncTodayStep() {
        StepDetailRepository.INSTANCE.getGetInstance().syncTodayStep(new BaseDeviceResult<TodaySportDataRsp>() { // from class: com.qcwireless.qcwatch.ui.home.step.day.DayStepFragment$syncTodayStep$1
            @Override // com.qcwireless.qcwatch.ui.base.repository.base.BaseDeviceResult
            public void result(int errorCode, TodaySportDataRsp t) {
                Intrinsics.checkNotNullParameter(t, "t");
                AwLog.i(Author.HeZhiYuan, "-----1");
            }
        });
        StepDetailRepository.INSTANCE.getGetInstance().syncTodayStepDetail(0, new BaseDeviceResult<ReadDetailSportDataRsp>() { // from class: com.qcwireless.qcwatch.ui.home.step.day.DayStepFragment$syncTodayStep$2
            @Override // com.qcwireless.qcwatch.ui.base.repository.base.BaseDeviceResult
            public void result(int errorCode, ReadDetailSportDataRsp t) {
                DayStepFragmentViewModel viewModel;
                Intrinsics.checkNotNullParameter(t, "t");
                ThreadExtKt.ktxRunOnBgSingleAnother(this, new Function1<DayStepFragment$syncTodayStep$2, Unit>() { // from class: com.qcwireless.qcwatch.ui.home.step.day.DayStepFragment$syncTodayStep$2$result$1
                    @Override // kotlin.jvm.functions.Function1
                    public /* bridge */ /* synthetic */ Unit invoke(DayStepFragment$syncTodayStep$2 dayStepFragment$syncTodayStep$2) {
                        invoke2(dayStepFragment$syncTodayStep$2);
                        return Unit.INSTANCE;
                    }

                    /* renamed from: invoke, reason: avoid collision after fix types in other method */
                    public final void invoke2(DayStepFragment$syncTodayStep$2 ktxRunOnBgSingleAnother) {
                        Intrinsics.checkNotNullParameter(ktxRunOnBgSingleAnother, "$this$ktxRunOnBgSingleAnother");
                        StepDetailRepository getInstance = StepDetailRepository.INSTANCE.getGetInstance();
                        String y_m_d = new DateUtil().getY_M_D();
                        Intrinsics.checkNotNullExpressionValue(y_m_d, "DateUtil().y_M_D");
                        getInstance.queryStepDetail(y_m_d);
                    }
                });
                viewModel = DayStepFragment.this.getViewModel();
                String y_m_d = new DateUtil().getY_M_D();
                Intrinsics.checkNotNullExpressionValue(y_m_d, "DateUtil().y_M_D");
                viewModel.queryStepDetailByDate(y_m_d);
            }
        });
    }

    @Override // com.qcwireless.qcwatch.ui.base.BaseFragment, androidx.fragment.app.Fragment
    public void onResume() {
        super.onResume();
        this.deviceNotifyListener = new MyDeviceNotifyListener();
        BleOperateManager bleOperateManager = BleOperateManager.getInstance();
        MyDeviceNotifyListener myDeviceNotifyListener = this.deviceNotifyListener;
        if (myDeviceNotifyListener == null) {
            Intrinsics.throwUninitializedPropertyAccessException("deviceNotifyListener");
            myDeviceNotifyListener = null;
        }
        bleOperateManager.addOutDeviceListener(11, myDeviceNotifyListener);
    }

    private final void queryTarget(final String step, final float distanceSource, final String distance, final int calorie) {
        ThreadExtKt.ktxRunOnBgSingle(this, new Function1<DayStepFragment, Unit>() { // from class: com.qcwireless.qcwatch.ui.home.step.day.DayStepFragment$queryTarget$1
            /* JADX INFO: Access modifiers changed from: package-private */
            /* JADX WARN: 'super' call moved to the top of the method (can break code semantics) */
            {
                super(1);
            }

            @Override // kotlin.jvm.functions.Function1
            public /* bridge */ /* synthetic */ Unit invoke(DayStepFragment dayStepFragment) {
                invoke2(dayStepFragment);
                return Unit.INSTANCE;
            }

            /* JADX WARN: Multi-variable type inference failed */
            /* JADX WARN: Type inference failed for: r1v2, types: [T, com.qcwireless.qcwatch.ui.base.repository.entity.TargetEntity] */
            /* JADX WARN: Type inference failed for: r1v33, types: [T, com.qcwireless.qcwatch.ui.base.repository.entity.TargetEntity] */
            /* renamed from: invoke, reason: avoid collision after fix types in other method */
            public final void invoke2(final DayStepFragment ktxRunOnBgSingle) {
                String string;
                Intrinsics.checkNotNullParameter(ktxRunOnBgSingle, "$this$ktxRunOnBgSingle");
                final Ref.ObjectRef objectRef = new Ref.ObjectRef();
                objectRef.element = UserProfileRepository.INSTANCE.getGetInstance().queryTarget();
                if (objectRef.element == 0) {
                    objectRef.element = new TargetEntity(UserConfig.INSTANCE.getInstance().getDeviceAddressNoClear(), 10000, 200.0f, 5.0f, 1.5f, 8.0f);
                }
                ktxRunOnBgSingle.target = (TargetEntity) objectRef.element;
                FragmentDayStepBinding fragmentDayStepBinding = ktxRunOnBgSingle.binding;
                if (fragmentDayStepBinding == null) {
                    Intrinsics.throwUninitializedPropertyAccessException("binding");
                    fragmentDayStepBinding = null;
                }
                FragmentDayStepBinding fragmentDayStepBinding2 = fragmentDayStepBinding;
                final String str = step;
                final float f = distanceSource;
                final int i = calorie;
                final String str2 = distance;
                if (UserConfig.INSTANCE.getInstance().getMetric()) {
                    string = ktxRunOnBgSingle.getString(R.string.qc_text_88);
                } else {
                    string = ktxRunOnBgSingle.getString(R.string.qc_text_358);
                }
                final String str3 = string;
                Intrinsics.checkNotNullExpressionValue(str3, "if (UserConfig.getInstan…xt_358)\n                }");
                ThreadExtKt.ktxRunOnUi(fragmentDayStepBinding2, new Function1<FragmentDayStepBinding, Unit>() { // from class: com.qcwireless.qcwatch.ui.home.step.day.DayStepFragment$queryTarget$1$1$1
                    /* JADX INFO: Access modifiers changed from: package-private */
                    /* JADX WARN: 'super' call moved to the top of the method (can break code semantics) */
                    {
                        super(1);
                    }

                    @Override // kotlin.jvm.functions.Function1
                    public /* bridge */ /* synthetic */ Unit invoke(FragmentDayStepBinding fragmentDayStepBinding3) {
                        invoke2(fragmentDayStepBinding3);
                        return Unit.INSTANCE;
                    }

                    /* renamed from: invoke, reason: avoid collision after fix types in other method */
                    public final void invoke2(FragmentDayStepBinding ktxRunOnUi) {
                        Intrinsics.checkNotNullParameter(ktxRunOnUi, "$this$ktxRunOnUi");
                        ktxRunOnUi.tvStep1.setText(str);
                        ktxRunOnUi.tvStep2.setText('/' + objectRef.element.getGoalSteps() + ktxRunOnBgSingle.getString(R.string.qc_text_82));
                        ktxRunOnUi.pbStep.setProgress((Integer.parseInt(str) * 100) / objectRef.element.getGoalSteps());
                        if (UserConfig.INSTANCE.getInstance().getMetric()) {
                            ktxRunOnUi.pbDistance.setProgress((int) ((f * 100) / objectRef.element.getGoalDistance()));
                        } else {
                            ktxRunOnUi.pbDistance.setProgress((int) ((MetricUtilsKt.kmToIn(f) * 100) / objectRef.element.getGoalDistance()));
                        }
                        if (objectRef.element.getGoalCalorie() <= 1.0f) {
                            ktxRunOnUi.pbCalorie.setProgress((i * 100) / 200);
                        } else {
                            ktxRunOnUi.pbCalorie.setProgress((i * 100) / ((int) objectRef.element.getGoalCalorie()));
                        }
                    }
                });
                try {
                    if (UserConfig.INSTANCE.getInstance().getMetric()) {
                        final int goalDistance = (int) ((TargetEntity) objectRef.element).getGoalDistance();
                        ThreadExtKt.ktxRunOnUi(fragmentDayStepBinding2, new Function1<FragmentDayStepBinding, Unit>() { // from class: com.qcwireless.qcwatch.ui.home.step.day.DayStepFragment$queryTarget$1$1$2
                            /* JADX INFO: Access modifiers changed from: package-private */
                            /* JADX WARN: 'super' call moved to the top of the method (can break code semantics) */
                            {
                                super(1);
                            }

                            @Override // kotlin.jvm.functions.Function1
                            public /* bridge */ /* synthetic */ Unit invoke(FragmentDayStepBinding fragmentDayStepBinding3) {
                                invoke2(fragmentDayStepBinding3);
                                return Unit.INSTANCE;
                            }

                            /* renamed from: invoke, reason: avoid collision after fix types in other method */
                            public final void invoke2(FragmentDayStepBinding ktxRunOnUi) {
                                Intrinsics.checkNotNullParameter(ktxRunOnUi, "$this$ktxRunOnUi");
                                ktxRunOnUi.tvDistance1.setText(String.valueOf(str2));
                                ktxRunOnUi.tvDistance2.setText('/' + goalDistance + str3);
                            }
                        });
                    } else {
                        final int goalDistance2 = (int) ((TargetEntity) objectRef.element).getGoalDistance();
                        ThreadExtKt.ktxRunOnUi(fragmentDayStepBinding2, new Function1<FragmentDayStepBinding, Unit>() { // from class: com.qcwireless.qcwatch.ui.home.step.day.DayStepFragment$queryTarget$1$1$3
                            /* JADX INFO: Access modifiers changed from: package-private */
                            /* JADX WARN: 'super' call moved to the top of the method (can break code semantics) */
                            {
                                super(1);
                            }

                            @Override // kotlin.jvm.functions.Function1
                            public /* bridge */ /* synthetic */ Unit invoke(FragmentDayStepBinding fragmentDayStepBinding3) {
                                invoke2(fragmentDayStepBinding3);
                                return Unit.INSTANCE;
                            }

                            /* renamed from: invoke, reason: avoid collision after fix types in other method */
                            public final void invoke2(FragmentDayStepBinding ktxRunOnUi) {
                                Intrinsics.checkNotNullParameter(ktxRunOnUi, "$this$ktxRunOnUi");
                                ktxRunOnUi.tvDistance1.setText(String.valueOf(str2));
                                ktxRunOnUi.tvDistance2.setText('/' + goalDistance2 + str3);
                            }
                        });
                    }
                } catch (Exception unused) {
                }
                ThreadExtKt.ktxRunOnUi(fragmentDayStepBinding2, new Function1<FragmentDayStepBinding, Unit>() { // from class: com.qcwireless.qcwatch.ui.home.step.day.DayStepFragment$queryTarget$1$1$4
                    /* JADX INFO: Access modifiers changed from: package-private */
                    /* JADX WARN: 'super' call moved to the top of the method (can break code semantics) */
                    {
                        super(1);
                    }

                    @Override // kotlin.jvm.functions.Function1
                    public /* bridge */ /* synthetic */ Unit invoke(FragmentDayStepBinding fragmentDayStepBinding3) {
                        invoke2(fragmentDayStepBinding3);
                        return Unit.INSTANCE;
                    }

                    /* renamed from: invoke, reason: avoid collision after fix types in other method */
                    public final void invoke2(FragmentDayStepBinding ktxRunOnUi) {
                        Intrinsics.checkNotNullParameter(ktxRunOnUi, "$this$ktxRunOnUi");
                        ktxRunOnUi.tvCalorie1.setText(String.valueOf(i));
                        ktxRunOnUi.tvCalorie2.setText('/' + ((int) objectRef.element.getGoalCalorie()) + ktxRunOnBgSingle.getString(R.string.qc_text_110));
                    }
                });
            }
        });
    }

    private final void daySportPlusDetail(final DateUtil start) {
        ThreadExtKt.ktxRunOnBgSingle(this, new Function1<DayStepFragment, Unit>() { // from class: com.qcwireless.qcwatch.ui.home.step.day.DayStepFragment$daySportPlusDetail$1
            /* JADX INFO: Access modifiers changed from: package-private */
            {
                super(1);
            }

            @Override // kotlin.jvm.functions.Function1
            public /* bridge */ /* synthetic */ Unit invoke(DayStepFragment dayStepFragment) {
                invoke2(dayStepFragment);
                return Unit.INSTANCE;
            }

            /* renamed from: invoke, reason: avoid collision after fix types in other method */
            public final void invoke2(DayStepFragment ktxRunOnBgSingle) {
                Intrinsics.checkNotNullParameter(ktxRunOnBgSingle, "$this$ktxRunOnBgSingle");
                SportPlusRepository getInstance = SportPlusRepository.INSTANCE.getGetInstance();
                DateUtil dateUtil = DateUtil.this;
                final SportPlusDetail querySportByDate = getInstance.querySportByDate(dateUtil, dateUtil);
                if (querySportByDate != null) {
                    ThreadExtKt.ktxRunOnUi(ktxRunOnBgSingle, new Function1<DayStepFragment, Unit>() { // from class: com.qcwireless.qcwatch.ui.home.step.day.DayStepFragment$daySportPlusDetail$1.1
                        {
                            super(1);
                        }

                        @Override // kotlin.jvm.functions.Function1
                        public /* bridge */ /* synthetic */ Unit invoke(DayStepFragment dayStepFragment) {
                            invoke2(dayStepFragment);
                            return Unit.INSTANCE;
                        }

                        /* JADX WARN: Removed duplicated region for block: B:104:0x033c A[Catch: Exception -> 0x0353, TryCatch #0 {Exception -> 0x0353, blocks: (B:6:0x0019, B:9:0x002a, B:11:0x0033, B:14:0x003e, B:16:0x0044, B:17:0x0048, B:18:0x0156, B:21:0x0165, B:23:0x016f, B:26:0x0179, B:28:0x017f, B:29:0x0183, B:31:0x0190, B:32:0x0194, B:34:0x01a1, B:35:0x01a5, B:37:0x01b3, B:38:0x01b7, B:40:0x01c4, B:41:0x01c8, B:43:0x01d6, B:44:0x01da, B:46:0x01eb, B:48:0x01f7, B:50:0x01fd, B:51:0x0202, B:55:0x020f, B:57:0x0215, B:58:0x021a, B:61:0x0227, B:63:0x022d, B:64:0x0231, B:66:0x0244, B:68:0x024a, B:69:0x024f, B:72:0x025c, B:74:0x0262, B:75:0x0267, B:78:0x0274, B:80:0x027c, B:82:0x0282, B:83:0x0286, B:84:0x02a9, B:86:0x02b3, B:88:0x02b9, B:89:0x02bd, B:90:0x02e4, B:92:0x02ec, B:94:0x02f2, B:95:0x02f6, B:96:0x0319, B:98:0x0325, B:100:0x032b, B:101:0x0330, B:104:0x033c, B:106:0x0342, B:107:0x0347, B:110:0x0308, B:112:0x030e, B:113:0x0312, B:114:0x02d2, B:116:0x02d8, B:117:0x02dc, B:118:0x0298, B:120:0x029e, B:121:0x02a2, B:122:0x0051, B:124:0x0060, B:126:0x0083, B:127:0x0087, B:129:0x0098, B:130:0x009c, B:132:0x00b4, B:134:0x00ba, B:135:0x00be, B:136:0x00c7, B:138:0x00cd, B:139:0x00d1, B:140:0x00db, B:142:0x0106, B:144:0x010c, B:145:0x0110, B:146:0x012b, B:148:0x0131, B:149:0x0135, B:151:0x0144, B:152:0x0148, B:153:0x0118, B:155:0x011e, B:156:0x0122), top: B:5:0x0019 }] */
                        /* JADX WARN: Removed duplicated region for block: B:110:0x0308 A[Catch: Exception -> 0x0353, TryCatch #0 {Exception -> 0x0353, blocks: (B:6:0x0019, B:9:0x002a, B:11:0x0033, B:14:0x003e, B:16:0x0044, B:17:0x0048, B:18:0x0156, B:21:0x0165, B:23:0x016f, B:26:0x0179, B:28:0x017f, B:29:0x0183, B:31:0x0190, B:32:0x0194, B:34:0x01a1, B:35:0x01a5, B:37:0x01b3, B:38:0x01b7, B:40:0x01c4, B:41:0x01c8, B:43:0x01d6, B:44:0x01da, B:46:0x01eb, B:48:0x01f7, B:50:0x01fd, B:51:0x0202, B:55:0x020f, B:57:0x0215, B:58:0x021a, B:61:0x0227, B:63:0x022d, B:64:0x0231, B:66:0x0244, B:68:0x024a, B:69:0x024f, B:72:0x025c, B:74:0x0262, B:75:0x0267, B:78:0x0274, B:80:0x027c, B:82:0x0282, B:83:0x0286, B:84:0x02a9, B:86:0x02b3, B:88:0x02b9, B:89:0x02bd, B:90:0x02e4, B:92:0x02ec, B:94:0x02f2, B:95:0x02f6, B:96:0x0319, B:98:0x0325, B:100:0x032b, B:101:0x0330, B:104:0x033c, B:106:0x0342, B:107:0x0347, B:110:0x0308, B:112:0x030e, B:113:0x0312, B:114:0x02d2, B:116:0x02d8, B:117:0x02dc, B:118:0x0298, B:120:0x029e, B:121:0x02a2, B:122:0x0051, B:124:0x0060, B:126:0x0083, B:127:0x0087, B:129:0x0098, B:130:0x009c, B:132:0x00b4, B:134:0x00ba, B:135:0x00be, B:136:0x00c7, B:138:0x00cd, B:139:0x00d1, B:140:0x00db, B:142:0x0106, B:144:0x010c, B:145:0x0110, B:146:0x012b, B:148:0x0131, B:149:0x0135, B:151:0x0144, B:152:0x0148, B:153:0x0118, B:155:0x011e, B:156:0x0122), top: B:5:0x0019 }] */
                        /* JADX WARN: Removed duplicated region for block: B:114:0x02d2 A[Catch: Exception -> 0x0353, TryCatch #0 {Exception -> 0x0353, blocks: (B:6:0x0019, B:9:0x002a, B:11:0x0033, B:14:0x003e, B:16:0x0044, B:17:0x0048, B:18:0x0156, B:21:0x0165, B:23:0x016f, B:26:0x0179, B:28:0x017f, B:29:0x0183, B:31:0x0190, B:32:0x0194, B:34:0x01a1, B:35:0x01a5, B:37:0x01b3, B:38:0x01b7, B:40:0x01c4, B:41:0x01c8, B:43:0x01d6, B:44:0x01da, B:46:0x01eb, B:48:0x01f7, B:50:0x01fd, B:51:0x0202, B:55:0x020f, B:57:0x0215, B:58:0x021a, B:61:0x0227, B:63:0x022d, B:64:0x0231, B:66:0x0244, B:68:0x024a, B:69:0x024f, B:72:0x025c, B:74:0x0262, B:75:0x0267, B:78:0x0274, B:80:0x027c, B:82:0x0282, B:83:0x0286, B:84:0x02a9, B:86:0x02b3, B:88:0x02b9, B:89:0x02bd, B:90:0x02e4, B:92:0x02ec, B:94:0x02f2, B:95:0x02f6, B:96:0x0319, B:98:0x0325, B:100:0x032b, B:101:0x0330, B:104:0x033c, B:106:0x0342, B:107:0x0347, B:110:0x0308, B:112:0x030e, B:113:0x0312, B:114:0x02d2, B:116:0x02d8, B:117:0x02dc, B:118:0x0298, B:120:0x029e, B:121:0x02a2, B:122:0x0051, B:124:0x0060, B:126:0x0083, B:127:0x0087, B:129:0x0098, B:130:0x009c, B:132:0x00b4, B:134:0x00ba, B:135:0x00be, B:136:0x00c7, B:138:0x00cd, B:139:0x00d1, B:140:0x00db, B:142:0x0106, B:144:0x010c, B:145:0x0110, B:146:0x012b, B:148:0x0131, B:149:0x0135, B:151:0x0144, B:152:0x0148, B:153:0x0118, B:155:0x011e, B:156:0x0122), top: B:5:0x0019 }] */
                        /* JADX WARN: Removed duplicated region for block: B:118:0x0298 A[Catch: Exception -> 0x0353, TryCatch #0 {Exception -> 0x0353, blocks: (B:6:0x0019, B:9:0x002a, B:11:0x0033, B:14:0x003e, B:16:0x0044, B:17:0x0048, B:18:0x0156, B:21:0x0165, B:23:0x016f, B:26:0x0179, B:28:0x017f, B:29:0x0183, B:31:0x0190, B:32:0x0194, B:34:0x01a1, B:35:0x01a5, B:37:0x01b3, B:38:0x01b7, B:40:0x01c4, B:41:0x01c8, B:43:0x01d6, B:44:0x01da, B:46:0x01eb, B:48:0x01f7, B:50:0x01fd, B:51:0x0202, B:55:0x020f, B:57:0x0215, B:58:0x021a, B:61:0x0227, B:63:0x022d, B:64:0x0231, B:66:0x0244, B:68:0x024a, B:69:0x024f, B:72:0x025c, B:74:0x0262, B:75:0x0267, B:78:0x0274, B:80:0x027c, B:82:0x0282, B:83:0x0286, B:84:0x02a9, B:86:0x02b3, B:88:0x02b9, B:89:0x02bd, B:90:0x02e4, B:92:0x02ec, B:94:0x02f2, B:95:0x02f6, B:96:0x0319, B:98:0x0325, B:100:0x032b, B:101:0x0330, B:104:0x033c, B:106:0x0342, B:107:0x0347, B:110:0x0308, B:112:0x030e, B:113:0x0312, B:114:0x02d2, B:116:0x02d8, B:117:0x02dc, B:118:0x0298, B:120:0x029e, B:121:0x02a2, B:122:0x0051, B:124:0x0060, B:126:0x0083, B:127:0x0087, B:129:0x0098, B:130:0x009c, B:132:0x00b4, B:134:0x00ba, B:135:0x00be, B:136:0x00c7, B:138:0x00cd, B:139:0x00d1, B:140:0x00db, B:142:0x0106, B:144:0x010c, B:145:0x0110, B:146:0x012b, B:148:0x0131, B:149:0x0135, B:151:0x0144, B:152:0x0148, B:153:0x0118, B:155:0x011e, B:156:0x0122), top: B:5:0x0019 }] */
                        /* JADX WARN: Removed duplicated region for block: B:28:0x017f A[Catch: Exception -> 0x0353, TryCatch #0 {Exception -> 0x0353, blocks: (B:6:0x0019, B:9:0x002a, B:11:0x0033, B:14:0x003e, B:16:0x0044, B:17:0x0048, B:18:0x0156, B:21:0x0165, B:23:0x016f, B:26:0x0179, B:28:0x017f, B:29:0x0183, B:31:0x0190, B:32:0x0194, B:34:0x01a1, B:35:0x01a5, B:37:0x01b3, B:38:0x01b7, B:40:0x01c4, B:41:0x01c8, B:43:0x01d6, B:44:0x01da, B:46:0x01eb, B:48:0x01f7, B:50:0x01fd, B:51:0x0202, B:55:0x020f, B:57:0x0215, B:58:0x021a, B:61:0x0227, B:63:0x022d, B:64:0x0231, B:66:0x0244, B:68:0x024a, B:69:0x024f, B:72:0x025c, B:74:0x0262, B:75:0x0267, B:78:0x0274, B:80:0x027c, B:82:0x0282, B:83:0x0286, B:84:0x02a9, B:86:0x02b3, B:88:0x02b9, B:89:0x02bd, B:90:0x02e4, B:92:0x02ec, B:94:0x02f2, B:95:0x02f6, B:96:0x0319, B:98:0x0325, B:100:0x032b, B:101:0x0330, B:104:0x033c, B:106:0x0342, B:107:0x0347, B:110:0x0308, B:112:0x030e, B:113:0x0312, B:114:0x02d2, B:116:0x02d8, B:117:0x02dc, B:118:0x0298, B:120:0x029e, B:121:0x02a2, B:122:0x0051, B:124:0x0060, B:126:0x0083, B:127:0x0087, B:129:0x0098, B:130:0x009c, B:132:0x00b4, B:134:0x00ba, B:135:0x00be, B:136:0x00c7, B:138:0x00cd, B:139:0x00d1, B:140:0x00db, B:142:0x0106, B:144:0x010c, B:145:0x0110, B:146:0x012b, B:148:0x0131, B:149:0x0135, B:151:0x0144, B:152:0x0148, B:153:0x0118, B:155:0x011e, B:156:0x0122), top: B:5:0x0019 }] */
                        /* JADX WARN: Removed duplicated region for block: B:31:0x0190 A[Catch: Exception -> 0x0353, TryCatch #0 {Exception -> 0x0353, blocks: (B:6:0x0019, B:9:0x002a, B:11:0x0033, B:14:0x003e, B:16:0x0044, B:17:0x0048, B:18:0x0156, B:21:0x0165, B:23:0x016f, B:26:0x0179, B:28:0x017f, B:29:0x0183, B:31:0x0190, B:32:0x0194, B:34:0x01a1, B:35:0x01a5, B:37:0x01b3, B:38:0x01b7, B:40:0x01c4, B:41:0x01c8, B:43:0x01d6, B:44:0x01da, B:46:0x01eb, B:48:0x01f7, B:50:0x01fd, B:51:0x0202, B:55:0x020f, B:57:0x0215, B:58:0x021a, B:61:0x0227, B:63:0x022d, B:64:0x0231, B:66:0x0244, B:68:0x024a, B:69:0x024f, B:72:0x025c, B:74:0x0262, B:75:0x0267, B:78:0x0274, B:80:0x027c, B:82:0x0282, B:83:0x0286, B:84:0x02a9, B:86:0x02b3, B:88:0x02b9, B:89:0x02bd, B:90:0x02e4, B:92:0x02ec, B:94:0x02f2, B:95:0x02f6, B:96:0x0319, B:98:0x0325, B:100:0x032b, B:101:0x0330, B:104:0x033c, B:106:0x0342, B:107:0x0347, B:110:0x0308, B:112:0x030e, B:113:0x0312, B:114:0x02d2, B:116:0x02d8, B:117:0x02dc, B:118:0x0298, B:120:0x029e, B:121:0x02a2, B:122:0x0051, B:124:0x0060, B:126:0x0083, B:127:0x0087, B:129:0x0098, B:130:0x009c, B:132:0x00b4, B:134:0x00ba, B:135:0x00be, B:136:0x00c7, B:138:0x00cd, B:139:0x00d1, B:140:0x00db, B:142:0x0106, B:144:0x010c, B:145:0x0110, B:146:0x012b, B:148:0x0131, B:149:0x0135, B:151:0x0144, B:152:0x0148, B:153:0x0118, B:155:0x011e, B:156:0x0122), top: B:5:0x0019 }] */
                        /* JADX WARN: Removed duplicated region for block: B:34:0x01a1 A[Catch: Exception -> 0x0353, TryCatch #0 {Exception -> 0x0353, blocks: (B:6:0x0019, B:9:0x002a, B:11:0x0033, B:14:0x003e, B:16:0x0044, B:17:0x0048, B:18:0x0156, B:21:0x0165, B:23:0x016f, B:26:0x0179, B:28:0x017f, B:29:0x0183, B:31:0x0190, B:32:0x0194, B:34:0x01a1, B:35:0x01a5, B:37:0x01b3, B:38:0x01b7, B:40:0x01c4, B:41:0x01c8, B:43:0x01d6, B:44:0x01da, B:46:0x01eb, B:48:0x01f7, B:50:0x01fd, B:51:0x0202, B:55:0x020f, B:57:0x0215, B:58:0x021a, B:61:0x0227, B:63:0x022d, B:64:0x0231, B:66:0x0244, B:68:0x024a, B:69:0x024f, B:72:0x025c, B:74:0x0262, B:75:0x0267, B:78:0x0274, B:80:0x027c, B:82:0x0282, B:83:0x0286, B:84:0x02a9, B:86:0x02b3, B:88:0x02b9, B:89:0x02bd, B:90:0x02e4, B:92:0x02ec, B:94:0x02f2, B:95:0x02f6, B:96:0x0319, B:98:0x0325, B:100:0x032b, B:101:0x0330, B:104:0x033c, B:106:0x0342, B:107:0x0347, B:110:0x0308, B:112:0x030e, B:113:0x0312, B:114:0x02d2, B:116:0x02d8, B:117:0x02dc, B:118:0x0298, B:120:0x029e, B:121:0x02a2, B:122:0x0051, B:124:0x0060, B:126:0x0083, B:127:0x0087, B:129:0x0098, B:130:0x009c, B:132:0x00b4, B:134:0x00ba, B:135:0x00be, B:136:0x00c7, B:138:0x00cd, B:139:0x00d1, B:140:0x00db, B:142:0x0106, B:144:0x010c, B:145:0x0110, B:146:0x012b, B:148:0x0131, B:149:0x0135, B:151:0x0144, B:152:0x0148, B:153:0x0118, B:155:0x011e, B:156:0x0122), top: B:5:0x0019 }] */
                        /* JADX WARN: Removed duplicated region for block: B:37:0x01b3 A[Catch: Exception -> 0x0353, TryCatch #0 {Exception -> 0x0353, blocks: (B:6:0x0019, B:9:0x002a, B:11:0x0033, B:14:0x003e, B:16:0x0044, B:17:0x0048, B:18:0x0156, B:21:0x0165, B:23:0x016f, B:26:0x0179, B:28:0x017f, B:29:0x0183, B:31:0x0190, B:32:0x0194, B:34:0x01a1, B:35:0x01a5, B:37:0x01b3, B:38:0x01b7, B:40:0x01c4, B:41:0x01c8, B:43:0x01d6, B:44:0x01da, B:46:0x01eb, B:48:0x01f7, B:50:0x01fd, B:51:0x0202, B:55:0x020f, B:57:0x0215, B:58:0x021a, B:61:0x0227, B:63:0x022d, B:64:0x0231, B:66:0x0244, B:68:0x024a, B:69:0x024f, B:72:0x025c, B:74:0x0262, B:75:0x0267, B:78:0x0274, B:80:0x027c, B:82:0x0282, B:83:0x0286, B:84:0x02a9, B:86:0x02b3, B:88:0x02b9, B:89:0x02bd, B:90:0x02e4, B:92:0x02ec, B:94:0x02f2, B:95:0x02f6, B:96:0x0319, B:98:0x0325, B:100:0x032b, B:101:0x0330, B:104:0x033c, B:106:0x0342, B:107:0x0347, B:110:0x0308, B:112:0x030e, B:113:0x0312, B:114:0x02d2, B:116:0x02d8, B:117:0x02dc, B:118:0x0298, B:120:0x029e, B:121:0x02a2, B:122:0x0051, B:124:0x0060, B:126:0x0083, B:127:0x0087, B:129:0x0098, B:130:0x009c, B:132:0x00b4, B:134:0x00ba, B:135:0x00be, B:136:0x00c7, B:138:0x00cd, B:139:0x00d1, B:140:0x00db, B:142:0x0106, B:144:0x010c, B:145:0x0110, B:146:0x012b, B:148:0x0131, B:149:0x0135, B:151:0x0144, B:152:0x0148, B:153:0x0118, B:155:0x011e, B:156:0x0122), top: B:5:0x0019 }] */
                        /* JADX WARN: Removed duplicated region for block: B:40:0x01c4 A[Catch: Exception -> 0x0353, TryCatch #0 {Exception -> 0x0353, blocks: (B:6:0x0019, B:9:0x002a, B:11:0x0033, B:14:0x003e, B:16:0x0044, B:17:0x0048, B:18:0x0156, B:21:0x0165, B:23:0x016f, B:26:0x0179, B:28:0x017f, B:29:0x0183, B:31:0x0190, B:32:0x0194, B:34:0x01a1, B:35:0x01a5, B:37:0x01b3, B:38:0x01b7, B:40:0x01c4, B:41:0x01c8, B:43:0x01d6, B:44:0x01da, B:46:0x01eb, B:48:0x01f7, B:50:0x01fd, B:51:0x0202, B:55:0x020f, B:57:0x0215, B:58:0x021a, B:61:0x0227, B:63:0x022d, B:64:0x0231, B:66:0x0244, B:68:0x024a, B:69:0x024f, B:72:0x025c, B:74:0x0262, B:75:0x0267, B:78:0x0274, B:80:0x027c, B:82:0x0282, B:83:0x0286, B:84:0x02a9, B:86:0x02b3, B:88:0x02b9, B:89:0x02bd, B:90:0x02e4, B:92:0x02ec, B:94:0x02f2, B:95:0x02f6, B:96:0x0319, B:98:0x0325, B:100:0x032b, B:101:0x0330, B:104:0x033c, B:106:0x0342, B:107:0x0347, B:110:0x0308, B:112:0x030e, B:113:0x0312, B:114:0x02d2, B:116:0x02d8, B:117:0x02dc, B:118:0x0298, B:120:0x029e, B:121:0x02a2, B:122:0x0051, B:124:0x0060, B:126:0x0083, B:127:0x0087, B:129:0x0098, B:130:0x009c, B:132:0x00b4, B:134:0x00ba, B:135:0x00be, B:136:0x00c7, B:138:0x00cd, B:139:0x00d1, B:140:0x00db, B:142:0x0106, B:144:0x010c, B:145:0x0110, B:146:0x012b, B:148:0x0131, B:149:0x0135, B:151:0x0144, B:152:0x0148, B:153:0x0118, B:155:0x011e, B:156:0x0122), top: B:5:0x0019 }] */
                        /* JADX WARN: Removed duplicated region for block: B:43:0x01d6 A[Catch: Exception -> 0x0353, TryCatch #0 {Exception -> 0x0353, blocks: (B:6:0x0019, B:9:0x002a, B:11:0x0033, B:14:0x003e, B:16:0x0044, B:17:0x0048, B:18:0x0156, B:21:0x0165, B:23:0x016f, B:26:0x0179, B:28:0x017f, B:29:0x0183, B:31:0x0190, B:32:0x0194, B:34:0x01a1, B:35:0x01a5, B:37:0x01b3, B:38:0x01b7, B:40:0x01c4, B:41:0x01c8, B:43:0x01d6, B:44:0x01da, B:46:0x01eb, B:48:0x01f7, B:50:0x01fd, B:51:0x0202, B:55:0x020f, B:57:0x0215, B:58:0x021a, B:61:0x0227, B:63:0x022d, B:64:0x0231, B:66:0x0244, B:68:0x024a, B:69:0x024f, B:72:0x025c, B:74:0x0262, B:75:0x0267, B:78:0x0274, B:80:0x027c, B:82:0x0282, B:83:0x0286, B:84:0x02a9, B:86:0x02b3, B:88:0x02b9, B:89:0x02bd, B:90:0x02e4, B:92:0x02ec, B:94:0x02f2, B:95:0x02f6, B:96:0x0319, B:98:0x0325, B:100:0x032b, B:101:0x0330, B:104:0x033c, B:106:0x0342, B:107:0x0347, B:110:0x0308, B:112:0x030e, B:113:0x0312, B:114:0x02d2, B:116:0x02d8, B:117:0x02dc, B:118:0x0298, B:120:0x029e, B:121:0x02a2, B:122:0x0051, B:124:0x0060, B:126:0x0083, B:127:0x0087, B:129:0x0098, B:130:0x009c, B:132:0x00b4, B:134:0x00ba, B:135:0x00be, B:136:0x00c7, B:138:0x00cd, B:139:0x00d1, B:140:0x00db, B:142:0x0106, B:144:0x010c, B:145:0x0110, B:146:0x012b, B:148:0x0131, B:149:0x0135, B:151:0x0144, B:152:0x0148, B:153:0x0118, B:155:0x011e, B:156:0x0122), top: B:5:0x0019 }] */
                        /* JADX WARN: Removed duplicated region for block: B:46:0x01eb A[Catch: Exception -> 0x0353, TryCatch #0 {Exception -> 0x0353, blocks: (B:6:0x0019, B:9:0x002a, B:11:0x0033, B:14:0x003e, B:16:0x0044, B:17:0x0048, B:18:0x0156, B:21:0x0165, B:23:0x016f, B:26:0x0179, B:28:0x017f, B:29:0x0183, B:31:0x0190, B:32:0x0194, B:34:0x01a1, B:35:0x01a5, B:37:0x01b3, B:38:0x01b7, B:40:0x01c4, B:41:0x01c8, B:43:0x01d6, B:44:0x01da, B:46:0x01eb, B:48:0x01f7, B:50:0x01fd, B:51:0x0202, B:55:0x020f, B:57:0x0215, B:58:0x021a, B:61:0x0227, B:63:0x022d, B:64:0x0231, B:66:0x0244, B:68:0x024a, B:69:0x024f, B:72:0x025c, B:74:0x0262, B:75:0x0267, B:78:0x0274, B:80:0x027c, B:82:0x0282, B:83:0x0286, B:84:0x02a9, B:86:0x02b3, B:88:0x02b9, B:89:0x02bd, B:90:0x02e4, B:92:0x02ec, B:94:0x02f2, B:95:0x02f6, B:96:0x0319, B:98:0x0325, B:100:0x032b, B:101:0x0330, B:104:0x033c, B:106:0x0342, B:107:0x0347, B:110:0x0308, B:112:0x030e, B:113:0x0312, B:114:0x02d2, B:116:0x02d8, B:117:0x02dc, B:118:0x0298, B:120:0x029e, B:121:0x02a2, B:122:0x0051, B:124:0x0060, B:126:0x0083, B:127:0x0087, B:129:0x0098, B:130:0x009c, B:132:0x00b4, B:134:0x00ba, B:135:0x00be, B:136:0x00c7, B:138:0x00cd, B:139:0x00d1, B:140:0x00db, B:142:0x0106, B:144:0x010c, B:145:0x0110, B:146:0x012b, B:148:0x0131, B:149:0x0135, B:151:0x0144, B:152:0x0148, B:153:0x0118, B:155:0x011e, B:156:0x0122), top: B:5:0x0019 }] */
                        /* JADX WARN: Removed duplicated region for block: B:61:0x0227 A[Catch: Exception -> 0x0353, TryCatch #0 {Exception -> 0x0353, blocks: (B:6:0x0019, B:9:0x002a, B:11:0x0033, B:14:0x003e, B:16:0x0044, B:17:0x0048, B:18:0x0156, B:21:0x0165, B:23:0x016f, B:26:0x0179, B:28:0x017f, B:29:0x0183, B:31:0x0190, B:32:0x0194, B:34:0x01a1, B:35:0x01a5, B:37:0x01b3, B:38:0x01b7, B:40:0x01c4, B:41:0x01c8, B:43:0x01d6, B:44:0x01da, B:46:0x01eb, B:48:0x01f7, B:50:0x01fd, B:51:0x0202, B:55:0x020f, B:57:0x0215, B:58:0x021a, B:61:0x0227, B:63:0x022d, B:64:0x0231, B:66:0x0244, B:68:0x024a, B:69:0x024f, B:72:0x025c, B:74:0x0262, B:75:0x0267, B:78:0x0274, B:80:0x027c, B:82:0x0282, B:83:0x0286, B:84:0x02a9, B:86:0x02b3, B:88:0x02b9, B:89:0x02bd, B:90:0x02e4, B:92:0x02ec, B:94:0x02f2, B:95:0x02f6, B:96:0x0319, B:98:0x0325, B:100:0x032b, B:101:0x0330, B:104:0x033c, B:106:0x0342, B:107:0x0347, B:110:0x0308, B:112:0x030e, B:113:0x0312, B:114:0x02d2, B:116:0x02d8, B:117:0x02dc, B:118:0x0298, B:120:0x029e, B:121:0x02a2, B:122:0x0051, B:124:0x0060, B:126:0x0083, B:127:0x0087, B:129:0x0098, B:130:0x009c, B:132:0x00b4, B:134:0x00ba, B:135:0x00be, B:136:0x00c7, B:138:0x00cd, B:139:0x00d1, B:140:0x00db, B:142:0x0106, B:144:0x010c, B:145:0x0110, B:146:0x012b, B:148:0x0131, B:149:0x0135, B:151:0x0144, B:152:0x0148, B:153:0x0118, B:155:0x011e, B:156:0x0122), top: B:5:0x0019 }] */
                        /* JADX WARN: Removed duplicated region for block: B:80:0x027c A[Catch: Exception -> 0x0353, TryCatch #0 {Exception -> 0x0353, blocks: (B:6:0x0019, B:9:0x002a, B:11:0x0033, B:14:0x003e, B:16:0x0044, B:17:0x0048, B:18:0x0156, B:21:0x0165, B:23:0x016f, B:26:0x0179, B:28:0x017f, B:29:0x0183, B:31:0x0190, B:32:0x0194, B:34:0x01a1, B:35:0x01a5, B:37:0x01b3, B:38:0x01b7, B:40:0x01c4, B:41:0x01c8, B:43:0x01d6, B:44:0x01da, B:46:0x01eb, B:48:0x01f7, B:50:0x01fd, B:51:0x0202, B:55:0x020f, B:57:0x0215, B:58:0x021a, B:61:0x0227, B:63:0x022d, B:64:0x0231, B:66:0x0244, B:68:0x024a, B:69:0x024f, B:72:0x025c, B:74:0x0262, B:75:0x0267, B:78:0x0274, B:80:0x027c, B:82:0x0282, B:83:0x0286, B:84:0x02a9, B:86:0x02b3, B:88:0x02b9, B:89:0x02bd, B:90:0x02e4, B:92:0x02ec, B:94:0x02f2, B:95:0x02f6, B:96:0x0319, B:98:0x0325, B:100:0x032b, B:101:0x0330, B:104:0x033c, B:106:0x0342, B:107:0x0347, B:110:0x0308, B:112:0x030e, B:113:0x0312, B:114:0x02d2, B:116:0x02d8, B:117:0x02dc, B:118:0x0298, B:120:0x029e, B:121:0x02a2, B:122:0x0051, B:124:0x0060, B:126:0x0083, B:127:0x0087, B:129:0x0098, B:130:0x009c, B:132:0x00b4, B:134:0x00ba, B:135:0x00be, B:136:0x00c7, B:138:0x00cd, B:139:0x00d1, B:140:0x00db, B:142:0x0106, B:144:0x010c, B:145:0x0110, B:146:0x012b, B:148:0x0131, B:149:0x0135, B:151:0x0144, B:152:0x0148, B:153:0x0118, B:155:0x011e, B:156:0x0122), top: B:5:0x0019 }] */
                        /* JADX WARN: Removed duplicated region for block: B:86:0x02b3 A[Catch: Exception -> 0x0353, TryCatch #0 {Exception -> 0x0353, blocks: (B:6:0x0019, B:9:0x002a, B:11:0x0033, B:14:0x003e, B:16:0x0044, B:17:0x0048, B:18:0x0156, B:21:0x0165, B:23:0x016f, B:26:0x0179, B:28:0x017f, B:29:0x0183, B:31:0x0190, B:32:0x0194, B:34:0x01a1, B:35:0x01a5, B:37:0x01b3, B:38:0x01b7, B:40:0x01c4, B:41:0x01c8, B:43:0x01d6, B:44:0x01da, B:46:0x01eb, B:48:0x01f7, B:50:0x01fd, B:51:0x0202, B:55:0x020f, B:57:0x0215, B:58:0x021a, B:61:0x0227, B:63:0x022d, B:64:0x0231, B:66:0x0244, B:68:0x024a, B:69:0x024f, B:72:0x025c, B:74:0x0262, B:75:0x0267, B:78:0x0274, B:80:0x027c, B:82:0x0282, B:83:0x0286, B:84:0x02a9, B:86:0x02b3, B:88:0x02b9, B:89:0x02bd, B:90:0x02e4, B:92:0x02ec, B:94:0x02f2, B:95:0x02f6, B:96:0x0319, B:98:0x0325, B:100:0x032b, B:101:0x0330, B:104:0x033c, B:106:0x0342, B:107:0x0347, B:110:0x0308, B:112:0x030e, B:113:0x0312, B:114:0x02d2, B:116:0x02d8, B:117:0x02dc, B:118:0x0298, B:120:0x029e, B:121:0x02a2, B:122:0x0051, B:124:0x0060, B:126:0x0083, B:127:0x0087, B:129:0x0098, B:130:0x009c, B:132:0x00b4, B:134:0x00ba, B:135:0x00be, B:136:0x00c7, B:138:0x00cd, B:139:0x00d1, B:140:0x00db, B:142:0x0106, B:144:0x010c, B:145:0x0110, B:146:0x012b, B:148:0x0131, B:149:0x0135, B:151:0x0144, B:152:0x0148, B:153:0x0118, B:155:0x011e, B:156:0x0122), top: B:5:0x0019 }] */
                        /* JADX WARN: Removed duplicated region for block: B:92:0x02ec A[Catch: Exception -> 0x0353, TryCatch #0 {Exception -> 0x0353, blocks: (B:6:0x0019, B:9:0x002a, B:11:0x0033, B:14:0x003e, B:16:0x0044, B:17:0x0048, B:18:0x0156, B:21:0x0165, B:23:0x016f, B:26:0x0179, B:28:0x017f, B:29:0x0183, B:31:0x0190, B:32:0x0194, B:34:0x01a1, B:35:0x01a5, B:37:0x01b3, B:38:0x01b7, B:40:0x01c4, B:41:0x01c8, B:43:0x01d6, B:44:0x01da, B:46:0x01eb, B:48:0x01f7, B:50:0x01fd, B:51:0x0202, B:55:0x020f, B:57:0x0215, B:58:0x021a, B:61:0x0227, B:63:0x022d, B:64:0x0231, B:66:0x0244, B:68:0x024a, B:69:0x024f, B:72:0x025c, B:74:0x0262, B:75:0x0267, B:78:0x0274, B:80:0x027c, B:82:0x0282, B:83:0x0286, B:84:0x02a9, B:86:0x02b3, B:88:0x02b9, B:89:0x02bd, B:90:0x02e4, B:92:0x02ec, B:94:0x02f2, B:95:0x02f6, B:96:0x0319, B:98:0x0325, B:100:0x032b, B:101:0x0330, B:104:0x033c, B:106:0x0342, B:107:0x0347, B:110:0x0308, B:112:0x030e, B:113:0x0312, B:114:0x02d2, B:116:0x02d8, B:117:0x02dc, B:118:0x0298, B:120:0x029e, B:121:0x02a2, B:122:0x0051, B:124:0x0060, B:126:0x0083, B:127:0x0087, B:129:0x0098, B:130:0x009c, B:132:0x00b4, B:134:0x00ba, B:135:0x00be, B:136:0x00c7, B:138:0x00cd, B:139:0x00d1, B:140:0x00db, B:142:0x0106, B:144:0x010c, B:145:0x0110, B:146:0x012b, B:148:0x0131, B:149:0x0135, B:151:0x0144, B:152:0x0148, B:153:0x0118, B:155:0x011e, B:156:0x0122), top: B:5:0x0019 }] */
                        /* JADX WARN: Removed duplicated region for block: B:98:0x0325 A[Catch: Exception -> 0x0353, TryCatch #0 {Exception -> 0x0353, blocks: (B:6:0x0019, B:9:0x002a, B:11:0x0033, B:14:0x003e, B:16:0x0044, B:17:0x0048, B:18:0x0156, B:21:0x0165, B:23:0x016f, B:26:0x0179, B:28:0x017f, B:29:0x0183, B:31:0x0190, B:32:0x0194, B:34:0x01a1, B:35:0x01a5, B:37:0x01b3, B:38:0x01b7, B:40:0x01c4, B:41:0x01c8, B:43:0x01d6, B:44:0x01da, B:46:0x01eb, B:48:0x01f7, B:50:0x01fd, B:51:0x0202, B:55:0x020f, B:57:0x0215, B:58:0x021a, B:61:0x0227, B:63:0x022d, B:64:0x0231, B:66:0x0244, B:68:0x024a, B:69:0x024f, B:72:0x025c, B:74:0x0262, B:75:0x0267, B:78:0x0274, B:80:0x027c, B:82:0x0282, B:83:0x0286, B:84:0x02a9, B:86:0x02b3, B:88:0x02b9, B:89:0x02bd, B:90:0x02e4, B:92:0x02ec, B:94:0x02f2, B:95:0x02f6, B:96:0x0319, B:98:0x0325, B:100:0x032b, B:101:0x0330, B:104:0x033c, B:106:0x0342, B:107:0x0347, B:110:0x0308, B:112:0x030e, B:113:0x0312, B:114:0x02d2, B:116:0x02d8, B:117:0x02dc, B:118:0x0298, B:120:0x029e, B:121:0x02a2, B:122:0x0051, B:124:0x0060, B:126:0x0083, B:127:0x0087, B:129:0x0098, B:130:0x009c, B:132:0x00b4, B:134:0x00ba, B:135:0x00be, B:136:0x00c7, B:138:0x00cd, B:139:0x00d1, B:140:0x00db, B:142:0x0106, B:144:0x010c, B:145:0x0110, B:146:0x012b, B:148:0x0131, B:149:0x0135, B:151:0x0144, B:152:0x0148, B:153:0x0118, B:155:0x011e, B:156:0x0122), top: B:5:0x0019 }] */
                        /* renamed from: invoke, reason: avoid collision after fix types in other method */
                        /*
                            Code decompiled incorrectly, please refer to instructions dump.
                            To view partially-correct code enable 'Show inconsistent code' option in preferences
                        */
                        public final void invoke2(com.qcwireless.qcwatch.ui.home.step.day.DayStepFragment r11) {
                            /*
                                Method dump skipped, instructions count: 856
                                To view this dump change 'Code comments level' option to 'DEBUG'
                            */
                            throw new UnsupportedOperationException("Method not decompiled: com.qcwireless.qcwatch.ui.home.step.day.DayStepFragment$daySportPlusDetail$1.AnonymousClass1.invoke2(com.qcwireless.qcwatch.ui.home.step.day.DayStepFragment):void");
                        }
                    });
                } else {
                    ThreadExtKt.ktxRunOnUi(ktxRunOnBgSingle, new Function1<DayStepFragment, Unit>() { // from class: com.qcwireless.qcwatch.ui.home.step.day.DayStepFragment$daySportPlusDetail$1.2
                        @Override // kotlin.jvm.functions.Function1
                        public /* bridge */ /* synthetic */ Unit invoke(DayStepFragment dayStepFragment) {
                            invoke2(dayStepFragment);
                            return Unit.INSTANCE;
                        }

                        /* renamed from: invoke, reason: avoid collision after fix types in other method */
                        public final void invoke2(DayStepFragment ktxRunOnUi) {
                            Intrinsics.checkNotNullParameter(ktxRunOnUi, "$this$ktxRunOnUi");
                            FragmentDayStepBinding fragmentDayStepBinding = ktxRunOnUi.binding;
                            if (fragmentDayStepBinding == null) {
                                Intrinsics.throwUninitializedPropertyAccessException("binding");
                                fragmentDayStepBinding = null;
                            }
                            ViewKt.gone(fragmentDayStepBinding.todayStepActivity);
                        }
                    });
                }
            }
        });
    }

    @Override // com.qcwireless.qcwatch.ui.base.BaseFragment, androidx.fragment.app.Fragment
    public void onDestroy() {
        super.onDestroy();
        EventBus.getDefault().unregister(this);
    }

    /* compiled from: DayStepFragment.kt */
    @Metadata(d1 = {"\u0000\u0018\n\u0002\u0018\u0002\n\u0002\u0018\u0002\n\u0002\b\u0002\n\u0002\u0010\u0002\n\u0000\n\u0002\u0018\u0002\n\u0000\b\u0086\u0004\u0018\u00002\u00020\u0001B\u0005¢\u0006\u0002\u0010\u0002J\u0012\u0010\u0003\u001a\u00020\u00042\b\u0010\u0005\u001a\u0004\u0018\u00010\u0006H\u0016¨\u0006\u0007"}, d2 = {"Lcom/qcwireless/qcwatch/ui/home/step/day/DayStepFragment$MyDeviceNotifyListener;", "Lcom/oudmon/ble/base/communication/responseImpl/DeviceNotifyListener;", "(Lcom/qcwireless/qcwatch/ui/home/step/day/DayStepFragment;)V", "onDataResponse", "", "resultEntity", "Lcom/oudmon/ble/base/communication/rsp/DeviceNotifyRsp;", "app_championRelease"}, k = 1, mv = {1, 6, 0}, xi = 48)
    /* loaded from: classes2.dex */
    public final class MyDeviceNotifyListener extends DeviceNotifyListener {
        public MyDeviceNotifyListener() {
        }

        @Override // com.oudmon.ble.base.communication.responseImpl.DeviceNotifyListener, com.oudmon.ble.base.communication.ICommandResponse
        public void onDataResponse(DeviceNotifyRsp resultEntity) {
            Intrinsics.checkNotNull(resultEntity);
            if (resultEntity.getStatus() == 0) {
                if (SyncStatus.INSTANCE.getGetInstance().getSync() || SyncStatus.INSTANCE.getGetInstance().getSyncSportPlus() || QCApplication.INSTANCE.getGetInstance().getUpdating() == 1 || QCApplication.INSTANCE.getGetInstance().getUpdating() == 2 || QCApplication.INSTANCE.getGetInstance().getUpdating() == 3) {
                    LogToFile.getInstance().wtf("设备刷新返回，没有同步");
                    AwLog.i(Author.HeZhiYuan, "正在数据同步或者固件升级...");
                    return;
                }
                AwLog.i(Author.HeZhiYuan, "设备触发刷新，数据类型:" + resultEntity.getDataType());
                LogToFile.getInstance().wtf("设备触发刷新，数据类型:" + resultEntity.getDataType());
                BleOperateManager.getInstance().removeOthersListener();
                if (resultEntity.getDataType() == 18) {
                    AwLog.i(Author.HeZhiYuan, ByteUtil.bytesToString(resultEntity.getLoadData()));
                    int bytes2Int = BLEDataFormatUtils.bytes2Int(new byte[]{resultEntity.getLoadData()[1], resultEntity.getLoadData()[2], resultEntity.getLoadData()[3]});
                    try {
                        if (DayStepFragment.this.date.isToday()) {
                            FragmentDayStepBinding fragmentDayStepBinding = DayStepFragment.this.binding;
                            if (fragmentDayStepBinding == null) {
                                Intrinsics.throwUninitializedPropertyAccessException("binding");
                                fragmentDayStepBinding = null;
                            }
                            fragmentDayStepBinding.stepTotal.setTitleValue(String.valueOf(bytes2Int));
                        }
                    } catch (Exception e) {
                        e.printStackTrace();
                    }
                }
            }
        }
    }

    /* compiled from: DayStepFragment.kt */
    @Metadata(d1 = {"\u0000\u0012\n\u0002\u0018\u0002\n\u0002\u0010\u0000\n\u0002\b\u0002\n\u0002\u0018\u0002\n\u0000\b\u0086\u0003\u0018\u00002\u00020\u0001B\u0007\b\u0002¢\u0006\u0002\u0010\u0002J\u0006\u0010\u0003\u001a\u00020\u0004¨\u0006\u0005"}, d2 = {"Lcom/qcwireless/qcwatch/ui/home/step/day/DayStepFragment$Companion;", "", "()V", "newInstance", "Lcom/qcwireless/qcwatch/ui/home/step/day/DayStepFragment;", "app_championRelease"}, k = 1, mv = {1, 6, 0}, xi = 48)
    /* loaded from: classes2.dex */
    public static final class Companion {
        public /* synthetic */ Companion(DefaultConstructorMarker defaultConstructorMarker) {
            this();
        }

        private Companion() {
        }

        public final DayStepFragment newInstance() {
            return new DayStepFragment();
        }
    }
}
