package androidx.camera.camera2.internal;

import android.hardware.camera2.CameraAccessException;
import android.hardware.camera2.CameraCaptureSession;
import android.hardware.camera2.CameraDevice;
import android.hardware.camera2.CaptureRequest;
import android.view.Surface;
import androidx.camera.camera2.internal.compat.CameraCaptureSessionCompat;
import com.google.common.util.concurrent.ListenableFuture;
import java.util.List;
import java.util.concurrent.Executor;

/* JADX INFO: Access modifiers changed from: package-private */
/* loaded from: classes.dex */
public interface SynchronizedCaptureSession {

    /* loaded from: classes.dex */
    public static abstract class StateCallback {
        /* JADX INFO: Access modifiers changed from: package-private */
        public void onActive(SynchronizedCaptureSession session) {
        }

        /* JADX INFO: Access modifiers changed from: package-private */
        public void onCaptureQueueEmpty(SynchronizedCaptureSession session) {
        }

        /* JADX INFO: Access modifiers changed from: package-private */
        public void onClosed(SynchronizedCaptureSession session) {
        }

        /* JADX INFO: Access modifiers changed from: package-private */
        public void onConfigureFailed(SynchronizedCaptureSession session) {
        }

        /* JADX INFO: Access modifiers changed from: package-private */
        public void onConfigured(SynchronizedCaptureSession session) {
        }

        /* JADX INFO: Access modifiers changed from: package-private */
        public void onReady(SynchronizedCaptureSession session) {
        }

        /* JADX INFO: Access modifiers changed from: package-private */
        public void onSessionFinished(SynchronizedCaptureSession session) {
        }

        /* JADX INFO: Access modifiers changed from: package-private */
        public void onSurfacePrepared(SynchronizedCaptureSession session, Surface surface) {
        }
    }

    void abortCaptures() throws CameraAccessException;

    int captureBurstRequests(List<CaptureRequest> requests, CameraCaptureSession.CaptureCallback listener) throws CameraAccessException;

    int captureBurstRequests(List<CaptureRequest> requests, Executor executor, CameraCaptureSession.CaptureCallback listener) throws CameraAccessException;

    int captureSingleRequest(CaptureRequest request, CameraCaptureSession.CaptureCallback listener) throws CameraAccessException;

    int captureSingleRequest(CaptureRequest request, Executor executor, CameraCaptureSession.CaptureCallback listener) throws CameraAccessException;

    void close();

    void finishClose();

    CameraDevice getDevice();

    StateCallback getStateCallback();

    ListenableFuture<Void> getSynchronizedBlocker(String feature);

    int setRepeatingBurstRequests(List<CaptureRequest> requests, CameraCaptureSession.CaptureCallback listener) throws CameraAccessException;

    int setRepeatingBurstRequests(List<CaptureRequest> requests, Executor executor, CameraCaptureSession.CaptureCallback listener) throws CameraAccessException;

    int setSingleRepeatingRequest(CaptureRequest request, CameraCaptureSession.CaptureCallback listener) throws CameraAccessException;

    int setSingleRepeatingRequest(CaptureRequest request, Executor executor, CameraCaptureSession.CaptureCallback listener) throws CameraAccessException;

    void stopRepeating() throws CameraAccessException;

    CameraCaptureSessionCompat toCameraCaptureSessionCompat();
}
