package com.iwown.awlog;

import android.text.TextUtils;
import android.util.Log;
import com.iwown.awlog.impl.LogConfigImpl;
import com.iwown.awlog.util.ObjectUtil;
import com.iwown.awlog.util.Utils;
import java.io.File;
import java.util.IllegalFormatConversionException;
import java.util.Iterator;
import java.util.MissingFormatArgumentException;
import java.util.UnknownFormatConversionException;

/* loaded from: classes2.dex */
public class LoggerUtil implements Printer {
    private static final int MIN_STACK_OFFSET = 5;
    String LINE_SEPARATOR = System.getProperty("line.separator");
    private final ThreadLocal<String> localTags = new ThreadLocal<>();
    private LogConfigImpl mLogConfig = LogConfigImpl.getInstance();

    private synchronized void logString(int i, String str, String str2, Object... objArr) {
        logString(i, str2, str, false, objArr);
    }

    private void logString(int i, String str, String str2, boolean z, Object... objArr) {
        if (TextUtils.isEmpty(str2)) {
            str2 = generateTag();
        }
        if (!z && objArr != null && objArr.length > 0) {
            try {
                str = String.format(str, objArr);
            } catch (IllegalFormatConversionException | MissingFormatArgumentException | UnknownFormatConversionException e) {
                printLog(5, str2, Log.getStackTraceString(e));
            }
        }
        if (!this.mLogConfig.isLogSwitch() || i < this.mLogConfig.getLogLevel()) {
            return;
        }
        if (str.length() > 2800) {
            if (this.mLogConfig.isShowBorder()) {
                printLog(i, str2, Utils.printDividingLine(1));
                printLog(i, str2, Utils.printDividingLine(3) + getTopStackInfo());
                printLog(i, str2, Utils.printDividingLine(4));
            }
            Iterator<String> it = ObjectUtil.largeStringToList(str).iterator();
            while (it.hasNext()) {
                logString(i, it.next(), str2, true, objArr);
            }
            if (this.mLogConfig.isShowBorder()) {
                printLog(i, str2, Utils.printDividingLine(2));
                return;
            }
            return;
        }
        if (!this.mLogConfig.isShowBorder()) {
            printLog(i, str2, str);
            return;
        }
        int i2 = 0;
        if (z) {
            String[] split = str.split(this.LINE_SEPARATOR);
            int length = split.length;
            while (i2 < length) {
                printLog(i, str2, Utils.printDividingLine(3) + split[i2]);
                i2++;
            }
            return;
        }
        printLog(i, str2, Utils.printDividingLine(1));
        printLog(i, str2, Utils.printDividingLine(3) + getTopStackInfo());
        printLog(i, str2, Utils.printDividingLine(4));
        String[] split2 = str.split(this.LINE_SEPARATOR);
        int length2 = split2.length;
        while (i2 < length2) {
            printLog(i, str2, Utils.printDividingLine(3) + split2[i2]);
            i2++;
        }
        printLog(i, str2, Utils.printDividingLine(2));
    }

    private void logObject(int i, String str, Object obj) {
        logString(i, str, ObjectUtil.objectToString(obj), new Object[0]);
    }

    private String generateTag() {
        String str = this.localTags.get();
        if (!TextUtils.isEmpty(str)) {
            this.localTags.remove();
            return str;
        }
        return this.mLogConfig.getPrefix();
    }

    private StackTraceElement getCurrentStackTrace() {
        int methodOffset;
        StackTraceElement[] stackTrace = Thread.currentThread().getStackTrace();
        int stackOffset = getStackOffset(stackTrace, AwLog.class);
        if (stackOffset == -1 && (stackOffset = getStackOffset(stackTrace, LoggerUtil.class)) == -1) {
            return null;
        }
        if (this.mLogConfig.getMethodOffset() > 0 && (methodOffset = this.mLogConfig.getMethodOffset() + stackOffset) < stackTrace.length) {
            stackOffset = methodOffset;
        }
        return stackTrace[stackOffset];
    }

    private String getTopStackInfo() {
        StackTraceElement currentStackTrace = getCurrentStackTrace();
        String stackTraceElement = currentStackTrace.toString();
        String substring = stackTraceElement.substring(stackTraceElement.lastIndexOf(40), stackTraceElement.length());
        String className = currentStackTrace.getClassName();
        return String.format("%s.%s%s", className.substring(className.lastIndexOf(".") + 1), currentStackTrace.getMethodName(), substring);
    }

    private int getStackOffset(StackTraceElement[] stackTraceElementArr, Class cls) {
        for (int i = 5; i < stackTraceElementArr.length; i++) {
            String className = stackTraceElementArr[i].getClassName();
            if (!(cls.equals(LoggerUtil.class) && i < stackTraceElementArr.length - 1 && stackTraceElementArr[i + 1].getClassName().equals(LoggerUtil.class.getName())) && className.equals(cls.getName())) {
                return i + 1;
            }
        }
        return -1;
    }

    @Override // com.iwown.awlog.Printer
    public void d(String str, Object obj) {
        logObject(1, str, obj);
    }

    @Override // com.iwown.awlog.Printer
    public void e(String str, Object obj) {
        logObject(5, str, obj);
    }

    @Override // com.iwown.awlog.Printer
    public void w(String str, Object obj) {
        logObject(4, str, obj);
    }

    @Override // com.iwown.awlog.Printer
    public void i(String str, Object obj) {
        logObject(3, str, obj);
    }

    @Override // com.iwown.awlog.Printer
    public void v(String str, Object obj) {
        logObject(2, str, obj);
    }

    @Override // com.iwown.awlog.Printer
    public void wtf(String str, String str2) {
        writeToFile(str2, str);
    }

    private void printLog(int i, String str, String str2) {
        if (!this.mLogConfig.isShowBorder()) {
            str2 = getTopStackInfo() + ": " + str2;
        }
        switch (i) {
            case 1:
                Log.d(str, str2);
                return;
            case 2:
                Log.v(str, str2);
                return;
            case 3:
                Log.i(str, str2);
                return;
            case 4:
                Log.w(str, str2);
                return;
            case 5:
                Log.e(str, str2);
                return;
            case 6:
                Log.wtf(str, str2);
                return;
            default:
                return;
        }
    }

    private void writeToFile(String str, String str2) {
        if (TextUtils.isEmpty(str)) {
            throw new RuntimeException("Log File Path must not be empty");
        }
        File file = new File(str);
        if (!file.getParentFile().exists()) {
            file.getParentFile().mkdirs();
        }
        if (this.mLogConfig.getEngine() != null) {
            this.mLogConfig.getEngine().writeToFile(file, str2);
            return;
        }
        throw new IllegalArgumentException("LogFileEngine must not Null");
    }
}
