package com.oudmon.ble.base.communication;

import com.bumptech.glide.load.Key;
import com.iwown.awlog.Author;
import com.iwown.awlog.AwLog;
import com.oudmon.ble.base.bluetooth.BleOperateManager;
import com.oudmon.ble.base.bluetooth.queue.BleDataBean;
import com.oudmon.ble.base.bluetooth.queue.BleThreadManager;
import com.oudmon.ble.base.communication.bigData.AlarmNewEntity;
import com.oudmon.ble.base.communication.bigData.CustomWatchFaceEntity;
import com.oudmon.ble.base.communication.bigData.bean.BaseBean;
import com.oudmon.ble.base.communication.bigData.bean.ClassicBluetooth;
import com.oudmon.ble.base.communication.bigData.bean.ContactBean;
import com.oudmon.ble.base.communication.bigData.bean.ECardEntity;
import com.oudmon.ble.base.communication.bigData.bean.ManualHeartRate;
import com.oudmon.ble.base.communication.bigData.resp.ILargeDataBaseResponse;
import com.oudmon.ble.base.communication.bigData.resp.ILargeDataClassicBluetoothResponse;
import com.oudmon.ble.base.communication.bigData.resp.ILargeDataManualHeartRateResponse;
import com.oudmon.ble.base.communication.bigData.resp.ILargeDataQrCodeResponse;
import com.oudmon.ble.base.communication.rsp.SleepNewProtoResp;
import com.oudmon.ble.base.communication.utils.ByteUtil;
import com.oudmon.ble.base.communication.utils.CRC16;
import com.oudmon.ble.base.request.EnableNotifyRequest;
import com.oudmon.ble.base.request.WriteRequest;
import com.oudmon.ble.base.util.DateUtil;
import com.qcwireless.qc_utils.bytes.DataTransferUtils;
import java.io.UnsupportedEncodingException;
import java.nio.charset.Charset;
import java.nio.charset.StandardCharsets;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.LinkedList;
import java.util.List;
import java.util.UUID;
import java.util.concurrent.ConcurrentHashMap;

/* loaded from: classes2.dex */
public class LargeDataHandler {
    public static final byte ACTION_AVATAR_Device = 74;
    public static final byte ACTION_Alarm = 44;
    public static final byte ACTION_BT_MAC_Protocol = 46;
    public static final byte ACTION_Blood_Oxygen = 42;
    public static final byte ACTION_Blood_Sugar = 71;
    public static final byte ACTION_Contact = 45;
    public static final byte ACTION_Contacts_New = 41;
    public static final byte ACTION_Custom_WatchFace = 58;
    public static final byte ACTION_E_CARD_Protocol = 47;
    public static final byte ACTION_GPS_Navigation = 72;
    public static final byte ACTION_Location_Protocol = 32;
    public static final byte ACTION_ManualHeartRate_Protocol = 40;
    public static final byte ACTION_New_Sleep_Protocol = 39;
    private static LargeDataHandler mInstance;
    private static final UUID SERIAL_PORT_SERVICE = UUID.fromString("de5bf728-d711-4e47-af26-65e3012a5dc7");
    private static final UUID SERIAL_PORT_CHARACTER_NOTIFY = UUID.fromString("de5bf729-d711-4e47-af26-65e3012a5dc7");
    private static final UUID SERIAL_PORT_CHARACTER_WRITE = UUID.fromString("de5bf72a-d711-4e47-af26-65e3012a5dc7");
    private EnableNotifyRequest enableNotifyRequest = new EnableNotifyRequest(SERIAL_PORT_SERVICE, SERIAL_PORT_CHARACTER_NOTIFY, new EnableNotifyRequest.ListenerCallback() { // from class: com.oudmon.ble.base.communication.LargeDataHandler.1
        @Override // com.oudmon.ble.base.request.EnableNotifyRequest.ListenerCallback
        public void enable(boolean z) {
            if (z) {
                return;
            }
            AwLog.i(Author.HeZhiYuan, "enable:" + z);
            LargeDataHandler.this.initEnable();
        }
    });
    private ConcurrentHashMap<Integer, ILargeDataResponse> respMap = new ConcurrentHashMap<>();
    private int mPackageLength = JPackageManager.getInstance().getLength();

    private LargeDataHandler() {
    }

    public static LargeDataHandler getInstance() {
        if (mInstance == null) {
            synchronized (LargeDataHandler.class) {
                if (mInstance == null) {
                    mInstance = new LargeDataHandler();
                }
            }
        }
        return mInstance;
    }

    public void initEnable() {
        this.enableNotifyRequest.setEnable(true);
        BleOperateManager.getInstance().execute(this.enableNotifyRequest);
    }

    public void disEnable() {
        this.enableNotifyRequest.setEnable(false);
        BleOperateManager.getInstance().execute(this.enableNotifyRequest);
    }

    public void syncBloodOxygen(int i, ILargeDataResponse iLargeDataResponse) {
        this.respMap.put(42, iLargeDataResponse);
        BleThreadManager.getInstance().addData(new BleDataBean(addHeader(42, new byte[]{(byte) i}), JPackageManager.getInstance().getLength()));
    }

    public void syncBloodSugar(int i, ILargeDataResponse iLargeDataResponse) {
        this.respMap.put(71, iLargeDataResponse);
        BleThreadManager.getInstance().addData(new BleDataBean(addHeader(71, new byte[]{(byte) i}), JPackageManager.getInstance().getLength()));
    }

    public void readCustomWatch(ILargeDataResponse iLargeDataResponse) {
        this.respMap.put(58, iLargeDataResponse);
        BleThreadManager.getInstance().addData(new BleDataBean(addHeader(58, new byte[]{1}), JPackageManager.getInstance().getLength()));
    }

    public void syncContact(byte[] bArr) {
        BleThreadManager.getInstance().addData(new BleDataBean(addHeader(45, bArr), JPackageManager.getInstance().getLength()));
    }

    public void setDeviceNickName(String str) {
        if (str.isEmpty()) {
            BleThreadManager.getInstance().addData(new BleDataBean(addHeader(74, new byte[]{1, 1}), JPackageManager.getInstance().getLength()));
            return;
        }
        byte[] bytes = str.getBytes(Charset.forName("unicode"));
        if (!ByteUtil.byteArrayToString(bytes).startsWith("fffe")) {
            int i = 0;
            while (i < bytes.length) {
                int i2 = i + 2;
                int bytesToInt = ByteUtil.bytesToInt(Arrays.copyOfRange(bytes, i, i2));
                bytes[i] = (byte) ByteUtil.hiword(bytesToInt);
                bytes[i + 1] = (byte) ByteUtil.loword(bytesToInt);
                i = i2;
            }
        }
        BleThreadManager.getInstance().addData(new BleDataBean(addHeader(74, ByteUtil.concat(new byte[]{1, 1}, bytes)), JPackageManager.getInstance().getLength()));
    }

    public void gpsNavigationRunning(int i, int i2, String str) {
        byte[] bytes = str.getBytes(Charset.forName("unicode"));
        if (!ByteUtil.byteArrayToString(bytes).startsWith("fffe")) {
            int i3 = 0;
            while (i3 < bytes.length) {
                int i4 = i3 + 2;
                int bytesToInt = ByteUtil.bytesToInt(Arrays.copyOfRange(bytes, i3, i4));
                bytes[i3] = (byte) ByteUtil.hiword(bytesToInt);
                bytes[i3 + 1] = (byte) ByteUtil.loword(bytesToInt);
                i3 = i4;
            }
        }
        BleThreadManager.getInstance().addData(new BleDataBean(addHeader(72, ByteUtil.concat(new byte[]{1, (byte) (bytes.length + 2), (byte) i, (byte) i2}, bytes)), JPackageManager.getInstance().getLength()));
    }

    public void gpsNavigationStatus(int i) {
        BleThreadManager.getInstance().addData(new BleDataBean(addHeader(72, new byte[]{(byte) i, 0}), JPackageManager.getInstance().getLength()));
    }

    public void syncContactMore(List<ContactBean> list, final ILargeDataBaseResponse iLargeDataBaseResponse) {
        int size = list.size();
        byte[] bArr = new byte[0];
        final LinkedList linkedList = new LinkedList();
        for (int i = 0; i < list.size(); i++) {
            ContactBean contactBean = list.get(i);
            String contactName = contactBean.getContactName();
            if (contactName.getBytes().length > 32) {
                contactName = getWholeText(contactName, 32);
            }
            byte[] bytes = contactName.getBytes();
            byte[] concat = ByteUtil.concat(bArr, ByteUtil.concat(ByteUtil.intToByte((byte) bytes.length, 1), bytes));
            String phoneNumber = contactBean.getPhoneNumber();
            if (phoneNumber.getBytes().length > 18) {
                phoneNumber = getWholeText(phoneNumber, 18);
            }
            byte[] bytes2 = phoneNumber.getBytes();
            bArr = ByteUtil.concat(concat, ByteUtil.concat(ByteUtil.intToByte(bytes2.length, 1), bytes2));
            if (bArr.length > 950) {
                linkedList.add(bArr);
                bArr = new byte[0];
            }
        }
        linkedList.add(bArr);
        final int size2 = linkedList.size();
        BleThreadManager.getInstance().addData(new BleDataBean(addHeader(41, new byte[]{(byte) (size2 + 1), 0, (byte) ByteUtil.loword(size), (byte) ByteUtil.hiword(size)}), JPackageManager.getInstance().getLength()));
        final int[] iArr = {0};
        this.respMap.put(41, new ILargeDataResponse() { // from class: com.oudmon.ble.base.communication.LargeDataHandler.2
            @Override // com.oudmon.ble.base.communication.ILargeDataResponse
            public void parseData(int i2, byte[] bArr2) {
                if (i2 == 41 && ByteUtil.bytesToInt(Arrays.copyOfRange(bArr2, 6, 7)) == 0) {
                    if (linkedList.size() == 0) {
                        AwLog.i(Author.HeZhiYuan, "下发完了联系人");
                        iLargeDataBaseResponse.resp(new BaseBean(0));
                        return;
                    }
                    int[] iArr2 = iArr;
                    iArr2[0] = iArr2[0] + 1;
                    byte[] addHeader = LargeDataHandler.this.addHeader(41, ByteUtil.concat(new byte[]{(byte) (size2 + 1), (byte) iArr2[0]}, (byte[]) linkedList.removeFirst()));
                    for (int i3 = 0; i3 < addHeader.length; i3 += JPackageManager.getInstance().getLength()) {
                        int min = Math.min(JPackageManager.getInstance().getLength(), addHeader.length - i3);
                        byte[] bArr3 = new byte[min];
                        System.arraycopy(addHeader, i3, bArr3, 0, min);
                        BleThreadManager.getInstance().addData(new BleDataBean(bArr3, JPackageManager.getInstance().getLength()));
                    }
                }
            }
        });
    }

    public void packageLength() {
        this.mPackageLength = JPackageManager.getInstance().getLength();
    }

    public void syncSleepList(int i, final ILargeDataSleepResponse iLargeDataSleepResponse) {
        this.respMap.put(39, new ILargeDataResponse() { // from class: com.oudmon.ble.base.communication.LargeDataHandler.3
            @Override // com.oudmon.ble.base.communication.ILargeDataResponse
            public void parseData(int i2, byte[] bArr) {
                if (i2 == 39) {
                    if (ByteUtil.bytesToInt(Arrays.copyOfRange(bArr, 6, 7)) > 0) {
                        int bytesToInt = ByteUtil.bytesToInt(Arrays.copyOfRange(bArr, 2, 4));
                        LargeDataHandler.this.parseDaySleep(ByteUtil.bytesToInt(Arrays.copyOfRange(bArr, 7, 8)), bArr, 7, ByteUtil.bytesToInt(Arrays.copyOfRange(bArr, 8, 9)) + 2, bytesToInt, iLargeDataSleepResponse);
                        return;
                    }
                    ILargeDataSleepResponse iLargeDataSleepResponse2 = iLargeDataSleepResponse;
                    if (iLargeDataSleepResponse2 != null) {
                        iLargeDataSleepResponse2.sleepData(null);
                    }
                }
            }
        });
        byte[] bArr = new byte[1];
        if (i == 0) {
            bArr[0] = 0;
        } else {
            bArr[0] = -1;
        }
        BleThreadManager.getInstance().addData(new BleDataBean(addHeader(39, bArr), this.mPackageLength));
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void parseDaySleep(int i, byte[] bArr, int i2, int i3, int i4, ILargeDataSleepResponse iLargeDataSleepResponse) {
        try {
            SleepNewProtoResp sleepNewProtoResp = new SleepNewProtoResp();
            DateUtil dateUtil = new DateUtil();
            dateUtil.addDay(-i);
            byte[] copyOfRange = Arrays.copyOfRange(bArr, i2, i2 + i3);
            AwLog.i(Author.HeZhiYuan, ByteUtil.byteArrayToString(copyOfRange));
            int bytesToInt = ByteUtil.bytesToInt(Arrays.copyOfRange(copyOfRange, 2, 4));
            sleepNewProtoResp.setEt((int) (dateUtil.getZeroTime() + (ByteUtil.bytesToInt(Arrays.copyOfRange(copyOfRange, 4, 6)) * 60)));
            if (bytesToInt >= 1080) {
                dateUtil.addDay(-1);
            }
            sleepNewProtoResp.setSt((int) (dateUtil.getZeroTime() + (bytesToInt * 60)));
            ArrayList arrayList = new ArrayList();
            byte[] copyOfRange2 = Arrays.copyOfRange(copyOfRange, 6, copyOfRange.length);
            for (int i5 = 0; i5 < copyOfRange2.length; i5++) {
                if (i5 % 2 == 1) {
                    SleepNewProtoResp.DetailBean detailBean = new SleepNewProtoResp.DetailBean();
                    detailBean.setT(copyOfRange2[i5 - 1]);
                    if (copyOfRange2[i5] < 0) {
                        detailBean.setD(ByteUtil.byteToInt(copyOfRange2[i5]));
                    } else {
                        detailBean.setD(copyOfRange2[i5]);
                    }
                    arrayList.add(detailBean);
                }
            }
            sleepNewProtoResp.setList(arrayList);
            if (iLargeDataSleepResponse != null) {
                iLargeDataSleepResponse.sleepData(sleepNewProtoResp);
            }
            if (copyOfRange.length + i2 < i4) {
                try {
                    parseDaySleep(ByteUtil.bytesToInt(Arrays.copyOfRange(bArr, copyOfRange.length + i2, copyOfRange.length + i2 + 1)), bArr, i2 + copyOfRange.length, ByteUtil.bytesToInt(Arrays.copyOfRange(bArr, copyOfRange.length + i2 + 1, copyOfRange.length + i2 + 2)) + 2, i4, iLargeDataSleepResponse);
                } catch (Exception e) {
                    e.printStackTrace();
                }
            }
        } catch (Exception e2) {
            e2.printStackTrace();
        }
    }

    public void syncManualHeartRateList(int i, final ILargeDataManualHeartRateResponse iLargeDataManualHeartRateResponse) {
        this.respMap.put(40, new ILargeDataResponse() { // from class: com.oudmon.ble.base.communication.LargeDataHandler.4
            @Override // com.oudmon.ble.base.communication.ILargeDataResponse
            public void parseData(int i2, byte[] bArr) {
                if (i2 == 40) {
                    ManualHeartRate manualHeartRate = new ManualHeartRate();
                    manualHeartRate.setIndex(ByteUtil.bytesToInt(Arrays.copyOfRange(bArr, 6, 7)));
                    ArrayList arrayList = new ArrayList();
                    byte[] copyOfRange = Arrays.copyOfRange(bArr, 7, bArr.length);
                    for (int i3 = 0; i3 < copyOfRange.length / 3; i3++) {
                        ManualHeartRate.DetailBean detailBean = new ManualHeartRate.DetailBean();
                        int i4 = i3 * 3;
                        int i5 = i4 + 2;
                        detailBean.setM(ByteUtil.bytesToInt(Arrays.copyOfRange(copyOfRange, i4, i5)));
                        detailBean.setV(ByteUtil.bytesToInt(Arrays.copyOfRange(copyOfRange, i5, i4 + 3)));
                        arrayList.add(detailBean);
                    }
                    manualHeartRate.setData(arrayList);
                    ILargeDataManualHeartRateResponse iLargeDataManualHeartRateResponse2 = iLargeDataManualHeartRateResponse;
                    if (iLargeDataManualHeartRateResponse2 != null) {
                        iLargeDataManualHeartRateResponse2.manualHeart(manualHeartRate);
                    }
                }
            }
        });
        byte[] bArr = new byte[1];
        if (i != 0) {
            bArr[0] = -1;
        }
        BleThreadManager.getInstance().addData(new BleDataBean(addHeader(40, bArr), this.mPackageLength));
    }

    public void syncClassicBluetooth(final ILargeDataClassicBluetoothResponse iLargeDataClassicBluetoothResponse) {
        this.respMap.put(46, new ILargeDataResponse() { // from class: com.oudmon.ble.base.communication.LargeDataHandler.5
            @Override // com.oudmon.ble.base.communication.ILargeDataResponse
            public void parseData(int i, byte[] bArr) {
                if (i == 46) {
                    ClassicBluetooth classicBluetooth = new ClassicBluetooth();
                    classicBluetooth.setDeviceMac(LargeDataHandler.this.bytesToMac(Arrays.copyOfRange(bArr, 6, 12)));
                    classicBluetooth.setDeviceName(new String(Arrays.copyOfRange(bArr, 13, bArr[12] + 13), StandardCharsets.UTF_8));
                    ILargeDataClassicBluetoothResponse iLargeDataClassicBluetoothResponse2 = iLargeDataClassicBluetoothResponse;
                    if (iLargeDataClassicBluetoothResponse2 != null) {
                        iLargeDataClassicBluetoothResponse2.classicBluetooth(classicBluetooth);
                    }
                }
            }
        });
        BleThreadManager.getInstance().addData(new BleDataBean(addHeader(46, new byte[1]), this.mPackageLength));
    }

    public void writeCustomWatch(CustomWatchFaceEntity customWatchFaceEntity) {
        byte[] bArr = {2};
        for (int i = 0; i < customWatchFaceEntity.getData().size(); i++) {
            CustomWatchFaceEntity.CustomElement customElement = customWatchFaceEntity.getData().get(i);
            bArr = ByteUtil.concat(bArr, new byte[]{(byte) customElement.getType(), (byte) ByteUtil.loword(customElement.getX()), (byte) ByteUtil.hiword(customElement.getX()), (byte) ByteUtil.loword(customElement.getY()), (byte) ByteUtil.hiword(customElement.getY()), (byte) customElement.getR(), (byte) customElement.getG(), (byte) customElement.getB()});
        }
        BleThreadManager.getInstance().addData(new BleDataBean(addHeader(58, bArr), this.mPackageLength));
    }

    public void writeAlarm(AlarmNewEntity alarmNewEntity) {
        try {
            byte[] bArr = {2, (byte) alarmNewEntity.getTotal()};
            for (AlarmNewEntity.AlarmBean alarmBean : alarmNewEntity.getData()) {
                bArr = ByteUtil.concat(bArr, ByteUtil.concat(new byte[]{(byte) alarmBean.getAlarmLength(), (byte) alarmBean.getRepeatAndEnable(), (byte) ByteUtil.loword(alarmBean.getMin()), (byte) ByteUtil.hiword(alarmBean.getMin())}, alarmBean.getContent().getBytes(Key.STRING_CHARSET_NAME)));
            }
            BleThreadManager.getInstance().addData(new BleDataBean(addHeader(44, bArr), this.mPackageLength));
        } catch (UnsupportedEncodingException e) {
            e.printStackTrace();
        }
    }

    public void readAlarm(ILargeDataResponse iLargeDataResponse) {
        this.respMap.put(44, iLargeDataResponse);
        BleThreadManager.getInstance().addData(new BleDataBean(addHeader(44, new byte[]{1}), this.mPackageLength));
    }

    public void writeQrCode(ECardEntity eCardEntity) {
        BleThreadManager.getInstance().addData(new BleDataBean(addHeader(47, ByteUtil.concat(new byte[]{2, (byte) eCardEntity.getType(), (byte) eCardEntity.getUrl().getBytes(StandardCharsets.UTF_8).length}, eCardEntity.getUrl().getBytes(StandardCharsets.UTF_8))), this.mPackageLength));
    }

    public void writeQrCodeWithType() {
        BleThreadManager.getInstance().addData(new BleDataBean(addHeader(47, ByteUtil.concat(new byte[]{2, -1, 0}, "".getBytes(StandardCharsets.UTF_8))), this.mPackageLength));
    }

    public void deviceRequestLocation(final ILargeDataResponse iLargeDataResponse) {
        this.respMap.put(32, new ILargeDataResponse() { // from class: com.oudmon.ble.base.communication.LargeDataHandler.6
            @Override // com.oudmon.ble.base.communication.ILargeDataResponse
            public void parseData(int i, byte[] bArr) {
                ILargeDataResponse iLargeDataResponse2;
                if (i == 32 && ByteUtil.bytesToInt(Arrays.copyOfRange(bArr, 6, 7)) == 1 && (iLargeDataResponse2 = iLargeDataResponse) != null) {
                    iLargeDataResponse2.parseData(32, bArr);
                }
            }
        });
    }

    public void writeLocation(double d, double d2, String str) {
        int i = (int) d2;
        double d3 = (d2 - i) * 60.0d;
        int i2 = (int) d3;
        int i3 = (int) d;
        double d4 = (d - i3) * 60.0d;
        int i4 = (int) d4;
        BleThreadManager.getInstance().addData(new BleDataBean(addHeader(32, ByteUtil.concat(new byte[]{2, (byte) ByteUtil.loword(i), (byte) ByteUtil.hiword(i), (byte) Math.abs(i2), (byte) ((int) ((float) Math.abs((d3 - i2) * 60.0d))), (byte) (((r12 - r13) * 10000.0f) / 100.0f), (byte) ByteUtil.loword(i3), (byte) ByteUtil.hiword(i3), (byte) Math.abs(i4), (byte) ((int) ((float) Math.abs((d4 - i4) * 60.0d))), (byte) (((r10 - r11) * 10000.0f) / 100.0f)}, str.getBytes(StandardCharsets.UTF_8))), this.mPackageLength));
    }

    public void readQrCode(final int i, final ILargeDataQrCodeResponse iLargeDataQrCodeResponse) {
        this.respMap.put(47, new ILargeDataResponse() { // from class: com.oudmon.ble.base.communication.LargeDataHandler.7
            @Override // com.oudmon.ble.base.communication.ILargeDataResponse
            public void parseData(int i2, byte[] bArr) {
                if (i2 == 47) {
                    try {
                        AwLog.i(Author.HeZhiYuan, ByteUtil.byteArrayToString(bArr));
                        int bytesToInt = ByteUtil.bytesToInt(Arrays.copyOfRange(bArr, 6, 7));
                        if (bytesToInt == 1) {
                            ECardEntity eCardEntity = new ECardEntity();
                            eCardEntity.setType(i);
                            eCardEntity.setDeviceError(2);
                            eCardEntity.setReadOrWrite(bytesToInt);
                            eCardEntity.setUrl(new String(Arrays.copyOfRange(bArr, 9, bArr[8] + 9), StandardCharsets.UTF_8));
                            ILargeDataQrCodeResponse iLargeDataQrCodeResponse2 = iLargeDataQrCodeResponse;
                            if (iLargeDataQrCodeResponse2 != null) {
                                iLargeDataQrCodeResponse2.qrCode(eCardEntity);
                            }
                        } else if (bytesToInt == 2) {
                            int bytesToInt2 = ByteUtil.bytesToInt(Arrays.copyOfRange(bArr, 7, 8));
                            if (bytesToInt2 == 255) {
                                if (iLargeDataQrCodeResponse != null) {
                                    ECardEntity eCardEntity2 = new ECardEntity();
                                    eCardEntity2.setReadOrWrite(bytesToInt);
                                    if (ByteUtil.bytesToInt(Arrays.copyOfRange(bArr, 8, 9)) == 0) {
                                        eCardEntity2.setType(255);
                                        eCardEntity2.setSupport(true);
                                        eCardEntity2.setDeviceError(2);
                                        eCardEntity2.setReadOrWrite(bytesToInt);
                                        iLargeDataQrCodeResponse.qrCode(eCardEntity2);
                                    } else {
                                        eCardEntity2.setType(255);
                                        eCardEntity2.setSupport(false);
                                        eCardEntity2.setDeviceError(2);
                                        eCardEntity2.setReadOrWrite(bytesToInt);
                                        iLargeDataQrCodeResponse.qrCode(eCardEntity2);
                                    }
                                }
                            } else if (ByteUtil.bytesToInt(Arrays.copyOfRange(bArr, 8, 9)) == 1) {
                                if (iLargeDataQrCodeResponse != null) {
                                    ECardEntity eCardEntity3 = new ECardEntity();
                                    eCardEntity3.setType(bytesToInt2);
                                    eCardEntity3.setDeviceError(1);
                                    eCardEntity3.setReadOrWrite(bytesToInt);
                                    iLargeDataQrCodeResponse.qrCode(eCardEntity3);
                                }
                            } else if (iLargeDataQrCodeResponse != null) {
                                ECardEntity eCardEntity4 = new ECardEntity();
                                eCardEntity4.setType(bytesToInt2);
                                eCardEntity4.setReadOrWrite(bytesToInt);
                                eCardEntity4.setDeviceError(0);
                                iLargeDataQrCodeResponse.qrCode(eCardEntity4);
                            }
                        }
                    } catch (Exception e) {
                        e.printStackTrace();
                    }
                }
            }
        });
        if (i != 255) {
            BleThreadManager.getInstance().addData(new BleDataBean(addHeader(47, new byte[]{1, (byte) i}), this.mPackageLength));
        }
    }

    public ConcurrentHashMap<Integer, ILargeDataResponse> getRespMap() {
        return this.respMap;
    }

    public void cleanMap() {
        this.respMap.clear();
    }

    /* JADX INFO: Access modifiers changed from: private */
    public byte[] addHeader(int i, byte[] bArr) {
        byte[] bArr2 = new byte[(bArr == null ? 0 : bArr.length) + 6];
        bArr2[0] = -68;
        bArr2[1] = (byte) i;
        if (bArr != null && bArr.length > 0) {
            System.arraycopy(DataTransferUtils.shortToBytes((short) bArr.length), 0, bArr2, 2, 2);
            System.arraycopy(DataTransferUtils.shortToBytes((short) CRC16.calcCrc16(bArr)), 0, bArr2, 4, 2);
            System.arraycopy(bArr, 0, bArr2, 6, bArr.length);
        } else {
            bArr2[4] = -1;
            bArr2[5] = -1;
        }
        return bArr2;
    }

    private WriteRequest getWriteRequest(byte[] bArr) {
        AwLog.i(Author.HeZhiYuan, "getWriteRequest: data=" + DataTransferUtils.getHexString(bArr));
        WriteRequest noRspInstance = WriteRequest.getNoRspInstance(SERIAL_PORT_SERVICE, SERIAL_PORT_CHARACTER_WRITE);
        noRspInstance.setValue(bArr);
        return noRspInstance;
    }

    public String bytesToMac(byte[] bArr) {
        StringBuilder sb = new StringBuilder();
        for (byte b : bArr) {
            String upperCase = Integer.toHexString(b & 255).toUpperCase();
            if (upperCase.length() == 1) {
                upperCase = "0" + upperCase;
            }
            sb.append(upperCase);
            sb.append(":");
        }
        return sb.substring(0, sb.length() - 1);
    }

    public String getWholeText(String str, int i) {
        if (str == null) {
            return str;
        }
        try {
            if (str.getBytes("utf-8").length <= i) {
                return str;
            }
            char[] charArray = str.toCharArray();
            int length = charArray.length;
            int i2 = 0;
            int i3 = 0;
            while (true) {
                if (i2 >= length) {
                    i2 = 0;
                    break;
                }
                char c = charArray[i2];
                i3 = (c < 0 || c > 127) ? (c < 128 || c > 2047) ? i3 + 3 : i3 + 2 : i3 + 1;
                if (i3 > i) {
                    break;
                }
                i2++;
            }
            return String.valueOf(charArray, 0, i2);
        } catch (UnsupportedEncodingException unused) {
            return str;
        }
    }
}
