package com.oudmon.ble.base.communication.file;

import android.app.Application;
import com.iwown.awlog.Author;
import com.iwown.awlog.AwLog;
import com.oudmon.ble.base.bluetooth.BleOperateManager;
import com.oudmon.ble.base.bluetooth.OnGattEventCallback;
import com.oudmon.ble.base.bluetooth.queue.BleDataBean;
import com.oudmon.ble.base.bluetooth.queue.BleThreadManager;
import com.oudmon.ble.base.communication.CompressUtils;
import com.oudmon.ble.base.communication.JPackageManager;
import com.oudmon.ble.base.communication.utils.ByteUtil;
import com.oudmon.ble.base.communication.utils.CRC16;
import com.oudmon.ble.base.request.EnableNotifyRequest;
import com.oudmon.ble.base.util.DateUtil;
import com.qcwireless.qc_utils.bytes.DataTransferUtils;
import java.io.BufferedReader;
import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStreamReader;
import java.io.RandomAccessFile;
import java.nio.charset.Charset;
import java.text.DecimalFormat;
import java.text.DecimalFormatSymbols;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Iterator;
import java.util.List;
import java.util.Locale;
import java.util.UUID;
import java.util.concurrent.CopyOnWriteArraySet;

/* loaded from: classes2.dex */
public class EbookHandle {
    private static final String TAG = "EbookHandle";
    private static EbookHandle mInstance;
    private byte[] mFileSend;
    private byte[] mFileSendA;
    private byte[] mFileSendB;
    private byte[] mReceivedData;
    private boolean mReceiving;
    private static final UUID SERIAL_PORT_SERVICE = UUID.fromString("de5bf728-d711-4e47-af26-65e3012a5dc7");
    private static final UUID SERIAL_PORT_CHARACTER_NOTIFY = UUID.fromString("de5bf729-d711-4e47-af26-65e3012a5dc7");
    private static final UUID SERIAL_PORT_CHARACTER_WRITE = UUID.fromString("de5bf72a-d711-4e47-af26-65e3012a5dc7");
    public static int FileTypeEbook = 4;
    public static int FileTypeAlbum = 5;
    public static int FileTypeLYRICS = 6;
    private ArrayList<String> fileNames = new ArrayList<>();
    private EnableNotifyRequest enableNotifyRequest = new EnableNotifyRequest(SERIAL_PORT_SERVICE, SERIAL_PORT_CHARACTER_NOTIFY, new EnableNotifyRequest.ListenerCallback() { // from class: com.oudmon.ble.base.communication.file.EbookHandle.1
        @Override // com.oudmon.ble.base.request.EnableNotifyRequest.ListenerCallback
        public void enable(boolean z) {
        }
    });
    private CopyOnWriteArraySet<IEbookCallback> mCallbackArray = new CopyOnWriteArraySet<>();
    private int currFileType = 0;
    private String logPath = "";
    private String logPath1 = "";
    private IEbookCallback mCallback = new IEbookCallback() { // from class: com.oudmon.ble.base.communication.file.EbookHandle.2
        @Override // com.oudmon.ble.base.communication.file.IEbookCallback
        public void onFileNames(ArrayList<String> arrayList) {
            Iterator it = EbookHandle.this.mCallbackArray.iterator();
            while (it.hasNext()) {
                ((IEbookCallback) it.next()).onFileNames(arrayList);
            }
        }

        @Override // com.oudmon.ble.base.communication.file.IEbookCallback
        public void onProgress(float f) {
            Iterator it = EbookHandle.this.mCallbackArray.iterator();
            while (it.hasNext()) {
                ((IEbookCallback) it.next()).onProgress(f);
            }
        }

        @Override // com.oudmon.ble.base.communication.file.IEbookCallback
        public void onComplete() {
            Iterator it = EbookHandle.this.mCallbackArray.iterator();
            while (it.hasNext()) {
                ((IEbookCallback) it.next()).onComplete();
            }
        }

        @Override // com.oudmon.ble.base.communication.file.IEbookCallback
        public void onDeleteSuccess(int i) {
            Iterator it = EbookHandle.this.mCallbackArray.iterator();
            while (it.hasNext()) {
                ((IEbookCallback) it.next()).onDeleteSuccess(i);
            }
        }

        @Override // com.oudmon.ble.base.communication.file.IEbookCallback
        public void onActionResult(int i) {
            Iterator it = EbookHandle.this.mCallbackArray.iterator();
            while (it.hasNext()) {
                ((IEbookCallback) it.next()).onActionResult(i);
            }
        }
    };
    private short mPocketIndex = 0;
    private short mPocketIndexA = 0;
    private short mPocketIndexB = 0;
    private int totalSize = 1;
    private int sizeA = 1;
    private int sizeB = 1;
    private int mTotalCount = 0;
    private int mReceivedCount = 0;
    private OnGattEventCallback callback = new OnGattEventCallback() { // from class: com.oudmon.ble.base.communication.file.EbookHandle.3
        @Override // com.oudmon.ble.base.bluetooth.OnGattEventCallback
        public void onReceivedData(String str, byte[] bArr) {
            if (bArr != null) {
                if ((bArr[0] & 255) == 188 && bArr[1] == 49) {
                    AwLog.i(Author.HeZhiYuan, "初始化完成，开始向手环发送实际文件");
                    if (bArr[6] > 0) {
                        EbookHandle.this.mCallback.onActionResult(bArr[6]);
                        return;
                    } else {
                        EbookHandle.this.cmdSendPacket();
                        return;
                    }
                }
                if ((bArr[0] & 255) == 188 && bArr[1] == 50) {
                    if (EbookHandle.this.readNextBigPocket()) {
                        float parseFloat = Float.parseFloat(new DecimalFormat("#.00", new DecimalFormatSymbols(Locale.US)).format((((EbookHandle.this.mPocketIndex * 1024) * 1.0f) * 100.0f) / EbookHandle.this.totalSize));
                        AwLog.i(Author.HeZhiYuan, "向手环发送数据进度: " + parseFloat + ", 包序: " + ((int) EbookHandle.this.mPocketIndex) + "总包:" + EbookHandle.this.totalSize);
                        EbookHandle.this.mCallback.onProgress(Math.min(parseFloat, 100.0f));
                        return;
                    }
                    AwLog.i(Author.HeZhiYuan, "向手环发送数据完毕, 包序: " + ((int) EbookHandle.this.mPocketIndex));
                    EbookHandle.this.cmdCheck();
                    return;
                }
                if ((bArr[0] & 255) == 188 && bArr[1] == 51) {
                    AwLog.i(Author.HeZhiYuan, "===============回调 onComplete");
                    EbookHandle.this.mFileSend = new byte[0];
                    if (bArr[6] > 0) {
                        EbookHandle.this.mCallback.onActionResult(bArr[6]);
                        return;
                    } else {
                        EbookHandle.this.mCallback.onComplete();
                        return;
                    }
                }
                if ((bArr[0] & 255) != 188 || bArr[1] != Byte.MIN_VALUE) {
                    if (EbookHandle.this.mReceiving) {
                        System.arraycopy(bArr, 0, EbookHandle.this.mReceivedData, EbookHandle.this.mReceivedCount, bArr.length);
                        EbookHandle.access$812(EbookHandle.this, bArr.length);
                        EbookHandle ebookHandle = EbookHandle.this;
                        ebookHandle.mReceiving = ebookHandle.mReceivedCount < EbookHandle.this.mTotalCount;
                        AwLog.i(Author.HeZhiYuan, "文件：->3 mTotalCount: " + EbookHandle.this.mTotalCount + ", mReceivedCount: " + EbookHandle.this.mReceivedCount + ", mReceiving: " + EbookHandle.this.mReceiving);
                        if (EbookHandle.this.mReceiving) {
                            return;
                        }
                        AwLog.i(Author.HeZhiYuan, "文件：->4 ->" + DataTransferUtils.getHexString(EbookHandle.this.mReceivedData));
                        int bytesToInt = ByteUtil.bytesToInt(Arrays.copyOfRange(EbookHandle.this.mReceivedData, 1, 2));
                        if (ByteUtil.bytesToInt(Arrays.copyOfRange(EbookHandle.this.mReceivedData, 2, 3)) == 0) {
                            EbookHandle.this.fileNames = new ArrayList();
                        }
                        AwLog.i(Author.HeZhiYuan, Integer.valueOf(bytesToInt));
                        if (bytesToInt > 0) {
                            int bytesToInt2 = ByteUtil.bytesToInt(Arrays.copyOfRange(EbookHandle.this.mReceivedData, 4, 5));
                            EbookHandle ebookHandle2 = EbookHandle.this;
                            ebookHandle2.parseEbookData(ebookHandle2.mReceivedData, 5, bytesToInt2, bytesToInt, 0);
                            return;
                        }
                        EbookHandle.this.mCallback.onFileNames(EbookHandle.this.fileNames);
                        return;
                    }
                    if ((bArr[0] & 255) == 188 && bArr[1] == -127) {
                        EbookHandle.this.mCallback.onDeleteSuccess(ByteUtil.bytesToInt(Arrays.copyOfRange(bArr, 6, 7)));
                        return;
                    }
                    return;
                }
                EbookHandle.this.mTotalCount = DataTransferUtils.bytesToShort(bArr, 2);
                EbookHandle.this.mReceivedCount = bArr.length - 6;
                EbookHandle ebookHandle3 = EbookHandle.this;
                ebookHandle3.mReceivedData = new byte[ebookHandle3.mTotalCount];
                System.arraycopy(bArr, 6, EbookHandle.this.mReceivedData, 0, EbookHandle.this.mReceivedCount);
                EbookHandle ebookHandle4 = EbookHandle.this;
                ebookHandle4.mReceiving = ebookHandle4.mReceivedCount < EbookHandle.this.mTotalCount;
                AwLog.i(Author.HeZhiYuan, "文件：-> 1mTotalCount: " + EbookHandle.this.mTotalCount + ", mReceivedCount: " + EbookHandle.this.mReceivedCount + ", mReceiving: " + EbookHandle.this.mReceiving);
                if (EbookHandle.this.mReceiving) {
                    return;
                }
                AwLog.i(Author.HeZhiYuan, "文件：->2->" + DataTransferUtils.getHexString(EbookHandle.this.mReceivedData));
                int bytesToInt3 = ByteUtil.bytesToInt(Arrays.copyOfRange(EbookHandle.this.mReceivedData, 1, 2));
                if (ByteUtil.bytesToInt(Arrays.copyOfRange(EbookHandle.this.mReceivedData, 2, 3)) == 0) {
                    EbookHandle.this.fileNames = new ArrayList();
                }
                AwLog.i(Author.HeZhiYuan, Integer.valueOf(bytesToInt3));
                if (bytesToInt3 > 0) {
                    int bytesToInt4 = ByteUtil.bytesToInt(Arrays.copyOfRange(EbookHandle.this.mReceivedData, 4, 5));
                    EbookHandle ebookHandle5 = EbookHandle.this;
                    ebookHandle5.parseEbookData(ebookHandle5.mReceivedData, 5, bytesToInt4, bytesToInt3, 0);
                    return;
                }
                EbookHandle.this.mCallback.onFileNames(EbookHandle.this.fileNames);
            }
        }
    };
    boolean mPocketIndexAFlag = false;
    private int mPackageLength = JPackageManager.getInstance().getLength();

    static /* synthetic */ int access$812(EbookHandle ebookHandle, int i) {
        int i2 = ebookHandle.mReceivedCount + i;
        ebookHandle.mReceivedCount = i2;
        return i2;
    }

    public int getCurrFileType() {
        return this.currFileType;
    }

    public void setCurrFileType(int i) {
        this.currFileType = i;
    }

    public static EbookHandle getInstance() {
        if (mInstance == null) {
            synchronized (EbookHandle.class) {
                if (mInstance == null) {
                    mInstance = new EbookHandle();
                }
            }
        }
        return mInstance;
    }

    private EbookHandle() {
        AwLog.i(Author.HeZhiYuan, "create FileHandle.. mPackageLength: " + this.mPackageLength);
    }

    public void initRegister() {
        BleOperateManager.getInstance().setCallback(this.callback);
    }

    public void setBleOperateManagerCallback() {
        BleOperateManager.getInstance().setCallback(this.callback);
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void parseEbookData(byte[] bArr, int i, int i2, int i3, int i4) {
        int i5 = i4 + 1;
        int i6 = i2 + i;
        try {
            this.fileNames.add(unicodeByteToStr(Arrays.copyOfRange(bArr, i, i6)));
            if (i5 < i3) {
                parseEbookData(bArr, i6 + 1, bArr[i6], i3, i5);
            } else {
                this.mCallback.onFileNames(this.fileNames);
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    public String unicodeByteToStr(byte[] bArr) {
        StringBuilder sb = new StringBuilder();
        int i = 0;
        while (i < bArr.length) {
            int i2 = i + 2;
            sb.append((char) ByteUtil.bytesToInt(Arrays.copyOfRange(bArr, i, i2)));
            i = i2;
        }
        return sb.toString();
    }

    public void registerCallback(IEbookCallback iEbookCallback) {
        try {
            this.mCallbackArray.remove(iEbookCallback);
            this.mCallbackArray.add(iEbookCallback);
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    public void removeCallback(ICallback iCallback) {
        try {
            this.mCallbackArray.remove(iCallback);
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    public void clearCallback() {
        try {
            this.mCallbackArray.clear();
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    public void start(int i) {
        BleThreadManager.getInstance().addData(new BleDataBean(addHeader(128, new byte[]{2, (byte) i}), this.mPackageLength));
    }

    public void deleteEbook(int i, String str) {
        try {
            byte[] bytes = str.getBytes(Charset.forName("unicode"));
            if (!ByteUtil.byteArrayToString(bytes).startsWith("fffe")) {
                int i2 = 0;
                while (i2 < bytes.length) {
                    int i3 = i2 + 2;
                    int bytesToInt = ByteUtil.bytesToInt(Arrays.copyOfRange(bytes, i2, i3));
                    bytes[i2] = (byte) ByteUtil.hiword(bytesToInt);
                    bytes[i2 + 1] = (byte) ByteUtil.loword(bytesToInt);
                    i2 = i3;
                }
            }
            BleThreadManager.getInstance().addData(new BleDataBean(addHeader(129, ByteUtil.concat(new byte[]{2, (byte) i, (byte) bytes.length}, bytes)), this.mPackageLength));
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    public boolean executeFilePrepare(String str) {
        BufferedReader bufferedReader;
        int i = this.currFileType;
        BufferedReader bufferedReader2 = null;
        r3 = null;
        RandomAccessFile randomAccessFile = null;
        bufferedReader2 = null;
        if (i == FileTypeEbook || i == FileTypeLYRICS) {
            File file = new File(str);
            if (!file.exists()) {
                AwLog.i(Author.HeZhiYuan, "准备发送的文件不存在！");
                return false;
            }
            String charset = charset(str);
            AwLog.i(Author.HeZhiYuan, charset);
            StringBuffer stringBuffer = new StringBuffer();
            try {
                try {
                    try {
                        bufferedReader = new BufferedReader(new InputStreamReader(new FileInputStream(str), charset));
                        while (true) {
                            try {
                                String readLine = bufferedReader.readLine();
                                if (readLine == null) {
                                    break;
                                }
                                stringBuffer.append(readLine);
                                stringBuffer.append("\n");
                            } catch (IOException e) {
                                e = e;
                                bufferedReader2 = bufferedReader;
                                e.printStackTrace();
                                if (bufferedReader2 != null) {
                                    bufferedReader2.close();
                                }
                                return false;
                            } catch (Throwable th) {
                                th = th;
                                bufferedReader2 = bufferedReader;
                                if (bufferedReader2 != null) {
                                    try {
                                        bufferedReader2.close();
                                    } catch (IOException e2) {
                                        e2.printStackTrace();
                                    }
                                }
                                throw th;
                            }
                        }
                        bufferedReader.close();
                        String stringBuffer2 = stringBuffer.toString();
                        this.mPocketIndexA = (short) 0;
                        this.mPocketIndexB = (short) 0;
                        this.mPocketIndex = (short) 0;
                        if (file.length() > 10485760) {
                            this.mFileSend = new byte[0];
                            AwLog.i(Author.HeZhiYuan, Integer.valueOf(stringBuffer2.length()));
                            int i2 = 2;
                            int length = stringBuffer2.length() / 2;
                            String substring = stringBuffer2.substring(0, length);
                            String substring2 = stringBuffer2.substring(length);
                            this.mFileSendA = substring.getBytes(Charset.forName("unicode"));
                            byte[] bytes = substring2.getBytes(Charset.forName("unicode"));
                            this.mFileSendB = bytes;
                            byte[] bArr = this.mFileSendA;
                            this.sizeA = bArr.length;
                            this.sizeB = bytes.length;
                            if (!ByteUtil.byteArraySubToString(bArr).startsWith("fffe")) {
                                int i3 = 0;
                                while (i3 < this.sizeA) {
                                    int i4 = i3 + 2;
                                    int bytesToInt = ByteUtil.bytesToInt(Arrays.copyOfRange(this.mFileSendA, i3, i4));
                                    this.mFileSendA[i3] = (byte) ByteUtil.hiword(bytesToInt);
                                    this.mFileSendA[i3 + 1] = (byte) ByteUtil.loword(bytesToInt);
                                    i3 = i4;
                                }
                            }
                            if (!ByteUtil.byteArraySubToString(this.mFileSendB).startsWith("fffe")) {
                                while (i2 < this.sizeB) {
                                    int i5 = i2 + 2;
                                    int bytesToInt2 = ByteUtil.bytesToInt(Arrays.copyOfRange(this.mFileSendB, i2, i5));
                                    this.mFileSendB[i2 - 2] = (byte) ByteUtil.hiword(bytesToInt2);
                                    this.mFileSendB[i2 - 1] = (byte) ByteUtil.loword(bytesToInt2);
                                    i2 = i5;
                                }
                            }
                            int i6 = 1024 - (this.sizeA % 1024);
                            byte[] bArr2 = new byte[i6];
                            System.arraycopy(this.mFileSendB, 0, bArr2, 0, i6);
                            byte[] bArr3 = this.mFileSendB;
                            byte[] bArr4 = new byte[bArr3.length - i6];
                            System.arraycopy(bArr3, 0, bArr4, 0, bArr3.length - i6);
                            byte[] concat = ByteUtil.concat(this.mFileSendA, bArr2);
                            this.mFileSendA = concat;
                            this.sizeA = concat.length;
                            this.mFileSendB = bArr4;
                            this.sizeB = bArr4.length;
                            AwLog.i(Author.HeZhiYuan, this.sizeA + "----" + this.sizeB);
                            this.totalSize = this.sizeA + this.sizeB;
                        } else {
                            byte[] bytes2 = stringBuffer2.getBytes(Charset.forName("unicode"));
                            this.mFileSend = bytes2;
                            this.totalSize = bytes2.length;
                            if (!ByteUtil.byteArraySubToString(bytes2).startsWith("fffe")) {
                                int i7 = 0;
                                while (i7 < this.totalSize) {
                                    int i8 = i7 + 2;
                                    int bytesToInt3 = ByteUtil.bytesToInt(Arrays.copyOfRange(this.mFileSend, i7, i8));
                                    this.mFileSend[i7] = (byte) ByteUtil.hiword(bytesToInt3);
                                    this.mFileSend[i7 + 1] = (byte) ByteUtil.loword(bytesToInt3);
                                    i7 = i8;
                                }
                            }
                        }
                    } catch (Throwable th2) {
                        th = th2;
                    }
                } catch (IOException e3) {
                    e = e3;
                }
            } catch (IOException e4) {
                e4.printStackTrace();
            }
            if (this.totalSize <= 0) {
                bufferedReader.close();
                return false;
            }
            try {
                bufferedReader.close();
            } catch (IOException e5) {
                e5.printStackTrace();
            }
            return true;
        }
        if (i != FileTypeAlbum) {
            return false;
        }
        if (!new File(str).exists()) {
            AwLog.i(Author.HeZhiYuan, "准备发送的文件不存在！");
            return false;
        }
        try {
            try {
                RandomAccessFile randomAccessFile2 = new RandomAccessFile(str, "r");
                try {
                    byte[] bArr5 = new byte[(int) randomAccessFile2.length()];
                    this.mFileSend = bArr5;
                    this.totalSize = bArr5.length;
                    this.mPocketIndex = (short) 0;
                    AwLog.e(Author.HeZhiYuan, "准备发送的文件.. dataSize = " + this.mFileSend.length + ", readSize = " + randomAccessFile2.read(bArr5, 0, bArr5.length));
                    try {
                        randomAccessFile2.close();
                    } catch (IOException e6) {
                        e6.printStackTrace();
                    }
                    return true;
                } catch (Exception e7) {
                    e = e7;
                    randomAccessFile = randomAccessFile2;
                    e.printStackTrace();
                    if (randomAccessFile != null) {
                        try {
                            randomAccessFile.close();
                        } catch (IOException e8) {
                            e8.printStackTrace();
                        }
                    }
                    return false;
                } catch (Throwable th3) {
                    th = th3;
                    randomAccessFile = randomAccessFile2;
                    if (randomAccessFile != null) {
                        try {
                            randomAccessFile.close();
                        } catch (IOException e9) {
                            e9.printStackTrace();
                        }
                    }
                    throw th;
                }
            } catch (Throwable th4) {
                th = th4;
            }
        } catch (Exception e10) {
            e = e10;
        }
    }

    public boolean executeFilePrepareAlbum(byte[] bArr) {
        try {
            this.mFileSend = bArr;
            this.totalSize = bArr.length;
            this.mPocketIndex = (short) 0;
            AwLog.e(Author.HeZhiYuan, "准备发送的文件.. dataSize = " + this.mFileSend.length + ", readSize = " + this.totalSize);
            return true;
        } catch (Exception e) {
            e.printStackTrace();
            return false;
        }
    }

    /* JADX WARN: Removed duplicated region for block: B:17:0x0053 A[Catch: Exception -> 0x0095, LOOP:0: B:17:0x0053->B:45:0x0053, LOOP_START, TryCatch #0 {Exception -> 0x0095, blocks: (B:3:0x0005, B:5:0x001a, B:8:0x001e, B:11:0x0026, B:15:0x004e, B:17:0x0053, B:48:0x006f, B:37:0x0080, B:40:0x0088, B:59:0x0091, B:61:0x002e, B:63:0x0032, B:66:0x0039, B:68:0x003f, B:70:0x0045), top: B:2:0x0005 }] */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
        To view partially-correct code enable 'Show inconsistent code' option in preferences
    */
    public static java.lang.String charset(java.lang.String r8) {
        /*
            java.lang.String r0 = "GBK"
            r1 = 3
            byte[] r2 = new byte[r1]
            java.io.BufferedInputStream r3 = new java.io.BufferedInputStream     // Catch: java.lang.Exception -> L95
            java.io.FileInputStream r4 = new java.io.FileInputStream     // Catch: java.lang.Exception -> L95
            r4.<init>(r8)     // Catch: java.lang.Exception -> L95
            r3.<init>(r4)     // Catch: java.lang.Exception -> L95
            r8 = 0
            r3.mark(r8)     // Catch: java.lang.Exception -> L95
            int r1 = r3.read(r2, r8, r1)     // Catch: java.lang.Exception -> L95
            r4 = -1
            if (r1 != r4) goto L1e
            r3.close()     // Catch: java.lang.Exception -> L95
            return r0
        L1e:
            r1 = r2[r8]     // Catch: java.lang.Exception -> L95
            java.lang.String r5 = "UTF-8"
            r6 = -2
            r7 = 1
            if (r1 != r4) goto L2e
            r1 = r2[r7]     // Catch: java.lang.Exception -> L95
            if (r1 != r6) goto L2e
            java.lang.String r0 = "UTF-16LE"
        L2c:
            r8 = 1
            goto L4e
        L2e:
            r1 = r2[r8]     // Catch: java.lang.Exception -> L95
            if (r1 != r6) goto L39
            r1 = r2[r7]     // Catch: java.lang.Exception -> L95
            if (r1 != r4) goto L39
            java.lang.String r0 = "UTF-16BE"
            goto L2c
        L39:
            r1 = r2[r8]     // Catch: java.lang.Exception -> L95
            r6 = -17
            if (r1 != r6) goto L4e
            r1 = r2[r7]     // Catch: java.lang.Exception -> L95
            r6 = -69
            if (r1 != r6) goto L4e
            r1 = 2
            r1 = r2[r1]     // Catch: java.lang.Exception -> L95
            r2 = -65
            if (r1 != r2) goto L4e
            r0 = r5
            goto L2c
        L4e:
            r3.reset()     // Catch: java.lang.Exception -> L95
            if (r8 != 0) goto L91
        L53:
            int r8 = r3.read()     // Catch: java.lang.Exception -> L95
            if (r8 == r4) goto L91
            r1 = 240(0xf0, float:3.36E-43)
            if (r8 < r1) goto L5e
            goto L91
        L5e:
            r1 = 191(0xbf, float:2.68E-43)
            r2 = 128(0x80, float:1.794E-43)
            if (r2 > r8) goto L67
            if (r8 > r1) goto L67
            goto L91
        L67:
            r6 = 192(0xc0, float:2.69E-43)
            if (r6 > r8) goto L78
            r6 = 223(0xdf, float:3.12E-43)
            if (r8 > r6) goto L78
            int r8 = r3.read()     // Catch: java.lang.Exception -> L95
            if (r2 > r8) goto L91
            if (r8 > r1) goto L91
            goto L53
        L78:
            r6 = 224(0xe0, float:3.14E-43)
            if (r6 > r8) goto L53
            r6 = 239(0xef, float:3.35E-43)
            if (r8 > r6) goto L53
            int r8 = r3.read()     // Catch: java.lang.Exception -> L95
            if (r2 > r8) goto L91
            if (r8 > r1) goto L91
            int r8 = r3.read()     // Catch: java.lang.Exception -> L95
            if (r2 > r8) goto L91
            if (r8 > r1) goto L91
            r0 = r5
        L91:
            r3.close()     // Catch: java.lang.Exception -> L95
            goto L99
        L95:
            r8 = move-exception
            r8.printStackTrace()
        L99:
            return r0
        */
        throw new UnsupportedOperationException("Method not decompiled: com.oudmon.ble.base.communication.file.EbookHandle.charset(java.lang.String):java.lang.String");
    }

    public void cmdFileInit(String str) {
        try {
            setBleOperateManagerCallback();
            byte[] bytes = str.getBytes(Charset.forName("unicode"));
            if (!ByteUtil.byteArrayToString(bytes).startsWith("fffe")) {
                int i = 0;
                while (i < bytes.length) {
                    int i2 = i + 2;
                    int bytesToInt = ByteUtil.bytesToInt(Arrays.copyOfRange(bytes, i, i2));
                    bytes[i] = (byte) ByteUtil.hiword(bytesToInt);
                    bytes[i + 1] = (byte) ByteUtil.loword(bytesToInt);
                    i = i2;
                }
            }
            AwLog.i(Author.HeZhiYuan, ByteUtil.byteArrayToString(bytes));
            byte[] bArr = new byte[bytes.length + 10];
            bArr[0] = (byte) this.currFileType;
            System.arraycopy(DataTransferUtils.intToBytes(this.totalSize), 0, bArr, 1, 4);
            bArr[9] = (byte) bytes.length;
            System.arraycopy(bytes, 0, bArr, 10, bytes.length);
            sendPocketToBle(addHeader(49, bArr));
            AwLog.i(Author.HeZhiYuan, "cmdFileInit.. 完成");
        } catch (Exception e) {
            AwLog.i(Author.HeZhiYuan, "cmdFileInit.. Exception: " + e.getMessage());
            e.printStackTrace();
        }
    }

    public void cmdSendPacket() {
        setBleOperateManagerCallback();
        if (this.mFileSend == null) {
            return;
        }
        AwLog.i(Author.HeZhiYuan, "cmdSendPacket.. 开始发送数据，数据长度: " + this.totalSize);
        readNextBigPocket();
    }

    /* JADX INFO: Access modifiers changed from: private */
    public boolean readNextBigPocket() {
        try {
            setBleOperateManagerCallback();
            short s = this.mPocketIndex;
            int i = s * 1024;
            int i2 = this.totalSize;
            if (i < i2) {
                if (this.mFileSend.length > 0) {
                    int min = Math.min(1024, i2 - (s * 1024));
                    byte[] bArr = new byte[min];
                    System.arraycopy(this.mFileSend, this.mPocketIndex * 1024, bArr, 0, min);
                    byte[] compress = CompressUtils.compress(bArr);
                    byte[] bArr2 = new byte[compress.length + 2];
                    System.arraycopy(DataTransferUtils.shortToBytes((short) (this.mPocketIndex + 1)), 0, bArr2, 0, 2);
                    System.arraycopy(compress, 0, bArr2, 2, compress.length);
                    sendPocketToBle(addHeader(50, bArr2));
                    this.mPocketIndex = (short) (this.mPocketIndex + 1);
                    return true;
                }
                short s2 = this.mPocketIndexA;
                int i3 = s2 * 1024;
                int i4 = this.sizeA;
                if (i3 < i4) {
                    int min2 = Math.min(1024, i4 - (s2 * 1024));
                    byte[] bArr3 = new byte[min2];
                    System.arraycopy(this.mFileSendA, this.mPocketIndexA * 1024, bArr3, 0, min2);
                    byte[] compress2 = CompressUtils.compress(bArr3);
                    byte[] bArr4 = new byte[compress2.length + 2];
                    System.arraycopy(DataTransferUtils.shortToBytes((short) (this.mPocketIndexA + 1)), 0, bArr4, 0, 2);
                    System.arraycopy(compress2, 0, bArr4, 2, compress2.length);
                    sendPocketToBle(addHeader(50, bArr4));
                    short s3 = (short) (this.mPocketIndexA + 1);
                    this.mPocketIndexA = s3;
                    this.mPocketIndex = (short) (s3 + this.mPocketIndexB);
                    return true;
                }
                int min3 = Math.min(1024, this.sizeB - (this.mPocketIndexB * 1024));
                byte[] bArr5 = new byte[min3];
                System.arraycopy(this.mFileSendB, this.mPocketIndexB * 1024, bArr5, 0, min3);
                byte[] compress3 = CompressUtils.compress(bArr5);
                byte[] bArr6 = new byte[compress3.length + 2];
                System.arraycopy(DataTransferUtils.shortToBytes((short) (this.mPocketIndexA + this.mPocketIndexB + 1)), 0, bArr6, 0, 2);
                System.arraycopy(compress3, 0, bArr6, 2, compress3.length);
                sendPocketToBle(addHeader(50, bArr6));
                short s4 = (short) (this.mPocketIndexB + 1);
                this.mPocketIndexB = s4;
                this.mPocketIndex = (short) (this.mPocketIndexA + s4);
                return true;
            }
            AwLog.i(Author.HeZhiYuan, "文件发送完毕");
            return false;
        } catch (Exception e) {
            e.printStackTrace();
            AwLog.i(Author.HeZhiYuan, "文件发送异常: " + e.getMessage());
            return false;
        }
    }

    private void sendPocketToBle(byte[] bArr) {
        setBleOperateManagerCallback();
        resetPackageLength();
        BleThreadManager.getInstance().addData(new BleDataBean(bArr, this.mPackageLength));
    }

    private void resetPackageLength() {
        this.mPackageLength = JPackageManager.getInstance().getLength();
        AwLog.i(Author.HeZhiYuan, "resetPackageLength.. mPackageLength: " + this.mPackageLength);
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void cmdCheck() {
        BleThreadManager.getInstance().addData(new BleDataBean(addHeader(51, null), this.mPackageLength));
    }

    public void endAndRelease() {
        this.enableNotifyRequest.setEnable(false);
        BleOperateManager.getInstance().execute(this.enableNotifyRequest);
        BleOperateManager.getInstance().setCallback(null);
    }

    private byte[] addHeader(int i, byte[] bArr) {
        byte[] bArr2 = new byte[(bArr == null ? 0 : bArr.length) + 6];
        bArr2[0] = -68;
        bArr2[1] = (byte) i;
        if (bArr != null && bArr.length > 0) {
            System.arraycopy(DataTransferUtils.shortToBytes((short) bArr.length), 0, bArr2, 2, 2);
            System.arraycopy(DataTransferUtils.shortToBytes((short) CRC16.calcCrc16(bArr)), 0, bArr2, 4, 2);
            System.arraycopy(bArr, 0, bArr2, 6, bArr.length);
        } else {
            bArr2[4] = -1;
            bArr2[5] = -1;
        }
        return bArr2;
    }

    public List<List<byte[]>> subListBySegment(List<byte[]> list, int i) {
        List<byte[]> subList;
        ArrayList arrayList = new ArrayList();
        int size = list.size();
        if (size > 0 && i > 0) {
            int i2 = size / i;
            for (int i3 = 0; i3 < i; i3++) {
                if (i3 == i - 1) {
                    subList = list.subList(i2 * i3, size);
                } else {
                    subList = list.subList(i2 * i3, (i3 + 1) * i2);
                }
                arrayList.add(subList);
            }
        } else {
            arrayList.add(list);
        }
        return arrayList;
    }

    public void initPath(Application application) {
        this.logPath = application.getExternalFilesDir("") + "/log/" + new DateUtil().getY_M_D() + "1_log.txt";
        this.logPath1 = application.getExternalFilesDir("") + "/log/" + new DateUtil().getY_M_D() + "2_log.txt";
    }
}
