package com.qcwireless.qcwatch.ui.base.view;

import android.content.Context;
import android.graphics.Canvas;
import android.graphics.Paint;
import android.graphics.Rect;
import android.graphics.RectF;
import android.util.AttributeSet;
import android.view.View;
import com.qcwireless.ring.R;
import skin.support.content.res.SkinCompatResources;

/* loaded from: classes2.dex */
public class PGBloodSugarView extends View {
    private int bloodSugar;
    private Context context;
    private int height;
    private Paint paint;
    private Paint textDownPaint;
    private Paint valuePaint;
    private int width;

    public PGBloodSugarView(Context context) {
        super(context);
        this.context = context;
        initView();
    }

    public PGBloodSugarView(Context context, AttributeSet attrs) {
        super(context, attrs);
        this.context = context;
        initView();
    }

    public PGBloodSugarView(Context context, AttributeSet attrs, int defStyleAttr) {
        super(context, attrs, defStyleAttr);
        this.context = context;
        initView();
    }

    public PGBloodSugarView(Context context, AttributeSet attrs, int defStyleAttr, int defStyleRes) {
        super(context, attrs, defStyleAttr, defStyleRes);
        this.context = context;
        initView();
    }

    private void initView() {
        Paint paint = new Paint();
        this.paint = paint;
        paint.setAntiAlias(true);
        this.paint.setStyle(Paint.Style.STROKE);
        this.paint.setStrokeJoin(Paint.Join.ROUND);
        this.paint.setStrokeWidth(dp2px(this.context, 1.5f));
        this.paint.setColor(SkinCompatResources.getColor(this.context, R.color.q_view_blood_sugar_2));
        Paint paint2 = new Paint();
        this.valuePaint = paint2;
        paint2.setAntiAlias(true);
        this.valuePaint.setStyle(Paint.Style.FILL);
        this.valuePaint.setStrokeJoin(Paint.Join.ROUND);
        this.valuePaint.setStrokeWidth(dp2px(this.context, 1.5f));
        this.valuePaint.setColor(SkinCompatResources.getColor(this.context, R.color.q_view_blood_sugar_2));
        Paint paint3 = new Paint();
        this.textDownPaint = paint3;
        paint3.setAntiAlias(true);
        this.textDownPaint.setStyle(Paint.Style.FILL);
        this.textDownPaint.setColor(SkinCompatResources.getColor(this.context, R.color.q_view_blood_sugar_2));
        this.textDownPaint.setStrokeWidth(2.0f);
        this.textDownPaint.setTextSize(dp2px(this.context, 8.0f));
    }

    public void setBloodSugar(int value) {
        this.bloodSugar = value;
        postInvalidate();
    }

    @Override // android.view.View
    protected void onDraw(Canvas canvas) {
        super.onDraw(canvas);
        canvas.drawRoundRect(2.5f, 2.5f, this.width - 2.5f, dp2px(this.context, 25.0f) - 2.5f, 10.0f, 10.0f, this.paint);
        int i = this.width / 4;
        canvas.drawText("0", getTextWidth(this.textDownPaint, "0"), dp2px(this.context, 36.0f), this.textDownPaint);
        canvas.drawText("5", i - (getTextWidth(this.textDownPaint, "00") / 2.0f), dp2px(this.context, 36.0f), this.textDownPaint);
        canvas.drawText("10", (i * 2) - (getTextWidth(this.textDownPaint, "00") / 2.0f), dp2px(this.context, 36.0f), this.textDownPaint);
        canvas.drawText("15", (i * 3) - (getTextWidth(this.textDownPaint, "00") / 2.0f), dp2px(this.context, 36.0f), this.textDownPaint);
        canvas.drawText("20", (i * 4) - getTextWidth(this.textDownPaint, "000"), dp2px(this.context, 36.0f), this.textDownPaint);
        if (this.bloodSugar > 0) {
            canvas.drawRoundRect(new RectF(dp2px(this.context, 2.0f), dp2px(this.context, 3.0f), (int) (((((r0 * 1.0f) / 10.0f) * this.width) * 1.0f) / 20.0f), dp2px(this.context, 22.0f)), 10.0f, 10.0f, this.valuePaint);
        }
    }

    @Override // android.view.View
    protected void onMeasure(int widthMeasureSpec, int heightMeasureSpec) {
        super.onMeasure(widthMeasureSpec, heightMeasureSpec);
        this.width = getMySize(200, widthMeasureSpec);
        if (getLayoutParams().height == -2) {
            this.height = (int) dp2px(this.context, 20.0f);
        } else {
            this.height = getMySize(200, heightMeasureSpec);
        }
        setMeasuredDimension(this.width, this.height);
        postInvalidate();
    }

    public float getTextWidth(Paint paint, String str) {
        float f = 0.0f;
        if (str != null && str.length() > 0) {
            int length = str.length();
            paint.getTextWidths(str, new float[length]);
            for (int i = 0; i < length; i++) {
                f += (float) Math.ceil(r2[i]);
            }
        }
        return f;
    }

    public float getTextHeight(Paint paint, String str) {
        paint.getTextBounds(str, 0, str.length(), new Rect());
        return r0.height();
    }

    public float dp2px(Context context, float dp) {
        return (dp * context.getResources().getDisplayMetrics().density) + 0.5f;
    }

    public int getMySize(int defaultSize, int measureSpec) {
        int mode = View.MeasureSpec.getMode(measureSpec);
        return (mode == Integer.MIN_VALUE || mode == 1073741824) ? View.MeasureSpec.getSize(measureSpec) : defaultSize;
    }
}
