package com.qcwireless.qcwatch.ui.base.view;

import android.content.Context;
import android.graphics.Canvas;
import android.graphics.Paint;
import android.util.AttributeSet;
import android.view.View;
import androidx.core.content.ContextCompat;
import com.oudmon.ble.base.util.DateUtil;
import com.qcwireless.qcwatch.ui.base.view.QSleepBarChart;
import com.qcwireless.ring.R;
import java.util.ArrayList;
import java.util.List;
import skin.support.content.res.SkinCompatResources;

/* loaded from: classes2.dex */
public class QSleepHomeBarChart extends View {
    public static final int Type_Sleep_Awake = 3;
    public static final int Type_Sleep_Deep = 1;
    public static final int Type_Sleep_Light = 2;
    protected int bottomOffset;
    private Context context;
    private List<QSleepBarChart.SleepDataBean> data;
    private float height;
    private List<XTextChange> labelsList;
    private int leftRightOffset;
    private Paint paintBottom;
    private long sleepEnd;
    private Paint sleepPaint;
    private long sleepStart;
    private Paint textDownPaint;
    private float width;

    public QSleepHomeBarChart(Context context) {
        super(context);
        this.data = new ArrayList();
        this.leftRightOffset = 10;
        this.bottomOffset = 50;
        this.labelsList = new ArrayList();
        this.context = context;
        init(context, null);
    }

    public QSleepHomeBarChart(Context context, AttributeSet attrs) {
        super(context, attrs);
        this.data = new ArrayList();
        this.leftRightOffset = 10;
        this.bottomOffset = 50;
        this.labelsList = new ArrayList();
        this.context = context;
        init(context, attrs);
    }

    public QSleepHomeBarChart(Context context, AttributeSet attrs, int defStyleAttr) {
        super(context, attrs, defStyleAttr);
        this.data = new ArrayList();
        this.leftRightOffset = 10;
        this.bottomOffset = 50;
        this.labelsList = new ArrayList();
        this.context = context;
        init(context, attrs);
    }

    public QSleepHomeBarChart(Context context, AttributeSet attrs, int defStyleAttr, int defStyleRes) {
        super(context, attrs, defStyleAttr, defStyleRes);
        this.data = new ArrayList();
        this.leftRightOffset = 10;
        this.bottomOffset = 50;
        this.labelsList = new ArrayList();
        this.context = context;
        init(context, attrs);
    }

    public List<QSleepBarChart.SleepDataBean> getData() {
        return this.data;
    }

    public void setData(long sleepStart, long sleepEnd, List<QSleepBarChart.SleepDataBean> data) {
        if (data == null) {
            data = new ArrayList<>();
        }
        this.data = data;
        this.sleepStart = sleepStart;
        this.sleepEnd = sleepEnd;
        if (data.size() == 0) {
            initXLabels("00:00", "24:00");
        } else {
            initXLabels(new DateUtil(sleepStart, true).getHHmmDate(), new DateUtil(sleepEnd, true).getHHmmDate());
        }
        postInvalidate();
    }

    private void init(Context context, AttributeSet attrs) {
        Paint paint = new Paint();
        this.sleepPaint = paint;
        paint.setAntiAlias(true);
        this.sleepPaint.setStyle(Paint.Style.FILL);
        this.sleepPaint.setStrokeWidth(1.5f);
        Paint paint2 = new Paint();
        this.paintBottom = paint2;
        paint2.setStyle(Paint.Style.FILL);
        this.paintBottom.setStrokeJoin(Paint.Join.ROUND);
        this.paintBottom.setAntiAlias(true);
        this.paintBottom.setStrokeWidth(dp2px(context, 1.0f));
        this.paintBottom.setColor(SkinCompatResources.getColor(context, R.color.q_view_sleep_1));
        Paint paint3 = new Paint();
        this.textDownPaint = paint3;
        paint3.setAntiAlias(true);
        this.textDownPaint.setStyle(Paint.Style.FILL);
        this.textDownPaint.setStrokeWidth(2.0f);
        this.textDownPaint.setTextSize(dp2px(context, 8.0f));
        this.textDownPaint.setColor(SkinCompatResources.getColor(context, R.color.q_view_sleep_1));
    }

    public float dp2px(Context context, float dp) {
        return (dp * context.getResources().getDisplayMetrics().density) + 0.5f;
    }

    private void initXLabels(String start, String end) {
        this.labelsList.clear();
        XTextChange xTextChange = new XTextChange();
        xTextChange.setLabel(start);
        xTextChange.setX(this.leftRightOffset);
        xTextChange.setY(dp2px(this.context, 82.0f));
        this.labelsList.add(xTextChange);
        XTextChange xTextChange2 = new XTextChange();
        xTextChange2.setLabel(end);
        xTextChange2.setX((this.width - getTextWidth(this.textDownPaint, "00:00")) - this.leftRightOffset);
        xTextChange2.setY(dp2px(this.context, 82.0f));
        this.labelsList.add(xTextChange2);
    }

    public float getTextWidth(Paint paint, String str) {
        float f = 0.0f;
        if (str != null && str.length() > 0) {
            int length = str.length();
            paint.getTextWidths(str, new float[length]);
            for (int i = 0; i < length; i++) {
                f += (float) Math.ceil(r2[i]);
            }
        }
        return f;
    }

    @Override // android.view.View
    protected void onMeasure(int widthMeasureSpec, int heightMeasureSpec) {
        super.onMeasure(widthMeasureSpec, heightMeasureSpec);
        this.width = getMySize(200, widthMeasureSpec);
        if (getLayoutParams().height == -2) {
            this.height = 100.0f;
        } else {
            this.height = getMySize(100, heightMeasureSpec);
        }
        List<QSleepBarChart.SleepDataBean> list = this.data;
        if (list == null || list.size() == 0) {
            initXLabels("00:00", "24:00");
        } else {
            initXLabels(new DateUtil(this.sleepStart, true).getHHmmDate(), new DateUtil(this.sleepEnd, true).getHHmmDate());
        }
        postInvalidate();
    }

    public int getMySize(int defaultSize, int measureSpec) {
        int mode = View.MeasureSpec.getMode(measureSpec);
        return (mode == Integer.MIN_VALUE || mode == 1073741824) ? View.MeasureSpec.getSize(measureSpec) : defaultSize;
    }

    @Override // android.view.View
    protected void onLayout(boolean changed, int left, int top2, int right, int bottom) {
        super.onLayout(changed, left, top2, right, bottom);
    }

    @Override // android.view.View
    protected void onDraw(Canvas canvas) {
        super.onDraw(canvas);
        for (XTextChange xTextChange : this.labelsList) {
            canvas.drawText(xTextChange.label, xTextChange.x, xTextChange.y, this.textDownPaint);
        }
        int i = (int) ((this.height - this.bottomOffset) / 5.0f);
        for (QSleepBarChart.SleepDataBean sleepDataBean : this.data) {
            if (sleepDataBean.getType() == 1) {
                this.sleepPaint.setColor(ContextCompat.getColor(this.context, R.color.q_view_sleep_1));
                float f = this.leftRightOffset;
                long sleepStart = sleepDataBean.getSleepStart();
                long j = this.sleepStart;
                float f2 = (float) (sleepStart - j);
                float f3 = this.width;
                int i2 = this.leftRightOffset;
                long sleepEnd = sleepDataBean.getSleepEnd();
                long j2 = this.sleepStart;
                canvas.drawRect(f + ((f2 * (f3 - (i2 * 2))) / ((float) (this.sleepEnd - j))), i, i2 + ((((float) (sleepEnd - j2)) * (this.width - (this.leftRightOffset * 2))) / ((float) (this.sleepEnd - j2))), i * 5, this.sleepPaint);
            } else if (sleepDataBean.getType() == 2) {
                this.sleepPaint.setColor(ContextCompat.getColor(this.context, R.color.q_view_sleep_2));
                float f4 = this.leftRightOffset;
                long sleepStart2 = sleepDataBean.getSleepStart();
                long j3 = this.sleepStart;
                float f5 = (float) (sleepStart2 - j3);
                float f6 = this.width;
                int i3 = this.leftRightOffset;
                long sleepEnd2 = sleepDataBean.getSleepEnd();
                long j4 = this.sleepStart;
                canvas.drawRect(f4 + ((f5 * (f6 - (i3 * 2))) / ((float) (this.sleepEnd - j3))), i * 2, i3 + ((((float) (sleepEnd2 - j4)) * (this.width - (this.leftRightOffset * 2))) / ((float) (this.sleepEnd - j4))), i * 5, this.sleepPaint);
            } else if (sleepDataBean.getType() == 3) {
                this.sleepPaint.setColor(ContextCompat.getColor(this.context, R.color.q_view_sleep_3));
                float f7 = this.leftRightOffset;
                long sleepStart3 = sleepDataBean.getSleepStart();
                long j5 = this.sleepStart;
                float f8 = (float) (sleepStart3 - j5);
                float f9 = this.width;
                int i4 = this.leftRightOffset;
                long sleepEnd3 = sleepDataBean.getSleepEnd();
                long j6 = this.sleepStart;
                canvas.drawRect(f7 + ((f8 * (f9 - (i4 * 2))) / ((float) (this.sleepEnd - j5))), i * 3, i4 + ((((float) (sleepEnd3 - j6)) * (this.width - (this.leftRightOffset * 2))) / ((float) (this.sleepEnd - j6))), i * 5, this.sleepPaint);
            }
        }
        int i5 = this.leftRightOffset;
        float f10 = this.height;
        int i6 = this.bottomOffset;
        canvas.drawLine(i5, f10 - i6, this.width - i5, f10 - i6, this.paintBottom);
    }

    public long getNumberRecent(long[] intarray, long number) {
        long abs = Math.abs(number - intarray[0]);
        long j = intarray[0];
        for (long j2 : intarray) {
            long abs2 = Math.abs(number - j2);
            if (abs2 <= abs) {
                j = j2;
                abs = abs2;
            }
        }
        return j;
    }

    /* loaded from: classes2.dex */
    public class XTextChange {
        public String label;
        public int max;
        public int min;
        public float x;
        public float y;

        public XTextChange() {
        }

        public int getMin() {
            return this.min;
        }

        public void setMin(int min) {
            this.min = min;
        }

        public int getMax() {
            return this.max;
        }

        public void setMax(int max) {
            this.max = max;
        }

        public String getLabel() {
            return this.label;
        }

        public void setLabel(String label) {
            this.label = label;
        }

        public float getX() {
            return this.x;
        }

        public void setX(float x) {
            this.x = x;
        }

        public float getY() {
            return this.y;
        }

        public void setY(float y) {
            this.y = y;
        }
    }
}
