package com.qcwireless.qcwatch.ui.base.view;

import android.animation.ValueAnimator;
import android.content.Context;
import android.content.res.TypedArray;
import android.graphics.Canvas;
import android.graphics.DashPathEffect;
import android.graphics.LinearGradient;
import android.graphics.Paint;
import android.graphics.Shader;
import android.util.AttributeSet;
import android.view.MotionEvent;
import androidx.collection.ArrayMap;
import androidx.core.content.ContextCompat;
import androidx.core.view.ViewCompat;
import com.blankj.utilcode.constant.CacheConstants;
import com.qcwireless.qc_utils.date.DateUtil;
import com.qcwireless.qcwatch.R;
import com.qcwireless.qcwatch.ui.base.view.BaseChartView;
import com.qcwireless.qcwatch.ui.base.view.animator.ChartAnimator;
import java.math.RoundingMode;
import java.text.DecimalFormat;
import java.text.DecimalFormatSymbols;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import java.util.Locale;
import java.util.Map;

/* loaded from: classes2.dex */
public class QStepBarChart extends BaseChartView {
    static final /* synthetic */ boolean $assertionsDisabled = false;
    private StepDataBean currBean;
    private List<StepDataBean> data;
    DecimalFormat df;
    private Map<String, StepDataBean> hashData;
    private List<BaseChartView.XTextChange> labelsList;
    private int leftRightOffset;
    protected OnSelectedListener listener;
    private ChartAnimator mAnimator;
    private int maxStep;
    private int[] timeArray;

    /* loaded from: classes2.dex */
    public interface OnSelectedListener {
        void onSelected(StepDataBean bean);
    }

    public QStepBarChart(Context context) {
        super(context);
        this.data = new ArrayList();
        this.hashData = new ArrayMap();
        this.labelsList = new ArrayList();
        this.maxStep = 1000;
        this.timeArray = new int[24];
        this.leftRightOffset = 100;
        init(context, null);
    }

    public QStepBarChart(Context context, AttributeSet attrs) {
        super(context, attrs);
        this.data = new ArrayList();
        this.hashData = new ArrayMap();
        this.labelsList = new ArrayList();
        this.maxStep = 1000;
        this.timeArray = new int[24];
        this.leftRightOffset = 100;
        init(context, attrs);
    }

    public QStepBarChart(Context context, AttributeSet attrs, int defStyleAttr) {
        super(context, attrs, defStyleAttr);
        this.data = new ArrayList();
        this.hashData = new ArrayMap();
        this.labelsList = new ArrayList();
        this.maxStep = 1000;
        this.timeArray = new int[24];
        this.leftRightOffset = 100;
        init(context, attrs);
    }

    public QStepBarChart(Context context, AttributeSet attrs, int defStyleAttr, int defStyleRes) {
        super(context, attrs, defStyleAttr, defStyleRes);
        this.data = new ArrayList();
        this.hashData = new ArrayMap();
        this.labelsList = new ArrayList();
        this.maxStep = 1000;
        this.timeArray = new int[24];
        this.leftRightOffset = 100;
        init(context, attrs);
    }

    public OnSelectedListener getListener() {
        return this.listener;
    }

    public void setListener(OnSelectedListener listener) {
        this.listener = listener;
    }

    public List<StepDataBean> getData() {
        return this.data;
    }

    public void setData(List<StepDataBean> data) {
        this.data = data;
        this.maxStep = 1000;
        for (int i = 0; i < data.size(); i++) {
            int steps = data.get(i).getSteps();
            if (steps > this.maxStep) {
                this.maxStep = ((steps / 100) + 2) * 100;
            }
            this.hashData.put(data.get(i).getTimeStamp() + "", data.get(i));
        }
        this.fingerXDefault = new DateUtil().getHour() * CacheConstants.HOUR;
        int intValue = getNumberThree(this.timeArray, Integer.valueOf((int) this.fingerXDefault)).intValue();
        int i2 = this.width;
        int i3 = this.leftRightOffset;
        this.fingerX = (((i2 - (i3 * 2)) * intValue) / CacheConstants.DAY) + i3;
        if (this.hashData.get(intValue + "") != null) {
            StepDataBean stepDataBean = this.hashData.get(intValue + "");
            this.currBean = stepDataBean;
            this.valueSelected = stepDataBean.getSteps();
        } else {
            this.currBean = new StepDataBean(43200L, 0, 0, 0);
            this.valueSelected = 0;
        }
        OnSelectedListener onSelectedListener = this.listener;
        if (onSelectedListener != null) {
            onSelectedListener.onSelected(this.currBean);
        }
        postInvalidate();
        this.mAnimator.animateY(1000);
    }

    private void init(Context context, AttributeSet attrs) {
        DecimalFormat decimalFormat = new DecimalFormat("0.0", new DecimalFormatSymbols(Locale.US));
        this.df = decimalFormat;
        decimalFormat.setRoundingMode(RoundingMode.HALF_UP);
        for (int i = 0; i < 24; i++) {
            this.timeArray[i] = i * CacheConstants.HOUR;
        }
        initAttr(context, attrs);
        this.mAnimator = new ChartAnimator(new ValueAnimator.AnimatorUpdateListener() { // from class: com.qcwireless.qcwatch.ui.base.view.QStepBarChart.1
            @Override // android.animation.ValueAnimator.AnimatorUpdateListener
            public void onAnimationUpdate(ValueAnimator animation) {
                QStepBarChart.this.postInvalidate();
            }
        });
        this.avgLinePaint.setStrokeWidth(dp2px(context, 0.05f));
        this.avgLinePaint.setPathEffect(new DashPathEffect(new float[]{5.0f, 5.0f}, 0.0f));
        this.avgLinePaint.setStyle(Paint.Style.STROKE);
    }

    private void initXLabels() {
        this.labelsList.clear();
        int i = (this.width - (this.leftRightOffset * 2)) / 8;
        BaseChartView.XTextChange xTextChange = new BaseChartView.XTextChange();
        xTextChange.setLabel("00:00");
        xTextChange.setX(this.leftRightOffset - (getTextWidth(this.textDownPaint, "00:00") / 2.0f));
        xTextChange.setY(this.lineHeight - (this.textSize / 2.0f));
        xTextChange.setMin(1);
        xTextChange.setMax(this.leftRightOffset + i);
        this.labelsList.add(xTextChange);
        BaseChartView.XTextChange xTextChange2 = new BaseChartView.XTextChange();
        xTextChange2.setLabel("06:00");
        xTextChange2.setX((this.leftRightOffset + (i * 2)) - (getTextWidth(this.textDownPaint, "00:00") / 2.0f));
        xTextChange2.setY(this.lineHeight - (this.textSize / 2.0f));
        xTextChange2.setMin(this.leftRightOffset + i);
        int i2 = i * 3;
        xTextChange2.setMax(this.leftRightOffset + i2);
        this.labelsList.add(xTextChange2);
        BaseChartView.XTextChange xTextChange3 = new BaseChartView.XTextChange();
        xTextChange3.setLabel("12:00");
        xTextChange3.setX((this.leftRightOffset + (i * 4)) - (getTextWidth(this.textDownPaint, "00:00") / 2.0f));
        xTextChange3.setY(this.lineHeight - (this.textSize / 2.0f));
        xTextChange3.setMin(this.leftRightOffset + i2);
        int i3 = i * 5;
        xTextChange3.setMax(this.leftRightOffset + i3);
        this.labelsList.add(xTextChange3);
        BaseChartView.XTextChange xTextChange4 = new BaseChartView.XTextChange();
        xTextChange4.setLabel("18:00");
        xTextChange4.setX((this.leftRightOffset + (i * 6)) - (getTextWidth(this.textDownPaint, "00:00") / 2.0f));
        xTextChange4.setY(this.lineHeight - (this.textSize / 2.0f));
        xTextChange4.setMin(this.leftRightOffset + i3);
        int i4 = i * 7;
        xTextChange4.setMax(this.leftRightOffset + i4);
        this.labelsList.add(xTextChange4);
        BaseChartView.XTextChange xTextChange5 = new BaseChartView.XTextChange();
        xTextChange5.setLabel("23:59");
        xTextChange5.setX((this.leftRightOffset + r0) - (getTextWidth(this.textDownPaint, "00:00") / 2.0f));
        xTextChange5.setY(this.lineHeight - (this.textSize / 2.0f));
        xTextChange5.setMin(this.leftRightOffset + i4);
        xTextChange5.setMax(this.leftRightOffset + (i * 8));
        this.labelsList.add(xTextChange5);
    }

    @Override // android.view.View
    protected void onMeasure(int widthMeasureSpec, int heightMeasureSpec) {
        super.onMeasure(widthMeasureSpec, heightMeasureSpec);
        this.width = getMySize(this.diameterDefault, widthMeasureSpec);
        if (getLayoutParams().height == -2) {
            this.height = this.diameterDefault;
        } else {
            this.height = getMySize(this.diameterDefault, heightMeasureSpec);
        }
        setMeasuredDimension(this.width, this.height);
        this.diameterDefault = (int) dp2px(this.context, 200.0f);
        DateUtil dateUtil = new DateUtil();
        this.fingerXDefault = dateUtil.getHour() * CacheConstants.HOUR;
        int intValue = getNumberThree(this.timeArray, Integer.valueOf((int) this.fingerXDefault)).intValue();
        int i = this.width;
        int i2 = this.leftRightOffset;
        this.fingerX = (((i - (i2 * 2)) * intValue) / CacheConstants.DAY) + i2;
        if (this.hashData.get(intValue + "") != null) {
            StepDataBean stepDataBean = this.hashData.get(intValue + "");
            this.currBean = stepDataBean;
            this.valueSelected = stepDataBean.getSteps();
        } else {
            this.currBean = new StepDataBean(dateUtil.getHour() * CacheConstants.HOUR, 0, 0, 0);
            this.valueSelected = 0;
        }
        initXLabels();
        this.fingerXMax = (this.width - this.circleRadiusMin) - getTextWidth(this.avgLinePaint, "000");
        if (this.data.size() > 0) {
            setData(this.data);
        }
        postInvalidate();
    }

    /* JADX INFO: Access modifiers changed from: protected */
    @Override // com.qcwireless.qcwatch.ui.base.view.BaseChartView, android.view.View
    public void onLayout(boolean changed, int left, int top2, int right, int bottom) {
        super.onLayout(changed, left, top2, right, bottom);
        this.mPaddingStart = getPaddingStart();
        this.mPaddingEnd = getPaddingEnd();
        this.mPaddingTop = getPaddingTop();
        this.mPaddingBottom = getPaddingBottom();
        this.bezierHeight = 0.0f;
    }

    private void initAttr(Context context, AttributeSet attrs) {
        if (attrs != null) {
            TypedArray obtainStyledAttributes = context.obtainStyledAttributes(attrs, R.styleable.qc_chart);
            this.colorBall = obtainStyledAttributes.getColor(1, ViewCompat.MEASURED_STATE_MASK);
            this.colorLine = obtainStyledAttributes.getColor(4, ViewCompat.MEASURED_STATE_MASK);
            this.textDownColor = obtainStyledAttributes.getColor(8, ViewCompat.MEASURED_STATE_MASK);
            this.colorValue = obtainStyledAttributes.getColor(5, ViewCompat.MEASURED_STATE_MASK);
            this.colorValueSelected = obtainStyledAttributes.getColor(6, -1);
            this.colorBgSelected = obtainStyledAttributes.getColor(3, ViewCompat.MEASURED_STATE_MASK);
            this.valueMin = obtainStyledAttributes.getInteger(11, this.offset);
            this.valueMax = obtainStyledAttributes.getInteger(10, CacheConstants.DAY);
            this.valueSelected = obtainStyledAttributes.getInteger(12, 43200);
            this.lineHeight = (int) dp2px(context, obtainStyledAttributes.getInteger(7, 185));
            this.bottomOffset = (int) dp2px(context, obtainStyledAttributes.getInteger(0, 30));
            obtainStyledAttributes.recycle();
            initPublic(context, attrs);
        }
    }

    /* JADX INFO: Access modifiers changed from: protected */
    @Override // com.qcwireless.qcwatch.ui.base.view.BaseChartView, android.view.View
    public void onDraw(Canvas canvas) {
        super.onDraw(canvas);
        this.bezierHeight = (this.circleRadiusMax * 2.0f) + 5.0f;
        this.circleRadius = this.circleRadiusMin + (this.circleRadiusMax - this.circleRadiusMin);
        this.spaceToLine = this.circleRadiusMin * 2.0f;
        for (BaseChartView.XTextChange xTextChange : this.labelsList) {
            if (this.fingerX > xTextChange.getMin() && this.fingerX <= xTextChange.getMax()) {
                canvas.drawText(xTextChange.label, xTextChange.x, this.lineHeight - this.spaceToLine, this.textDownPaint);
            } else {
                canvas.drawText(xTextChange.label, xTextChange.x, xTextChange.y, this.textDownPaint);
            }
        }
        String str = this.valueSelected + "";
        float textWidth = this.fingerX - (getTextWidth(this.textPaint, str) / 2.0f);
        float textWidth2 = this.fingerX + (getTextWidth(this.textPaint, str) / 2.0f);
        if (textWidth <= 0.0f) {
            textWidth2 = getTextWidth(this.textPaint, str);
        }
        if (textWidth2 >= this.width) {
            int i = this.width;
            getTextWidth(this.textPaint, str);
        }
        canvas.drawLine(this.leftRightOffset, (this.lineHeight - this.bottomOffset) + 2, this.width - this.leftRightOffset, (this.lineHeight - this.bottomOffset) + 2, this.avgLinePaint);
        canvas.drawText("0", this.width - getTextWidth(this.avgLinePaint, "000"), (this.lineHeight - this.bottomOffset) + 8, this.textDownPaint);
        canvas.drawLine(this.leftRightOffset, (this.lineHeight - this.bottomOffset) - (((this.maxStep / 3) * (this.lineHeight - this.bottomOffset)) / this.maxStep), this.width - this.leftRightOffset, (this.lineHeight - this.bottomOffset) - (((this.maxStep / 3) * (this.lineHeight - this.bottomOffset)) / this.maxStep), this.avgLinePaint);
        canvas.drawText(this.df.format(((this.maxStep / 3) * 1.0f) / 1000.0f) + "K", this.width - getTextWidth(this.avgLinePaint, "0000"), (this.lineHeight - this.bottomOffset) - (((this.maxStep / 3) * (this.lineHeight - this.bottomOffset)) / this.maxStep), this.textDownPaint);
        canvas.drawLine((float) this.leftRightOffset, (float) ((this.lineHeight - this.bottomOffset) - ((((this.maxStep / 3) * 2) * (this.lineHeight - this.bottomOffset)) / this.maxStep)), (float) (this.width - this.leftRightOffset), (float) ((this.lineHeight - this.bottomOffset) - ((((this.maxStep / 3) * 2) * (this.lineHeight - this.bottomOffset)) / this.maxStep)), this.avgLinePaint);
        canvas.drawText(this.df.format((double) ((((float) ((this.maxStep / 3) * 2)) * 1.0f) / 1000.0f)) + "K", this.width - getTextWidth(this.avgLinePaint, "0000"), (this.lineHeight - this.bottomOffset) - ((((this.maxStep / 3) * 2) * (this.lineHeight - this.bottomOffset)) / this.maxStep), this.textDownPaint);
        Iterator<StepDataBean> it = this.data.iterator();
        while (true) {
            if (it.hasNext()) {
                StepDataBean next = it.next();
                if (next.getSteps() != 0) {
                    this.stepPaint.setStrokeCap(Paint.Cap.ROUND);
                    int phaseY = (int) (((next.getSteps() * (this.lineHeight - this.bottomOffset)) / this.maxStep >= 1 ? r3 : 1) * this.mAnimator.getPhaseY());
                    long timeStamp = next.getTimeStamp();
                    int i2 = this.width;
                    float f = (float) (((timeStamp * (i2 - (r6 * 2))) / 86400) + this.leftRightOffset);
                    float f2 = this.lineHeight - this.bottomOffset;
                    long timeStamp2 = next.getTimeStamp();
                    int i3 = this.width;
                    canvas.drawLine(f, f2, (float) (((timeStamp2 * (i3 - (r14 * 2))) / 86400) + this.leftRightOffset), (this.lineHeight - this.bottomOffset) - phaseY, this.stepPaint);
                }
            } else {
                this.linePaint.setShader(new LinearGradient(this.fingerX, this.lineHeight - this.bottomOffset, this.fingerX, 60.0f, new int[]{ContextCompat.getColor(this.context, com.qcwireless.ring.R.color.q_view_step_3), ContextCompat.getColor(this.context, com.qcwireless.ring.R.color.q_view_step_4), ContextCompat.getColor(this.context, com.qcwireless.ring.R.color.q_view_step_3)}, (float[]) null, Shader.TileMode.CLAMP));
                this.linePaint.setStrokeWidth(2.0f);
                canvas.drawLine(this.fingerX, this.lineHeight - this.bottomOffset, this.fingerX, 60.0f, this.linePaint);
                return;
            }
        }
    }

    @Override // android.view.View
    public boolean onTouchEvent(MotionEvent event) {
        int action = event.getAction();
        if (action == 0) {
            this.fingerX = event.getX();
            getParent().requestDisallowInterceptTouchEvent(true);
            float f = this.fingerX;
            int i = this.leftRightOffset;
            if (f < i) {
                this.fingerX = i;
            }
            if (this.fingerX > this.fingerXMax) {
                this.fingerX = this.fingerXMax;
            }
            this.animatorFingerIn.start();
            this.valueSelected = (int) (((this.fingerX - this.leftRightOffset) * 86400.0f) / (this.width - (this.leftRightOffset * 2)));
            int intValue = getNumberThree(this.timeArray, Integer.valueOf(this.valueSelected)).intValue();
            int i2 = this.width;
            int i3 = this.leftRightOffset;
            this.fingerX = (((i2 - (i3 * 2)) * intValue) / CacheConstants.DAY) + i3;
            if (this.hashData.get(intValue + "") != null) {
                StepDataBean stepDataBean = this.hashData.get(intValue + "");
                this.currBean = stepDataBean;
                this.valueSelected = stepDataBean.getSteps();
            } else {
                this.valueSelected = 0;
            }
            postInvalidate();
        } else if (action == 1) {
            getParent().requestDisallowInterceptTouchEvent(false);
            this.animatorFingerOut.start();
        } else if (action == 2) {
            this.fingerX = event.getX();
            if (this.fingerX < this.fingerXmin) {
                this.fingerX = this.fingerXmin;
            }
            if (this.fingerX > this.fingerXMax) {
                this.fingerX = this.fingerXMax;
            }
            this.valueSelected = (int) (((this.fingerX - this.leftRightOffset) * 86400.0f) / (this.width - (this.leftRightOffset * 2)));
            int intValue2 = getNumberThree(this.timeArray, Integer.valueOf(this.valueSelected)).intValue();
            int i4 = this.width;
            int i5 = this.leftRightOffset;
            this.fingerX = (((i4 - (i5 * 2)) * intValue2) / CacheConstants.DAY) + i5;
            if (this.hashData.get(intValue2 + "") != null) {
                StepDataBean stepDataBean2 = this.hashData.get(intValue2 + "");
                this.currBean = stepDataBean2;
                this.valueSelected = stepDataBean2.getSteps();
            } else {
                this.valueSelected = 0;
            }
            postInvalidate();
        }
        OnSelectedListener onSelectedListener = this.listener;
        if (onSelectedListener != null) {
            onSelectedListener.onSelected(this.currBean);
        }
        return true;
    }

    /* loaded from: classes2.dex */
    public static class StepDataBean {
        private int calorie;
        private int distance;
        private int steps;
        private long timeStamp;

        public StepDataBean(long timeStamp, int steps) {
            this.timeStamp = timeStamp;
            this.steps = steps;
        }

        public StepDataBean(long timeStamp, int steps, int distance, int calorie) {
            this.timeStamp = timeStamp;
            this.steps = steps;
            this.distance = distance;
            this.calorie = calorie;
        }

        public long getTimeStamp() {
            return this.timeStamp;
        }

        public void setTimeStamp(long timeStamp) {
            this.timeStamp = timeStamp;
        }

        public int getSteps() {
            return this.steps;
        }

        public void setSteps(int steps) {
            this.steps = steps;
        }

        public int getDistance() {
            return this.distance;
        }

        public void setDistance(int distance) {
            this.distance = distance;
        }

        public int getCalorie() {
            return this.calorie;
        }

        public void setCalorie(int calorie) {
            this.calorie = calorie;
        }
    }
}
