package com.qcwireless.qcwatch.ui.home.healthy;

import android.animation.ObjectAnimator;
import android.app.NotificationManager;
import android.content.ActivityNotFoundException;
import android.content.ComponentName;
import android.content.Context;
import android.content.Intent;
import android.graphics.Bitmap;
import android.graphics.Canvas;
import android.graphics.Paint;
import android.graphics.Rect;
import android.net.Uri;
import android.os.Build;
import android.os.Bundle;
import android.os.Handler;
import android.os.Looper;
import android.os.Message;
import android.os.Parcelable;
import android.os.PowerManager;
import android.provider.Settings;
import android.text.TextUtils;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.view.animation.LinearInterpolator;
import android.widget.Button;
import android.widget.ImageView;
import android.widget.TextView;
import androidx.constraintlayout.motion.widget.Key;
import androidx.constraintlayout.widget.ConstraintLayout;
import androidx.core.content.FileProvider;
import androidx.core.view.GravityCompat;
import androidx.core.widget.NestedScrollView;
import androidx.fragment.app.FragmentActivity;
import androidx.lifecycle.LifecycleOwner;
import androidx.lifecycle.Observer;
import androidx.recyclerview.widget.GridLayoutManager;
import androidx.recyclerview.widget.RecyclerView;
import androidx.work.WorkRequest;
import com.chad.library.adapter.base.BaseQuickAdapter;
import com.chad.library.adapter.base.listener.OnItemClickListener;
import com.google.android.gms.fitness.FitnessActivities;
import com.hjq.permissions.OnPermissionCallback;
import com.hjq.permissions.XXPermissions;
import com.iwown.awlog.Author;
import com.iwown.awlog.AwLog;
import com.luck.picture.lib.config.SelectMimeType;
import com.oudmon.ble.base.bluetooth.BleOperateManager;
import com.oudmon.ble.base.communication.CommandHandle;
import com.oudmon.ble.base.communication.ICommandResponse;
import com.oudmon.ble.base.communication.file.FileHandle;
import com.oudmon.ble.base.communication.req.SimpleKeyReq;
import com.oudmon.ble.base.communication.req.TargetSettingReq;
import com.oudmon.ble.base.communication.responseImpl.DeviceNotifyListener;
import com.oudmon.ble.base.communication.responseImpl.DeviceSportNotifyListener;
import com.oudmon.ble.base.communication.rsp.BaseRspCmd;
import com.oudmon.ble.base.communication.rsp.BatteryRsp;
import com.oudmon.ble.base.communication.rsp.DeviceNotifyRsp;
import com.oudmon.ble.base.communication.rsp.TargetSettingRsp;
import com.oudmon.ble.base.communication.utils.BLEDataFormatUtils;
import com.oudmon.ble.base.communication.utils.ByteUtil;
import com.oudmon.ble.base.util.LogToFile;
import com.qcwireless.qc_utils.date.DateUtil;
import com.qcwireless.qcwatch.QCApplication;
import com.qcwireless.qcwatch.QJavaApplication;
import com.qcwireless.qcwatch.base.dialog.BottomDialog;
import com.qcwireless.qcwatch.base.dialog.CenterDialog;
import com.qcwireless.qcwatch.base.event.BatteryLowEvent;
import com.qcwireless.qcwatch.base.event.BluetoothEvent;
import com.qcwireless.qcwatch.base.event.BluetoothSyncEvent;
import com.qcwireless.qcwatch.base.event.DeviceNotifyTypeEvent;
import com.qcwireless.qcwatch.base.event.DeviceSyncTodayStepsAndDetailEvent;
import com.qcwireless.qcwatch.base.event.DeviceSyncTodayStepsEvent;
import com.qcwireless.qcwatch.base.event.DeviceToAppSyncEvent;
import com.qcwireless.qcwatch.base.event.DeviceUnitEvent;
import com.qcwireless.qcwatch.base.event.FinishFirstSettingEvent;
import com.qcwireless.qcwatch.base.event.FirmUpdateEvent;
import com.qcwireless.qcwatch.base.event.ManualRefreshEvent;
import com.qcwireless.qcwatch.base.event.MessageEvent;
import com.qcwireless.qcwatch.base.event.RefreshEvent;
import com.qcwireless.qcwatch.base.event.TodayDataSyncEvent;
import com.qcwireless.qcwatch.base.event.WatchFaceDownloadEvent;
import com.qcwireless.qcwatch.base.ktx.ThreadExtKt;
import com.qcwireless.qcwatch.base.permission.PermissionUtilKt;
import com.qcwireless.qcwatch.base.pref.PreUtil;
import com.qcwireless.qcwatch.base.pref.UserConfig;
import com.qcwireless.qcwatch.base.utils.AndroidVersion;
import com.qcwireless.qcwatch.base.utils.FileUtils;
import com.qcwireless.qcwatch.base.utils.MetricUtilsKt;
import com.qcwireless.qcwatch.base.utils.MoshiUtilsKt;
import com.qcwireless.qcwatch.base.view.GlobalKt;
import com.qcwireless.qcwatch.base.view.Localization;
import com.qcwireless.qcwatch.base.view.ViewKt;
import com.qcwireless.qcwatch.databinding.FragmentHealthyBinding;
import com.qcwireless.qcwatch.ui.activity.MainActivity;
import com.qcwireless.qcwatch.ui.base.BaseFragment;
import com.qcwireless.qcwatch.ui.base.bean.event.HealthItemRefreshEvent;
import com.qcwireless.qcwatch.ui.base.repository.entity.StepTotal;
import com.qcwireless.qcwatch.ui.base.repository.entity.TargetEntity;
import com.qcwireless.qcwatch.ui.base.repository.mine.UserProfileRepository;
import com.qcwireless.qcwatch.ui.base.thread.ThreadManager;
import com.qcwireless.qcwatch.ui.base.util.LocationUtils;
import com.qcwireless.qcwatch.ui.base.util.NotificationUtils;
import com.qcwireless.qcwatch.ui.base.view.MyRecycleView;
import com.qcwireless.qcwatch.ui.base.view.healthy.MarqueeView;
import com.qcwireless.qcwatch.ui.base.view.healthy.PubuProgressCircle;
import com.qcwireless.qcwatch.ui.device.connect.DeviceBindActivity;
import com.qcwireless.qcwatch.ui.device.dfu.DeviceFirmwareUpdateActivity;
import com.qcwireless.qcwatch.ui.device.dfu.WatchFileDismissActivity;
import com.qcwireless.qcwatch.ui.device.more.SystemSettingActivity;
import com.qcwireless.qcwatch.ui.device.push.message.MessagePushActivity;
import com.qcwireless.qcwatch.ui.device.vm.DeviceViewModel;
import com.qcwireless.qcwatch.ui.home.drag.DragSelectActivity;
import com.qcwireless.qcwatch.ui.home.gps.GpsActivity;
import com.qcwireless.qcwatch.ui.home.gps.service.TrackingService;
import com.qcwireless.qcwatch.ui.home.guide.BackgroundRunningGuideOneActivity;
import com.qcwireless.qcwatch.ui.home.healthy.HealthyFragment;
import com.qcwireless.qcwatch.ui.home.healthy.adapter.MultipleItemQuickAdapter;
import com.qcwireless.qcwatch.ui.home.healthy.bean.MeasureBean;
import com.qcwireless.qcwatch.ui.home.healthy.sync.SyncStatus;
import com.qcwireless.qcwatch.ui.home.healthy.vm.HealthyViewModel;
import com.qcwireless.qcwatch.ui.home.sport.SportGoActivity;
import com.qcwireless.qcwatch.ui.home.sport.SportRunningActivity;
import com.qcwireless.qcwatch.ui.home.step.StepActivity;
import com.qcwireless.qcwatch.ui.mine.about.AboutActivity;
import com.qcwireless.qcwatch.ui.mine.goal.GoalSettingActivity;
import com.qcwireless.qcwatch.ui.mine.question.FQuestionActivity;
import com.qcwireless.qcwatch.ui.mine.ucenter.UserProfileActivity;
import com.qcwireless.ring.R;
import com.scwang.smart.refresh.layout.api.RefreshLayout;
import com.scwang.smart.refresh.layout.listener.OnRefreshListener;
import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.Serializable;
import java.math.BigDecimal;
import java.math.RoundingMode;
import java.util.ArrayList;
import java.util.List;
import java.util.Locale;
import java.util.Objects;
import kotlin.Lazy;
import kotlin.LazyKt;
import kotlin.Metadata;
import kotlin.Pair;
import kotlin.Unit;
import kotlin.jvm.functions.Function0;
import kotlin.jvm.functions.Function1;
import kotlin.jvm.internal.DefaultConstructorMarker;
import kotlin.jvm.internal.Intrinsics;
import kotlin.jvm.internal.Ref;
import kotlin.jvm.internal.Reflection;
import kotlin.math.MathKt;
import kotlin.text.Regex;
import kotlin.text.StringsKt;
import kotlinx.coroutines.BuildersKt__Builders_commonKt;
import kotlinx.coroutines.GlobalScope;
import org.greenrobot.eventbus.EventBus;
import org.greenrobot.eventbus.Subscribe;
import org.greenrobot.eventbus.ThreadMode;
import org.koin.androidx.viewmodel.ext.android.LifecycleOwnerExtKt;
import org.koin.core.qualifier.Qualifier;
import skin.support.content.res.SkinCompatResources;

/* compiled from: HealthyFragment.kt */
@Metadata(d1 = {"\u0000ì\u0001\n\u0002\u0018\u0002\n\u0002\u0018\u0002\n\u0002\b\u0002\n\u0002\u0018\u0002\n\u0000\n\u0002\u0018\u0002\n\u0000\n\u0002\u0018\u0002\n\u0000\n\u0002\u0018\u0002\n\u0000\n\u0002\u0018\u0002\n\u0000\n\u0002\u0018\u0002\n\u0000\n\u0002\u0018\u0002\n\u0002\b\u0005\n\u0002\u0018\u0002\n\u0000\n\u0002\u0018\u0002\n\u0000\n\u0002\u0018\u0002\n\u0000\n\u0002\u0018\u0002\n\u0000\n\u0002\u0018\u0002\n\u0000\n\u0002\u0018\u0002\n\u0002\b\u0003\n\u0002\u0018\u0002\n\u0000\n\u0002\u0010\u000b\n\u0000\n\u0002\u0010\b\n\u0002\b\u0002\n\u0002\u0018\u0002\n\u0000\n\u0002\u0018\u0002\n\u0002\b\u0007\n\u0002\u0018\u0002\n\u0002\b\u0005\n\u0002\u0010!\n\u0002\u0010\u000e\n\u0002\b\u0002\n\u0002\u0010\u0002\n\u0002\b\u0005\n\u0002\u0018\u0002\n\u0002\b\u0003\n\u0002\u0018\u0002\n\u0002\b\b\n\u0002\u0018\u0002\n\u0000\n\u0002\u0018\u0002\n\u0000\n\u0002\u0018\u0002\n\u0000\n\u0002\u0018\u0002\n\u0000\n\u0002\u0018\u0002\n\u0002\b\u0005\n\u0002\u0018\u0002\n\u0002\b\u0005\n\u0002\u0018\u0002\n\u0002\b\u0002\n\u0002\u0018\u0002\n\u0002\b\r\n\u0002\u0018\u0002\n\u0002\b\t\u0018\u0000 y2\u00020\u0001:\u0007yz{|}~\u007fB\u0005¢\u0006\u0002\u0010\u0002J\b\u0010=\u001a\u00020&H\u0002J \u0010>\u001a\u00020?2\u0006\u0010@\u001a\u00020(2\u0006\u0010A\u001a\u00020(2\u0006\u0010B\u001a\u00020(H\u0002J\u0010\u0010C\u001a\u00020(2\u0006\u0010D\u001a\u00020EH\u0002J\b\u0010F\u001a\u00020?H\u0002J\u0010\u0010G\u001a\u00020?2\u0006\u0010H\u001a\u00020IH\u0002J\b\u0010J\u001a\u00020?H\u0002J\b\u0010K\u001a\u00020&H\u0002J\b\u0010L\u001a\u00020?H\u0016J\b\u0010M\u001a\u00020?H\u0002J\"\u0010N\u001a\u00020?2\u0006\u0010O\u001a\u00020(2\u0006\u0010P\u001a\u00020(2\b\u0010Q\u001a\u0004\u0018\u00010RH\u0016J&\u0010S\u001a\u0004\u0018\u00010T2\u0006\u0010U\u001a\u00020V2\b\u0010W\u001a\u0004\u0018\u00010X2\b\u0010Y\u001a\u0004\u0018\u00010ZH\u0016J\b\u0010[\u001a\u00020?H\u0016J\u0010\u0010\\\u001a\u00020?2\u0006\u0010]\u001a\u00020&H\u0016J\u0010\u0010^\u001a\u00020?2\u0006\u0010_\u001a\u00020`H\u0007J\b\u0010a\u001a\u00020?H\u0016J\b\u0010b\u001a\u00020?H\u0016J\b\u0010c\u001a\u00020?H\u0016J\u0010\u0010d\u001a\u00020?2\u0006\u0010e\u001a\u00020fH\u0002J\u0010\u0010g\u001a\u00020<2\u0006\u0010h\u001a\u00020iH\u0002J\u0010\u0010j\u001a\u00020?2\u0006\u0010k\u001a\u00020<H\u0002J\b\u0010l\u001a\u00020?H\u0002J\b\u0010m\u001a\u00020?H\u0002J\b\u0010n\u001a\u00020?H\u0002J\u0016\u0010o\u001a\u00020?2\f\u0010p\u001a\b\u0012\u0004\u0012\u00020<0;H\u0002J\b\u0010q\u001a\u00020?H\u0002J\b\u0010r\u001a\u00020?H\u0002J\b\u0010s\u001a\u00020?H\u0002J\b\u0010t\u001a\u00020?H\u0002J\u0010\u0010u\u001a\u00020i2\u0006\u0010v\u001a\u00020wH\u0002J\b\u0010x\u001a\u00020?H\u0002R\u000e\u0010\u0003\u001a\u00020\u0004X\u0082.¢\u0006\u0002\n\u0000R\u0010\u0010\u0005\u001a\u0004\u0018\u00010\u0006X\u0082\u000e¢\u0006\u0002\n\u0000R\u000e\u0010\u0007\u001a\u00020\bX\u0082.¢\u0006\u0002\n\u0000R\u000e\u0010\t\u001a\u00020\nX\u0082.¢\u0006\u0002\n\u0000R\u000e\u0010\u000b\u001a\u00020\fX\u0082.¢\u0006\u0002\n\u0000R\u0012\u0010\r\u001a\u00060\u000eR\u00020\u0000X\u0082.¢\u0006\u0002\n\u0000R\u001b\u0010\u000f\u001a\u00020\u00108BX\u0082\u0084\u0002¢\u0006\f\n\u0004\b\u0013\u0010\u0014\u001a\u0004\b\u0011\u0010\u0012R\u000e\u0010\u0015\u001a\u00020\u0016X\u0082\u0004¢\u0006\u0002\n\u0000R\u000e\u0010\u0017\u001a\u00020\u0018X\u0082.¢\u0006\u0002\n\u0000R\u000e\u0010\u0019\u001a\u00020\u001aX\u0082.¢\u0006\u0002\n\u0000R\u000e\u0010\u001b\u001a\u00020\u001cX\u0082.¢\u0006\u0002\n\u0000R\u0012\u0010\u001d\u001a\u00060\u001eR\u00020\u0000X\u0082\u0004¢\u0006\u0002\n\u0000R\u0012\u0010\u001f\u001a\u00060 R\u00020\u0000X\u0082\u0004¢\u0006\u0002\n\u0000R\u000e\u0010!\u001a\u00020\u0018X\u0082.¢\u0006\u0002\n\u0000R\u000e\u0010\"\u001a\u00020\u0018X\u0082.¢\u0006\u0002\n\u0000R\u0010\u0010#\u001a\u0004\u0018\u00010$X\u0082\u000e¢\u0006\u0002\n\u0000R\u000e\u0010%\u001a\u00020&X\u0082\u000e¢\u0006\u0002\n\u0000R\u000e\u0010'\u001a\u00020(X\u0082\u000e¢\u0006\u0002\n\u0000R\u000e\u0010)\u001a\u00020(X\u0082\u000e¢\u0006\u0002\n\u0000R\u0012\u0010*\u001a\u00060+R\u00020\u0000X\u0082\u0004¢\u0006\u0002\n\u0000R\u000e\u0010,\u001a\u00020-X\u0082.¢\u0006\u0002\n\u0000R\u000e\u0010.\u001a\u00020-X\u0082.¢\u0006\u0002\n\u0000R\u000e\u0010/\u001a\u00020-X\u0082.¢\u0006\u0002\n\u0000R\u000e\u00100\u001a\u00020-X\u0082.¢\u0006\u0002\n\u0000R\u000e\u00101\u001a\u00020-X\u0082.¢\u0006\u0002\n\u0000R\u000e\u00102\u001a\u00020-X\u0082.¢\u0006\u0002\n\u0000R\u000e\u00103\u001a\u00020-X\u0082.¢\u0006\u0002\n\u0000R\u001b\u00104\u001a\u0002058BX\u0082\u0084\u0002¢\u0006\f\n\u0004\b8\u0010\u0014\u001a\u0004\b6\u00107R\u000e\u00109\u001a\u00020\u0018X\u0082.¢\u0006\u0002\n\u0000R\u0014\u0010:\u001a\b\u0012\u0004\u0012\u00020<0;X\u0082\u000e¢\u0006\u0002\n\u0000¨\u0006\u0080\u0001"}, d2 = {"Lcom/qcwireless/qcwatch/ui/home/healthy/HealthyFragment;", "Lcom/qcwireless/qcwatch/ui/base/BaseFragment;", "()V", "barChart", "Lcom/qcwireless/qcwatch/ui/base/view/healthy/PubuProgressCircle;", "batteryDialog", "Lcom/qcwireless/qcwatch/base/dialog/CenterDialog;", "binding", "Lcom/qcwireless/qcwatch/databinding/FragmentHealthyBinding;", "bleStatus", "Landroid/widget/ImageView;", "btnAdd", "Landroid/widget/Button;", "deviceNotifyListener", "Lcom/qcwireless/qcwatch/ui/home/healthy/HealthyFragment$MyDeviceNotifyListener;", "deviceViewModel", "Lcom/qcwireless/qcwatch/ui/device/vm/DeviceViewModel;", "getDeviceViewModel", "()Lcom/qcwireless/qcwatch/ui/device/vm/DeviceViewModel;", "deviceViewModel$delegate", "Lkotlin/Lazy;", "handler", "Landroid/os/Handler;", "headerClick", "Landroidx/constraintlayout/widget/ConstraintLayout;", "healthyAdapter", "Lcom/qcwireless/qcwatch/ui/home/healthy/adapter/MultipleItemQuickAdapter;", "marqueeView", "Lcom/qcwireless/qcwatch/ui/base/view/healthy/MarqueeView;", "myRunnable", "Lcom/qcwireless/qcwatch/ui/home/healthy/HealthyFragment$MyRunnable;", "mySportDeviceNotifyListener", "Lcom/qcwireless/qcwatch/ui/home/healthy/HealthyFragment$MySportDeviceNotifyListener;", "noBinding", "noDataLayout", "rotationAnimator", "Landroid/animation/ObjectAnimator;", "sportRunning", "", "sportStatus", "", "sportType", "tenSecondsRefreshRunnable", "Lcom/qcwireless/qcwatch/ui/home/healthy/HealthyFragment$TenSecondsRefreshRunnable;", "todayCalorie", "Landroid/widget/TextView;", "todayDate", "todayDistance", "todayDistanceUnit", "todayStep", "tvComment", "tvProgress", "viewModel", "Lcom/qcwireless/qcwatch/ui/home/healthy/vm/HealthyViewModel;", "getViewModel", "()Lcom/qcwireless/qcwatch/ui/home/healthy/vm/HealthyViewModel;", "viewModel$delegate", "warmingLayout", "warmingList", "", "", "checkPermission", "deviceNotification", "", "step", "distance", "calorie", "getTotalItemsHeight", "recyclerView", "Landroidx/recyclerview/widget/RecyclerView;", "healthyModule", "homePageRefreshTodayData", "it", "Lcom/qcwireless/qcwatch/ui/home/healthy/vm/HealthyViewModel$HealthUI;", "initWarming", "isNotificationListenerEnabled", "loadDataOnce", "observe", "onActivityResult", "requestCode", "resultCode", "data", "Landroid/content/Intent;", "onCreateView", "Landroid/view/View;", "inflater", "Landroid/view/LayoutInflater;", "container", "Landroid/view/ViewGroup;", "savedInstanceState", "Landroid/os/Bundle;", "onDestroy", "onHiddenChanged", "hidden", "onMessageEvent", "messageEvent", "Lcom/qcwireless/qcwatch/base/event/MessageEvent;", "onPause", "onResume", "onStop", "openNotificationSettings", "context", "Landroid/content/Context;", "saveScreenshotToStorage", "screenshot", "Landroid/graphics/Bitmap;", "shareImage", "imagePath", "showChinaOnlyDialog", "showLocationWarningDialog", "showNotificationDialog", "showPermissionWarmingDialog", "permissions", "showRingBatteryLowDialog", "startRotationAnimation", "startSyncData", "stopRotationAnimation", "takeScreenshot", "nestedScrollView", "Landroidx/core/widget/NestedScrollView;", "tenSecondsRefresh", "Companion", "LocationPermissionCallback", "MyDeviceNotifyListener", "MyRunnable", "MySportDeviceNotifyListener", "ScanLocationPermissionCallback", "TenSecondsRefreshRunnable", "app_championRelease"}, k = 1, mv = {1, 6, 0}, xi = 48)
/* loaded from: classes2.dex */
public final class HealthyFragment extends BaseFragment {

    /* renamed from: Companion, reason: from kotlin metadata */
    public static final Companion INSTANCE = new Companion(null);
    private PubuProgressCircle barChart;
    private CenterDialog batteryDialog;
    private FragmentHealthyBinding binding;
    private ImageView bleStatus;
    private Button btnAdd;
    private MyDeviceNotifyListener deviceNotifyListener;

    /* renamed from: deviceViewModel$delegate, reason: from kotlin metadata */
    private final Lazy deviceViewModel;
    private final Handler handler;
    private ConstraintLayout headerClick;
    private MultipleItemQuickAdapter healthyAdapter;
    private MarqueeView marqueeView;
    private final MyRunnable myRunnable;
    private final MySportDeviceNotifyListener mySportDeviceNotifyListener;
    private ConstraintLayout noBinding;
    private ConstraintLayout noDataLayout;
    private ObjectAnimator rotationAnimator;
    private boolean sportRunning;
    private int sportStatus;
    private int sportType;
    private final TenSecondsRefreshRunnable tenSecondsRefreshRunnable;
    private TextView todayCalorie;
    private TextView todayDate;
    private TextView todayDistance;
    private TextView todayDistanceUnit;
    private TextView todayStep;
    private TextView tvComment;
    private TextView tvProgress;

    /* renamed from: viewModel$delegate, reason: from kotlin metadata */
    private final Lazy viewModel;
    private ConstraintLayout warmingLayout;
    private List<String> warmingList;

    /* JADX INFO: Access modifiers changed from: private */
    /* renamed from: loadDataOnce$lambda-6, reason: not valid java name */
    public static final void m719loadDataOnce$lambda6(View view) {
    }

    public HealthyFragment() {
        final HealthyFragment healthyFragment = this;
        final Qualifier qualifier = null;
        final byte b = 0 == true ? 1 : 0;
        this.viewModel = LazyKt.lazy(new Function0<HealthyViewModel>() { // from class: com.qcwireless.qcwatch.ui.home.healthy.HealthyFragment$special$$inlined$viewModel$default$1
            /* JADX WARN: 'super' call moved to the top of the method (can break code semantics) */
            {
                super(0);
            }

            /* JADX WARN: Can't rename method to resolve collision */
            /* JADX WARN: Type inference failed for: r0v1, types: [com.qcwireless.qcwatch.ui.home.healthy.vm.HealthyViewModel, androidx.lifecycle.ViewModel] */
            @Override // kotlin.jvm.functions.Function0
            public final HealthyViewModel invoke() {
                return LifecycleOwnerExtKt.getViewModel(LifecycleOwner.this, Reflection.getOrCreateKotlinClass(HealthyViewModel.class), qualifier, b);
            }
        });
        this.myRunnable = new MyRunnable();
        this.warmingList = new ArrayList();
        this.tenSecondsRefreshRunnable = new TenSecondsRefreshRunnable();
        this.mySportDeviceNotifyListener = new MySportDeviceNotifyListener();
        final byte b2 = 0 == true ? 1 : 0;
        final byte b3 = 0 == true ? 1 : 0;
        this.deviceViewModel = LazyKt.lazy(new Function0<DeviceViewModel>() { // from class: com.qcwireless.qcwatch.ui.home.healthy.HealthyFragment$special$$inlined$viewModel$default$2
            /* JADX WARN: 'super' call moved to the top of the method (can break code semantics) */
            {
                super(0);
            }

            /* JADX WARN: Can't rename method to resolve collision */
            /* JADX WARN: Type inference failed for: r0v1, types: [androidx.lifecycle.ViewModel, com.qcwireless.qcwatch.ui.device.vm.DeviceViewModel] */
            @Override // kotlin.jvm.functions.Function0
            public final DeviceViewModel invoke() {
                return LifecycleOwnerExtKt.getViewModel(LifecycleOwner.this, Reflection.getOrCreateKotlinClass(DeviceViewModel.class), b2, b3);
            }
        });
        final Looper mainLooper = Looper.getMainLooper();
        this.handler = new Handler(mainLooper) { // from class: com.qcwireless.qcwatch.ui.home.healthy.HealthyFragment$handler$1
            @Override // android.os.Handler
            public void handleMessage(Message msg) {
                Intrinsics.checkNotNullParameter(msg, "msg");
                super.handleMessage(msg);
            }
        };
    }

    /* JADX INFO: Access modifiers changed from: private */
    public final HealthyViewModel getViewModel() {
        return (HealthyViewModel) this.viewModel.getValue();
    }

    /* JADX INFO: Access modifiers changed from: private */
    public final DeviceViewModel getDeviceViewModel() {
        return (DeviceViewModel) this.deviceViewModel.getValue();
    }

    @Override // com.qcwireless.qcwatch.ui.base.BaseFragment, androidx.fragment.app.Fragment
    public View onCreateView(LayoutInflater inflater, ViewGroup container, Bundle savedInstanceState) {
        Intrinsics.checkNotNullParameter(inflater, "inflater");
        FragmentHealthyBinding inflate = FragmentHealthyBinding.inflate(inflater, container, false);
        Intrinsics.checkNotNullExpressionValue(inflate, "inflate(inflater, container, false)");
        this.binding = inflate;
        EventBus.getDefault().register(this);
        FragmentHealthyBinding fragmentHealthyBinding = this.binding;
        if (fragmentHealthyBinding == null) {
            Intrinsics.throwUninitializedPropertyAccessException("binding");
            fragmentHealthyBinding = null;
        }
        return fragmentHealthyBinding.getRoot();
    }

    private final void observe() {
        HealthyViewModel viewModel = getViewModel();
        viewModel.getUiState().observe(getViewLifecycleOwner(), new Observer() { // from class: com.qcwireless.qcwatch.ui.home.healthy.HealthyFragment$$ExternalSyntheticLambda15
            @Override // androidx.lifecycle.Observer
            public final void onChanged(Object obj) {
                HealthyFragment.m723observe$lambda3$lambda0(HealthyFragment.this, (HealthyViewModel.HealthUI) obj);
            }
        });
        viewModel.getFileDismissStatue().observe(getViewLifecycleOwner(), new Observer() { // from class: com.qcwireless.qcwatch.ui.home.healthy.HealthyFragment$$ExternalSyntheticLambda16
            @Override // androidx.lifecycle.Observer
            public final void onChanged(Object obj) {
                HealthyFragment.m724observe$lambda3$lambda2(HealthyFragment.this, (ArrayList) obj);
            }
        });
        viewModel.queryInitHealthData();
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* renamed from: observe$lambda-3$lambda-0, reason: not valid java name */
    public static final void m723observe$lambda3$lambda0(HealthyFragment this$0, HealthyViewModel.HealthUI it) {
        Intrinsics.checkNotNullParameter(this$0, "this$0");
        TextView textView = null;
        TextView textView2 = null;
        if (it.getRefreshType() == 1) {
            SyncStatus.INSTANCE.getGetInstance().setSync(false);
            FragmentHealthyBinding fragmentHealthyBinding = this$0.binding;
            if (fragmentHealthyBinding == null) {
                Intrinsics.throwUninitializedPropertyAccessException("binding");
                fragmentHealthyBinding = null;
            }
            fragmentHealthyBinding.syncRefresh.finishRefresh();
            this$0.stopRotationAnimation();
        }
        if (it.getRefreshType() == 3) {
            if (it.getTotalSteps() != null) {
                Intrinsics.checkNotNullExpressionValue(it, "it");
                this$0.homePageRefreshTodayData(it);
                return;
            }
            return;
        }
        if (it.getRefreshType() == 4) {
            if (it.getTotalSteps() != null) {
                Intrinsics.checkNotNullExpressionValue(it, "it");
                this$0.homePageRefreshTodayData(it);
            }
            it.getStepHourData();
            if ((it != null ? it.getTotalSteps() : null) != null) {
                StepTotal totalSteps = it.getTotalSteps();
                Intrinsics.checkNotNull(totalSteps);
                PreUtil.putInt(PreUtil.Action_Today_Steps, totalSteps.getStep());
            }
            new NotificationUtils(QJavaApplication.getInstance().getApplication()).initBandNotification();
            return;
        }
        if (it.getTotalSteps() != null) {
            if (UserConfig.INSTANCE.getInstance().getDeviceAddressNoClear().length() > 0) {
                Intrinsics.checkNotNullExpressionValue(it, "it");
                this$0.homePageRefreshTodayData(it);
                StepTotal totalSteps2 = it.getTotalSteps();
                Intrinsics.checkNotNull(totalSteps2);
                PreUtil.putInt(PreUtil.Action_Today_Steps, totalSteps2.getStep());
                new NotificationUtils(QJavaApplication.getInstance().getApplication()).initBandNotification();
                UserConfig.INSTANCE.getInstance().setLastSyncTodaySteps(new DateUtil().getUnixTimestamp() + 180);
                UserConfig.INSTANCE.getInstance().save();
                it.getStepHourData();
                this$0.healthyModule();
                this$0.getViewModel().syncTodayStepNotification();
            }
        }
        TextView textView3 = this$0.todayStep;
        if (textView3 == null) {
            Intrinsics.throwUninitializedPropertyAccessException("todayStep");
            textView3 = null;
        }
        textView3.setText("--");
        TextView textView4 = this$0.todayDistance;
        if (textView4 == null) {
            Intrinsics.throwUninitializedPropertyAccessException("todayDistance");
            textView4 = null;
        }
        textView4.setText("--");
        TextView textView5 = this$0.todayCalorie;
        if (textView5 == null) {
            Intrinsics.throwUninitializedPropertyAccessException("todayCalorie");
            textView5 = null;
        }
        textView5.setText("--");
        TextView textView6 = this$0.todayDate;
        if (textView6 == null) {
            Intrinsics.throwUninitializedPropertyAccessException("todayDate");
            textView6 = null;
        }
        textView6.setText(new DateUtil().getY_M_D());
        if (UserConfig.INSTANCE.getInstance().getMetric()) {
            TextView textView7 = this$0.todayDistanceUnit;
            if (textView7 == null) {
                Intrinsics.throwUninitializedPropertyAccessException("todayDistanceUnit");
            } else {
                textView2 = textView7;
            }
            textView2.setText(this$0.getString(R.string.qc_text_88));
        } else {
            TextView textView8 = this$0.todayDistanceUnit;
            if (textView8 == null) {
                Intrinsics.throwUninitializedPropertyAccessException("todayDistanceUnit");
            } else {
                textView = textView8;
            }
            textView.setText(this$0.getString(R.string.qc_text_358));
        }
        it.getStepHourData();
        this$0.healthyModule();
        this$0.getViewModel().syncTodayStepNotification();
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* renamed from: observe$lambda-3$lambda-2, reason: not valid java name */
    public static final void m724observe$lambda3$lambda2(HealthyFragment this$0, ArrayList it) {
        Intrinsics.checkNotNullParameter(this$0, "this$0");
        Bundle bundle = new Bundle();
        Intrinsics.checkNotNullExpressionValue(it, "it");
        bundle.putString("fileNames", MoshiUtilsKt.toJson(it));
        bundle.putInt("background", 0);
        HealthyFragment healthyFragment = this$0;
        FragmentActivity it2 = healthyFragment.getActivity();
        if (it2 != null) {
            ArrayList<Pair> arrayList = new ArrayList();
            Intrinsics.checkNotNullExpressionValue(it2, "it");
            Intent intent = new Intent(it2, (Class<?>) WatchFileDismissActivity.class);
            intent.setFlags(1);
            intent.putExtras(bundle);
            for (Pair pair : arrayList) {
                if (pair != null) {
                    String str = (String) pair.getFirst();
                    Object second = pair.getSecond();
                    if (second instanceof Integer) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).intValue()), "putExtra(name, value)");
                    } else if (second instanceof Byte) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).byteValue()), "putExtra(name, value)");
                    } else if (second instanceof Character) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Character) second).charValue()), "putExtra(name, value)");
                    } else if (second instanceof Short) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).shortValue()), "putExtra(name, value)");
                    } else if (second instanceof Boolean) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Boolean) second).booleanValue()), "putExtra(name, value)");
                    } else if (second instanceof Long) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).longValue()), "putExtra(name, value)");
                    } else if (second instanceof Float) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).floatValue()), "putExtra(name, value)");
                    } else if (second instanceof Double) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).doubleValue()), "putExtra(name, value)");
                    } else if (second instanceof String) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (String) second), "putExtra(name, value)");
                    } else if (second instanceof CharSequence) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (CharSequence) second), "putExtra(name, value)");
                    } else if (second instanceof Parcelable) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Parcelable) second), "putExtra(name, value)");
                    } else if (second instanceof Object[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Serializable) second), "putExtra(name, value)");
                    } else if (second instanceof ArrayList) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Serializable) second), "putExtra(name, value)");
                    } else if (second instanceof Serializable) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Serializable) second), "putExtra(name, value)");
                    } else if (second instanceof boolean[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (boolean[]) second), "putExtra(name, value)");
                    } else if (second instanceof byte[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (byte[]) second), "putExtra(name, value)");
                    } else if (second instanceof short[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (short[]) second), "putExtra(name, value)");
                    } else if (second instanceof char[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (char[]) second), "putExtra(name, value)");
                    } else if (second instanceof int[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (int[]) second), "putExtra(name, value)");
                    } else if (second instanceof long[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (long[]) second), "putExtra(name, value)");
                    } else if (second instanceof float[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (float[]) second), "putExtra(name, value)");
                    } else if (second instanceof double[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (double[]) second), "putExtra(name, value)");
                    } else if (second instanceof Bundle) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Bundle) second), "putExtra(name, value)");
                    } else if (second instanceof Intent) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Parcelable) second), "putExtra(name, value)");
                    } else {
                        Unit unit = Unit.INSTANCE;
                    }
                }
            }
            healthyFragment.startActivity(intent);
        }
    }

    private final void homePageRefreshTodayData(final HealthyViewModel.HealthUI it) {
        TextView textView = null;
        try {
            if (UserConfig.INSTANCE.getInstance().getDeviceAddress().length() == 0) {
                ConstraintLayout constraintLayout = this.noBinding;
                if (constraintLayout == null) {
                    Intrinsics.throwUninitializedPropertyAccessException("noBinding");
                    constraintLayout = null;
                }
                ViewKt.visible(constraintLayout);
            } else {
                ConstraintLayout constraintLayout2 = this.noBinding;
                if (constraintLayout2 == null) {
                    Intrinsics.throwUninitializedPropertyAccessException("noBinding");
                    constraintLayout2 = null;
                }
                ViewKt.gone(constraintLayout2);
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
        TextView textView2 = this.todayDate;
        if (textView2 == null) {
            Intrinsics.throwUninitializedPropertyAccessException("todayDate");
            textView2 = null;
        }
        StepTotal totalSteps = it.getTotalSteps();
        Intrinsics.checkNotNull(totalSteps);
        textView2.setText(totalSteps.getDateStr());
        TextView textView3 = this.todayStep;
        if (textView3 == null) {
            Intrinsics.throwUninitializedPropertyAccessException("todayStep");
            textView3 = null;
        }
        StepTotal totalSteps2 = it.getTotalSteps();
        Intrinsics.checkNotNull(totalSteps2);
        textView3.setText(String.valueOf(totalSteps2.getStep()));
        if (UserConfig.INSTANCE.getInstance().getMetric()) {
            try {
                Intrinsics.checkNotNull(it.getTotalSteps());
                String valueOf = String.valueOf(new BigDecimal(String.valueOf((r8.getDistance() * 1.0f) / 1000)).setScale(2, RoundingMode.HALF_UP));
                TextView textView4 = this.todayDistance;
                if (textView4 == null) {
                    Intrinsics.throwUninitializedPropertyAccessException("todayDistance");
                    textView4 = null;
                }
                textView4.setText(valueOf);
                TextView textView5 = this.todayDistanceUnit;
                if (textView5 == null) {
                    Intrinsics.throwUninitializedPropertyAccessException("todayDistanceUnit");
                    textView5 = null;
                }
                textView5.setText(getString(R.string.qc_text_88));
            } catch (Exception unused) {
            }
        } else {
            try {
                Intrinsics.checkNotNull(it.getTotalSteps());
                String valueOf2 = String.valueOf(new BigDecimal(String.valueOf(MetricUtilsKt.kmToIn((r8.getDistance() * 1.0f) / 1000))).setScale(2, RoundingMode.HALF_UP));
                TextView textView6 = this.todayDistance;
                if (textView6 == null) {
                    Intrinsics.throwUninitializedPropertyAccessException("todayDistance");
                    textView6 = null;
                }
                textView6.setText(valueOf2);
                TextView textView7 = this.todayDistanceUnit;
                if (textView7 == null) {
                    Intrinsics.throwUninitializedPropertyAccessException("todayDistanceUnit");
                    textView7 = null;
                }
                textView7.setText(getString(R.string.qc_text_358));
            } catch (Exception e2) {
                e2.printStackTrace();
            }
        }
        TextView textView8 = this.todayCalorie;
        if (textView8 == null) {
            Intrinsics.throwUninitializedPropertyAccessException("todayCalorie");
            textView8 = null;
        }
        StepTotal totalSteps3 = it.getTotalSteps();
        Intrinsics.checkNotNull(totalSteps3);
        textView8.setText(String.valueOf(totalSteps3.getCarolie() / 1000));
        StepTotal totalSteps4 = it.getTotalSteps();
        Intrinsics.checkNotNull(totalSteps4);
        if (totalSteps4.getStep() <= 0) {
            TextView textView9 = this.todayStep;
            if (textView9 == null) {
                Intrinsics.throwUninitializedPropertyAccessException("todayStep");
                textView9 = null;
            }
            textView9.setText("--");
        }
        StepTotal totalSteps5 = it.getTotalSteps();
        Intrinsics.checkNotNull(totalSteps5);
        if (totalSteps5.getDistance() <= 0) {
            TextView textView10 = this.todayDistance;
            if (textView10 == null) {
                Intrinsics.throwUninitializedPropertyAccessException("todayDistance");
                textView10 = null;
            }
            textView10.setText("--");
        }
        StepTotal totalSteps6 = it.getTotalSteps();
        Intrinsics.checkNotNull(totalSteps6);
        if (totalSteps6.getCarolie() <= 0) {
            TextView textView11 = this.todayCalorie;
            if (textView11 == null) {
                Intrinsics.throwUninitializedPropertyAccessException("todayCalorie");
            } else {
                textView = textView11;
            }
            textView.setText("--");
        }
        ThreadExtKt.ktxRunOnBgSingle(this, new Function1<HealthyFragment, Unit>() { // from class: com.qcwireless.qcwatch.ui.home.healthy.HealthyFragment$homePageRefreshTodayData$1
            /* JADX INFO: Access modifiers changed from: package-private */
            {
                super(1);
            }

            @Override // kotlin.jvm.functions.Function1
            public /* bridge */ /* synthetic */ Unit invoke(HealthyFragment healthyFragment) {
                invoke2(healthyFragment);
                return Unit.INSTANCE;
            }

            /* renamed from: invoke, reason: avoid collision after fix types in other method */
            public final void invoke2(HealthyFragment ktxRunOnBgSingle) {
                ConstraintLayout constraintLayout3;
                ConstraintLayout constraintLayout4;
                Intrinsics.checkNotNullParameter(ktxRunOnBgSingle, "$this$ktxRunOnBgSingle");
                final TargetEntity queryTarget = UserProfileRepository.INSTANCE.getGetInstance().queryTarget();
                if (queryTarget == null) {
                    constraintLayout3 = ktxRunOnBgSingle.headerClick;
                    ConstraintLayout constraintLayout5 = null;
                    if (constraintLayout3 == null) {
                        Intrinsics.throwUninitializedPropertyAccessException("headerClick");
                        constraintLayout3 = null;
                    }
                    ViewKt.gone(constraintLayout3);
                    constraintLayout4 = ktxRunOnBgSingle.noDataLayout;
                    if (constraintLayout4 == null) {
                        Intrinsics.throwUninitializedPropertyAccessException("noDataLayout");
                    } else {
                        constraintLayout5 = constraintLayout4;
                    }
                    ViewKt.visible(constraintLayout5);
                    final HealthyViewModel.HealthUI healthUI = HealthyViewModel.HealthUI.this;
                    ThreadExtKt.ktxRunOnUi(ktxRunOnBgSingle, new Function1<HealthyFragment, Unit>() { // from class: com.qcwireless.qcwatch.ui.home.healthy.HealthyFragment$homePageRefreshTodayData$1.2
                        {
                            super(1);
                        }

                        @Override // kotlin.jvm.functions.Function1
                        public /* bridge */ /* synthetic */ Unit invoke(HealthyFragment healthyFragment) {
                            invoke2(healthyFragment);
                            return Unit.INSTANCE;
                        }

                        /* renamed from: invoke, reason: avoid collision after fix types in other method */
                        public final void invoke2(HealthyFragment ktxRunOnUi) {
                            PubuProgressCircle pubuProgressCircle;
                            TextView textView12;
                            TextView textView13;
                            Intrinsics.checkNotNullParameter(ktxRunOnUi, "$this$ktxRunOnUi");
                            pubuProgressCircle = ktxRunOnUi.barChart;
                            TextView textView14 = null;
                            if (pubuProgressCircle == null) {
                                Intrinsics.throwUninitializedPropertyAccessException("barChart");
                                pubuProgressCircle = null;
                            }
                            StepTotal totalSteps7 = HealthyViewModel.HealthUI.this.getTotalSteps();
                            Intrinsics.checkNotNull(totalSteps7);
                            pubuProgressCircle.refreshViewGoal(totalSteps7.getStep(), 10000);
                            textView12 = ktxRunOnUi.tvComment;
                            if (textView12 == null) {
                                Intrinsics.throwUninitializedPropertyAccessException("tvComment");
                                textView12 = null;
                            }
                            textView12.setText("");
                            textView13 = ktxRunOnUi.tvProgress;
                            if (textView13 == null) {
                                Intrinsics.throwUninitializedPropertyAccessException("tvProgress");
                            } else {
                                textView14 = textView13;
                            }
                            textView14.setText("0");
                        }
                    });
                    return;
                }
                final HealthyViewModel.HealthUI healthUI2 = HealthyViewModel.HealthUI.this;
                ThreadExtKt.ktxRunOnUi(ktxRunOnBgSingle, new Function1<HealthyFragment, Unit>() { // from class: com.qcwireless.qcwatch.ui.home.healthy.HealthyFragment$homePageRefreshTodayData$1.1
                    /* JADX WARN: 'super' call moved to the top of the method (can break code semantics) */
                    {
                        super(1);
                    }

                    @Override // kotlin.jvm.functions.Function1
                    public /* bridge */ /* synthetic */ Unit invoke(HealthyFragment healthyFragment) {
                        invoke2(healthyFragment);
                        return Unit.INSTANCE;
                    }

                    /* renamed from: invoke, reason: avoid collision after fix types in other method */
                    public final void invoke2(HealthyFragment ktxRunOnUi) {
                        ConstraintLayout constraintLayout6;
                        ConstraintLayout constraintLayout7;
                        PubuProgressCircle pubuProgressCircle;
                        TextView textView12;
                        ConstraintLayout constraintLayout8;
                        TextView textView13;
                        ConstraintLayout constraintLayout9;
                        TextView textView14;
                        ConstraintLayout constraintLayout10;
                        TextView textView15;
                        ConstraintLayout constraintLayout11;
                        ConstraintLayout constraintLayout12;
                        Intrinsics.checkNotNullParameter(ktxRunOnUi, "$this$ktxRunOnUi");
                        TextView textView16 = null;
                        if (UserConfig.INSTANCE.getInstance().getDeviceAddressNoClear().length() > 0) {
                            constraintLayout11 = ktxRunOnUi.headerClick;
                            if (constraintLayout11 == null) {
                                Intrinsics.throwUninitializedPropertyAccessException("headerClick");
                                constraintLayout11 = null;
                            }
                            ViewKt.visible(constraintLayout11);
                            constraintLayout12 = ktxRunOnUi.noDataLayout;
                            if (constraintLayout12 == null) {
                                Intrinsics.throwUninitializedPropertyAccessException("noDataLayout");
                                constraintLayout12 = null;
                            }
                            ViewKt.gone(constraintLayout12);
                        } else {
                            constraintLayout6 = ktxRunOnUi.headerClick;
                            if (constraintLayout6 == null) {
                                Intrinsics.throwUninitializedPropertyAccessException("headerClick");
                                constraintLayout6 = null;
                            }
                            ViewKt.gone(constraintLayout6);
                            constraintLayout7 = ktxRunOnUi.noDataLayout;
                            if (constraintLayout7 == null) {
                                Intrinsics.throwUninitializedPropertyAccessException("noDataLayout");
                                constraintLayout7 = null;
                            }
                            ViewKt.visible(constraintLayout7);
                        }
                        Intrinsics.checkNotNull(HealthyViewModel.HealthUI.this.getTotalSteps());
                        int roundToInt = MathKt.roundToInt(((r0.getStep() * 100) * 1.0f) / queryTarget.getGoalSteps());
                        int i = roundToInt <= 100 ? roundToInt : 100;
                        pubuProgressCircle = ktxRunOnUi.barChart;
                        if (pubuProgressCircle == null) {
                            Intrinsics.throwUninitializedPropertyAccessException("barChart");
                            pubuProgressCircle = null;
                        }
                        StepTotal totalSteps7 = HealthyViewModel.HealthUI.this.getTotalSteps();
                        Intrinsics.checkNotNull(totalSteps7);
                        pubuProgressCircle.refreshViewGoal(totalSteps7.getStep(), queryTarget.getGoalSteps());
                        textView12 = ktxRunOnUi.tvProgress;
                        if (textView12 == null) {
                            Intrinsics.throwUninitializedPropertyAccessException("tvProgress");
                            textView12 = null;
                        }
                        textView12.setText(String.valueOf(i));
                        if (i <= 30) {
                            constraintLayout10 = ktxRunOnUi.headerClick;
                            if (constraintLayout10 == null) {
                                Intrinsics.throwUninitializedPropertyAccessException("headerClick");
                                constraintLayout10 = null;
                            }
                            constraintLayout10.setBackground(SkinCompatResources.getDrawable(ktxRunOnUi.getActivity(), R.mipmap.ring_activity_bg_3));
                            textView15 = ktxRunOnUi.tvComment;
                            if (textView15 == null) {
                                Intrinsics.throwUninitializedPropertyAccessException("tvComment");
                            } else {
                                textView16 = textView15;
                            }
                            textView16.setText(ktxRunOnUi.getString(R.string.qc_text_8012));
                            return;
                        }
                        if (31 <= i && i < 61) {
                            constraintLayout9 = ktxRunOnUi.headerClick;
                            if (constraintLayout9 == null) {
                                Intrinsics.throwUninitializedPropertyAccessException("headerClick");
                                constraintLayout9 = null;
                            }
                            constraintLayout9.setBackground(SkinCompatResources.getDrawable(ktxRunOnUi.getActivity(), R.mipmap.ring_activity_bg_1));
                            textView14 = ktxRunOnUi.tvComment;
                            if (textView14 == null) {
                                Intrinsics.throwUninitializedPropertyAccessException("tvComment");
                            } else {
                                textView16 = textView14;
                            }
                            textView16.setText(ktxRunOnUi.getString(R.string.qc_text_8011));
                            return;
                        }
                        constraintLayout8 = ktxRunOnUi.headerClick;
                        if (constraintLayout8 == null) {
                            Intrinsics.throwUninitializedPropertyAccessException("headerClick");
                            constraintLayout8 = null;
                        }
                        constraintLayout8.setBackground(SkinCompatResources.getDrawable(ktxRunOnUi.getActivity(), R.mipmap.ring_activity_bg_2));
                        textView13 = ktxRunOnUi.tvComment;
                        if (textView13 == null) {
                            Intrinsics.throwUninitializedPropertyAccessException("tvComment");
                        } else {
                            textView16 = textView13;
                        }
                        textView16.setText(ktxRunOnUi.getString(R.string.qc_text_8013));
                    }
                });
            }
        });
    }

    @Override // com.qcwireless.qcwatch.ui.base.BaseFragment, androidx.fragment.app.Fragment
    public void onResume() {
        super.onResume();
        boolean z = false;
        if (!UserConfig.INSTANCE.getInstance().getLoginStatus()) {
            if (UserConfig.INSTANCE.getInstance().getUserToken().length() == 0) {
                getViewModel().getTokenNotLogin();
            }
        }
        if (!BleOperateManager.getInstance().isConnected()) {
            ThreadManager.getInstance().wakeUpNotWait();
        }
        MyDeviceNotifyListener myDeviceNotifyListener = null;
        try {
            if (UserConfig.INSTANCE.getInstance().getDeviceName().length() == 0) {
                ConstraintLayout constraintLayout = this.noBinding;
                if (constraintLayout == null) {
                    Intrinsics.throwUninitializedPropertyAccessException("noBinding");
                    constraintLayout = null;
                }
                ViewKt.visible(constraintLayout);
            } else {
                ConstraintLayout constraintLayout2 = this.noBinding;
                if (constraintLayout2 == null) {
                    Intrinsics.throwUninitializedPropertyAccessException("noBinding");
                    constraintLayout2 = null;
                }
                ViewKt.gone(constraintLayout2);
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
        if (!BleOperateManager.getInstance().isConnected()) {
            FragmentHealthyBinding fragmentHealthyBinding = this.binding;
            if (fragmentHealthyBinding == null) {
                Intrinsics.throwUninitializedPropertyAccessException("binding");
                fragmentHealthyBinding = null;
            }
            if (fragmentHealthyBinding.syncRefresh.isRefreshing()) {
                FragmentHealthyBinding fragmentHealthyBinding2 = this.binding;
                if (fragmentHealthyBinding2 == null) {
                    Intrinsics.throwUninitializedPropertyAccessException("binding");
                    fragmentHealthyBinding2 = null;
                }
                fragmentHealthyBinding2.syncRefresh.finishRefresh();
                stopRotationAnimation();
            }
            ImageView imageView = this.bleStatus;
            if (imageView == null) {
                Intrinsics.throwUninitializedPropertyAccessException("bleStatus");
                imageView = null;
            }
            imageView.setImageResource(R.mipmap.ble_disconnect);
        } else {
            ImageView imageView2 = this.bleStatus;
            if (imageView2 == null) {
                Intrinsics.throwUninitializedPropertyAccessException("bleStatus");
                imageView2 = null;
            }
            imageView2.setImageResource(R.mipmap.ble_connect);
        }
        initWarming();
        this.handler.removeCallbacks(this.tenSecondsRefreshRunnable);
        this.handler.postDelayed(this.tenSecondsRefreshRunnable, WorkRequest.MIN_BACKOFF_MILLIS);
        try {
            if (BleOperateManager.getInstance().isConnected()) {
                StringBuilder sb = new StringBuilder();
                sb.append("----前台同步数据状态：");
                sb.append(UserConfig.INSTANCE.getInstance().getLastTenMinSyncTime() < new DateUtil().getUnixTimestamp());
                AwLog.i(Author.HeZhiYuan, sb.toString());
                if (UserConfig.INSTANCE.getInstance().getLastTenMinSyncTime() < new DateUtil().getUnixTimestamp()) {
                    startSyncData();
                }
            }
        } catch (Exception e2) {
            e2.printStackTrace();
        }
        AwLog.i(Author.HeZhiYuan, "-----onResume--------");
        this.deviceNotifyListener = new MyDeviceNotifyListener();
        BleOperateManager bleOperateManager = BleOperateManager.getInstance();
        MyDeviceNotifyListener myDeviceNotifyListener2 = this.deviceNotifyListener;
        if (myDeviceNotifyListener2 == null) {
            Intrinsics.throwUninitializedPropertyAccessException("deviceNotifyListener");
        } else {
            myDeviceNotifyListener = myDeviceNotifyListener2;
        }
        bleOperateManager.addOutDeviceListener(100, myDeviceNotifyListener);
        BleOperateManager.getInstance().addSportDeviceListener(120, this.mySportDeviceNotifyListener);
        if (StringsKt.equals(Build.BRAND, "xiaomi", true) || StringsKt.equals(Build.BRAND, "redmi", true)) {
            this.handler.postDelayed(new Runnable() { // from class: com.qcwireless.qcwatch.ui.home.healthy.HealthyFragment$$ExternalSyntheticLambda21
                @Override // java.lang.Runnable
                public final void run() {
                    HealthyFragment.m725onResume$lambda4(HealthyFragment.this);
                }
            }, WorkRequest.MIN_BACKOFF_MILLIS);
        }
        getViewModel().queryNotificationHealthData();
        healthyModule();
        String battery = UserConfig.INSTANCE.getInstance().getBattery();
        if (battery != null) {
            int parseInt = Integer.parseInt(battery);
            if (1 <= parseInt && parseInt < 20) {
                z = true;
            }
            if (z && UserConfig.INSTANCE.getInstance().getBatteryWarmingOpen() && !UserConfig.INSTANCE.getInstance().getBatteryLow()) {
                showRingBatteryLowDialog();
            }
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* renamed from: onResume$lambda-4, reason: not valid java name */
    public static final void m725onResume$lambda4(HealthyFragment this$0) {
        Intrinsics.checkNotNullParameter(this$0, "this$0");
        this$0.initWarming();
    }

    private final void startRotationAnimation() {
        if (BleOperateManager.getInstance().isConnected()) {
            ImageView imageView = this.bleStatus;
            ImageView imageView2 = null;
            if (imageView == null) {
                Intrinsics.throwUninitializedPropertyAccessException("bleStatus");
                imageView = null;
            }
            imageView.setImageDrawable(SkinCompatResources.getDrawable(getActivity(), R.mipmap.ble_connect_sync));
            ImageView imageView3 = this.bleStatus;
            if (imageView3 == null) {
                Intrinsics.throwUninitializedPropertyAccessException("bleStatus");
            } else {
                imageView2 = imageView3;
            }
            ObjectAnimator ofFloat = ObjectAnimator.ofFloat(imageView2, Key.ROTATION, 0.0f, 360.0f);
            this.rotationAnimator = ofFloat;
            if (ofFloat != null) {
                ofFloat.setDuration(TrackingService.Constant.FASTEST_UPDATE_INTERVAL);
                ofFloat.setInterpolator(new LinearInterpolator());
                ofFloat.setRepeatCount(-1);
                ofFloat.start();
            }
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    public final void stopRotationAnimation() {
        try {
            ImageView imageView = null;
            if (BleOperateManager.getInstance().isConnected()) {
                ImageView imageView2 = this.bleStatus;
                if (imageView2 == null) {
                    Intrinsics.throwUninitializedPropertyAccessException("bleStatus");
                } else {
                    imageView = imageView2;
                }
                imageView.setImageDrawable(SkinCompatResources.getDrawable(getActivity(), R.mipmap.ble_connect));
            } else {
                ImageView imageView3 = this.bleStatus;
                if (imageView3 == null) {
                    Intrinsics.throwUninitializedPropertyAccessException("bleStatus");
                } else {
                    imageView = imageView3;
                }
                imageView.setImageDrawable(SkinCompatResources.getDrawable(getActivity(), R.mipmap.ble_disconnect));
            }
            ObjectAnimator objectAnimator = this.rotationAnimator;
            if (objectAnimator != null) {
                objectAnimator.cancel();
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    /* compiled from: HealthyFragment.kt */
    @Metadata(d1 = {"\u0000\u0018\n\u0002\u0018\u0002\n\u0002\u0018\u0002\n\u0002\b\u0002\n\u0002\u0010\u0002\n\u0000\n\u0002\u0018\u0002\n\u0000\b\u0086\u0004\u0018\u00002\u00020\u0001B\u0005¢\u0006\u0002\u0010\u0002J\u0012\u0010\u0003\u001a\u00020\u00042\b\u0010\u0005\u001a\u0004\u0018\u00010\u0006H\u0016¨\u0006\u0007"}, d2 = {"Lcom/qcwireless/qcwatch/ui/home/healthy/HealthyFragment$MySportDeviceNotifyListener;", "Lcom/oudmon/ble/base/communication/responseImpl/DeviceSportNotifyListener;", "(Lcom/qcwireless/qcwatch/ui/home/healthy/HealthyFragment;)V", "onDataResponse", "", "resultEntity", "Lcom/oudmon/ble/base/communication/rsp/DeviceNotifyRsp;", "app_championRelease"}, k = 1, mv = {1, 6, 0}, xi = 48)
    /* loaded from: classes2.dex */
    public final class MySportDeviceNotifyListener extends DeviceSportNotifyListener {
        public MySportDeviceNotifyListener() {
        }

        @Override // com.oudmon.ble.base.communication.responseImpl.DeviceSportNotifyListener, com.oudmon.ble.base.communication.ICommandResponse
        public void onDataResponse(DeviceNotifyRsp resultEntity) {
            super.onDataResponse(resultEntity);
            Intrinsics.checkNotNull(resultEntity);
            if (resultEntity.getStatus() == 0) {
                HealthyFragment.this.sportRunning = true;
                HealthyFragment.this.sportType = BLEDataFormatUtils.bytes2Int(new byte[]{resultEntity.getLoadData()[0]});
                HealthyFragment.this.sportStatus = BLEDataFormatUtils.bytes2Int(new byte[]{resultEntity.getLoadData()[1]});
                AwLog.i(Author.HeZhiYuan, Integer.valueOf(HealthyFragment.this.sportType));
            }
        }
    }

    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r0v16, types: [androidx.constraintlayout.widget.ConstraintLayout] */
    private final void initWarming() {
        try {
            this.warmingList.clear();
            if (!isNotificationListenerEnabled()) {
                List<String> list = this.warmingList;
                String string = getString(R.string.qc_text_389);
                Intrinsics.checkNotNullExpressionValue(string, "getString(R.string.qc_text_389)");
                list.add(string);
            }
            if (!checkPermission()) {
                List<String> list2 = this.warmingList;
                String string2 = getString(R.string.qc_text_390);
                Intrinsics.checkNotNullExpressionValue(string2, "getString(R.string.qc_text_390)");
                list2.add(string2);
            }
            if (!UserConfig.INSTANCE.getInstance().getWarmingAutoStart()) {
                List<String> list3 = this.warmingList;
                String string3 = getString(R.string.qc_text_391);
                Intrinsics.checkNotNullExpressionValue(string3, "getString(R.string.qc_text_391)");
                list3.add(string3);
            }
            if (!UserConfig.INSTANCE.getInstance().getWarmingLock()) {
                List<String> list4 = this.warmingList;
                String string4 = getString(R.string.qc_text_392);
                Intrinsics.checkNotNullExpressionValue(string4, "getString(R.string.qc_text_392)");
                list4.add(string4);
            }
            if (!UserConfig.INSTANCE.getInstance().getWarmingBatteryAllow()) {
                List<String> list5 = this.warmingList;
                String string5 = getString(R.string.qc_text_393);
                Intrinsics.checkNotNullExpressionValue(string5, "getString(R.string.qc_text_393)");
                list5.add(string5);
            }
            if (BleOperateManager.getInstance().isConnected()) {
                if (!PermissionUtilKt.hasCallPhonePermission((FragmentActivity) getActivity())) {
                    List<String> list6 = this.warmingList;
                    String string6 = getString(R.string.qc_text_451);
                    Intrinsics.checkNotNullExpressionValue(string6, "getString(R.string.qc_text_451)");
                    list6.add(string6);
                }
                if (!PermissionUtilKt.hasSMSPermission((FragmentActivity) getActivity())) {
                    List<String> list7 = this.warmingList;
                    String string7 = getString(R.string.qc_text_452);
                    Intrinsics.checkNotNullExpressionValue(string7, "getString(R.string.qc_text_452)");
                    list7.add(string7);
                }
            }
            MarqueeView marqueeView = null;
            if (this.warmingList.size() > 0) {
                ConstraintLayout constraintLayout = this.warmingLayout;
                if (constraintLayout == null) {
                    Intrinsics.throwUninitializedPropertyAccessException("warmingLayout");
                    constraintLayout = null;
                }
                ViewKt.gone(constraintLayout);
                MarqueeView marqueeView2 = this.marqueeView;
                if (marqueeView2 == null) {
                    Intrinsics.throwUninitializedPropertyAccessException("marqueeView");
                } else {
                    marqueeView = marqueeView2;
                }
                marqueeView.startWithList(this.warmingList);
                return;
            }
            ?? r0 = this.warmingLayout;
            if (r0 == 0) {
                Intrinsics.throwUninitializedPropertyAccessException("warmingLayout");
            } else {
                marqueeView = r0;
            }
            ViewKt.gone(marqueeView);
        } catch (Exception unused) {
        }
    }

    @Override // com.qcwireless.qcwatch.ui.base.BaseFragment, androidx.fragment.app.Fragment
    public void onStop() {
        super.onStop();
        AwLog.i(Author.HeZhiYuan, "----------onStop");
        MarqueeView marqueeView = null;
        try {
            MultipleItemQuickAdapter multipleItemQuickAdapter = this.healthyAdapter;
            if (multipleItemQuickAdapter == null) {
                Intrinsics.throwUninitializedPropertyAccessException("healthyAdapter");
                multipleItemQuickAdapter = null;
            }
            multipleItemQuickAdapter.removeMeasure();
        } catch (Exception e) {
            e.printStackTrace();
        }
        MarqueeView marqueeView2 = this.marqueeView;
        if (marqueeView2 == null) {
            Intrinsics.throwUninitializedPropertyAccessException("marqueeView");
        } else {
            marqueeView = marqueeView2;
        }
        marqueeView.stopFlipping();
        this.handler.removeCallbacks(this.tenSecondsRefreshRunnable);
    }

    @Override // androidx.fragment.app.Fragment
    public void onHiddenChanged(boolean hidden) {
        super.onHiddenChanged(hidden);
        if (hidden) {
            AwLog.i(Author.HeZhiYuan, "----hidden---");
            this.handler.removeCallbacks(this.tenSecondsRefreshRunnable);
        }
    }

    @Override // com.qcwireless.qcwatch.ui.base.BaseFragment, androidx.fragment.app.Fragment
    public void onPause() {
        super.onPause();
        this.handler.removeCallbacks(this.tenSecondsRefreshRunnable);
    }

    @Override // com.qcwireless.qcwatch.ui.base.BaseFragment
    public void loadDataOnce() {
        super.loadDataOnce();
        this.healthyAdapter = new MultipleItemQuickAdapter(getActivity(), getViewModel().getItemList());
        boolean z = true;
        GridLayoutManager gridLayoutManager = new GridLayoutManager(getActivity(), 1);
        MultipleItemQuickAdapter multipleItemQuickAdapter = null;
        View view = LayoutInflater.from(getActivity()).inflate(R.layout.recycleview_item_footer, (ViewGroup) null);
        View headerView = LayoutInflater.from(getActivity()).inflate(R.layout.recycleview_item_header, (ViewGroup) null);
        View findViewById = headerView.findViewById(R.id.today_step_layout);
        Intrinsics.checkNotNullExpressionValue(findViewById, "headerView.findViewById<…>(R.id.today_step_layout)");
        this.headerClick = (ConstraintLayout) findViewById;
        View findViewById2 = headerView.findViewById(R.id.activity_no_data_layout);
        Intrinsics.checkNotNullExpressionValue(findViewById2, "headerView.findViewById<….activity_no_data_layout)");
        this.noDataLayout = (ConstraintLayout) findViewById2;
        View findViewById3 = headerView.findViewById(R.id.tv_today_steps);
        Intrinsics.checkNotNullExpressionValue(findViewById3, "headerView.findViewById(R.id.tv_today_steps)");
        this.todayStep = (TextView) findViewById3;
        View findViewById4 = headerView.findViewById(R.id.tv_distance);
        Intrinsics.checkNotNullExpressionValue(findViewById4, "headerView.findViewById(R.id.tv_distance)");
        this.todayDistance = (TextView) findViewById4;
        View findViewById5 = headerView.findViewById(R.id.tv_distance_unit);
        Intrinsics.checkNotNullExpressionValue(findViewById5, "headerView.findViewById(R.id.tv_distance_unit)");
        this.todayDistanceUnit = (TextView) findViewById5;
        View findViewById6 = headerView.findViewById(R.id.tv_calorie);
        Intrinsics.checkNotNullExpressionValue(findViewById6, "headerView.findViewById(R.id.tv_calorie)");
        this.todayCalorie = (TextView) findViewById6;
        View findViewById7 = headerView.findViewById(R.id.qc_step_chart);
        Intrinsics.checkNotNullExpressionValue(findViewById7, "headerView.findViewById(R.id.qc_step_chart)");
        this.barChart = (PubuProgressCircle) findViewById7;
        View findViewById8 = headerView.findViewById(R.id.image_ble_status);
        Intrinsics.checkNotNullExpressionValue(findViewById8, "headerView.findViewById(R.id.image_ble_status)");
        this.bleStatus = (ImageView) findViewById8;
        View findViewById9 = headerView.findViewById(R.id.marquee_view);
        Intrinsics.checkNotNullExpressionValue(findViewById9, "headerView.findViewById(R.id.marquee_view)");
        this.marqueeView = (MarqueeView) findViewById9;
        View findViewById10 = headerView.findViewById(R.id.warming_info);
        Intrinsics.checkNotNullExpressionValue(findViewById10, "headerView.findViewById(R.id.warming_info)");
        this.warmingLayout = (ConstraintLayout) findViewById10;
        ConstraintLayout constraintLayout = this.headerClick;
        if (constraintLayout == null) {
            Intrinsics.throwUninitializedPropertyAccessException("headerClick");
            constraintLayout = null;
        }
        View findViewById11 = constraintLayout.findViewById(R.id.home_step_date);
        Intrinsics.checkNotNullExpressionValue(findViewById11, "headerClick.findViewById(R.id.home_step_date)");
        this.todayDate = (TextView) findViewById11;
        View findViewById12 = headerView.findViewById(R.id.btn_add_device);
        Intrinsics.checkNotNullExpressionValue(findViewById12, "headerView.findViewById(R.id.btn_add_device)");
        this.btnAdd = (Button) findViewById12;
        View findViewById13 = headerView.findViewById(R.id.data_no_binding);
        Intrinsics.checkNotNullExpressionValue(findViewById13, "headerView.findViewById(R.id.data_no_binding)");
        this.noBinding = (ConstraintLayout) findViewById13;
        View findViewById14 = headerView.findViewById(R.id.tv_activity_score);
        Intrinsics.checkNotNullExpressionValue(findViewById14, "headerView.findViewById(R.id.tv_activity_score)");
        this.tvProgress = (TextView) findViewById14;
        View findViewById15 = headerView.findViewById(R.id.tv_activity_comment);
        Intrinsics.checkNotNullExpressionValue(findViewById15, "headerView.findViewById(R.id.tv_activity_comment)");
        this.tvComment = (TextView) findViewById15;
        ImageView imageView = (ImageView) headerView.findViewById(R.id.to_menu);
        ImageView imageView2 = (ImageView) headerView.findViewById(R.id.image_share);
        FragmentHealthyBinding fragmentHealthyBinding = this.binding;
        if (fragmentHealthyBinding == null) {
            Intrinsics.throwUninitializedPropertyAccessException("binding");
            fragmentHealthyBinding = null;
        }
        fragmentHealthyBinding.navigationView.setOnClickListener(new View.OnClickListener() { // from class: com.qcwireless.qcwatch.ui.home.healthy.HealthyFragment$$ExternalSyntheticLambda12
            @Override // android.view.View.OnClickListener
            public final void onClick(View view2) {
                HealthyFragment.m719loadDataOnce$lambda6(view2);
            }
        });
        try {
            if (UserConfig.INSTANCE.getInstance().getDeviceName().length() == 0) {
                ConstraintLayout constraintLayout2 = this.noBinding;
                if (constraintLayout2 == null) {
                    Intrinsics.throwUninitializedPropertyAccessException("noBinding");
                    constraintLayout2 = null;
                }
                ViewKt.visible(constraintLayout2);
                if (UserConfig.INSTANCE.getInstance().getDeviceAddressNoClear().length() > 0) {
                    ConstraintLayout constraintLayout3 = this.headerClick;
                    if (constraintLayout3 == null) {
                        Intrinsics.throwUninitializedPropertyAccessException("headerClick");
                        constraintLayout3 = null;
                    }
                    ViewKt.visible(constraintLayout3);
                    ConstraintLayout constraintLayout4 = this.noDataLayout;
                    if (constraintLayout4 == null) {
                        Intrinsics.throwUninitializedPropertyAccessException("noDataLayout");
                        constraintLayout4 = null;
                    }
                    ViewKt.gone(constraintLayout4);
                } else {
                    ConstraintLayout constraintLayout5 = this.headerClick;
                    if (constraintLayout5 == null) {
                        Intrinsics.throwUninitializedPropertyAccessException("headerClick");
                        constraintLayout5 = null;
                    }
                    ViewKt.gone(constraintLayout5);
                    ConstraintLayout constraintLayout6 = this.noDataLayout;
                    if (constraintLayout6 == null) {
                        Intrinsics.throwUninitializedPropertyAccessException("noDataLayout");
                        constraintLayout6 = null;
                    }
                    ViewKt.visible(constraintLayout6);
                }
            } else {
                ConstraintLayout constraintLayout7 = this.noBinding;
                if (constraintLayout7 == null) {
                    Intrinsics.throwUninitializedPropertyAccessException("noBinding");
                    constraintLayout7 = null;
                }
                ViewKt.gone(constraintLayout7);
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
        imageView2.setOnClickListener(new View.OnClickListener() { // from class: com.qcwireless.qcwatch.ui.home.healthy.HealthyFragment$$ExternalSyntheticLambda8
            @Override // android.view.View.OnClickListener
            public final void onClick(View view2) {
                HealthyFragment.m720loadDataOnce$lambda7(HealthyFragment.this, view2);
            }
        });
        FragmentHealthyBinding fragmentHealthyBinding2 = this.binding;
        if (fragmentHealthyBinding2 == null) {
            Intrinsics.throwUninitializedPropertyAccessException("binding");
            fragmentHealthyBinding2 = null;
        }
        fragmentHealthyBinding2.tvProfile.setOnClickListener(new View.OnClickListener() { // from class: com.qcwireless.qcwatch.ui.home.healthy.HealthyFragment$$ExternalSyntheticLambda23
            @Override // android.view.View.OnClickListener
            public final void onClick(View view2) {
                HealthyFragment.m721loadDataOnce$lambda8(HealthyFragment.this, view2);
            }
        });
        FragmentHealthyBinding fragmentHealthyBinding3 = this.binding;
        if (fragmentHealthyBinding3 == null) {
            Intrinsics.throwUninitializedPropertyAccessException("binding");
            fragmentHealthyBinding3 = null;
        }
        fragmentHealthyBinding3.tvTarget.setOnClickListener(new View.OnClickListener() { // from class: com.qcwireless.qcwatch.ui.home.healthy.HealthyFragment$$ExternalSyntheticLambda6
            @Override // android.view.View.OnClickListener
            public final void onClick(View view2) {
                HealthyFragment.m722loadDataOnce$lambda9(HealthyFragment.this, view2);
            }
        });
        FragmentHealthyBinding fragmentHealthyBinding4 = this.binding;
        if (fragmentHealthyBinding4 == null) {
            Intrinsics.throwUninitializedPropertyAccessException("binding");
            fragmentHealthyBinding4 = null;
        }
        fragmentHealthyBinding4.tvSystem.setOnClickListener(new View.OnClickListener() { // from class: com.qcwireless.qcwatch.ui.home.healthy.HealthyFragment$$ExternalSyntheticLambda24
            @Override // android.view.View.OnClickListener
            public final void onClick(View view2) {
                HealthyFragment.m703loadDataOnce$lambda10(HealthyFragment.this, view2);
            }
        });
        FragmentHealthyBinding fragmentHealthyBinding5 = this.binding;
        if (fragmentHealthyBinding5 == null) {
            Intrinsics.throwUninitializedPropertyAccessException("binding");
            fragmentHealthyBinding5 = null;
        }
        fragmentHealthyBinding5.tvFaq.setOnClickListener(new View.OnClickListener() { // from class: com.qcwireless.qcwatch.ui.home.healthy.HealthyFragment$$ExternalSyntheticLambda7
            @Override // android.view.View.OnClickListener
            public final void onClick(View view2) {
                HealthyFragment.m704loadDataOnce$lambda12(HealthyFragment.this, view2);
            }
        });
        FragmentHealthyBinding fragmentHealthyBinding6 = this.binding;
        if (fragmentHealthyBinding6 == null) {
            Intrinsics.throwUninitializedPropertyAccessException("binding");
            fragmentHealthyBinding6 = null;
        }
        fragmentHealthyBinding6.tvAbout.setOnClickListener(new View.OnClickListener() { // from class: com.qcwireless.qcwatch.ui.home.healthy.HealthyFragment$$ExternalSyntheticLambda28
            @Override // android.view.View.OnClickListener
            public final void onClick(View view2) {
                HealthyFragment.m705loadDataOnce$lambda13(HealthyFragment.this, view2);
            }
        });
        imageView.setOnClickListener(new View.OnClickListener() { // from class: com.qcwireless.qcwatch.ui.home.healthy.HealthyFragment$$ExternalSyntheticLambda4
            @Override // android.view.View.OnClickListener
            public final void onClick(View view2) {
                HealthyFragment.m706loadDataOnce$lambda14(HealthyFragment.this, view2);
            }
        });
        TextView textView = this.todayDate;
        if (textView == null) {
            Intrinsics.throwUninitializedPropertyAccessException("todayDate");
            textView = null;
        }
        textView.setText(new DateUtil().getY_M_D());
        ImageView imageView3 = (ImageView) headerView.findViewById(R.id.image_right);
        try {
            if (UserConfig.INSTANCE.getInstance().getDeviceName().length() != 0) {
                z = false;
            }
            if (z) {
                ConstraintLayout constraintLayout8 = this.noBinding;
                if (constraintLayout8 == null) {
                    Intrinsics.throwUninitializedPropertyAccessException("noBinding");
                    constraintLayout8 = null;
                }
                ViewKt.visible(constraintLayout8);
            } else {
                ConstraintLayout constraintLayout9 = this.noBinding;
                if (constraintLayout9 == null) {
                    Intrinsics.throwUninitializedPropertyAccessException("noBinding");
                    constraintLayout9 = null;
                }
                ViewKt.gone(constraintLayout9);
            }
        } catch (Exception e2) {
            e2.printStackTrace();
        }
        imageView3.setOnClickListener(new View.OnClickListener() { // from class: com.qcwireless.qcwatch.ui.home.healthy.HealthyFragment$$ExternalSyntheticLambda3
            @Override // android.view.View.OnClickListener
            public final void onClick(View view2) {
                HealthyFragment.m707loadDataOnce$lambda15(HealthyFragment.this, view2);
            }
        });
        Button button = this.btnAdd;
        if (button == null) {
            Intrinsics.throwUninitializedPropertyAccessException("btnAdd");
            button = null;
        }
        button.setOnClickListener(new View.OnClickListener() { // from class: com.qcwireless.qcwatch.ui.home.healthy.HealthyFragment$$ExternalSyntheticLambda2
            @Override // android.view.View.OnClickListener
            public final void onClick(View view2) {
                HealthyFragment.m708loadDataOnce$lambda16(HealthyFragment.this, view2);
            }
        });
        MarqueeView marqueeView = this.marqueeView;
        if (marqueeView == null) {
            Intrinsics.throwUninitializedPropertyAccessException("marqueeView");
            marqueeView = null;
        }
        marqueeView.startFlipping();
        MarqueeView marqueeView2 = this.marqueeView;
        if (marqueeView2 == null) {
            Intrinsics.throwUninitializedPropertyAccessException("marqueeView");
            marqueeView2 = null;
        }
        marqueeView2.setOnItemClickListener(new MarqueeView.OnItemClickListener() { // from class: com.qcwireless.qcwatch.ui.home.healthy.HealthyFragment$$ExternalSyntheticLambda19
            @Override // com.qcwireless.qcwatch.ui.base.view.healthy.MarqueeView.OnItemClickListener
            public final void onItemClick(int i, TextView textView2) {
                HealthyFragment.m709loadDataOnce$lambda18(HealthyFragment.this, i, textView2);
            }
        });
        ConstraintLayout constraintLayout10 = this.noDataLayout;
        if (constraintLayout10 == null) {
            Intrinsics.throwUninitializedPropertyAccessException("noDataLayout");
            constraintLayout10 = null;
        }
        constraintLayout10.setOnClickListener(new View.OnClickListener() { // from class: com.qcwireless.qcwatch.ui.home.healthy.HealthyFragment$$ExternalSyntheticLambda5
            @Override // android.view.View.OnClickListener
            public final void onClick(View view2) {
                HealthyFragment.m711loadDataOnce$lambda19(HealthyFragment.this, view2);
            }
        });
        ConstraintLayout constraintLayout11 = this.headerClick;
        if (constraintLayout11 == null) {
            Intrinsics.throwUninitializedPropertyAccessException("headerClick");
            constraintLayout11 = null;
        }
        constraintLayout11.setOnClickListener(new View.OnClickListener() { // from class: com.qcwireless.qcwatch.ui.home.healthy.HealthyFragment$$ExternalSyntheticLambda26
            @Override // android.view.View.OnClickListener
            public final void onClick(View view2) {
                HealthyFragment.m712loadDataOnce$lambda20(HealthyFragment.this, view2);
            }
        });
        ImageView imageView4 = this.bleStatus;
        if (imageView4 == null) {
            Intrinsics.throwUninitializedPropertyAccessException("bleStatus");
            imageView4 = null;
        }
        imageView4.setOnClickListener(new View.OnClickListener() { // from class: com.qcwireless.qcwatch.ui.home.healthy.HealthyFragment$$ExternalSyntheticLambda29
            @Override // android.view.View.OnClickListener
            public final void onClick(View view2) {
                HealthyFragment.m713loadDataOnce$lambda21(HealthyFragment.this, view2);
            }
        });
        ((TextView) view.findViewById(R.id.healthy_tv_bottom_edit)).setOnClickListener(new View.OnClickListener() { // from class: com.qcwireless.qcwatch.ui.home.healthy.HealthyFragment$$ExternalSyntheticLambda27
            @Override // android.view.View.OnClickListener
            public final void onClick(View view2) {
                HealthyFragment.m714loadDataOnce$lambda22(HealthyFragment.this, view2);
            }
        });
        MultipleItemQuickAdapter multipleItemQuickAdapter2 = this.healthyAdapter;
        if (multipleItemQuickAdapter2 == null) {
            Intrinsics.throwUninitializedPropertyAccessException("healthyAdapter");
            multipleItemQuickAdapter2 = null;
        }
        Intrinsics.checkNotNullExpressionValue(view, "view");
        BaseQuickAdapter.addFooterView$default(multipleItemQuickAdapter2, view, 0, 0, 6, null);
        MultipleItemQuickAdapter multipleItemQuickAdapter3 = this.healthyAdapter;
        if (multipleItemQuickAdapter3 == null) {
            Intrinsics.throwUninitializedPropertyAccessException("healthyAdapter");
            multipleItemQuickAdapter3 = null;
        }
        Intrinsics.checkNotNullExpressionValue(headerView, "headerView");
        BaseQuickAdapter.addHeaderView$default(multipleItemQuickAdapter3, headerView, 0, 0, 6, null);
        final FragmentHealthyBinding fragmentHealthyBinding7 = this.binding;
        if (fragmentHealthyBinding7 == null) {
            Intrinsics.throwUninitializedPropertyAccessException("binding");
            fragmentHealthyBinding7 = null;
        }
        fragmentHealthyBinding7.healthyCardRcv.setLayoutManager(gridLayoutManager);
        MyRecycleView myRecycleView = fragmentHealthyBinding7.healthyCardRcv;
        MultipleItemQuickAdapter multipleItemQuickAdapter4 = this.healthyAdapter;
        if (multipleItemQuickAdapter4 == null) {
            Intrinsics.throwUninitializedPropertyAccessException("healthyAdapter");
            multipleItemQuickAdapter4 = null;
        }
        myRecycleView.setAdapter(multipleItemQuickAdapter4);
        fragmentHealthyBinding7.syncRefresh.setOnRefreshListener(new OnRefreshListener() { // from class: com.qcwireless.qcwatch.ui.home.healthy.HealthyFragment$$ExternalSyntheticLambda20
            @Override // com.scwang.smart.refresh.layout.listener.OnRefreshListener
            public final void onRefresh(RefreshLayout refreshLayout) {
                HealthyFragment.m715loadDataOnce$lambda24$lambda23(HealthyFragment.this, fragmentHealthyBinding7, refreshLayout);
            }
        });
        MultipleItemQuickAdapter multipleItemQuickAdapter5 = this.healthyAdapter;
        if (multipleItemQuickAdapter5 == null) {
            Intrinsics.throwUninitializedPropertyAccessException("healthyAdapter");
            multipleItemQuickAdapter5 = null;
        }
        HealthyFragment healthyFragment = this;
        multipleItemQuickAdapter5.getClickType().observe(healthyFragment, new Observer() { // from class: com.qcwireless.qcwatch.ui.home.healthy.HealthyFragment$$ExternalSyntheticLambda14
            @Override // androidx.lifecycle.Observer
            public final void onChanged(Object obj) {
                HealthyFragment.m716loadDataOnce$lambda26(HealthyFragment.this, (MeasureBean) obj);
            }
        });
        MultipleItemQuickAdapter multipleItemQuickAdapter6 = this.healthyAdapter;
        if (multipleItemQuickAdapter6 == null) {
            Intrinsics.throwUninitializedPropertyAccessException("healthyAdapter");
        } else {
            multipleItemQuickAdapter = multipleItemQuickAdapter6;
        }
        multipleItemQuickAdapter.setOnItemClickListener(new OnItemClickListener() { // from class: com.qcwireless.qcwatch.ui.home.healthy.HealthyFragment$$ExternalSyntheticLambda17
            @Override // com.chad.library.adapter.base.listener.OnItemClickListener
            public final void onItemClick(BaseQuickAdapter baseQuickAdapter, View view2, int i) {
                HealthyFragment.m717loadDataOnce$lambda27(HealthyFragment.this, baseQuickAdapter, view2, i);
            }
        });
        observe();
        getViewModel().syncTodayStepNotification();
        try {
            if (BleOperateManager.getInstance().isConnected()) {
                startSyncData();
            }
        } catch (Exception unused) {
        }
        this.handler.postDelayed(this.tenSecondsRefreshRunnable, 0L);
        DeviceViewModel deviceViewModel = getDeviceViewModel();
        deviceViewModel.init();
        deviceViewModel.getUiState().observe(healthyFragment, new Observer() { // from class: com.qcwireless.qcwatch.ui.home.healthy.HealthyFragment$$ExternalSyntheticLambda13
            @Override // androidx.lifecycle.Observer
            public final void onChanged(Object obj) {
                HealthyFragment.m718loadDataOnce$lambda29$lambda28(HealthyFragment.this, (DeviceViewModel.DeviceFragmentUI) obj);
            }
        });
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* renamed from: loadDataOnce$lambda-7, reason: not valid java name */
    public static final void m720loadDataOnce$lambda7(HealthyFragment this$0, View view) {
        Intrinsics.checkNotNullParameter(this$0, "this$0");
        FragmentHealthyBinding fragmentHealthyBinding = this$0.binding;
        if (fragmentHealthyBinding == null) {
            Intrinsics.throwUninitializedPropertyAccessException("binding");
            fragmentHealthyBinding = null;
        }
        NestedScrollView nestedScrollView = fragmentHealthyBinding.healthyCardNet;
        Intrinsics.checkNotNullExpressionValue(nestedScrollView, "binding.healthyCardNet");
        this$0.shareImage(this$0.saveScreenshotToStorage(this$0.takeScreenshot(nestedScrollView)));
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* renamed from: loadDataOnce$lambda-8, reason: not valid java name */
    public static final void m721loadDataOnce$lambda8(HealthyFragment this$0, View view) {
        Intrinsics.checkNotNullParameter(this$0, "this$0");
        if (!UserConfig.INSTANCE.getInstance().getLoginStatus()) {
            UserConfig.INSTANCE.getInstance().setUid(51668L);
            UserConfig.INSTANCE.getInstance().save();
        }
        HealthyFragment healthyFragment = this$0;
        FragmentActivity it = healthyFragment.getActivity();
        if (it != null) {
            ArrayList<Pair> arrayList = new ArrayList();
            Intrinsics.checkNotNullExpressionValue(it, "it");
            Intent intent = new Intent(it, (Class<?>) UserProfileActivity.class);
            for (Pair pair : arrayList) {
                if (pair != null) {
                    String str = (String) pair.getFirst();
                    Object second = pair.getSecond();
                    if (second instanceof Integer) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).intValue()), "putExtra(name, value)");
                    } else if (second instanceof Byte) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).byteValue()), "putExtra(name, value)");
                    } else if (second instanceof Character) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Character) second).charValue()), "putExtra(name, value)");
                    } else if (second instanceof Short) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).shortValue()), "putExtra(name, value)");
                    } else if (second instanceof Boolean) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Boolean) second).booleanValue()), "putExtra(name, value)");
                    } else if (second instanceof Long) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).longValue()), "putExtra(name, value)");
                    } else if (second instanceof Float) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).floatValue()), "putExtra(name, value)");
                    } else if (second instanceof Double) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).doubleValue()), "putExtra(name, value)");
                    } else if (second instanceof String) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (String) second), "putExtra(name, value)");
                    } else if (second instanceof CharSequence) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (CharSequence) second), "putExtra(name, value)");
                    } else if (second instanceof Parcelable) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Parcelable) second), "putExtra(name, value)");
                    } else if (second instanceof Object[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Serializable) second), "putExtra(name, value)");
                    } else if (second instanceof ArrayList) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Serializable) second), "putExtra(name, value)");
                    } else if (second instanceof Serializable) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Serializable) second), "putExtra(name, value)");
                    } else if (second instanceof boolean[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (boolean[]) second), "putExtra(name, value)");
                    } else if (second instanceof byte[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (byte[]) second), "putExtra(name, value)");
                    } else if (second instanceof short[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (short[]) second), "putExtra(name, value)");
                    } else if (second instanceof char[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (char[]) second), "putExtra(name, value)");
                    } else if (second instanceof int[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (int[]) second), "putExtra(name, value)");
                    } else if (second instanceof long[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (long[]) second), "putExtra(name, value)");
                    } else if (second instanceof float[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (float[]) second), "putExtra(name, value)");
                    } else if (second instanceof double[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (double[]) second), "putExtra(name, value)");
                    } else if (second instanceof Bundle) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Bundle) second), "putExtra(name, value)");
                    } else if (second instanceof Intent) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Parcelable) second), "putExtra(name, value)");
                    } else {
                        Unit unit = Unit.INSTANCE;
                    }
                }
            }
            healthyFragment.startActivity(intent);
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* renamed from: loadDataOnce$lambda-9, reason: not valid java name */
    public static final void m722loadDataOnce$lambda9(HealthyFragment this$0, View view) {
        Intrinsics.checkNotNullParameter(this$0, "this$0");
        if (!BleOperateManager.getInstance().isConnected()) {
            String string = this$0.getString(R.string.qc_text_75);
            Intrinsics.checkNotNullExpressionValue(string, "getString(R.string.qc_text_75)");
            GlobalKt.showToast$default(string, 0, 1, null);
            return;
        }
        HealthyFragment healthyFragment = this$0;
        FragmentActivity it = healthyFragment.getActivity();
        if (it != null) {
            ArrayList<Pair> arrayList = new ArrayList();
            Intrinsics.checkNotNullExpressionValue(it, "it");
            Intent intent = new Intent(it, (Class<?>) GoalSettingActivity.class);
            for (Pair pair : arrayList) {
                if (pair != null) {
                    String str = (String) pair.getFirst();
                    Object second = pair.getSecond();
                    if (second instanceof Integer) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).intValue()), "putExtra(name, value)");
                    } else if (second instanceof Byte) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).byteValue()), "putExtra(name, value)");
                    } else if (second instanceof Character) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Character) second).charValue()), "putExtra(name, value)");
                    } else if (second instanceof Short) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).shortValue()), "putExtra(name, value)");
                    } else if (second instanceof Boolean) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Boolean) second).booleanValue()), "putExtra(name, value)");
                    } else if (second instanceof Long) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).longValue()), "putExtra(name, value)");
                    } else if (second instanceof Float) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).floatValue()), "putExtra(name, value)");
                    } else if (second instanceof Double) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).doubleValue()), "putExtra(name, value)");
                    } else if (second instanceof String) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (String) second), "putExtra(name, value)");
                    } else if (second instanceof CharSequence) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (CharSequence) second), "putExtra(name, value)");
                    } else if (second instanceof Parcelable) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Parcelable) second), "putExtra(name, value)");
                    } else if (second instanceof Object[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Serializable) second), "putExtra(name, value)");
                    } else if (second instanceof ArrayList) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Serializable) second), "putExtra(name, value)");
                    } else if (second instanceof Serializable) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Serializable) second), "putExtra(name, value)");
                    } else if (second instanceof boolean[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (boolean[]) second), "putExtra(name, value)");
                    } else if (second instanceof byte[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (byte[]) second), "putExtra(name, value)");
                    } else if (second instanceof short[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (short[]) second), "putExtra(name, value)");
                    } else if (second instanceof char[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (char[]) second), "putExtra(name, value)");
                    } else if (second instanceof int[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (int[]) second), "putExtra(name, value)");
                    } else if (second instanceof long[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (long[]) second), "putExtra(name, value)");
                    } else if (second instanceof float[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (float[]) second), "putExtra(name, value)");
                    } else if (second instanceof double[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (double[]) second), "putExtra(name, value)");
                    } else if (second instanceof Bundle) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Bundle) second), "putExtra(name, value)");
                    } else if (second instanceof Intent) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Parcelable) second), "putExtra(name, value)");
                    } else {
                        Unit unit = Unit.INSTANCE;
                    }
                }
            }
            healthyFragment.startActivity(intent);
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* renamed from: loadDataOnce$lambda-10, reason: not valid java name */
    public static final void m703loadDataOnce$lambda10(HealthyFragment this$0, View view) {
        Intrinsics.checkNotNullParameter(this$0, "this$0");
        if (!BleOperateManager.getInstance().isConnected()) {
            String string = this$0.getString(R.string.qc_text_75);
            Intrinsics.checkNotNullExpressionValue(string, "getString(R.string.qc_text_75)");
            GlobalKt.showToast$default(string, 0, 1, null);
            return;
        }
        HealthyFragment healthyFragment = this$0;
        FragmentActivity it = healthyFragment.getActivity();
        if (it != null) {
            ArrayList<Pair> arrayList = new ArrayList();
            Intrinsics.checkNotNullExpressionValue(it, "it");
            Intent intent = new Intent(it, (Class<?>) SystemSettingActivity.class);
            for (Pair pair : arrayList) {
                if (pair != null) {
                    String str = (String) pair.getFirst();
                    Object second = pair.getSecond();
                    if (second instanceof Integer) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).intValue()), "putExtra(name, value)");
                    } else if (second instanceof Byte) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).byteValue()), "putExtra(name, value)");
                    } else if (second instanceof Character) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Character) second).charValue()), "putExtra(name, value)");
                    } else if (second instanceof Short) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).shortValue()), "putExtra(name, value)");
                    } else if (second instanceof Boolean) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Boolean) second).booleanValue()), "putExtra(name, value)");
                    } else if (second instanceof Long) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).longValue()), "putExtra(name, value)");
                    } else if (second instanceof Float) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).floatValue()), "putExtra(name, value)");
                    } else if (second instanceof Double) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).doubleValue()), "putExtra(name, value)");
                    } else if (second instanceof String) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (String) second), "putExtra(name, value)");
                    } else if (second instanceof CharSequence) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (CharSequence) second), "putExtra(name, value)");
                    } else if (second instanceof Parcelable) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Parcelable) second), "putExtra(name, value)");
                    } else if (second instanceof Object[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Serializable) second), "putExtra(name, value)");
                    } else if (second instanceof ArrayList) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Serializable) second), "putExtra(name, value)");
                    } else if (second instanceof Serializable) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Serializable) second), "putExtra(name, value)");
                    } else if (second instanceof boolean[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (boolean[]) second), "putExtra(name, value)");
                    } else if (second instanceof byte[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (byte[]) second), "putExtra(name, value)");
                    } else if (second instanceof short[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (short[]) second), "putExtra(name, value)");
                    } else if (second instanceof char[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (char[]) second), "putExtra(name, value)");
                    } else if (second instanceof int[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (int[]) second), "putExtra(name, value)");
                    } else if (second instanceof long[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (long[]) second), "putExtra(name, value)");
                    } else if (second instanceof float[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (float[]) second), "putExtra(name, value)");
                    } else if (second instanceof double[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (double[]) second), "putExtra(name, value)");
                    } else if (second instanceof Bundle) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Bundle) second), "putExtra(name, value)");
                    } else if (second instanceof Intent) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Parcelable) second), "putExtra(name, value)");
                    } else {
                        Unit unit = Unit.INSTANCE;
                    }
                }
            }
            healthyFragment.startActivity(intent);
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* renamed from: loadDataOnce$lambda-12, reason: not valid java name */
    public static final void m704loadDataOnce$lambda12(HealthyFragment this$0, View view) {
        String str;
        Intrinsics.checkNotNullParameter(this$0, "this$0");
        String language = Locale.getDefault().getLanguage();
        Intrinsics.checkNotNullExpressionValue(language, "language");
        String str2 = language;
        if (StringsKt.contains$default((CharSequence) str2, (CharSequence) "zh", false, 2, (Object) null)) {
            str = "https://api2.qcwxkjvip.com/questionWeb/qring2/index.html#/q_cn";
        } else if (StringsKt.contains$default((CharSequence) str2, (CharSequence) "es", false, 2, (Object) null)) {
            str = "https://api2.qcwxkjvip.com/questionWeb/qring2/index.html#/q_es";
        } else if (StringsKt.contains$default((CharSequence) str2, (CharSequence) "ja", false, 2, (Object) null)) {
            str = "https://api2.qcwxkjvip.com/questionWeb/qring2/index.html#/q_ja";
        } else if (StringsKt.contains$default((CharSequence) str2, (CharSequence) "de", false, 2, (Object) null)) {
            str = "https://api2.qcwxkjvip.com/questionWeb/qring2/index.html#/q_de";
        } else if (StringsKt.contains$default((CharSequence) str2, (CharSequence) Localization.language, false, 2, (Object) null)) {
            str = "https://api2.qcwxkjvip.com/questionWeb/qring2/index.html#/q_fr";
        } else if (StringsKt.contains$default((CharSequence) str2, (CharSequence) "cs", false, 2, (Object) null)) {
            str = "https://api2.qcwxkjvip.com/questionWeb/qring2/index.html#/q_cs";
        } else if (StringsKt.contains$default((CharSequence) str2, (CharSequence) "sk", false, 2, (Object) null)) {
            str = "https://api2.qcwxkjvip.com/questionWeb/qring2/index.html#/q_sk";
        } else if (StringsKt.contains$default((CharSequence) str2, (CharSequence) "hu", false, 2, (Object) null)) {
            str = "https://api2.qcwxkjvip.com/questionWeb/qring2/index.html#/q_hu";
        } else {
            str = StringsKt.contains$default((CharSequence) str2, (CharSequence) "pt", false, 2, (Object) null) ? "https://api2.qcwxkjvip.com/questionWeb/qring2/index.html#/q_pt" : "https://api2.qcwxkjvip.com/questionWeb/qring2/index.html#/q_en";
        }
        Bundle bundle = new Bundle();
        bundle.putString("url", str);
        HealthyFragment healthyFragment = this$0;
        FragmentActivity it = healthyFragment.getActivity();
        if (it != null) {
            ArrayList<Pair> arrayList = new ArrayList();
            Intrinsics.checkNotNullExpressionValue(it, "it");
            Intent intent = new Intent(it, (Class<?>) FQuestionActivity.class);
            intent.setFlags(1);
            intent.putExtras(bundle);
            for (Pair pair : arrayList) {
                if (pair != null) {
                    String str3 = (String) pair.getFirst();
                    Object second = pair.getSecond();
                    if (second instanceof Integer) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str3, ((Number) second).intValue()), "putExtra(name, value)");
                    } else if (second instanceof Byte) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str3, ((Number) second).byteValue()), "putExtra(name, value)");
                    } else if (second instanceof Character) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str3, ((Character) second).charValue()), "putExtra(name, value)");
                    } else if (second instanceof Short) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str3, ((Number) second).shortValue()), "putExtra(name, value)");
                    } else if (second instanceof Boolean) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str3, ((Boolean) second).booleanValue()), "putExtra(name, value)");
                    } else if (second instanceof Long) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str3, ((Number) second).longValue()), "putExtra(name, value)");
                    } else if (second instanceof Float) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str3, ((Number) second).floatValue()), "putExtra(name, value)");
                    } else if (second instanceof Double) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str3, ((Number) second).doubleValue()), "putExtra(name, value)");
                    } else if (second instanceof String) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str3, (String) second), "putExtra(name, value)");
                    } else if (second instanceof CharSequence) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str3, (CharSequence) second), "putExtra(name, value)");
                    } else if (second instanceof Parcelable) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str3, (Parcelable) second), "putExtra(name, value)");
                    } else if (second instanceof Object[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str3, (Serializable) second), "putExtra(name, value)");
                    } else if (second instanceof ArrayList) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str3, (Serializable) second), "putExtra(name, value)");
                    } else if (second instanceof Serializable) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str3, (Serializable) second), "putExtra(name, value)");
                    } else if (second instanceof boolean[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str3, (boolean[]) second), "putExtra(name, value)");
                    } else if (second instanceof byte[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str3, (byte[]) second), "putExtra(name, value)");
                    } else if (second instanceof short[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str3, (short[]) second), "putExtra(name, value)");
                    } else if (second instanceof char[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str3, (char[]) second), "putExtra(name, value)");
                    } else if (second instanceof int[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str3, (int[]) second), "putExtra(name, value)");
                    } else if (second instanceof long[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str3, (long[]) second), "putExtra(name, value)");
                    } else if (second instanceof float[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str3, (float[]) second), "putExtra(name, value)");
                    } else if (second instanceof double[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str3, (double[]) second), "putExtra(name, value)");
                    } else if (second instanceof Bundle) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str3, (Bundle) second), "putExtra(name, value)");
                    } else if (second instanceof Intent) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str3, (Parcelable) second), "putExtra(name, value)");
                    } else {
                        Unit unit = Unit.INSTANCE;
                    }
                }
            }
            healthyFragment.startActivity(intent);
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* renamed from: loadDataOnce$lambda-13, reason: not valid java name */
    public static final void m705loadDataOnce$lambda13(HealthyFragment this$0, View view) {
        Intrinsics.checkNotNullParameter(this$0, "this$0");
        HealthyFragment healthyFragment = this$0;
        FragmentActivity it = healthyFragment.getActivity();
        if (it != null) {
            ArrayList<Pair> arrayList = new ArrayList();
            Intrinsics.checkNotNullExpressionValue(it, "it");
            Intent intent = new Intent(it, (Class<?>) AboutActivity.class);
            for (Pair pair : arrayList) {
                if (pair != null) {
                    String str = (String) pair.getFirst();
                    Object second = pair.getSecond();
                    if (second instanceof Integer) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).intValue()), "putExtra(name, value)");
                    } else if (second instanceof Byte) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).byteValue()), "putExtra(name, value)");
                    } else if (second instanceof Character) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Character) second).charValue()), "putExtra(name, value)");
                    } else if (second instanceof Short) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).shortValue()), "putExtra(name, value)");
                    } else if (second instanceof Boolean) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Boolean) second).booleanValue()), "putExtra(name, value)");
                    } else if (second instanceof Long) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).longValue()), "putExtra(name, value)");
                    } else if (second instanceof Float) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).floatValue()), "putExtra(name, value)");
                    } else if (second instanceof Double) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).doubleValue()), "putExtra(name, value)");
                    } else if (second instanceof String) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (String) second), "putExtra(name, value)");
                    } else if (second instanceof CharSequence) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (CharSequence) second), "putExtra(name, value)");
                    } else if (second instanceof Parcelable) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Parcelable) second), "putExtra(name, value)");
                    } else if (second instanceof Object[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Serializable) second), "putExtra(name, value)");
                    } else if (second instanceof ArrayList) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Serializable) second), "putExtra(name, value)");
                    } else if (second instanceof Serializable) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Serializable) second), "putExtra(name, value)");
                    } else if (second instanceof boolean[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (boolean[]) second), "putExtra(name, value)");
                    } else if (second instanceof byte[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (byte[]) second), "putExtra(name, value)");
                    } else if (second instanceof short[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (short[]) second), "putExtra(name, value)");
                    } else if (second instanceof char[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (char[]) second), "putExtra(name, value)");
                    } else if (second instanceof int[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (int[]) second), "putExtra(name, value)");
                    } else if (second instanceof long[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (long[]) second), "putExtra(name, value)");
                    } else if (second instanceof float[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (float[]) second), "putExtra(name, value)");
                    } else if (second instanceof double[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (double[]) second), "putExtra(name, value)");
                    } else if (second instanceof Bundle) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Bundle) second), "putExtra(name, value)");
                    } else if (second instanceof Intent) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Parcelable) second), "putExtra(name, value)");
                    } else {
                        Unit unit = Unit.INSTANCE;
                    }
                }
            }
            healthyFragment.startActivity(intent);
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* renamed from: loadDataOnce$lambda-14, reason: not valid java name */
    public static final void m706loadDataOnce$lambda14(HealthyFragment this$0, View view) {
        Intrinsics.checkNotNullParameter(this$0, "this$0");
        FragmentHealthyBinding fragmentHealthyBinding = this$0.binding;
        if (fragmentHealthyBinding == null) {
            Intrinsics.throwUninitializedPropertyAccessException("binding");
            fragmentHealthyBinding = null;
        }
        fragmentHealthyBinding.drawerLayout.openDrawer(GravityCompat.START);
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* renamed from: loadDataOnce$lambda-15, reason: not valid java name */
    public static final void m707loadDataOnce$lambda15(HealthyFragment this$0, View view) {
        Intrinsics.checkNotNullParameter(this$0, "this$0");
        HealthyFragment healthyFragment = this$0;
        FragmentActivity it = healthyFragment.getActivity();
        if (it != null) {
            ArrayList<Pair> arrayList = new ArrayList();
            Intrinsics.checkNotNullExpressionValue(it, "it");
            Intent intent = new Intent(it, (Class<?>) BackgroundRunningGuideOneActivity.class);
            for (Pair pair : arrayList) {
                if (pair != null) {
                    String str = (String) pair.getFirst();
                    Object second = pair.getSecond();
                    if (second instanceof Integer) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).intValue()), "putExtra(name, value)");
                    } else if (second instanceof Byte) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).byteValue()), "putExtra(name, value)");
                    } else if (second instanceof Character) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Character) second).charValue()), "putExtra(name, value)");
                    } else if (second instanceof Short) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).shortValue()), "putExtra(name, value)");
                    } else if (second instanceof Boolean) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Boolean) second).booleanValue()), "putExtra(name, value)");
                    } else if (second instanceof Long) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).longValue()), "putExtra(name, value)");
                    } else if (second instanceof Float) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).floatValue()), "putExtra(name, value)");
                    } else if (second instanceof Double) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).doubleValue()), "putExtra(name, value)");
                    } else if (second instanceof String) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (String) second), "putExtra(name, value)");
                    } else if (second instanceof CharSequence) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (CharSequence) second), "putExtra(name, value)");
                    } else if (second instanceof Parcelable) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Parcelable) second), "putExtra(name, value)");
                    } else if (second instanceof Object[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Serializable) second), "putExtra(name, value)");
                    } else if (second instanceof ArrayList) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Serializable) second), "putExtra(name, value)");
                    } else if (second instanceof Serializable) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Serializable) second), "putExtra(name, value)");
                    } else if (second instanceof boolean[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (boolean[]) second), "putExtra(name, value)");
                    } else if (second instanceof byte[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (byte[]) second), "putExtra(name, value)");
                    } else if (second instanceof short[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (short[]) second), "putExtra(name, value)");
                    } else if (second instanceof char[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (char[]) second), "putExtra(name, value)");
                    } else if (second instanceof int[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (int[]) second), "putExtra(name, value)");
                    } else if (second instanceof long[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (long[]) second), "putExtra(name, value)");
                    } else if (second instanceof float[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (float[]) second), "putExtra(name, value)");
                    } else if (second instanceof double[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (double[]) second), "putExtra(name, value)");
                    } else if (second instanceof Bundle) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Bundle) second), "putExtra(name, value)");
                    } else if (second instanceof Intent) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Parcelable) second), "putExtra(name, value)");
                    } else {
                        Unit unit = Unit.INSTANCE;
                    }
                }
            }
            healthyFragment.startActivity(intent);
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* renamed from: loadDataOnce$lambda-16, reason: not valid java name */
    public static final void m708loadDataOnce$lambda16(HealthyFragment this$0, View view) {
        Intrinsics.checkNotNullParameter(this$0, "this$0");
        if (LocationUtils.isGPSEnable(this$0.getActivity())) {
            if (StringsKt.equals(Build.BRAND, "oppo", true)) {
                if (AndroidVersion.isAndroid12()) {
                    HealthyFragment healthyFragment = this$0;
                    FragmentActivity it = healthyFragment.getActivity();
                    if (it != null) {
                        ArrayList<Pair> arrayList = new ArrayList();
                        Intrinsics.checkNotNullExpressionValue(it, "it");
                        Intent intent = new Intent(it, (Class<?>) DeviceBindActivity.class);
                        for (Pair pair : arrayList) {
                            if (pair != null) {
                                String str = (String) pair.getFirst();
                                Object second = pair.getSecond();
                                if (second instanceof Integer) {
                                    Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).intValue()), "putExtra(name, value)");
                                } else if (second instanceof Byte) {
                                    Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).byteValue()), "putExtra(name, value)");
                                } else if (second instanceof Character) {
                                    Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Character) second).charValue()), "putExtra(name, value)");
                                } else if (second instanceof Short) {
                                    Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).shortValue()), "putExtra(name, value)");
                                } else if (second instanceof Boolean) {
                                    Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Boolean) second).booleanValue()), "putExtra(name, value)");
                                } else if (second instanceof Long) {
                                    Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).longValue()), "putExtra(name, value)");
                                } else if (second instanceof Float) {
                                    Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).floatValue()), "putExtra(name, value)");
                                } else if (second instanceof Double) {
                                    Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).doubleValue()), "putExtra(name, value)");
                                } else if (second instanceof String) {
                                    Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (String) second), "putExtra(name, value)");
                                } else if (second instanceof CharSequence) {
                                    Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (CharSequence) second), "putExtra(name, value)");
                                } else if (second instanceof Parcelable) {
                                    Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Parcelable) second), "putExtra(name, value)");
                                } else if (second instanceof Object[]) {
                                    Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Serializable) second), "putExtra(name, value)");
                                } else if (second instanceof ArrayList) {
                                    Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Serializable) second), "putExtra(name, value)");
                                } else if (second instanceof Serializable) {
                                    Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Serializable) second), "putExtra(name, value)");
                                } else if (second instanceof boolean[]) {
                                    Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (boolean[]) second), "putExtra(name, value)");
                                } else if (second instanceof byte[]) {
                                    Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (byte[]) second), "putExtra(name, value)");
                                } else if (second instanceof short[]) {
                                    Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (short[]) second), "putExtra(name, value)");
                                } else if (second instanceof char[]) {
                                    Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (char[]) second), "putExtra(name, value)");
                                } else if (second instanceof int[]) {
                                    Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (int[]) second), "putExtra(name, value)");
                                } else if (second instanceof long[]) {
                                    Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (long[]) second), "putExtra(name, value)");
                                } else if (second instanceof float[]) {
                                    Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (float[]) second), "putExtra(name, value)");
                                } else if (second instanceof double[]) {
                                    Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (double[]) second), "putExtra(name, value)");
                                } else if (second instanceof Bundle) {
                                    Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Bundle) second), "putExtra(name, value)");
                                } else if (second instanceof Intent) {
                                    Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Parcelable) second), "putExtra(name, value)");
                                } else {
                                    Unit unit = Unit.INSTANCE;
                                }
                            }
                        }
                        healthyFragment.startActivity(intent);
                        return;
                    }
                    return;
                }
                String language = Locale.getDefault().getLanguage();
                Intrinsics.checkNotNullExpressionValue(language, "language");
                if (StringsKt.startsWith$default(language, "zh", false, 2, (Object) null)) {
                    if (!UserConfig.INSTANCE.getInstance().getChinaOnly()) {
                        this$0.showChinaOnlyDialog();
                        return;
                    } else {
                        PermissionUtilKt.requestLocationPermission((FragmentActivity) this$0.getActivity(), new ScanLocationPermissionCallback());
                        return;
                    }
                }
                PermissionUtilKt.requestLocationPermission((FragmentActivity) this$0.getActivity(), new ScanLocationPermissionCallback());
                return;
            }
            String language2 = Locale.getDefault().getLanguage();
            Intrinsics.checkNotNullExpressionValue(language2, "language");
            if (StringsKt.startsWith$default(language2, "zh", false, 2, (Object) null)) {
                if (!UserConfig.INSTANCE.getInstance().getChinaOnly()) {
                    this$0.showChinaOnlyDialog();
                    return;
                } else {
                    PermissionUtilKt.requestLocationPermission((FragmentActivity) this$0.getActivity(), new ScanLocationPermissionCallback());
                    return;
                }
            }
            PermissionUtilKt.requestLocationPermission((FragmentActivity) this$0.getActivity(), new ScanLocationPermissionCallback());
            return;
        }
        String string = this$0.getString(R.string.qc_text_291);
        Intrinsics.checkNotNullExpressionValue(string, "getString(R.string.qc_text_291)");
        GlobalKt.showToast$default(string, 0, 1, null);
        this$0.startActivity(new Intent("android.settings.LOCATION_SOURCE_SETTINGS"));
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* renamed from: loadDataOnce$lambda-18, reason: not valid java name */
    public static final void m709loadDataOnce$lambda18(HealthyFragment this$0, int i, TextView textView) {
        Intrinsics.checkNotNullParameter(this$0, "this$0");
        if (StringsKt.equals(this$0.getString(R.string.qc_text_452), textView.getText().toString(), false)) {
            if (!this$0.isNotificationListenerEnabled()) {
                this$0.showNotificationDialog();
                return;
            }
            HealthyFragment healthyFragment = this$0;
            FragmentActivity it = healthyFragment.getActivity();
            if (it != null) {
                ArrayList<Pair> arrayList = new ArrayList();
                Intrinsics.checkNotNullExpressionValue(it, "it");
                Intent intent = new Intent(it, (Class<?>) MessagePushActivity.class);
                for (Pair pair : arrayList) {
                    if (pair != null) {
                        String str = (String) pair.getFirst();
                        Object second = pair.getSecond();
                        if (second instanceof Integer) {
                            Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).intValue()), "putExtra(name, value)");
                        } else if (second instanceof Byte) {
                            Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).byteValue()), "putExtra(name, value)");
                        } else if (second instanceof Character) {
                            Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Character) second).charValue()), "putExtra(name, value)");
                        } else if (second instanceof Short) {
                            Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).shortValue()), "putExtra(name, value)");
                        } else if (second instanceof Boolean) {
                            Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Boolean) second).booleanValue()), "putExtra(name, value)");
                        } else if (second instanceof Long) {
                            Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).longValue()), "putExtra(name, value)");
                        } else if (second instanceof Float) {
                            Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).floatValue()), "putExtra(name, value)");
                        } else if (second instanceof Double) {
                            Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).doubleValue()), "putExtra(name, value)");
                        } else if (second instanceof String) {
                            Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (String) second), "putExtra(name, value)");
                        } else if (second instanceof CharSequence) {
                            Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (CharSequence) second), "putExtra(name, value)");
                        } else if (second instanceof Parcelable) {
                            Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Parcelable) second), "putExtra(name, value)");
                        } else if (second instanceof Object[]) {
                            Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Serializable) second), "putExtra(name, value)");
                        } else if (second instanceof ArrayList) {
                            Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Serializable) second), "putExtra(name, value)");
                        } else if (second instanceof Serializable) {
                            Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Serializable) second), "putExtra(name, value)");
                        } else if (second instanceof boolean[]) {
                            Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (boolean[]) second), "putExtra(name, value)");
                        } else if (second instanceof byte[]) {
                            Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (byte[]) second), "putExtra(name, value)");
                        } else if (second instanceof short[]) {
                            Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (short[]) second), "putExtra(name, value)");
                        } else if (second instanceof char[]) {
                            Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (char[]) second), "putExtra(name, value)");
                        } else if (second instanceof int[]) {
                            Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (int[]) second), "putExtra(name, value)");
                        } else if (second instanceof long[]) {
                            Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (long[]) second), "putExtra(name, value)");
                        } else if (second instanceof float[]) {
                            Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (float[]) second), "putExtra(name, value)");
                        } else if (second instanceof double[]) {
                            Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (double[]) second), "putExtra(name, value)");
                        } else if (second instanceof Bundle) {
                            Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Bundle) second), "putExtra(name, value)");
                        } else if (second instanceof Intent) {
                            Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Parcelable) second), "putExtra(name, value)");
                        } else {
                            Unit unit = Unit.INSTANCE;
                        }
                    }
                }
                healthyFragment.startActivity(intent);
                return;
            }
            return;
        }
        if (StringsKt.equals(this$0.getString(R.string.qc_text_451), textView.getText().toString(), false)) {
            PermissionUtilKt.requestCallPhonePermission((FragmentActivity) this$0.getActivity(), new OnPermissionCallback() { // from class: com.qcwireless.qcwatch.ui.home.healthy.HealthyFragment$$ExternalSyntheticLambda18
                @Override // com.hjq.permissions.OnPermissionCallback
                public /* synthetic */ void onDenied(List list, boolean z) {
                    OnPermissionCallback.CC.$default$onDenied(this, list, z);
                }

                @Override // com.hjq.permissions.OnPermissionCallback
                public final void onGranted(List list, boolean z) {
                    HealthyFragment.m710loadDataOnce$lambda18$lambda17(list, z);
                }
            });
            return;
        }
        HealthyFragment healthyFragment2 = this$0;
        FragmentActivity it2 = healthyFragment2.getActivity();
        if (it2 != null) {
            ArrayList<Pair> arrayList2 = new ArrayList();
            Intrinsics.checkNotNullExpressionValue(it2, "it");
            Intent intent2 = new Intent(it2, (Class<?>) BackgroundRunningGuideOneActivity.class);
            for (Pair pair2 : arrayList2) {
                if (pair2 != null) {
                    String str2 = (String) pair2.getFirst();
                    Object second2 = pair2.getSecond();
                    if (second2 instanceof Integer) {
                        Intrinsics.checkNotNullExpressionValue(intent2.putExtra(str2, ((Number) second2).intValue()), "putExtra(name, value)");
                    } else if (second2 instanceof Byte) {
                        Intrinsics.checkNotNullExpressionValue(intent2.putExtra(str2, ((Number) second2).byteValue()), "putExtra(name, value)");
                    } else if (second2 instanceof Character) {
                        Intrinsics.checkNotNullExpressionValue(intent2.putExtra(str2, ((Character) second2).charValue()), "putExtra(name, value)");
                    } else if (second2 instanceof Short) {
                        Intrinsics.checkNotNullExpressionValue(intent2.putExtra(str2, ((Number) second2).shortValue()), "putExtra(name, value)");
                    } else if (second2 instanceof Boolean) {
                        Intrinsics.checkNotNullExpressionValue(intent2.putExtra(str2, ((Boolean) second2).booleanValue()), "putExtra(name, value)");
                    } else if (second2 instanceof Long) {
                        Intrinsics.checkNotNullExpressionValue(intent2.putExtra(str2, ((Number) second2).longValue()), "putExtra(name, value)");
                    } else if (second2 instanceof Float) {
                        Intrinsics.checkNotNullExpressionValue(intent2.putExtra(str2, ((Number) second2).floatValue()), "putExtra(name, value)");
                    } else if (second2 instanceof Double) {
                        Intrinsics.checkNotNullExpressionValue(intent2.putExtra(str2, ((Number) second2).doubleValue()), "putExtra(name, value)");
                    } else if (second2 instanceof String) {
                        Intrinsics.checkNotNullExpressionValue(intent2.putExtra(str2, (String) second2), "putExtra(name, value)");
                    } else if (second2 instanceof CharSequence) {
                        Intrinsics.checkNotNullExpressionValue(intent2.putExtra(str2, (CharSequence) second2), "putExtra(name, value)");
                    } else if (second2 instanceof Parcelable) {
                        Intrinsics.checkNotNullExpressionValue(intent2.putExtra(str2, (Parcelable) second2), "putExtra(name, value)");
                    } else if (second2 instanceof Object[]) {
                        Intrinsics.checkNotNullExpressionValue(intent2.putExtra(str2, (Serializable) second2), "putExtra(name, value)");
                    } else if (second2 instanceof ArrayList) {
                        Intrinsics.checkNotNullExpressionValue(intent2.putExtra(str2, (Serializable) second2), "putExtra(name, value)");
                    } else if (second2 instanceof Serializable) {
                        Intrinsics.checkNotNullExpressionValue(intent2.putExtra(str2, (Serializable) second2), "putExtra(name, value)");
                    } else if (second2 instanceof boolean[]) {
                        Intrinsics.checkNotNullExpressionValue(intent2.putExtra(str2, (boolean[]) second2), "putExtra(name, value)");
                    } else if (second2 instanceof byte[]) {
                        Intrinsics.checkNotNullExpressionValue(intent2.putExtra(str2, (byte[]) second2), "putExtra(name, value)");
                    } else if (second2 instanceof short[]) {
                        Intrinsics.checkNotNullExpressionValue(intent2.putExtra(str2, (short[]) second2), "putExtra(name, value)");
                    } else if (second2 instanceof char[]) {
                        Intrinsics.checkNotNullExpressionValue(intent2.putExtra(str2, (char[]) second2), "putExtra(name, value)");
                    } else if (second2 instanceof int[]) {
                        Intrinsics.checkNotNullExpressionValue(intent2.putExtra(str2, (int[]) second2), "putExtra(name, value)");
                    } else if (second2 instanceof long[]) {
                        Intrinsics.checkNotNullExpressionValue(intent2.putExtra(str2, (long[]) second2), "putExtra(name, value)");
                    } else if (second2 instanceof float[]) {
                        Intrinsics.checkNotNullExpressionValue(intent2.putExtra(str2, (float[]) second2), "putExtra(name, value)");
                    } else if (second2 instanceof double[]) {
                        Intrinsics.checkNotNullExpressionValue(intent2.putExtra(str2, (double[]) second2), "putExtra(name, value)");
                    } else if (second2 instanceof Bundle) {
                        Intrinsics.checkNotNullExpressionValue(intent2.putExtra(str2, (Bundle) second2), "putExtra(name, value)");
                    } else if (second2 instanceof Intent) {
                        Intrinsics.checkNotNullExpressionValue(intent2.putExtra(str2, (Parcelable) second2), "putExtra(name, value)");
                    } else {
                        Unit unit2 = Unit.INSTANCE;
                    }
                }
            }
            healthyFragment2.startActivity(intent2);
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* renamed from: loadDataOnce$lambda-18$lambda-17, reason: not valid java name */
    public static final void m710loadDataOnce$lambda18$lambda17(List list, boolean z) {
        Intrinsics.checkNotNullParameter(list, "<anonymous parameter 0>");
        if (z) {
            BuildersKt__Builders_commonKt.launch$default(GlobalScope.INSTANCE, null, null, new HealthyFragment$loadDataOnce$11$1$1(null), 3, null);
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* renamed from: loadDataOnce$lambda-19, reason: not valid java name */
    public static final void m711loadDataOnce$lambda19(HealthyFragment this$0, View view) {
        Intrinsics.checkNotNullParameter(this$0, "this$0");
        HealthyFragment healthyFragment = this$0;
        FragmentActivity it = healthyFragment.getActivity();
        if (it != null) {
            ArrayList<Pair> arrayList = new ArrayList();
            Intrinsics.checkNotNullExpressionValue(it, "it");
            Intent intent = new Intent(it, (Class<?>) StepActivity.class);
            for (Pair pair : arrayList) {
                if (pair != null) {
                    String str = (String) pair.getFirst();
                    Object second = pair.getSecond();
                    if (second instanceof Integer) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).intValue()), "putExtra(name, value)");
                    } else if (second instanceof Byte) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).byteValue()), "putExtra(name, value)");
                    } else if (second instanceof Character) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Character) second).charValue()), "putExtra(name, value)");
                    } else if (second instanceof Short) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).shortValue()), "putExtra(name, value)");
                    } else if (second instanceof Boolean) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Boolean) second).booleanValue()), "putExtra(name, value)");
                    } else if (second instanceof Long) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).longValue()), "putExtra(name, value)");
                    } else if (second instanceof Float) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).floatValue()), "putExtra(name, value)");
                    } else if (second instanceof Double) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).doubleValue()), "putExtra(name, value)");
                    } else if (second instanceof String) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (String) second), "putExtra(name, value)");
                    } else if (second instanceof CharSequence) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (CharSequence) second), "putExtra(name, value)");
                    } else if (second instanceof Parcelable) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Parcelable) second), "putExtra(name, value)");
                    } else if (second instanceof Object[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Serializable) second), "putExtra(name, value)");
                    } else if (second instanceof ArrayList) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Serializable) second), "putExtra(name, value)");
                    } else if (second instanceof Serializable) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Serializable) second), "putExtra(name, value)");
                    } else if (second instanceof boolean[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (boolean[]) second), "putExtra(name, value)");
                    } else if (second instanceof byte[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (byte[]) second), "putExtra(name, value)");
                    } else if (second instanceof short[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (short[]) second), "putExtra(name, value)");
                    } else if (second instanceof char[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (char[]) second), "putExtra(name, value)");
                    } else if (second instanceof int[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (int[]) second), "putExtra(name, value)");
                    } else if (second instanceof long[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (long[]) second), "putExtra(name, value)");
                    } else if (second instanceof float[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (float[]) second), "putExtra(name, value)");
                    } else if (second instanceof double[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (double[]) second), "putExtra(name, value)");
                    } else if (second instanceof Bundle) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Bundle) second), "putExtra(name, value)");
                    } else if (second instanceof Intent) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Parcelable) second), "putExtra(name, value)");
                    } else {
                        Unit unit = Unit.INSTANCE;
                    }
                }
            }
            healthyFragment.startActivity(intent);
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* renamed from: loadDataOnce$lambda-20, reason: not valid java name */
    public static final void m712loadDataOnce$lambda20(HealthyFragment this$0, View view) {
        Intrinsics.checkNotNullParameter(this$0, "this$0");
        HealthyFragment healthyFragment = this$0;
        FragmentActivity it = healthyFragment.getActivity();
        if (it != null) {
            ArrayList<Pair> arrayList = new ArrayList();
            Intrinsics.checkNotNullExpressionValue(it, "it");
            Intent intent = new Intent(it, (Class<?>) StepActivity.class);
            for (Pair pair : arrayList) {
                if (pair != null) {
                    String str = (String) pair.getFirst();
                    Object second = pair.getSecond();
                    if (second instanceof Integer) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).intValue()), "putExtra(name, value)");
                    } else if (second instanceof Byte) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).byteValue()), "putExtra(name, value)");
                    } else if (second instanceof Character) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Character) second).charValue()), "putExtra(name, value)");
                    } else if (second instanceof Short) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).shortValue()), "putExtra(name, value)");
                    } else if (second instanceof Boolean) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Boolean) second).booleanValue()), "putExtra(name, value)");
                    } else if (second instanceof Long) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).longValue()), "putExtra(name, value)");
                    } else if (second instanceof Float) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).floatValue()), "putExtra(name, value)");
                    } else if (second instanceof Double) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).doubleValue()), "putExtra(name, value)");
                    } else if (second instanceof String) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (String) second), "putExtra(name, value)");
                    } else if (second instanceof CharSequence) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (CharSequence) second), "putExtra(name, value)");
                    } else if (second instanceof Parcelable) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Parcelable) second), "putExtra(name, value)");
                    } else if (second instanceof Object[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Serializable) second), "putExtra(name, value)");
                    } else if (second instanceof ArrayList) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Serializable) second), "putExtra(name, value)");
                    } else if (second instanceof Serializable) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Serializable) second), "putExtra(name, value)");
                    } else if (second instanceof boolean[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (boolean[]) second), "putExtra(name, value)");
                    } else if (second instanceof byte[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (byte[]) second), "putExtra(name, value)");
                    } else if (second instanceof short[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (short[]) second), "putExtra(name, value)");
                    } else if (second instanceof char[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (char[]) second), "putExtra(name, value)");
                    } else if (second instanceof int[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (int[]) second), "putExtra(name, value)");
                    } else if (second instanceof long[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (long[]) second), "putExtra(name, value)");
                    } else if (second instanceof float[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (float[]) second), "putExtra(name, value)");
                    } else if (second instanceof double[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (double[]) second), "putExtra(name, value)");
                    } else if (second instanceof Bundle) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Bundle) second), "putExtra(name, value)");
                    } else if (second instanceof Intent) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Parcelable) second), "putExtra(name, value)");
                    } else {
                        Unit unit = Unit.INSTANCE;
                    }
                }
            }
            healthyFragment.startActivity(intent);
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* renamed from: loadDataOnce$lambda-21, reason: not valid java name */
    public static final void m713loadDataOnce$lambda21(HealthyFragment this$0, View view) {
        Intrinsics.checkNotNullParameter(this$0, "this$0");
        if (!BleOperateManager.getInstance().isConnected()) {
            ThreadManager.getInstance().reSetLastConnectTime(0);
            ThreadManager.getInstance().wakeUpNotWait();
        } else {
            this$0.startSyncData();
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* renamed from: loadDataOnce$lambda-22, reason: not valid java name */
    public static final void m714loadDataOnce$lambda22(HealthyFragment this$0, View view) {
        Intrinsics.checkNotNullParameter(this$0, "this$0");
        DragSelectActivity.INSTANCE.start(this$0.getActivity());
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* renamed from: loadDataOnce$lambda-24$lambda-23, reason: not valid java name */
    public static final void m715loadDataOnce$lambda24$lambda23(HealthyFragment this$0, FragmentHealthyBinding this_run, RefreshLayout it) {
        Intrinsics.checkNotNullParameter(this$0, "this$0");
        Intrinsics.checkNotNullParameter(this_run, "$this_run");
        Intrinsics.checkNotNullParameter(it, "it");
        if (!BleOperateManager.getInstance().isConnected()) {
            String string = this$0.getString(R.string.qc_text_75);
            Intrinsics.checkNotNullExpressionValue(string, "getString(R.string.qc_text_75)");
            GlobalKt.showToast$default(string, 0, 1, null);
            this_run.syncRefresh.finishRefresh(false);
            this$0.stopRotationAnimation();
            return;
        }
        AwLog.i(Author.HeZhiYuan, "下拉刷新,开始同步数据...");
        this$0.getViewModel().syncWatchData();
        SyncStatus.INSTANCE.getGetInstance().setSync(true);
        this$0.handler.removeCallbacks(this$0.myRunnable);
        this$0.handler.postDelayed(this$0.myRunnable, 13000L);
        this$0.startRotationAnimation();
        LogToFile.getInstance().wtf("开始同步所有数据");
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* renamed from: loadDataOnce$lambda-26, reason: not valid java name */
    public static final void m716loadDataOnce$lambda26(HealthyFragment this$0, MeasureBean measureBean) {
        Intrinsics.checkNotNullParameter(this$0, "this$0");
        measureBean.getStart();
        if (measureBean.getType() == 8) {
            if (this$0.sportRunning) {
                Bundle bundle = new Bundle();
                bundle.putInt("sportType", this$0.sportType);
                bundle.putInt("sportStatus", this$0.sportStatus);
                bundle.putInt(FitnessActivities.RUNNING, -1);
                this$0.sportRunning = false;
                HealthyFragment healthyFragment = this$0;
                FragmentActivity it = healthyFragment.getActivity();
                if (it != null) {
                    ArrayList<Pair> arrayList = new ArrayList();
                    Intrinsics.checkNotNullExpressionValue(it, "it");
                    Intent intent = new Intent(it, (Class<?>) SportRunningActivity.class);
                    intent.setFlags(1);
                    intent.putExtras(bundle);
                    for (Pair pair : arrayList) {
                        if (pair != null) {
                            String str = (String) pair.getFirst();
                            Object second = pair.getSecond();
                            if (second instanceof Integer) {
                                Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).intValue()), "putExtra(name, value)");
                            } else if (second instanceof Byte) {
                                Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).byteValue()), "putExtra(name, value)");
                            } else if (second instanceof Character) {
                                Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Character) second).charValue()), "putExtra(name, value)");
                            } else if (second instanceof Short) {
                                Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).shortValue()), "putExtra(name, value)");
                            } else if (second instanceof Boolean) {
                                Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Boolean) second).booleanValue()), "putExtra(name, value)");
                            } else if (second instanceof Long) {
                                Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).longValue()), "putExtra(name, value)");
                            } else if (second instanceof Float) {
                                Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).floatValue()), "putExtra(name, value)");
                            } else if (second instanceof Double) {
                                Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).doubleValue()), "putExtra(name, value)");
                            } else if (second instanceof String) {
                                Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (String) second), "putExtra(name, value)");
                            } else if (second instanceof CharSequence) {
                                Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (CharSequence) second), "putExtra(name, value)");
                            } else if (second instanceof Parcelable) {
                                Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Parcelable) second), "putExtra(name, value)");
                            } else if (second instanceof Object[]) {
                                Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Serializable) second), "putExtra(name, value)");
                            } else if (second instanceof ArrayList) {
                                Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Serializable) second), "putExtra(name, value)");
                            } else if (second instanceof Serializable) {
                                Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Serializable) second), "putExtra(name, value)");
                            } else if (second instanceof boolean[]) {
                                Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (boolean[]) second), "putExtra(name, value)");
                            } else if (second instanceof byte[]) {
                                Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (byte[]) second), "putExtra(name, value)");
                            } else if (second instanceof short[]) {
                                Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (short[]) second), "putExtra(name, value)");
                            } else if (second instanceof char[]) {
                                Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (char[]) second), "putExtra(name, value)");
                            } else if (second instanceof int[]) {
                                Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (int[]) second), "putExtra(name, value)");
                            } else if (second instanceof long[]) {
                                Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (long[]) second), "putExtra(name, value)");
                            } else if (second instanceof float[]) {
                                Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (float[]) second), "putExtra(name, value)");
                            } else if (second instanceof double[]) {
                                Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (double[]) second), "putExtra(name, value)");
                            } else if (second instanceof Bundle) {
                                Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Bundle) second), "putExtra(name, value)");
                            } else if (second instanceof Intent) {
                                Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Parcelable) second), "putExtra(name, value)");
                            } else {
                                Unit unit = Unit.INSTANCE;
                            }
                        }
                    }
                    healthyFragment.startActivity(intent);
                    return;
                }
                return;
            }
            this$0.sportRunning = false;
            HealthyFragment healthyFragment2 = this$0;
            FragmentActivity it2 = healthyFragment2.getActivity();
            if (it2 != null) {
                ArrayList<Pair> arrayList2 = new ArrayList();
                Intrinsics.checkNotNullExpressionValue(it2, "it");
                Intent intent2 = new Intent(it2, (Class<?>) SportGoActivity.class);
                for (Pair pair2 : arrayList2) {
                    if (pair2 != null) {
                        String str2 = (String) pair2.getFirst();
                        Object second2 = pair2.getSecond();
                        if (second2 instanceof Integer) {
                            Intrinsics.checkNotNullExpressionValue(intent2.putExtra(str2, ((Number) second2).intValue()), "putExtra(name, value)");
                        } else if (second2 instanceof Byte) {
                            Intrinsics.checkNotNullExpressionValue(intent2.putExtra(str2, ((Number) second2).byteValue()), "putExtra(name, value)");
                        } else if (second2 instanceof Character) {
                            Intrinsics.checkNotNullExpressionValue(intent2.putExtra(str2, ((Character) second2).charValue()), "putExtra(name, value)");
                        } else if (second2 instanceof Short) {
                            Intrinsics.checkNotNullExpressionValue(intent2.putExtra(str2, ((Number) second2).shortValue()), "putExtra(name, value)");
                        } else if (second2 instanceof Boolean) {
                            Intrinsics.checkNotNullExpressionValue(intent2.putExtra(str2, ((Boolean) second2).booleanValue()), "putExtra(name, value)");
                        } else if (second2 instanceof Long) {
                            Intrinsics.checkNotNullExpressionValue(intent2.putExtra(str2, ((Number) second2).longValue()), "putExtra(name, value)");
                        } else if (second2 instanceof Float) {
                            Intrinsics.checkNotNullExpressionValue(intent2.putExtra(str2, ((Number) second2).floatValue()), "putExtra(name, value)");
                        } else if (second2 instanceof Double) {
                            Intrinsics.checkNotNullExpressionValue(intent2.putExtra(str2, ((Number) second2).doubleValue()), "putExtra(name, value)");
                        } else if (second2 instanceof String) {
                            Intrinsics.checkNotNullExpressionValue(intent2.putExtra(str2, (String) second2), "putExtra(name, value)");
                        } else if (second2 instanceof CharSequence) {
                            Intrinsics.checkNotNullExpressionValue(intent2.putExtra(str2, (CharSequence) second2), "putExtra(name, value)");
                        } else if (second2 instanceof Parcelable) {
                            Intrinsics.checkNotNullExpressionValue(intent2.putExtra(str2, (Parcelable) second2), "putExtra(name, value)");
                        } else if (second2 instanceof Object[]) {
                            Intrinsics.checkNotNullExpressionValue(intent2.putExtra(str2, (Serializable) second2), "putExtra(name, value)");
                        } else if (second2 instanceof ArrayList) {
                            Intrinsics.checkNotNullExpressionValue(intent2.putExtra(str2, (Serializable) second2), "putExtra(name, value)");
                        } else if (second2 instanceof Serializable) {
                            Intrinsics.checkNotNullExpressionValue(intent2.putExtra(str2, (Serializable) second2), "putExtra(name, value)");
                        } else if (second2 instanceof boolean[]) {
                            Intrinsics.checkNotNullExpressionValue(intent2.putExtra(str2, (boolean[]) second2), "putExtra(name, value)");
                        } else if (second2 instanceof byte[]) {
                            Intrinsics.checkNotNullExpressionValue(intent2.putExtra(str2, (byte[]) second2), "putExtra(name, value)");
                        } else if (second2 instanceof short[]) {
                            Intrinsics.checkNotNullExpressionValue(intent2.putExtra(str2, (short[]) second2), "putExtra(name, value)");
                        } else if (second2 instanceof char[]) {
                            Intrinsics.checkNotNullExpressionValue(intent2.putExtra(str2, (char[]) second2), "putExtra(name, value)");
                        } else if (second2 instanceof int[]) {
                            Intrinsics.checkNotNullExpressionValue(intent2.putExtra(str2, (int[]) second2), "putExtra(name, value)");
                        } else if (second2 instanceof long[]) {
                            Intrinsics.checkNotNullExpressionValue(intent2.putExtra(str2, (long[]) second2), "putExtra(name, value)");
                        } else if (second2 instanceof float[]) {
                            Intrinsics.checkNotNullExpressionValue(intent2.putExtra(str2, (float[]) second2), "putExtra(name, value)");
                        } else if (second2 instanceof double[]) {
                            Intrinsics.checkNotNullExpressionValue(intent2.putExtra(str2, (double[]) second2), "putExtra(name, value)");
                        } else if (second2 instanceof Bundle) {
                            Intrinsics.checkNotNullExpressionValue(intent2.putExtra(str2, (Bundle) second2), "putExtra(name, value)");
                        } else if (second2 instanceof Intent) {
                            Intrinsics.checkNotNullExpressionValue(intent2.putExtra(str2, (Parcelable) second2), "putExtra(name, value)");
                        } else {
                            Unit unit2 = Unit.INSTANCE;
                        }
                    }
                }
                healthyFragment2.startActivity(intent2);
            }
        }
    }

    /*  JADX ERROR: JadxRuntimeException in pass: BlockProcessor
        jadx.core.utils.exceptions.JadxRuntimeException: CFG modification limit reached, blocks count: 1083
        	at jadx.core.dex.visitors.blocks.BlockProcessor.processBlocksTree(BlockProcessor.java:64)
        	at jadx.core.dex.visitors.blocks.BlockProcessor.visit(BlockProcessor.java:44)
        */
    /* JADX INFO: Access modifiers changed from: private */
    /* renamed from: loadDataOnce$lambda-27, reason: not valid java name */
    public static final void m717loadDataOnce$lambda27(com.qcwireless.qcwatch.ui.home.healthy.HealthyFragment r4, com.chad.library.adapter.base.BaseQuickAdapter r5, android.view.View r6, int r7) {
        /*
            Method dump skipped, instructions count: 4692
            To view this dump change 'Code comments level' option to 'DEBUG'
        */
        throw new UnsupportedOperationException("Method not decompiled: com.qcwireless.qcwatch.ui.home.healthy.HealthyFragment.m717loadDataOnce$lambda27(com.qcwireless.qcwatch.ui.home.healthy.HealthyFragment, com.chad.library.adapter.base.BaseQuickAdapter, android.view.View, int):void");
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* renamed from: loadDataOnce$lambda-29$lambda-28, reason: not valid java name */
    public static final void m718loadDataOnce$lambda29$lambda28(HealthyFragment this$0, DeviceViewModel.DeviceFragmentUI deviceFragmentUI) {
        HealthyFragment healthyFragment;
        FragmentActivity it;
        Intrinsics.checkNotNullParameter(this$0, "this$0");
        if (deviceFragmentUI.getRefreshType() == 2) {
            AwLog.i(Author.HeZhiYuan, deviceFragmentUI);
            if (BleOperateManager.getInstance().isConnected() && deviceFragmentUI.getDfuType() == 2 && (it = (healthyFragment = this$0).getActivity()) != null) {
                ArrayList<Pair> arrayList = new ArrayList();
                Intrinsics.checkNotNullExpressionValue(it, "it");
                Intent intent = new Intent(it, (Class<?>) DeviceFirmwareUpdateActivity.class);
                for (Pair pair : arrayList) {
                    if (pair != null) {
                        String str = (String) pair.getFirst();
                        Object second = pair.getSecond();
                        if (second instanceof Integer) {
                            Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).intValue()), "putExtra(name, value)");
                        } else if (second instanceof Byte) {
                            Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).byteValue()), "putExtra(name, value)");
                        } else if (second instanceof Character) {
                            Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Character) second).charValue()), "putExtra(name, value)");
                        } else if (second instanceof Short) {
                            Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).shortValue()), "putExtra(name, value)");
                        } else if (second instanceof Boolean) {
                            Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Boolean) second).booleanValue()), "putExtra(name, value)");
                        } else if (second instanceof Long) {
                            Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).longValue()), "putExtra(name, value)");
                        } else if (second instanceof Float) {
                            Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).floatValue()), "putExtra(name, value)");
                        } else if (second instanceof Double) {
                            Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).doubleValue()), "putExtra(name, value)");
                        } else if (second instanceof String) {
                            Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (String) second), "putExtra(name, value)");
                        } else if (second instanceof CharSequence) {
                            Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (CharSequence) second), "putExtra(name, value)");
                        } else if (second instanceof Parcelable) {
                            Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Parcelable) second), "putExtra(name, value)");
                        } else if (second instanceof Object[]) {
                            Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Serializable) second), "putExtra(name, value)");
                        } else if (second instanceof ArrayList) {
                            Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Serializable) second), "putExtra(name, value)");
                        } else if (second instanceof Serializable) {
                            Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Serializable) second), "putExtra(name, value)");
                        } else if (second instanceof boolean[]) {
                            Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (boolean[]) second), "putExtra(name, value)");
                        } else if (second instanceof byte[]) {
                            Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (byte[]) second), "putExtra(name, value)");
                        } else if (second instanceof short[]) {
                            Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (short[]) second), "putExtra(name, value)");
                        } else if (second instanceof char[]) {
                            Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (char[]) second), "putExtra(name, value)");
                        } else if (second instanceof int[]) {
                            Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (int[]) second), "putExtra(name, value)");
                        } else if (second instanceof long[]) {
                            Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (long[]) second), "putExtra(name, value)");
                        } else if (second instanceof float[]) {
                            Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (float[]) second), "putExtra(name, value)");
                        } else if (second instanceof double[]) {
                            Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (double[]) second), "putExtra(name, value)");
                        } else if (second instanceof Bundle) {
                            Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Bundle) second), "putExtra(name, value)");
                        } else if (second instanceof Intent) {
                            Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Parcelable) second), "putExtra(name, value)");
                        } else {
                            Unit unit = Unit.INSTANCE;
                        }
                    }
                }
                healthyFragment.startActivity(intent);
            }
        }
    }

    private final void startSyncData() {
        FragmentHealthyBinding fragmentHealthyBinding = null;
        if (!BleOperateManager.getInstance().isConnected()) {
            String string = getString(R.string.qc_text_75);
            Intrinsics.checkNotNullExpressionValue(string, "getString(R.string.qc_text_75)");
            GlobalKt.showToast$default(string, 0, 1, null);
            return;
        }
        FragmentHealthyBinding fragmentHealthyBinding2 = this.binding;
        if (fragmentHealthyBinding2 == null) {
            Intrinsics.throwUninitializedPropertyAccessException("binding");
        } else {
            fragmentHealthyBinding = fragmentHealthyBinding2;
        }
        if (fragmentHealthyBinding.syncRefresh.isRefreshing()) {
            return;
        }
        SyncStatus.INSTANCE.getGetInstance().setSync(true);
        fragmentHealthyBinding.syncRefresh.autoRefresh();
    }

    @Subscribe(threadMode = ThreadMode.MAIN)
    public final void onMessageEvent(MessageEvent messageEvent) {
        Intrinsics.checkNotNullParameter(messageEvent, "messageEvent");
        boolean z = messageEvent instanceof RefreshEvent;
        if (z && !Intrinsics.areEqual(getClass(), ((RefreshEvent) messageEvent).getActivityClass())) {
            this.handler.removeCallbacks(this.tenSecondsRefreshRunnable);
        }
        PubuProgressCircle pubuProgressCircle = null;
        ConstraintLayout constraintLayout = null;
        ConstraintLayout constraintLayout2 = null;
        ConstraintLayout constraintLayout3 = null;
        ImageView imageView = null;
        if (z && Intrinsics.areEqual(getClass(), ((RefreshEvent) messageEvent).getActivityClass())) {
            this.handler.removeCallbacks(this.tenSecondsRefreshRunnable);
            this.handler.postDelayed(this.tenSecondsRefreshRunnable, WorkRequest.MIN_BACKOFF_MILLIS);
            if (BleOperateManager.getInstance().isConnected()) {
                ImageView imageView2 = this.bleStatus;
                if (imageView2 == null) {
                    Intrinsics.throwUninitializedPropertyAccessException("bleStatus");
                    imageView2 = null;
                }
                imageView2.setImageResource(R.mipmap.ble_connect);
            } else {
                ImageView imageView3 = this.bleStatus;
                if (imageView3 == null) {
                    Intrinsics.throwUninitializedPropertyAccessException("bleStatus");
                    imageView3 = null;
                }
                imageView3.setImageResource(R.mipmap.ble_disconnect);
                UserConfig.INSTANCE.getInstance().setLastSyncTodaySteps(0L);
                UserConfig.INSTANCE.getInstance().save();
            }
            healthyModule();
            try {
                if (UserConfig.INSTANCE.getInstance().getDeviceName().length() == 0) {
                    ConstraintLayout constraintLayout4 = this.noBinding;
                    if (constraintLayout4 == null) {
                        Intrinsics.throwUninitializedPropertyAccessException("noBinding");
                        constraintLayout4 = null;
                    }
                    ViewKt.visible(constraintLayout4);
                    if (UserConfig.INSTANCE.getInstance().getDeviceAddressNoClear().length() > 0) {
                        ConstraintLayout constraintLayout5 = this.headerClick;
                        if (constraintLayout5 == null) {
                            Intrinsics.throwUninitializedPropertyAccessException("headerClick");
                            constraintLayout5 = null;
                        }
                        ViewKt.visible(constraintLayout5);
                        ConstraintLayout constraintLayout6 = this.noDataLayout;
                        if (constraintLayout6 == null) {
                            Intrinsics.throwUninitializedPropertyAccessException("noDataLayout");
                            constraintLayout6 = null;
                        }
                        ViewKt.gone(constraintLayout6);
                    } else {
                        ConstraintLayout constraintLayout7 = this.headerClick;
                        if (constraintLayout7 == null) {
                            Intrinsics.throwUninitializedPropertyAccessException("headerClick");
                            constraintLayout7 = null;
                        }
                        ViewKt.gone(constraintLayout7);
                        ConstraintLayout constraintLayout8 = this.noDataLayout;
                        if (constraintLayout8 == null) {
                            Intrinsics.throwUninitializedPropertyAccessException("noDataLayout");
                            constraintLayout8 = null;
                        }
                        ViewKt.visible(constraintLayout8);
                    }
                } else {
                    ConstraintLayout constraintLayout9 = this.noBinding;
                    if (constraintLayout9 == null) {
                        Intrinsics.throwUninitializedPropertyAccessException("noBinding");
                        constraintLayout9 = null;
                    }
                    ViewKt.gone(constraintLayout9);
                }
            } catch (Exception e) {
                e.printStackTrace();
            }
        }
        if (messageEvent instanceof DeviceUnitEvent ? true : messageEvent instanceof HealthItemRefreshEvent) {
            getViewModel().queryNotificationHealthData();
            healthyModule();
            return;
        }
        if (messageEvent instanceof BatteryLowEvent) {
            try {
                String battery = UserConfig.INSTANCE.getInstance().getBattery();
                if (battery != null) {
                    int parseInt = Integer.parseInt(battery);
                    if ((1 <= parseInt && parseInt < 20) && !UserConfig.INSTANCE.getInstance().getBatteryLow() && UserConfig.INSTANCE.getInstance().getBatteryWarmingOpen()) {
                        showRingBatteryLowDialog();
                        return;
                    }
                    return;
                }
                return;
            } catch (Exception e2) {
                e2.printStackTrace();
                return;
            }
        }
        if (messageEvent instanceof FinishFirstSettingEvent) {
            try {
                PubuProgressCircle pubuProgressCircle2 = this.barChart;
                if (pubuProgressCircle2 == null) {
                    Intrinsics.throwUninitializedPropertyAccessException("barChart");
                } else {
                    pubuProgressCircle = pubuProgressCircle2;
                }
                pubuProgressCircle.setRefresh(true);
            } catch (Exception e3) {
                e3.printStackTrace();
            }
            getViewModel().queryNotificationHealthData();
            healthyModule();
            return;
        }
        if (messageEvent instanceof BluetoothSyncEvent) {
            startSyncData();
            return;
        }
        if (messageEvent instanceof BluetoothEvent) {
            if (!((BluetoothEvent) messageEvent).getConnect()) {
                FileHandle.getInstance().clearCallback();
                FragmentHealthyBinding fragmentHealthyBinding = this.binding;
                if (fragmentHealthyBinding == null) {
                    Intrinsics.throwUninitializedPropertyAccessException("binding");
                    fragmentHealthyBinding = null;
                }
                fragmentHealthyBinding.syncRefresh.finishRefresh();
                stopRotationAnimation();
                ImageView imageView4 = this.bleStatus;
                if (imageView4 != null) {
                    if (imageView4 == null) {
                        Intrinsics.throwUninitializedPropertyAccessException("bleStatus");
                        imageView4 = null;
                    }
                    imageView4.setImageResource(R.mipmap.ble_disconnect);
                    UserConfig.INSTANCE.getInstance().setLastSyncTodaySteps(0L);
                    UserConfig.INSTANCE.getInstance().save();
                }
                try {
                    MultipleItemQuickAdapter multipleItemQuickAdapter = this.healthyAdapter;
                    if (multipleItemQuickAdapter == null) {
                        Intrinsics.throwUninitializedPropertyAccessException("healthyAdapter");
                        multipleItemQuickAdapter = null;
                    }
                    multipleItemQuickAdapter.removeMeasure();
                    if (UserConfig.INSTANCE.getInstance().getDeviceAddress().length() == 0) {
                        ConstraintLayout constraintLayout10 = this.noBinding;
                        if (constraintLayout10 == null) {
                            Intrinsics.throwUninitializedPropertyAccessException("noBinding");
                            constraintLayout10 = null;
                        }
                        ViewKt.visible(constraintLayout10);
                        if (UserConfig.INSTANCE.getInstance().getDeviceAddressNoClear().length() <= 0) {
                            r11 = false;
                        }
                        if (r11) {
                            ConstraintLayout constraintLayout11 = this.headerClick;
                            if (constraintLayout11 == null) {
                                Intrinsics.throwUninitializedPropertyAccessException("headerClick");
                                constraintLayout11 = null;
                            }
                            ViewKt.visible(constraintLayout11);
                            ConstraintLayout constraintLayout12 = this.noDataLayout;
                            if (constraintLayout12 == null) {
                                Intrinsics.throwUninitializedPropertyAccessException("noDataLayout");
                            } else {
                                constraintLayout = constraintLayout12;
                            }
                            ViewKt.gone(constraintLayout);
                            return;
                        }
                        ConstraintLayout constraintLayout13 = this.headerClick;
                        if (constraintLayout13 == null) {
                            Intrinsics.throwUninitializedPropertyAccessException("headerClick");
                            constraintLayout13 = null;
                        }
                        ViewKt.gone(constraintLayout13);
                        ConstraintLayout constraintLayout14 = this.noDataLayout;
                        if (constraintLayout14 == null) {
                            Intrinsics.throwUninitializedPropertyAccessException("noDataLayout");
                        } else {
                            constraintLayout2 = constraintLayout14;
                        }
                        ViewKt.visible(constraintLayout2);
                        return;
                    }
                    ConstraintLayout constraintLayout15 = this.noBinding;
                    if (constraintLayout15 == null) {
                        Intrinsics.throwUninitializedPropertyAccessException("noBinding");
                    } else {
                        constraintLayout3 = constraintLayout15;
                    }
                    ViewKt.gone(constraintLayout3);
                    return;
                } catch (Exception e4) {
                    e4.printStackTrace();
                    return;
                }
            }
            try {
                ConstraintLayout constraintLayout16 = this.noBinding;
                if (constraintLayout16 == null) {
                    Intrinsics.throwUninitializedPropertyAccessException("noBinding");
                    constraintLayout16 = null;
                }
                ViewKt.gone(constraintLayout16);
            } catch (Exception e5) {
                e5.printStackTrace();
            }
            ImageView imageView5 = this.bleStatus;
            if (imageView5 != null) {
                if (imageView5 == null) {
                    Intrinsics.throwUninitializedPropertyAccessException("bleStatus");
                } else {
                    imageView = imageView5;
                }
                imageView.setImageResource(R.mipmap.ble_connect);
                return;
            }
            return;
        }
        if (messageEvent instanceof ManualRefreshEvent ? true : messageEvent instanceof TodayDataSyncEvent) {
            AwLog.i(Author.HeZhiYuan, "---ManualRefreshEvent");
            healthyModule();
            return;
        }
        if (messageEvent instanceof WatchFaceDownloadEvent) {
            if (UserConfig.INSTANCE.getInstance().getLoginStatus()) {
                return;
            }
            if (UserConfig.INSTANCE.getInstance().getUserToken().length() == 0) {
                getViewModel().getTokenNotLogin();
                return;
            }
            return;
        }
        try {
            if (messageEvent instanceof DeviceSyncTodayStepsEvent) {
                if (getActivity() instanceof MainActivity) {
                    getViewModel().syncTodayStepNotification();
                    return;
                } else if (UserConfig.INSTANCE.getInstance().getLastSyncTodaySteps() < new DateUtil().getUnixTimestamp()) {
                    AwLog.i(Author.HeZhiYuan, "三分钟限制");
                    return;
                } else {
                    getViewModel().syncTodayStepNotification();
                    return;
                }
            }
            if (messageEvent instanceof DeviceSyncTodayStepsAndDetailEvent) {
                getViewModel().queryStepAndDetail();
            }
        } catch (Exception unused) {
        }
    }

    /* compiled from: HealthyFragment.kt */
    @Metadata(d1 = {"\u0000\u0012\n\u0002\u0018\u0002\n\u0002\u0018\u0002\n\u0002\b\u0002\n\u0002\u0010\u0002\n\u0000\b\u0086\u0004\u0018\u00002\u00020\u0001B\u0005¢\u0006\u0002\u0010\u0002J\b\u0010\u0003\u001a\u00020\u0004H\u0016¨\u0006\u0005"}, d2 = {"Lcom/qcwireless/qcwatch/ui/home/healthy/HealthyFragment$TenSecondsRefreshRunnable;", "Ljava/lang/Runnable;", "(Lcom/qcwireless/qcwatch/ui/home/healthy/HealthyFragment;)V", "run", "", "app_championRelease"}, k = 1, mv = {1, 6, 0}, xi = 48)
    /* loaded from: classes2.dex */
    public final class TenSecondsRefreshRunnable implements Runnable {
        public TenSecondsRefreshRunnable() {
        }

        @Override // java.lang.Runnable
        public void run() {
            if (HealthyFragment.this.isVisible() && BleOperateManager.getInstance().isConnected()) {
                AwLog.i(Author.HeZhiYuan, "---10秒同步--");
                HealthyFragment.this.handler.postDelayed(HealthyFragment.this.tenSecondsRefreshRunnable, WorkRequest.MIN_BACKOFF_MILLIS);
                HealthyFragment.this.tenSecondsRefresh();
            }
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    public final void tenSecondsRefresh() {
        try {
            getViewModel().syncTodayStepNotification();
        } catch (Exception unused) {
        }
    }

    private final void healthyModule() {
        BuildersKt__Builders_commonKt.launch$default(GlobalScope.INSTANCE, null, null, new HealthyFragment$healthyModule$1(this, null), 3, null);
    }

    /* compiled from: HealthyFragment.kt */
    @Metadata(d1 = {"\u0000\u0012\n\u0002\u0018\u0002\n\u0002\u0018\u0002\n\u0002\b\u0002\n\u0002\u0010\u0002\n\u0000\b\u0086\u0004\u0018\u00002\u00020\u0001B\u0005¢\u0006\u0002\u0010\u0002J\b\u0010\u0003\u001a\u00020\u0004H\u0016¨\u0006\u0005"}, d2 = {"Lcom/qcwireless/qcwatch/ui/home/healthy/HealthyFragment$MyRunnable;", "Ljava/lang/Runnable;", "(Lcom/qcwireless/qcwatch/ui/home/healthy/HealthyFragment;)V", "run", "", "app_championRelease"}, k = 1, mv = {1, 6, 0}, xi = 48)
    /* loaded from: classes2.dex */
    public final class MyRunnable implements Runnable {
        public MyRunnable() {
        }

        @Override // java.lang.Runnable
        public void run() {
            SyncStatus.INSTANCE.getGetInstance().setSync(false);
            FragmentHealthyBinding fragmentHealthyBinding = HealthyFragment.this.binding;
            FragmentHealthyBinding fragmentHealthyBinding2 = null;
            if (fragmentHealthyBinding == null) {
                Intrinsics.throwUninitializedPropertyAccessException("binding");
                fragmentHealthyBinding = null;
            }
            if (fragmentHealthyBinding.syncRefresh.isRefreshing()) {
                FragmentHealthyBinding fragmentHealthyBinding3 = HealthyFragment.this.binding;
                if (fragmentHealthyBinding3 == null) {
                    Intrinsics.throwUninitializedPropertyAccessException("binding");
                } else {
                    fragmentHealthyBinding2 = fragmentHealthyBinding3;
                }
                fragmentHealthyBinding2.syncRefresh.finishRefresh();
            }
            HealthyFragment.this.stopRotationAnimation();
            if (UserConfig.INSTANCE.getInstance().getFmVersion().length() > 0) {
                HealthyFragment.this.getDeviceViewModel().checkOta();
            }
            if (UserConfig.INSTANCE.getInstance().getNotificationGoTo()) {
                return;
            }
            Object systemService = HealthyFragment.this.getActivity().getSystemService("notification");
            Objects.requireNonNull(systemService, "null cannot be cast to non-null type android.app.NotificationManager");
            NotificationManager notificationManager = (NotificationManager) systemService;
            if (Build.VERSION.SDK_INT < 24 || notificationManager.areNotificationsEnabled()) {
                return;
            }
            HealthyFragment healthyFragment = HealthyFragment.this;
            healthyFragment.openNotificationSettings(healthyFragment.getActivity());
            UserConfig.INSTANCE.getInstance().setNotificationGoTo(true);
            UserConfig.INSTANCE.getInstance().save();
        }
    }

    /* compiled from: HealthyFragment.kt */
    @Metadata(d1 = {"\u0000\u0012\n\u0002\u0018\u0002\n\u0002\u0010\u0000\n\u0002\b\u0002\n\u0002\u0018\u0002\n\u0000\b\u0086\u0003\u0018\u00002\u00020\u0001B\u0007\b\u0002¢\u0006\u0002\u0010\u0002J\u0006\u0010\u0003\u001a\u00020\u0004¨\u0006\u0005"}, d2 = {"Lcom/qcwireless/qcwatch/ui/home/healthy/HealthyFragment$Companion;", "", "()V", "newInstance", "Lcom/qcwireless/qcwatch/ui/home/healthy/HealthyFragment;", "app_championRelease"}, k = 1, mv = {1, 6, 0}, xi = 48)
    /* loaded from: classes2.dex */
    public static final class Companion {
        public /* synthetic */ Companion(DefaultConstructorMarker defaultConstructorMarker) {
            this();
        }

        private Companion() {
        }

        public final HealthyFragment newInstance() {
            return new HealthyFragment();
        }
    }

    /* compiled from: HealthyFragment.kt */
    @Metadata(d1 = {"\u0000$\n\u0002\u0018\u0002\n\u0002\u0018\u0002\n\u0002\b\u0002\n\u0002\u0010\u0002\n\u0000\n\u0002\u0010!\n\u0002\u0010\u000e\n\u0000\n\u0002\u0010\u000b\n\u0002\b\u0003\b\u0086\u0004\u0018\u00002\u00020\u0001B\u0005¢\u0006\u0002\u0010\u0002J\u001e\u0010\u0003\u001a\u00020\u00042\f\u0010\u0005\u001a\b\u0012\u0004\u0012\u00020\u00070\u00062\u0006\u0010\b\u001a\u00020\tH\u0016J\u001e\u0010\n\u001a\u00020\u00042\f\u0010\u0005\u001a\b\u0012\u0004\u0012\u00020\u00070\u00062\u0006\u0010\u000b\u001a\u00020\tH\u0016¨\u0006\f"}, d2 = {"Lcom/qcwireless/qcwatch/ui/home/healthy/HealthyFragment$LocationPermissionCallback;", "Lcom/hjq/permissions/OnPermissionCallback;", "(Lcom/qcwireless/qcwatch/ui/home/healthy/HealthyFragment;)V", "onDenied", "", "permissions", "", "", "never", "", "onGranted", "all", "app_championRelease"}, k = 1, mv = {1, 6, 0}, xi = 48)
    /* loaded from: classes2.dex */
    public final class LocationPermissionCallback implements OnPermissionCallback {
        public LocationPermissionCallback() {
        }

        @Override // com.hjq.permissions.OnPermissionCallback
        public void onGranted(List<String> permissions, boolean all) {
            Intrinsics.checkNotNullParameter(permissions, "permissions");
            if (!all) {
                String string = HealthyFragment.this.getString(R.string.qc_text_269);
                Intrinsics.checkNotNullExpressionValue(string, "getString(R.string.qc_text_269)");
                GlobalKt.showToast$default(string, 0, 1, null);
                return;
            }
            HealthyFragment healthyFragment = HealthyFragment.this;
            FragmentActivity it = healthyFragment.getActivity();
            if (it != null) {
                ArrayList<Pair> arrayList = new ArrayList();
                Intrinsics.checkNotNullExpressionValue(it, "it");
                Intent intent = new Intent(it, (Class<?>) GpsActivity.class);
                for (Pair pair : arrayList) {
                    if (pair != null) {
                        String str = (String) pair.getFirst();
                        Object second = pair.getSecond();
                        if (second instanceof Integer) {
                            Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).intValue()), "putExtra(name, value)");
                        } else if (second instanceof Byte) {
                            Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).byteValue()), "putExtra(name, value)");
                        } else if (second instanceof Character) {
                            Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Character) second).charValue()), "putExtra(name, value)");
                        } else if (second instanceof Short) {
                            Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).shortValue()), "putExtra(name, value)");
                        } else if (second instanceof Boolean) {
                            Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Boolean) second).booleanValue()), "putExtra(name, value)");
                        } else if (second instanceof Long) {
                            Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).longValue()), "putExtra(name, value)");
                        } else if (second instanceof Float) {
                            Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).floatValue()), "putExtra(name, value)");
                        } else if (second instanceof Double) {
                            Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).doubleValue()), "putExtra(name, value)");
                        } else if (second instanceof String) {
                            Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (String) second), "putExtra(name, value)");
                        } else if (second instanceof CharSequence) {
                            Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (CharSequence) second), "putExtra(name, value)");
                        } else if (second instanceof Parcelable) {
                            Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Parcelable) second), "putExtra(name, value)");
                        } else if (second instanceof Object[]) {
                            Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Serializable) second), "putExtra(name, value)");
                        } else if (second instanceof ArrayList) {
                            Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Serializable) second), "putExtra(name, value)");
                        } else if (second instanceof Serializable) {
                            Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Serializable) second), "putExtra(name, value)");
                        } else if (second instanceof boolean[]) {
                            Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (boolean[]) second), "putExtra(name, value)");
                        } else if (second instanceof byte[]) {
                            Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (byte[]) second), "putExtra(name, value)");
                        } else if (second instanceof short[]) {
                            Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (short[]) second), "putExtra(name, value)");
                        } else if (second instanceof char[]) {
                            Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (char[]) second), "putExtra(name, value)");
                        } else if (second instanceof int[]) {
                            Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (int[]) second), "putExtra(name, value)");
                        } else if (second instanceof long[]) {
                            Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (long[]) second), "putExtra(name, value)");
                        } else if (second instanceof float[]) {
                            Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (float[]) second), "putExtra(name, value)");
                        } else if (second instanceof double[]) {
                            Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (double[]) second), "putExtra(name, value)");
                        } else if (second instanceof Bundle) {
                            Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Bundle) second), "putExtra(name, value)");
                        } else if (second instanceof Intent) {
                            Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Parcelable) second), "putExtra(name, value)");
                        } else {
                            Unit unit = Unit.INSTANCE;
                        }
                    }
                }
                healthyFragment.startActivity(intent);
            }
        }

        @Override // com.hjq.permissions.OnPermissionCallback
        public void onDenied(List<String> permissions, boolean never) {
            Intrinsics.checkNotNullParameter(permissions, "permissions");
            OnPermissionCallback.CC.$default$onDenied(this, permissions, never);
            if (never) {
                XXPermissions.startPermissionActivity(HealthyFragment.this.getActivity(), permissions);
            }
        }
    }

    /* compiled from: HealthyFragment.kt */
    @Metadata(d1 = {"\u0000$\n\u0002\u0018\u0002\n\u0002\u0018\u0002\n\u0002\b\u0002\n\u0002\u0010\u0002\n\u0000\n\u0002\u0010!\n\u0002\u0010\u000e\n\u0000\n\u0002\u0010\u000b\n\u0002\b\u0003\b\u0086\u0004\u0018\u00002\u00020\u0001B\u0005¢\u0006\u0002\u0010\u0002J\u001e\u0010\u0003\u001a\u00020\u00042\f\u0010\u0005\u001a\b\u0012\u0004\u0012\u00020\u00070\u00062\u0006\u0010\b\u001a\u00020\tH\u0016J\u001e\u0010\n\u001a\u00020\u00042\f\u0010\u0005\u001a\b\u0012\u0004\u0012\u00020\u00070\u00062\u0006\u0010\u000b\u001a\u00020\tH\u0016¨\u0006\f"}, d2 = {"Lcom/qcwireless/qcwatch/ui/home/healthy/HealthyFragment$ScanLocationPermissionCallback;", "Lcom/hjq/permissions/OnPermissionCallback;", "(Lcom/qcwireless/qcwatch/ui/home/healthy/HealthyFragment;)V", "onDenied", "", "permissions", "", "", "never", "", "onGranted", "all", "app_championRelease"}, k = 1, mv = {1, 6, 0}, xi = 48)
    /* loaded from: classes2.dex */
    public final class ScanLocationPermissionCallback implements OnPermissionCallback {
        public ScanLocationPermissionCallback() {
        }

        @Override // com.hjq.permissions.OnPermissionCallback
        public void onGranted(List<String> permissions, boolean all) {
            Intrinsics.checkNotNullParameter(permissions, "permissions");
            QCApplication.INSTANCE.getGetInstance().getLocationOnce(QCApplication.INSTANCE.getApplication());
            HealthyFragment healthyFragment = HealthyFragment.this;
            FragmentActivity it = healthyFragment.getActivity();
            if (it != null) {
                ArrayList<Pair> arrayList = new ArrayList();
                Intrinsics.checkNotNullExpressionValue(it, "it");
                Intent intent = new Intent(it, (Class<?>) DeviceBindActivity.class);
                for (Pair pair : arrayList) {
                    if (pair != null) {
                        String str = (String) pair.getFirst();
                        Object second = pair.getSecond();
                        if (second instanceof Integer) {
                            Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).intValue()), "putExtra(name, value)");
                        } else if (second instanceof Byte) {
                            Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).byteValue()), "putExtra(name, value)");
                        } else if (second instanceof Character) {
                            Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Character) second).charValue()), "putExtra(name, value)");
                        } else if (second instanceof Short) {
                            Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).shortValue()), "putExtra(name, value)");
                        } else if (second instanceof Boolean) {
                            Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Boolean) second).booleanValue()), "putExtra(name, value)");
                        } else if (second instanceof Long) {
                            Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).longValue()), "putExtra(name, value)");
                        } else if (second instanceof Float) {
                            Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).floatValue()), "putExtra(name, value)");
                        } else if (second instanceof Double) {
                            Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).doubleValue()), "putExtra(name, value)");
                        } else if (second instanceof String) {
                            Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (String) second), "putExtra(name, value)");
                        } else if (second instanceof CharSequence) {
                            Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (CharSequence) second), "putExtra(name, value)");
                        } else if (second instanceof Parcelable) {
                            Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Parcelable) second), "putExtra(name, value)");
                        } else if (second instanceof Object[]) {
                            Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Serializable) second), "putExtra(name, value)");
                        } else if (second instanceof ArrayList) {
                            Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Serializable) second), "putExtra(name, value)");
                        } else if (second instanceof Serializable) {
                            Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Serializable) second), "putExtra(name, value)");
                        } else if (second instanceof boolean[]) {
                            Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (boolean[]) second), "putExtra(name, value)");
                        } else if (second instanceof byte[]) {
                            Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (byte[]) second), "putExtra(name, value)");
                        } else if (second instanceof short[]) {
                            Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (short[]) second), "putExtra(name, value)");
                        } else if (second instanceof char[]) {
                            Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (char[]) second), "putExtra(name, value)");
                        } else if (second instanceof int[]) {
                            Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (int[]) second), "putExtra(name, value)");
                        } else if (second instanceof long[]) {
                            Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (long[]) second), "putExtra(name, value)");
                        } else if (second instanceof float[]) {
                            Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (float[]) second), "putExtra(name, value)");
                        } else if (second instanceof double[]) {
                            Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (double[]) second), "putExtra(name, value)");
                        } else if (second instanceof Bundle) {
                            Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Bundle) second), "putExtra(name, value)");
                        } else if (second instanceof Intent) {
                            Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Parcelable) second), "putExtra(name, value)");
                        } else {
                            Unit unit = Unit.INSTANCE;
                        }
                    }
                }
                healthyFragment.startActivity(intent);
            }
            AwLog.i(Author.HeZhiYuan, permissions);
        }

        @Override // com.hjq.permissions.OnPermissionCallback
        public void onDenied(List<String> permissions, boolean never) {
            Intrinsics.checkNotNullParameter(permissions, "permissions");
            OnPermissionCallback.CC.$default$onDenied(this, permissions, never);
            AwLog.i(Author.HeZhiYuan, permissions);
            AwLog.i(Author.HeZhiYuan, Boolean.valueOf(never));
            if (never) {
                try {
                    HealthyFragment.this.showPermissionWarmingDialog(permissions);
                } catch (Exception e) {
                    e.printStackTrace();
                }
            }
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    public final void showPermissionWarmingDialog(final List<String> permissions) {
        BottomDialog.Builder builder = new BottomDialog.Builder(getActivity());
        builder.setContentView(R.layout.layout_dialog_permission_warming);
        final BottomDialog create = builder.create();
        Intrinsics.checkNotNull(create);
        create.show();
        View contentView = create.getContentView();
        Intrinsics.checkNotNullExpressionValue(contentView, "bottomWarmingDialog!!.contentView");
        TextView textView = (TextView) contentView.findViewById(R.id.tv_dialog_cancel);
        TextView textView2 = (TextView) contentView.findViewById(R.id.tv_dialog_confirm);
        textView.setOnClickListener(new View.OnClickListener() { // from class: com.qcwireless.qcwatch.ui.home.healthy.HealthyFragment$$ExternalSyntheticLambda11
            @Override // android.view.View.OnClickListener
            public final void onClick(View view) {
                HealthyFragment.m730showPermissionWarmingDialog$lambda31(BottomDialog.this, this, permissions, view);
            }
        });
        textView2.setOnClickListener(new View.OnClickListener() { // from class: com.qcwireless.qcwatch.ui.home.healthy.HealthyFragment$$ExternalSyntheticLambda0
            @Override // android.view.View.OnClickListener
            public final void onClick(View view) {
                HealthyFragment.m731showPermissionWarmingDialog$lambda32(BottomDialog.this, this, permissions, view);
            }
        });
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* renamed from: showPermissionWarmingDialog$lambda-31, reason: not valid java name */
    public static final void m730showPermissionWarmingDialog$lambda31(BottomDialog bottomDialog, HealthyFragment this$0, List permissions, View view) {
        Intrinsics.checkNotNullParameter(this$0, "this$0");
        Intrinsics.checkNotNullParameter(permissions, "$permissions");
        Intrinsics.checkNotNull(bottomDialog);
        bottomDialog.dismiss();
        XXPermissions.startPermissionActivity(this$0.getActivity(), (List<String>) permissions);
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* renamed from: showPermissionWarmingDialog$lambda-32, reason: not valid java name */
    public static final void m731showPermissionWarmingDialog$lambda32(BottomDialog bottomDialog, HealthyFragment this$0, List permissions, View view) {
        Intrinsics.checkNotNullParameter(this$0, "this$0");
        Intrinsics.checkNotNullParameter(permissions, "$permissions");
        Intrinsics.checkNotNull(bottomDialog);
        bottomDialog.dismiss();
        XXPermissions.startPermissionActivity(this$0.getActivity(), (List<String>) permissions);
    }

    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r1v1, types: [T, com.qcwireless.qcwatch.base.dialog.BottomDialog] */
    private final void showLocationWarningDialog() {
        final Ref.ObjectRef objectRef = new Ref.ObjectRef();
        BottomDialog.Builder builder = new BottomDialog.Builder(getActivity());
        builder.setContentView(R.layout.layout_dialog_location_warning);
        objectRef.element = builder.create();
        ((BottomDialog) objectRef.element).show();
        View contentView = ((BottomDialog) objectRef.element).getContentView();
        Intrinsics.checkNotNullExpressionValue(contentView, "bottomDialog.contentView");
        TextView textView = (TextView) contentView.findViewById(R.id.tv_dialog_cancel);
        TextView textView2 = (TextView) contentView.findViewById(R.id.tv_dialog_confirm);
        textView.setOnClickListener(new View.OnClickListener() { // from class: com.qcwireless.qcwatch.ui.home.healthy.HealthyFragment$$ExternalSyntheticLambda10
            @Override // android.view.View.OnClickListener
            public final void onClick(View view) {
                HealthyFragment.m727showLocationWarningDialog$lambda33(Ref.ObjectRef.this, view);
            }
        });
        textView2.setOnClickListener(new View.OnClickListener() { // from class: com.qcwireless.qcwatch.ui.home.healthy.HealthyFragment$$ExternalSyntheticLambda9
            @Override // android.view.View.OnClickListener
            public final void onClick(View view) {
                HealthyFragment.m728showLocationWarningDialog$lambda34(HealthyFragment.this, objectRef, view);
            }
        });
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* JADX WARN: Multi-variable type inference failed */
    /* renamed from: showLocationWarningDialog$lambda-33, reason: not valid java name */
    public static final void m727showLocationWarningDialog$lambda33(Ref.ObjectRef bottomDialog, View view) {
        Intrinsics.checkNotNullParameter(bottomDialog, "$bottomDialog");
        ((BottomDialog) bottomDialog.element).dismiss();
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* JADX WARN: Multi-variable type inference failed */
    /* renamed from: showLocationWarningDialog$lambda-34, reason: not valid java name */
    public static final void m728showLocationWarningDialog$lambda34(HealthyFragment this$0, Ref.ObjectRef bottomDialog, View view) {
        Intrinsics.checkNotNullParameter(this$0, "this$0");
        Intrinsics.checkNotNullParameter(bottomDialog, "$bottomDialog");
        if (StringsKt.equals(Build.BRAND, "oppo", true)) {
            if (!AndroidVersion.isAndroid12()) {
                PermissionUtilKt.requestLocationPermission((FragmentActivity) this$0.getActivity(), new LocationPermissionCallback());
            }
        } else {
            PermissionUtilKt.requestLocationPermission((FragmentActivity) this$0.getActivity(), new LocationPermissionCallback());
        }
        ((BottomDialog) bottomDialog.element).dismiss();
    }

    private final boolean checkPermission() {
        if (Build.VERSION.SDK_INT < 23) {
            return false;
        }
        Object systemService = getActivity().getSystemService("power");
        Objects.requireNonNull(systemService, "null cannot be cast to non-null type android.os.PowerManager");
        return ((PowerManager) systemService).isIgnoringBatteryOptimizations(getActivity().getPackageName());
    }

    private final void showNotificationDialog() {
        CenterDialog.Builder builder = new CenterDialog.Builder(getActivity());
        builder.setContentView(R.layout.layout_dialog_notification);
        final CenterDialog create = builder.create();
        create.show();
        View contentView = create.getContentView();
        Intrinsics.checkNotNullExpressionValue(contentView, "bottomDialog.contentView");
        ((TextView) contentView.findViewById(R.id.tv_confirm)).setOnClickListener(new View.OnClickListener() { // from class: com.qcwireless.qcwatch.ui.home.healthy.HealthyFragment$$ExternalSyntheticLambda22
            @Override // android.view.View.OnClickListener
            public final void onClick(View view) {
                HealthyFragment.m729showNotificationDialog$lambda35(CenterDialog.this, this, view);
            }
        });
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* renamed from: showNotificationDialog$lambda-35, reason: not valid java name */
    public static final void m729showNotificationDialog$lambda35(CenterDialog centerDialog, HealthyFragment this$0, View view) {
        Intrinsics.checkNotNullParameter(this$0, "this$0");
        centerDialog.dismiss();
        try {
            this$0.startActivityForResult(new Intent("android.settings.ACTION_NOTIFICATION_LISTENER_SETTINGS"), 100);
        } catch (ActivityNotFoundException e) {
            e.printStackTrace();
        }
    }

    private final boolean isNotificationListenerEnabled() {
        String packageName = QCApplication.INSTANCE.getCONTEXT().getPackageName();
        String flat = Settings.Secure.getString(QCApplication.INSTANCE.getCONTEXT().getContentResolver(), "enabled_notification_listeners");
        String str = flat;
        if (!TextUtils.isEmpty(str)) {
            Intrinsics.checkNotNullExpressionValue(flat, "flat");
            Object[] array = new Regex(":").split(str, 0).toArray(new String[0]);
            Objects.requireNonNull(array, "null cannot be cast to non-null type kotlin.Array<T of kotlin.collections.ArraysKt__ArraysJVMKt.toTypedArray>");
            for (String str2 : (String[]) array) {
                ComponentName unflattenFromString = ComponentName.unflattenFromString(str2);
                if (unflattenFromString != null && TextUtils.equals(packageName, unflattenFromString.getPackageName())) {
                    return true;
                }
            }
        }
        return false;
    }

    @Override // androidx.fragment.app.Fragment
    public void onActivityResult(int requestCode, int resultCode, Intent data) {
        HealthyFragment healthyFragment;
        FragmentActivity it;
        super.onActivityResult(requestCode, resultCode, data);
        if (requestCode == 100 && isNotificationListenerEnabled() && (it = (healthyFragment = this).getActivity()) != null) {
            ArrayList<Pair> arrayList = new ArrayList();
            Intrinsics.checkNotNullExpressionValue(it, "it");
            Intent intent = new Intent(it, (Class<?>) MessagePushActivity.class);
            for (Pair pair : arrayList) {
                if (pair != null) {
                    String str = (String) pair.getFirst();
                    Object second = pair.getSecond();
                    if (second instanceof Integer) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).intValue()), "putExtra(name, value)");
                    } else if (second instanceof Byte) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).byteValue()), "putExtra(name, value)");
                    } else if (second instanceof Character) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Character) second).charValue()), "putExtra(name, value)");
                    } else if (second instanceof Short) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).shortValue()), "putExtra(name, value)");
                    } else if (second instanceof Boolean) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Boolean) second).booleanValue()), "putExtra(name, value)");
                    } else if (second instanceof Long) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).longValue()), "putExtra(name, value)");
                    } else if (second instanceof Float) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).floatValue()), "putExtra(name, value)");
                    } else if (second instanceof Double) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, ((Number) second).doubleValue()), "putExtra(name, value)");
                    } else if (second instanceof String) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (String) second), "putExtra(name, value)");
                    } else if (second instanceof CharSequence) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (CharSequence) second), "putExtra(name, value)");
                    } else if (second instanceof Parcelable) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Parcelable) second), "putExtra(name, value)");
                    } else if (second instanceof Object[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Serializable) second), "putExtra(name, value)");
                    } else if (second instanceof ArrayList) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Serializable) second), "putExtra(name, value)");
                    } else if (second instanceof Serializable) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Serializable) second), "putExtra(name, value)");
                    } else if (second instanceof boolean[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (boolean[]) second), "putExtra(name, value)");
                    } else if (second instanceof byte[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (byte[]) second), "putExtra(name, value)");
                    } else if (second instanceof short[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (short[]) second), "putExtra(name, value)");
                    } else if (second instanceof char[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (char[]) second), "putExtra(name, value)");
                    } else if (second instanceof int[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (int[]) second), "putExtra(name, value)");
                    } else if (second instanceof long[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (long[]) second), "putExtra(name, value)");
                    } else if (second instanceof float[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (float[]) second), "putExtra(name, value)");
                    } else if (second instanceof double[]) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (double[]) second), "putExtra(name, value)");
                    } else if (second instanceof Bundle) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Bundle) second), "putExtra(name, value)");
                    } else if (second instanceof Intent) {
                        Intrinsics.checkNotNullExpressionValue(intent.putExtra(str, (Parcelable) second), "putExtra(name, value)");
                    } else {
                        Unit unit = Unit.INSTANCE;
                    }
                }
            }
            healthyFragment.startActivity(intent);
        }
    }

    @Override // com.qcwireless.qcwatch.ui.base.BaseFragment, androidx.fragment.app.Fragment
    public void onDestroy() {
        super.onDestroy();
        BleOperateManager.getInstance().removeOutDeviceListener(100);
        EventBus.getDefault().unregister(this);
    }

    /* JADX INFO: Access modifiers changed from: private */
    public final void deviceNotification(int step, int distance, int calorie) {
        TextView textView = this.todayStep;
        TextView textView2 = null;
        if (textView == null) {
            Intrinsics.throwUninitializedPropertyAccessException("todayStep");
            textView = null;
        }
        textView.setText(String.valueOf(step));
        try {
            if (UserConfig.INSTANCE.getInstance().getMetric()) {
                String valueOf = String.valueOf(new BigDecimal(String.valueOf((distance * 1.0f) / 1000)).setScale(2, RoundingMode.HALF_UP));
                TextView textView3 = this.todayDistance;
                if (textView3 == null) {
                    Intrinsics.throwUninitializedPropertyAccessException("todayDistance");
                    textView3 = null;
                }
                textView3.setText(valueOf);
                TextView textView4 = this.todayDistanceUnit;
                if (textView4 == null) {
                    Intrinsics.throwUninitializedPropertyAccessException("todayDistanceUnit");
                    textView4 = null;
                }
                textView4.setText(getString(R.string.qc_text_88));
            } else {
                String valueOf2 = String.valueOf(new BigDecimal(String.valueOf(MetricUtilsKt.kmToIn((distance * 1.0f) / 1000))).setScale(2, RoundingMode.HALF_UP));
                TextView textView5 = this.todayDistance;
                if (textView5 == null) {
                    Intrinsics.throwUninitializedPropertyAccessException("todayDistance");
                    textView5 = null;
                }
                textView5.setText(valueOf2);
                TextView textView6 = this.todayDistanceUnit;
                if (textView6 == null) {
                    Intrinsics.throwUninitializedPropertyAccessException("todayDistanceUnit");
                    textView6 = null;
                }
                textView6.setText(getString(R.string.qc_text_358));
            }
        } catch (Exception unused) {
        }
        TextView textView7 = this.todayCalorie;
        if (textView7 == null) {
            Intrinsics.throwUninitializedPropertyAccessException("todayCalorie");
        } else {
            textView2 = textView7;
        }
        textView2.setText(String.valueOf(calorie / 1000));
        PreUtil.putInt(PreUtil.Action_Today_Steps, step);
        new NotificationUtils(QJavaApplication.getInstance().getApplication()).initBandNotification();
    }

    /* compiled from: HealthyFragment.kt */
    @Metadata(d1 = {"\u0000\u0018\n\u0002\u0018\u0002\n\u0002\u0018\u0002\n\u0002\b\u0002\n\u0002\u0010\u0002\n\u0000\n\u0002\u0018\u0002\n\u0000\b\u0086\u0004\u0018\u00002\u00020\u0001B\u0005¢\u0006\u0002\u0010\u0002J\u0012\u0010\u0003\u001a\u00020\u00042\b\u0010\u0005\u001a\u0004\u0018\u00010\u0006H\u0016¨\u0006\u0007"}, d2 = {"Lcom/qcwireless/qcwatch/ui/home/healthy/HealthyFragment$MyDeviceNotifyListener;", "Lcom/oudmon/ble/base/communication/responseImpl/DeviceNotifyListener;", "(Lcom/qcwireless/qcwatch/ui/home/healthy/HealthyFragment;)V", "onDataResponse", "", "resultEntity", "Lcom/oudmon/ble/base/communication/rsp/DeviceNotifyRsp;", "app_championRelease"}, k = 1, mv = {1, 6, 0}, xi = 48)
    /* loaded from: classes2.dex */
    public final class MyDeviceNotifyListener extends DeviceNotifyListener {
        public MyDeviceNotifyListener() {
        }

        @Override // com.oudmon.ble.base.communication.responseImpl.DeviceNotifyListener, com.oudmon.ble.base.communication.ICommandResponse
        public void onDataResponse(DeviceNotifyRsp resultEntity) {
            Intrinsics.checkNotNull(resultEntity);
            if (resultEntity.getStatus() == 0) {
                if (SyncStatus.INSTANCE.getGetInstance().getSync() || SyncStatus.INSTANCE.getGetInstance().getSyncSportPlus() || QCApplication.INSTANCE.getGetInstance().getUpdating() == 1 || QCApplication.INSTANCE.getGetInstance().getUpdating() == 2 || QCApplication.INSTANCE.getGetInstance().getUpdating() == 3) {
                    LogToFile.getInstance().wtf("设备刷新返回，没有同步");
                    AwLog.i(Author.HeZhiYuan, "正在数据同步或者固件升级...");
                    return;
                }
                AwLog.i(Author.HeZhiYuan, "设备触发刷新，数据类型:" + resultEntity.getDataType());
                LogToFile.getInstance().wtf("设备触发刷新，数据类型:" + resultEntity.getDataType());
                BleOperateManager.getInstance().removeOthersListener();
                switch (resultEntity.getDataType()) {
                    case 1:
                        HealthyFragment.this.getViewModel().syncTodayHeartSingleData();
                        return;
                    case 2:
                        HealthyFragment.this.getViewModel().syncBpSingle();
                        return;
                    case 3:
                        HealthyFragment.this.getViewModel().syncTodaySpo2Single(0);
                        return;
                    case 4:
                        HealthyFragment.this.getViewModel().syncTodayStepDetailSingle();
                        return;
                    case 5:
                        HealthyFragment.this.getViewModel().syncTodayTemperatureSingle();
                        return;
                    case 6:
                    case 8:
                    case 10:
                    case 14:
                    case 15:
                    case 17:
                    default:
                        return;
                    case 7:
                        HealthyFragment.this.sportRunning = false;
                        HealthyFragment.this.sportType = 0;
                        HealthyFragment.this.sportStatus = 0;
                        HealthyFragment.this.getViewModel().syncTodaySportPlusDetailSingle();
                        return;
                    case 9:
                    case 11:
                        EventBus.getDefault().post(new DeviceToAppSyncEvent(resultEntity.getDataType()));
                        return;
                    case 12:
                        try {
                            CommandHandle commandHandle = CommandHandle.getInstance();
                            SimpleKeyReq simpleKeyReq = new SimpleKeyReq((byte) 3);
                            final HealthyFragment healthyFragment = HealthyFragment.this;
                            commandHandle.executeReqCmd(simpleKeyReq, new ICommandResponse() { // from class: com.qcwireless.qcwatch.ui.home.healthy.HealthyFragment$MyDeviceNotifyListener$$ExternalSyntheticLambda1
                                @Override // com.oudmon.ble.base.communication.ICommandResponse
                                public final void onDataResponse(BaseRspCmd baseRspCmd) {
                                    HealthyFragment.MyDeviceNotifyListener.m734onDataResponse$lambda0(HealthyFragment.this, (BatteryRsp) baseRspCmd);
                                }
                            });
                            return;
                        } catch (Exception e) {
                            e.printStackTrace();
                            return;
                        }
                    case 13:
                        HealthyFragment.this.getViewModel().syncTodayBloodSugar(0);
                        return;
                    case 16:
                        CommandHandle.getInstance().executeReqCmd(TargetSettingReq.getReadInstance(), new ICommandResponse() { // from class: com.qcwireless.qcwatch.ui.home.healthy.HealthyFragment$MyDeviceNotifyListener$$ExternalSyntheticLambda0
                            @Override // com.oudmon.ble.base.communication.ICommandResponse
                            public final void onDataResponse(BaseRspCmd baseRspCmd) {
                                HealthyFragment.MyDeviceNotifyListener.m735onDataResponse$lambda1(HealthyFragment.MyDeviceNotifyListener.this, (TargetSettingRsp) baseRspCmd);
                            }
                        });
                        return;
                    case 18:
                        AwLog.i(Author.HeZhiYuan, ByteUtil.bytesToString(resultEntity.getLoadData()));
                        HealthyFragment.this.deviceNotification(BLEDataFormatUtils.bytes2Int(new byte[]{resultEntity.getLoadData()[1], resultEntity.getLoadData()[2], resultEntity.getLoadData()[3]}), BLEDataFormatUtils.bytes2Int(new byte[]{resultEntity.getLoadData()[7], resultEntity.getLoadData()[8], resultEntity.getLoadData()[9]}), BLEDataFormatUtils.bytes2Int(new byte[]{resultEntity.getLoadData()[4], resultEntity.getLoadData()[5], resultEntity.getLoadData()[6]}));
                        return;
                }
            }
        }

        /* JADX INFO: Access modifiers changed from: private */
        /* renamed from: onDataResponse$lambda-0, reason: not valid java name */
        public static final void m734onDataResponse$lambda0(HealthyFragment this$0, BatteryRsp batteryRsp) {
            Intrinsics.checkNotNullParameter(this$0, "this$0");
            UserConfig.INSTANCE.getInstance().setBattery(String.valueOf(batteryRsp.getBatteryValue()));
            UserConfig.INSTANCE.getInstance().save();
            if (batteryRsp.getBatteryValue() > 19) {
                UserConfig.INSTANCE.getInstance().setBatteryLow(false);
                NotificationUtils.lowBatteryNotification = false;
                UserConfig.INSTANCE.getInstance().save();
            }
            if (UserConfig.INSTANCE.getInstance().getBatteryWarmingOpen() && !UserConfig.INSTANCE.getInstance().getBatteryLow() && batteryRsp.getBatteryValue() < 20) {
                this$0.showRingBatteryLowDialog();
            }
            EventBus.getDefault().post(new FirmUpdateEvent());
        }

        /* JADX INFO: Access modifiers changed from: private */
        /* renamed from: onDataResponse$lambda-1, reason: not valid java name */
        public static final void m735onDataResponse$lambda1(MyDeviceNotifyListener this$0, final TargetSettingRsp targetSettingRsp) {
            Intrinsics.checkNotNullParameter(this$0, "this$0");
            AwLog.i(Author.HeZhiYuan, targetSettingRsp);
            if (targetSettingRsp.getAction() == 1) {
                ThreadExtKt.ktxRunOnBgSingle(this$0, new Function1<MyDeviceNotifyListener, Unit>() { // from class: com.qcwireless.qcwatch.ui.home.healthy.HealthyFragment$MyDeviceNotifyListener$onDataResponse$2$1
                    /* JADX INFO: Access modifiers changed from: package-private */
                    {
                        super(1);
                    }

                    @Override // kotlin.jvm.functions.Function1
                    public /* bridge */ /* synthetic */ Unit invoke(HealthyFragment.MyDeviceNotifyListener myDeviceNotifyListener) {
                        invoke2(myDeviceNotifyListener);
                        return Unit.INSTANCE;
                    }

                    /* renamed from: invoke, reason: avoid collision after fix types in other method */
                    public final void invoke2(HealthyFragment.MyDeviceNotifyListener ktxRunOnBgSingle) {
                        Intrinsics.checkNotNullParameter(ktxRunOnBgSingle, "$this$ktxRunOnBgSingle");
                        if (TargetSettingRsp.this.getStep() > 0) {
                            UserProfileRepository.INSTANCE.getGetInstance().insertTarget(new TargetEntity(UserConfig.INSTANCE.getInstance().getDeviceAddressNoClear(), TargetSettingRsp.this.getStep(), TargetSettingRsp.this.getCalorie() / 1000.0f, TargetSettingRsp.this.getDistance() / 1000.0f, 3.0f, 8.0f));
                            EventBus.getDefault().post(new DeviceNotifyTypeEvent(16));
                        }
                    }
                });
            }
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    public final void openNotificationSettings(Context context) {
        Intent intent = new Intent();
        intent.setAction("android.settings.APP_NOTIFICATION_SETTINGS");
        intent.putExtra("android.provider.extra.APP_PACKAGE", context.getPackageName());
        context.startActivity(intent);
    }

    /* JADX INFO: Access modifiers changed from: private */
    public final void showRingBatteryLowDialog() {
        CenterDialog.Builder builder = new CenterDialog.Builder(getActivity());
        builder.setContentView(R.layout.layout_dialog_battery_low);
        CenterDialog centerDialog = this.batteryDialog;
        if (centerDialog != null) {
            Intrinsics.checkNotNull(centerDialog);
            if (centerDialog.isShowing()) {
                AwLog.i(Author.HeZhiYuan, "battery dialog dismiss");
                return;
            }
        }
        CenterDialog create = builder.create();
        this.batteryDialog = create;
        Intrinsics.checkNotNull(create);
        create.show();
        CenterDialog centerDialog2 = this.batteryDialog;
        Intrinsics.checkNotNull(centerDialog2);
        View contentView = centerDialog2.getContentView();
        Intrinsics.checkNotNullExpressionValue(contentView, "batteryDialog!!.contentView");
        ((TextView) contentView.findViewById(R.id.tv_confirm)).setOnClickListener(new View.OnClickListener() { // from class: com.qcwireless.qcwatch.ui.home.healthy.HealthyFragment$$ExternalSyntheticLambda1
            @Override // android.view.View.OnClickListener
            public final void onClick(View view) {
                HealthyFragment.m732showRingBatteryLowDialog$lambda37(HealthyFragment.this, view);
            }
        });
        try {
            Object systemService = getActivity().getSystemService("notification");
            if (systemService == null) {
                throw new NullPointerException("null cannot be cast to non-null type android.app.NotificationManager");
            }
            NotificationManager notificationManager = (NotificationManager) systemService;
            if (Build.VERSION.SDK_INT >= 24) {
                if (!notificationManager.areNotificationsEnabled()) {
                    openNotificationSettings(getActivity());
                } else {
                    if (NotificationUtils.lowBatteryNotification) {
                        return;
                    }
                    new NotificationUtils(QJavaApplication.getInstance().getApplication()).initLowBatteryNotification();
                }
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* renamed from: showRingBatteryLowDialog$lambda-37, reason: not valid java name */
    public static final void m732showRingBatteryLowDialog$lambda37(HealthyFragment this$0, View view) {
        Intrinsics.checkNotNullParameter(this$0, "this$0");
        UserConfig.INSTANCE.getInstance().setBatteryLow(true);
        UserConfig.INSTANCE.getInstance().save();
        CenterDialog centerDialog = this$0.batteryDialog;
        Intrinsics.checkNotNull(centerDialog);
        centerDialog.dismiss();
    }

    private final void showChinaOnlyDialog() {
        CenterDialog.Builder builder = new CenterDialog.Builder(getActivity());
        builder.setContentView(R.layout.layout_dialog_battery_china_only);
        CenterDialog centerDialog = this.batteryDialog;
        if (centerDialog != null) {
            Intrinsics.checkNotNull(centerDialog);
            if (centerDialog.isShowing()) {
                AwLog.i(Author.HeZhiYuan, "battery dialog dismiss");
                return;
            }
        }
        CenterDialog create = builder.create();
        this.batteryDialog = create;
        Intrinsics.checkNotNull(create);
        create.show();
        CenterDialog centerDialog2 = this.batteryDialog;
        Intrinsics.checkNotNull(centerDialog2);
        View contentView = centerDialog2.getContentView();
        Intrinsics.checkNotNullExpressionValue(contentView, "batteryDialog!!.contentView");
        ((TextView) contentView.findViewById(R.id.tv_confirm)).setOnClickListener(new View.OnClickListener() { // from class: com.qcwireless.qcwatch.ui.home.healthy.HealthyFragment$$ExternalSyntheticLambda25
            @Override // android.view.View.OnClickListener
            public final void onClick(View view) {
                HealthyFragment.m726showChinaOnlyDialog$lambda38(HealthyFragment.this, view);
            }
        });
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* renamed from: showChinaOnlyDialog$lambda-38, reason: not valid java name */
    public static final void m726showChinaOnlyDialog$lambda38(HealthyFragment this$0, View view) {
        Intrinsics.checkNotNullParameter(this$0, "this$0");
        UserConfig.INSTANCE.getInstance().setChinaOnly(true);
        UserConfig.INSTANCE.getInstance().save();
        PermissionUtilKt.requestLocationPermission((FragmentActivity) this$0.getActivity(), new ScanLocationPermissionCallback());
        CenterDialog centerDialog = this$0.batteryDialog;
        Intrinsics.checkNotNull(centerDialog);
        centerDialog.dismiss();
    }

    private final int getTotalItemsHeight(RecyclerView recyclerView) {
        RecyclerView.LayoutManager layoutManager;
        RecyclerView.Adapter adapter = recyclerView.getAdapter();
        if (adapter == null || (layoutManager = recyclerView.getLayoutManager()) == null) {
            return 0;
        }
        int itemCount = adapter.getItemCount();
        int i = 0;
        for (int i2 = 0; i2 < itemCount; i2++) {
            View findViewByPosition = layoutManager.findViewByPosition(i2);
            if (findViewByPosition != null) {
                i += findViewByPosition.getHeight();
            }
        }
        return i;
    }

    private final Bitmap takeScreenshot(NestedScrollView nestedScrollView) {
        int childCount = nestedScrollView.getChildCount();
        int i = 0;
        for (int i2 = 0; i2 < childCount; i2++) {
            i += nestedScrollView.getChildAt(i2).getHeight();
        }
        Bitmap bitmap = Bitmap.createBitmap(nestedScrollView.getWidth(), i, Bitmap.Config.ARGB_8888);
        Canvas canvas = new Canvas(bitmap);
        Rect rect = new Rect(0, 0, nestedScrollView.getWidth(), i);
        Paint paint = new Paint();
        paint.setColor(SkinCompatResources.getColor(getActivity(), R.color.color_F9F9F9));
        canvas.drawRect(rect, paint);
        nestedScrollView.draw(canvas);
        Intrinsics.checkNotNullExpressionValue(bitmap, "bitmap");
        return bitmap;
    }

    private final String saveScreenshotToStorage(Bitmap screenshot) {
        File file = new File(FileUtils.INSTANCE.getGuideDirFile().getAbsoluteFile(), new DateUtil().getY_M_D_H_M_S() + "screenshot.png");
        try {
            FileOutputStream fileOutputStream = new FileOutputStream(file);
            screenshot.compress(Bitmap.CompressFormat.PNG, 100, fileOutputStream);
            fileOutputStream.flush();
            fileOutputStream.close();
        } catch (IOException e) {
            e.printStackTrace();
        }
        String absolutePath = file.getAbsolutePath();
        Intrinsics.checkNotNullExpressionValue(absolutePath, "imagePath.absolutePath");
        return absolutePath;
    }

    private final void shareImage(String imagePath) {
        Uri uriForFile = FileProvider.getUriForFile(getActivity(), getActivity().getPackageName() + ".imagePicker.provider", new File(imagePath));
        Intent intent = new Intent("android.intent.action.SEND");
        intent.setType(SelectMimeType.SYSTEM_IMAGE);
        intent.putExtra("android.intent.extra.STREAM", uriForFile);
        startActivity(Intent.createChooser(intent, "分享截图到"));
    }
}
