package com.sweetzpot.stravazpot.upload.request;

import com.sweetzpot.stravazpot.upload.api.UploadAPI;
import com.sweetzpot.stravazpot.upload.model.DataType;
import com.sweetzpot.stravazpot.upload.model.UploadActivityType;
import com.sweetzpot.stravazpot.upload.model.UploadStatus;
import com.sweetzpot.stravazpot.upload.rest.UploadRest;
import java.io.File;
import okhttp3.MediaType;
import okhttp3.MultipartBody;
import okhttp3.RequestBody;

/* loaded from: classes2.dex */
public class UploadFileRequest {
    private UploadActivityType activityType;
    private DataType dataType;
    private String description;
    private String externalID;
    private final File file;
    private boolean hasTrainer;
    private boolean isCommute;
    private boolean isPrivate;
    private String name;
    private final UploadRest restService;
    private final UploadAPI uploadAPI;

    public UploadFileRequest(File file, UploadRest uploadRest, UploadAPI uploadAPI) {
        this.file = file;
        this.restService = uploadRest;
        this.uploadAPI = uploadAPI;
    }

    public UploadFileRequest withDataType(DataType dataType) {
        this.dataType = dataType;
        return this;
    }

    public UploadFileRequest withActivityType(UploadActivityType uploadActivityType) {
        this.activityType = uploadActivityType;
        return this;
    }

    public UploadFileRequest withName(String str) {
        this.name = str;
        return this;
    }

    public UploadFileRequest withDescription(String str) {
        this.description = str;
        return this;
    }

    public UploadFileRequest isPrivate(boolean z) {
        this.isPrivate = z;
        return this;
    }

    public UploadFileRequest hasTrainer(boolean z) {
        this.hasTrainer = z;
        return this;
    }

    public UploadFileRequest isCommute(boolean z) {
        this.isCommute = z;
        return this;
    }

    public UploadFileRequest withExternalID(String str) {
        this.externalID = str;
        return this;
    }

    public UploadStatus execute() {
        return (UploadStatus) this.uploadAPI.execute(this.restService.upload(requestBodyFromString(this.activityType.toString()), requestBodyFromString(this.name), requestBodyFromString(this.description), booleanToInt(this.isPrivate), booleanToInt(this.hasTrainer), booleanToInt(this.isCommute), requestBodyFromString(this.dataType.toString()), requestBodyFromString(this.externalID), MultipartBody.Part.createFormData("file", this.file.getName(), RequestBody.create(MediaType.parse("multipart/form-data"), this.file))));
    }

    private RequestBody requestBodyFromString(String str) {
        return RequestBody.create(MultipartBody.FORM, str);
    }

    private Integer booleanToInt(boolean z) {
        return Integer.valueOf(z ? 1 : 0);
    }
}
