package me.pqpo.librarylog4a;

import android.util.Log;

/* loaded from: classes3.dex */
public class LogBuffer {
    private static final String TAG = "LogBuffer";
    private String bufferPath;
    private int bufferSize;
    private boolean compress;
    private String logPath;
    private long ptr;

    private native void changeLogPathNative(long j, String str);

    private native void flushAsyncNative(long j);

    private static native long initNative(String str, int i, String str2, boolean z);

    private native void releaseNative(long j);

    private native void writeNative(long j, String str);

    public LogBuffer(String str, int i, String str2, boolean z) {
        this.ptr = 0L;
        this.bufferPath = str;
        this.bufferSize = i;
        this.logPath = str2;
        this.compress = z;
        try {
            this.ptr = initNative(str, i, str2, z);
        } catch (Exception e) {
            Log.e(TAG, "LogBuffer Initialization Exception", e);
        }
    }

    public void changeLogPath(String str) {
        long j = this.ptr;
        if (j != 0) {
            try {
                changeLogPathNative(j, str);
                this.logPath = str;
            } catch (Exception e) {
                Log.e(TAG, e.getMessage(), e);
            }
        }
    }

    public boolean isCompress() {
        return this.compress;
    }

    public String getLogPath() {
        return this.logPath;
    }

    public String getBufferPath() {
        return this.bufferPath;
    }

    public int getBufferSize() {
        return this.bufferSize;
    }

    public void write(String str) {
        long j = this.ptr;
        if (j != 0) {
            try {
                writeNative(j, str);
            } catch (Exception e) {
                Log.e(TAG, e.getMessage(), e);
            }
        }
    }

    public void flushAsync() {
        long j = this.ptr;
        if (j != 0) {
            try {
                flushAsyncNative(j);
            } catch (Exception e) {
                Log.e(TAG, e.getMessage(), e);
            }
        }
    }

    public void release() {
        long j = this.ptr;
        if (j != 0) {
            try {
                releaseNative(j);
            } catch (Exception e) {
                Log.e(TAG, e.getMessage(), e);
            }
            this.ptr = 0L;
        }
    }

    static {
        System.loadLibrary("log4a-lib");
    }
}
