package skin.support.widget;

import android.content.res.TypedArray;
import android.graphics.drawable.Drawable;
import android.util.AttributeSet;
import android.widget.ImageView;
import androidx.core.widget.ImageViewCompat;
import skin.support.R;
import skin.support.content.res.SkinCompatResources;
import skin.support.content.res.SkinCompatVectorResources;

/* loaded from: classes3.dex */
public class SkinCompatImageHelper extends SkinCompatHelper {
    private static final String TAG = "SkinCompatImageHelper";
    private final ImageView mView;
    private int mSrcResId = 0;
    private int mSrcCompatResId = 0;
    private int mSrcTintResId = 0;

    public SkinCompatImageHelper(ImageView imageView) {
        this.mView = imageView;
    }

    public void loadFromAttributes(AttributeSet attributeSet, int i) {
        TypedArray typedArray = null;
        try {
            typedArray = this.mView.getContext().obtainStyledAttributes(attributeSet, R.styleable.SkinCompatImageView, i, 0);
            this.mSrcResId = typedArray.getResourceId(R.styleable.SkinCompatImageView_android_src, 0);
            this.mSrcCompatResId = typedArray.getResourceId(R.styleable.SkinCompatImageView_srcCompat, 0);
            int resourceId = typedArray.getResourceId(R.styleable.SkinCompatImageView_tint, 0);
            this.mSrcTintResId = resourceId;
            if (resourceId == 0) {
                this.mSrcTintResId = typedArray.getResourceId(R.styleable.SkinCompatImageView_android_tint, 0);
            }
            applySkin();
        } finally {
            if (typedArray != null) {
                typedArray.recycle();
            }
        }
    }

    public void setImageResource(int i) {
        this.mSrcResId = i;
        this.mSrcCompatResId = 0;
        applySkin();
    }

    @Override // skin.support.widget.SkinCompatHelper
    public void applySkin() {
        Drawable drawableCompat;
        int checkResourceId = checkResourceId(this.mSrcCompatResId);
        this.mSrcCompatResId = checkResourceId;
        if (checkResourceId != 0) {
            Drawable drawableCompat2 = SkinCompatVectorResources.getDrawableCompat(this.mView.getContext(), this.mSrcCompatResId);
            if (drawableCompat2 != null) {
                this.mView.setImageDrawable(drawableCompat2);
            }
        } else {
            int checkResourceId2 = checkResourceId(this.mSrcResId);
            this.mSrcResId = checkResourceId2;
            if (checkResourceId2 != 0 && (drawableCompat = SkinCompatVectorResources.getDrawableCompat(this.mView.getContext(), this.mSrcResId)) != null) {
                this.mView.setImageDrawable(drawableCompat);
            }
        }
        int checkResourceId3 = checkResourceId(this.mSrcTintResId);
        this.mSrcTintResId = checkResourceId3;
        if (checkResourceId3 != 0) {
            ImageViewCompat.setImageTintList(this.mView, SkinCompatResources.getColorStateList(this.mView.getContext(), this.mSrcTintResId));
        }
    }
}
